Class: FinchAPI::Client
Constant Summary
collapse
- DEFAULT_MAX_RETRIES =
Default max number of retries to attempt after a failed retryable request.
2
- DEFAULT_TIMEOUT_IN_SECONDS =
Default per-request timeout.
60.0
- DEFAULT_INITIAL_RETRY_DELAY =
Default initial retry delay in seconds. Overall delay is calculated using exponential backoff + jitter.
0.5
- DEFAULT_MAX_RETRY_DELAY =
Default max retry delay in seconds.
8.0
Internal::Transport::BaseClient::MAX_REDIRECTS, Internal::Transport::BaseClient::PLATFORM_HEADERS
Instance Attribute Summary collapse
#base_url, #headers, #idempotency_header, #initial_retry_delay, #max_retries, #max_retry_delay, #requester, #timeout
Instance Method Summary
collapse
follow_redirect, #inspect, reap_connection!, #request, #send_request, should_retry?, validate!
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(client_id: , client_secret: , access_token: nil, webhook_secret: , base_url: , max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client
Creates and returns a new client for interacting with the API.
‘“api.example.com/v2/”`. Defaults to `ENV`
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
|
# File 'lib/finch_api/client.rb', line 108
def initialize(
client_id: ENV["FINCH_CLIENT_ID"],
client_secret: ENV["FINCH_CLIENT_SECRET"],
access_token: nil,
webhook_secret: ENV["FINCH_WEBHOOK_SECRET"],
base_url: ENV["FINCH_BASE_URL"],
max_retries: self.class::DEFAULT_MAX_RETRIES,
timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS,
initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY,
max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY
)
base_url ||= "https://api.tryfinch.com"
= {
"finch-api-version" => "2020-09-17"
}
= ENV["FINCH_CUSTOM_HEADERS"]
unless .nil?
parsed = {}
.split("\n").each do |line|
colon = line.index(":")
unless colon.nil?
parsed[line[0...colon].strip] = line[(colon + 1)..].strip
end
end
= parsed.merge()
end
@client_id = client_id&.to_s
@client_secret = client_secret&.to_s
@access_token = access_token&.to_s
@webhook_secret = webhook_secret&.to_s
super(
base_url: base_url,
timeout: timeout,
max_retries: max_retries,
initial_retry_delay: initial_retry_delay,
max_retry_delay: max_retry_delay,
headers:
)
@access_tokens = FinchAPI::Resources::AccessTokens.new(client: self)
@hris = FinchAPI::Resources::HRIS.new(client: self)
@providers = FinchAPI::Resources::Providers.new(client: self)
@account = FinchAPI::Resources::Account.new(client: self)
@webhooks = FinchAPI::Resources::Webhooks.new(client: self)
@request_forwarding = FinchAPI::Resources::RequestForwarding.new(client: self)
@jobs = FinchAPI::Resources::Jobs.new(client: self)
@sandbox = FinchAPI::Resources::Sandbox.new(client: self)
@payroll = FinchAPI::Resources::Payroll.new(client: self)
@connect = FinchAPI::Resources::Connect.new(client: self)
end
|
Instance Attribute Details
#access_token ⇒ String?
19
20
21
|
# File 'lib/finch_api/client.rb', line 19
def access_token
@access_token
end
|
31
32
33
|
# File 'lib/finch_api/client.rb', line 31
def access_tokens
@access_tokens
end
|
40
41
42
|
# File 'lib/finch_api/client.rb', line 40
def account
@account
end
|
#client_id ⇒ String?
22
23
24
|
# File 'lib/finch_api/client.rb', line 22
def client_id
@client_id
end
|
#client_secret ⇒ String?
25
26
27
|
# File 'lib/finch_api/client.rb', line 25
def client_secret
@client_secret
end
|
58
59
60
|
# File 'lib/finch_api/client.rb', line 58
def connect
@connect
end
|
34
35
36
|
# File 'lib/finch_api/client.rb', line 34
def hris
@hris
end
|
49
50
51
|
# File 'lib/finch_api/client.rb', line 49
def jobs
@jobs
end
|
55
56
57
|
# File 'lib/finch_api/client.rb', line 55
def payroll
@payroll
end
|
37
38
39
|
# File 'lib/finch_api/client.rb', line 37
def providers
@providers
end
|
46
47
48
|
# File 'lib/finch_api/client.rb', line 46
def request_forwarding
@request_forwarding
end
|
52
53
54
|
# File 'lib/finch_api/client.rb', line 52
def sandbox
@sandbox
end
|
#webhook_secret ⇒ String?
28
29
30
|
# File 'lib/finch_api/client.rb', line 28
def webhook_secret
@webhook_secret
end
|
43
44
45
|
# File 'lib/finch_api/client.rb', line 43
def webhooks
@webhooks
end
|