Class: FinchAPI::Models::BaseWebhookEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/base_webhook_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id:, company_id:, connection_id: nil) ⇒ BaseWebhookEvent

Returns a new instance of BaseWebhookEvent.

Parameters:

  • account_id (String)
  • company_id (String)
  • connection_id (String) (defaults to: nil)


5
# File 'lib/finch-api/models/base_webhook_event.rb', line 5

def initialize(account_id:, company_id:, connection_id: nil, **) = super

Instance Attribute Details

#account_idString

DEPRECATED

Unique Finch ID of the employer account used to make this

connection. Use `connection_id` instead to identify the connection associated
with this event.

Returns:

  • (String)


12
# File 'lib/finch-api/models/base_webhook_event.rb', line 12

required :account_id, String

#company_idString

DEPRECATED

Unique Finch ID of the company for which data has been updated. Use

`connection_id` instead to identify the connection associated with this event.

Returns:

  • (String)


19
# File 'lib/finch-api/models/base_webhook_event.rb', line 19

required :company_id, String

#connection_idString?

Unique Finch ID of the connection associated with the webhook event.

Returns:

  • (String, nil)


25
# File 'lib/finch-api/models/base_webhook_event.rb', line 25

optional :connection_id, String