Class: FinchAPI::Models::Connect::SessionNewParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Connect::SessionNewParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/connect/session_new_params.rb
Overview
Defined Under Namespace
Modules: Product, Sandbox Classes: Integration
Instance Attribute Summary collapse
-
#customer_email ⇒ String?
Email address of the customer.
-
#customer_id ⇒ String
Unique identifier for the customer.
-
#customer_name ⇒ String
Name of the customer.
-
#integration ⇒ FinchAPI::Models::Connect::SessionNewParams::Integration?
Integration configuration for the connect session.
-
#manual ⇒ Boolean?
Enable manual authentication mode.
-
#minutes_to_expire ⇒ Float?
The number of minutes until the session expires (defaults to 129,600, which is 90 days).
-
#products ⇒ Array<Symbol, FinchAPI::Models::Connect::SessionNewParams::Product>
The Finch products to request access to.
-
#redirect_uri ⇒ String?
The URI to redirect to after the Connect flow is completed.
-
#sandbox ⇒ Symbol, ...
Sandbox mode for testing.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#customer_email ⇒ String?
Email address of the customer
36 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 36 optional :customer_email, String, nil?: true |
#customer_id ⇒ String
Unique identifier for the customer
15 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 15 required :customer_id, String |
#customer_name ⇒ String
Name of the customer
21 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 21 required :customer_name, String |
#integration ⇒ FinchAPI::Models::Connect::SessionNewParams::Integration?
Integration configuration for the connect session
42 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 42 optional :integration, -> { FinchAPI::Connect::SessionNewParams::Integration }, nil?: true |
#manual ⇒ Boolean?
Enable manual authentication mode
48 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 48 optional :manual, FinchAPI::Internal::Type::Boolean, nil?: true |
#minutes_to_expire ⇒ Float?
The number of minutes until the session expires (defaults to 129,600, which is 90 days)
55 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 55 optional :minutes_to_expire, Float, nil?: true |
#products ⇒ Array<Symbol, FinchAPI::Models::Connect::SessionNewParams::Product>
The Finch products to request access to. Use ‘benefits` to access deductions endpoints — `deduction` is a deprecated alias that is still accepted but should not be combined with `benefits`.
29 30 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 29 required :products, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Connect::SessionNewParams::Product] } |
#redirect_uri ⇒ String?
The URI to redirect to after the Connect flow is completed
61 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 61 optional :redirect_uri, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/connect/session_new_params.rb', line 108
|