Module: FinchAPI::Models::Connect::SessionNewParams::Product

Extended by:
Internal::Type::Enum
Defined in:
lib/finch_api/models/connect/session_new_params.rb

Constant Summary collapse

BENEFITS =
:benefits
COMPANY =
:company
DEDUCTION =
:deduction
DIRECTORY =
:directory
DOCUMENTS =
:documents
EMPLOYMENT =
:employment
INDIVIDUAL =
:individual
PAYMENT =
:payment
PAY_STATEMENT =
:pay_statement
RECORDKEEPING =
:recordkeeping
SSN =
:ssn

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(customer_id:, customer_name:, products:, customer_email: nil, integration: nil, manual: nil, minutes_to_expire: nil, redirect_uri: nil, sandbox: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::Connect::SessionNewParams for more details.

Parameters:

  • customer_id (String)

    Unique identifier for the customer

  • customer_name (String)

    Name of the customer

  • products (Array<Symbol, FinchAPI::Models::Connect::SessionNewParams::Product>)

    The Finch products to request access to. Use ‘benefits` to access deductions end

  • customer_email (String, nil) (defaults to: nil)

    Email address of the customer

  • integration (FinchAPI::Models::Connect::SessionNewParams::Integration, nil) (defaults to: nil)

    Integration configuration for the connect session

  • manual (Boolean, nil) (defaults to: nil)

    Enable manual authentication mode

  • minutes_to_expire (Float, nil) (defaults to: nil)

    The number of minutes until the session expires (defaults to 129,600, which is 9

  • redirect_uri (String, nil) (defaults to: nil)

    The URI to redirect to after the Connect flow is completed

  • sandbox (Symbol, FinchAPI::Models::Connect::SessionNewParams::Sandbox, nil) (defaults to: nil)

    Sandbox mode for testing

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/finch_api/models/connect/session_new_params.rb', line 93

module Product
  extend FinchAPI::Internal::Type::Enum

  BENEFITS = :benefits
  COMPANY = :company
  DEDUCTION = :deduction
  DIRECTORY = :directory
  DOCUMENTS = :documents
  EMPLOYMENT = :employment
  INDIVIDUAL = :individual
  PAYMENT = :payment
  PAY_STATEMENT = :pay_statement
  RECORDKEEPING = :recordkeeping
  SSN = :ssn

  # @!method self.values
  #   @return [Array<Symbol>]
end