Class: FinchAPI::Models::Connect::SessionReauthenticateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/connect/session_reauthenticate_params.rb

Overview

Defined Under Namespace

Modules: Product

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#connection_idString

The ID of the existing connection to reauthenticate

Returns:

  • (String)


15
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 15

required :connection_id, String

#minutes_to_expireInteger?

The number of minutes until the session expires (defaults to 43,200, which is 30 days)

Returns:

  • (Integer, nil)


22
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 22

optional :minutes_to_expire, Integer

#productsArray<Symbol, FinchAPI::Models::Connect::SessionReauthenticateParams::Product>?

The products to request access to (optional for reauthentication). Use ‘benefits` to access deductions endpoints — `deduction` is a deprecated alias that is still accepted but should not be combined with `benefits`.



30
31
32
33
34
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 30

optional :products,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Connect::SessionReauthenticateParams::Product]
},
nil?: true

#redirect_uriString?

The URI to redirect to after the Connect flow is completed

Returns:

  • (String, nil)


40
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 40

optional :redirect_uri, String, nil?: true