Module: FinchAPI::Models::Connect::SessionReauthenticateParams::Product

Extended by:
Internal::Type::Enum
Defined in:
lib/finch_api/models/connect/session_reauthenticate_params.rb

Constant Summary collapse

BENEFITS =
:benefits
COMPANY =
:company
DEDUCTION =
:deduction
DIRECTORY =
:directory
DOCUMENTS =
:documents
EMPLOYMENT =
:employment
INDIVIDUAL =
:individual
PAYMENT =
:payment
PAY_STATEMENT =
:pay_statement
RECORDKEEPING =
:recordkeeping
SSN =
:ssn

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 71

Instance Method Details

#initialize(connection_id:, minutes_to_expire: nil, products: nil, redirect_uri: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::Connect::SessionReauthenticateParams for more details.

Parameters:

  • connection_id (String)

    The ID of the existing connection to reauthenticate

  • minutes_to_expire (Integer) (defaults to: nil)

    The number of minutes until the session expires (defaults to 43,200, which is 30

  • products (Array<Symbol, FinchAPI::Models::Connect::SessionReauthenticateParams::Product>, nil) (defaults to: nil)

    The products to request access to (optional for reauthentication). Use ‘benefits

  • redirect_uri (String, nil) (defaults to: nil)

    The URI to redirect to after the Connect flow is completed

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 56

module Product
  extend FinchAPI::Internal::Type::Enum

  BENEFITS = :benefits
  COMPANY = :company
  DEDUCTION = :deduction
  DIRECTORY = :directory
  DOCUMENTS = :documents
  EMPLOYMENT = :employment
  INDIVIDUAL = :individual
  PAYMENT = :payment
  PAY_STATEMENT = :pay_statement
  RECORDKEEPING = :recordkeeping
  SSN = :ssn

  # @!method self.values
  #   @return [Array<Symbol>]
end