Class: FinchAPI::Models::HRIS::BenefitContribution::UnionMember2
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::BenefitContribution::UnionMember2
- Defined in:
- lib/finch_api/models/hris/benefit_contribution.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#tiers ⇒ Array<FinchAPI::Models::HRIS::BenefitContribution::UnionMember2::Tier>
Array of tier objects defining employer match tiers based on employee contribution thresholds.
-
#type ⇒ Symbol, FinchAPI::Models::HRIS::BenefitContribution::UnionMember2::Type
Tiered contribution type (only valid for company_contribution).
Instance Method Summary collapse
- #initialize(match: , threshold: ) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(match: , threshold: ) ⇒ Object
|
|
# File 'lib/finch_api/models/hris/benefit_contribution.rb', line 111
|
Instance Attribute Details
#tiers ⇒ Array<FinchAPI::Models::HRIS::BenefitContribution::UnionMember2::Tier>
Array of tier objects defining employer match tiers based on employee contribution thresholds.
83 84 |
# File 'lib/finch_api/models/hris/benefit_contribution.rb', line 83 required :tiers, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::BenefitContribution::UnionMember2::Tier] } |
#type ⇒ Symbol, FinchAPI::Models::HRIS::BenefitContribution::UnionMember2::Type
Tiered contribution type (only valid for company_contribution).
90 |
# File 'lib/finch_api/models/hris/benefit_contribution.rb', line 90 required :type, enum: -> { FinchAPI::HRIS::BenefitContribution::UnionMember2::Type } |