Class: FinchAPI::Models::HRIS::BenefitCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::BenefitCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/hris/benefit_create_params.rb,
sig/finch_api/models/hris/benefit_create_params.rbs
Overview
Defined Under Namespace
Classes: CompanyContribution
Instance Attribute Summary collapse
-
#company_contribution ⇒ FinchAPI::Models::HRIS::BenefitCreateParams::CompanyContribution?
The company match for this benefit.
-
#description ⇒ String?
Name of the benefit as it appears in the provider and pay statements.
-
#entity_ids ⇒ Array<String>?
The entity IDs to specify which entities' data to access.
-
#frequency ⇒ Symbol, ...
The frequency of the benefit deduction/contribution.
-
#type ⇒ Symbol, ...
Type of benefit.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
32 |
# File 'sig/finch_api/models/hris/benefit_create_params.rbs', line 32
def initialize: (
|
Instance Attribute Details
#company_contribution ⇒ FinchAPI::Models::HRIS::BenefitCreateParams::CompanyContribution?
The company match for this benefit.
21 22 23 |
# File 'lib/finch_api/models/hris/benefit_create_params.rb', line 21 optional :company_contribution, -> { FinchAPI::HRIS::BenefitCreateParams::CompanyContribution }, nil?: true |
#description ⇒ String?
Name of the benefit as it appears in the provider and pay statements. Recommend limiting this to <30 characters due to limitations in specific providers (e.g. Justworks).
31 |
# File 'lib/finch_api/models/hris/benefit_create_params.rb', line 31 optional :description, String |
#entity_ids ⇒ Array<String>?
The entity IDs to specify which entities' data to access.
15 |
# File 'lib/finch_api/models/hris/benefit_create_params.rb', line 15 optional :entity_ids, FinchAPI::Internal::Type::ArrayOf[String] |
#frequency ⇒ Symbol, ...
The frequency of the benefit deduction/contribution.
37 |
# File 'lib/finch_api/models/hris/benefit_create_params.rb', line 37 optional :frequency, enum: -> { FinchAPI::HRIS::BenefitFrequency }, nil?: true |
#type ⇒ Symbol, ...
Type of benefit.
43 |
# File 'lib/finch_api/models/hris/benefit_create_params.rb', line 43 optional :type, enum: -> { FinchAPI::HRIS::BenefitType }, nil?: true |
Instance Method Details
#to_hash ⇒ {
41 |
# File 'sig/finch_api/models/hris/benefit_create_params.rbs', line 41
def to_hash: -> {
|