Class: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/benefit_features_and_operations.rb

Overview

Defined Under Namespace

Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, #initialize, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#annual_maximumBoolean?

Whether the provider supports an annual maximum for this benefit.

Returns:

  • (Boolean, nil)


28
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 28

optional :annual_maximum, FinchAPI::Internal::Type::Boolean, nil?: true

#catch_upBoolean?

Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.

Returns:

  • (Boolean, nil)


35
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 35

optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true

#company_contributionArray<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution, nil>?

Supported contribution types. An empty array indicates contributions are not supported.



42
43
44
45
46
47
48
49
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 42

optional :company_contribution,
-> do
  FinchAPI::Internal::Type::ArrayOf[
    enum: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution,
    nil?: true
  ]
end,
nil?: true

#descriptionString?

Returns:

  • (String, nil)


54
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 54

optional :description, String, nil?: true

#employee_deductionArray<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil>?

Supported deduction types. An empty array indicates deductions are not supported.



61
62
63
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 61

optional :employee_deduction,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil?: true] },
nil?: true

#frequenciesArray<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>?

The list of frequencies supported by the provider for this benefit

Returns:



69
70
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 69

optional :frequencies,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Models::HRIS::BenefitFrequency, nil?: true] }

#hsa_contribution_limitArray<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit, nil>?

Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.



77
78
79
80
81
82
83
84
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 77

optional :hsa_contribution_limit,
-> do
  FinchAPI::Internal::Type::ArrayOf[
    enum: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit,
    nil?: true
  ]
end,
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 115