Module: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution

Extended by:
Internal::Type::Enum
Defined in:
lib/finch_api/models/hris/benefit_features_and_operations.rb

Constant Summary collapse

FIXED =
:fixed
PERCENT =
:percent

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Instance Method Details

#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, description: nil, employee_deduction: nil, frequencies: nil, hsa_contribution_limit: nil) ⇒ Object

Some parameter documentations has been truncated, see HRIS::BenefitFeaturesAndOperations::SupportedFeatures for more details.

Parameters:

  • annual_maximum (Boolean, nil) (defaults to: nil)

    Whether the provider supports an annual maximum for this benefit.

  • catch_up (Boolean, nil) (defaults to: nil)

    Whether the provider supports catch up for this benefit. This field will only be

  • company_contribution (Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution, nil>, nil) (defaults to: nil)

    Supported contribution types. An empty array indicates contributions are not sup

  • description (String, nil) (defaults to: nil)
  • employee_deduction (Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil>, nil) (defaults to: nil)

    Supported deduction types. An empty array indicates deductions are not supported

  • frequencies (Array<Symbol, FinchAPI::HRIS::BenefitFrequency, nil>) (defaults to: nil)

    The list of frequencies supported by the provider for this benefit

  • hsa_contribution_limit (Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit, nil>, nil) (defaults to: nil)

    Whether the provider supports HSA contribution limits. Empty if this feature is



105
106
107
108
109
110
111
112
113
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 105

module CompanyContribution
  extend FinchAPI::Internal::Type::Enum

  FIXED = :fixed
  PERCENT = :percent

  # @!method self.values
  #   @return [Array<Symbol>]
end