Class: FinchAPI::Models::HRIS::BenefitListSupportedBenefitsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb

Overview

Defined Under Namespace

Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#annual_maximumBoolean?

Whether the provider supports an annual maximum for this benefit.

Returns:

  • (Boolean, nil)


12
# File 'lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb', line 12

optional :annual_maximum, FinchAPI::Internal::Type::Boolean, nil?: true

#catch_upBoolean?

Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.

Returns:

  • (Boolean, nil)


19
# File 'lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb', line 19

optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true

#company_contributionArray<Symbol, FinchAPI::Models::HRIS::BenefitListSupportedBenefitsResponse::CompanyContribution, nil>?

Supported contribution types. An empty array indicates contributions are not supported.



26
27
28
# File 'lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb', line 26

optional :company_contribution,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Models::HRIS::BenefitListSupportedBenefitsResponse::CompanyContribution, nil?: true] },
nil?: true

#descriptionString?

Returns:

  • (String, nil)


33
# File 'lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb', line 33

optional :description, String, nil?: true

#employee_deductionArray<Symbol, FinchAPI::Models::HRIS::BenefitListSupportedBenefitsResponse::EmployeeDeduction, nil>?

Supported deduction types. An empty array indicates deductions are not supported.



40
41
42
# File 'lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb', line 40

optional :employee_deduction,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Models::HRIS::BenefitListSupportedBenefitsResponse::EmployeeDeduction, nil?: true] },
nil?: true

#frequenciesArray<Symbol, FinchAPI::HRIS::BenefitFrequency, nil>?

The list of frequencies supported by the provider for this benefit

Returns:



48
49
# File 'lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb', line 48

optional :frequencies,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFrequency, nil?: true] }

#hsa_contribution_limitArray<Symbol, FinchAPI::Models::HRIS::BenefitListSupportedBenefitsResponse::HsaContributionLimit, nil>?

Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.



56
57
58
# File 'lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb', line 56

optional :hsa_contribution_limit,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Models::HRIS::BenefitListSupportedBenefitsResponse::HsaContributionLimit, nil?: true] },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/benefit_list_supported_benefits_response.rb', line 84