Class: FinchAPI::Models::HRIS::Benefits::IndividualBenefit::Body

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/hris/benefits/individual_benefit.rb

Overview

def initialize: (Hash | FinchAPI::BaseModel) -> void

Defined Under Namespace

Modules: HsaContributionLimit

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, employee_deduction: nil, hsa_contribution_limit: nil) ⇒ Body

Returns a new instance of Body.

Parameters:



7
8
9
10
11
12
13
14
15
16
# File 'lib/finch-api/models/hris/benefits/individual_benefit.rb', line 7

def initialize(
  annual_maximum: nil,
  catch_up: nil,
  company_contribution: nil,
  employee_deduction: nil,
  hsa_contribution_limit: nil,
  **
)
  super
end

Instance Attribute Details

#annual_maximumInteger?

If the benefit supports annual maximum, the amount in cents for this individual.

Returns:

  • (Integer, nil)


49
# File 'lib/finch-api/models/hris/benefits/individual_benefit.rb', line 49

optional :annual_maximum, Integer, nil?: true

#catch_upBoolean?

If the benefit supports catch up (401k, 403b, etc.), whether catch up is enabled

for this individual.

Returns:

  • (Boolean, nil)


56
# File 'lib/finch-api/models/hris/benefits/individual_benefit.rb', line 56

optional :catch_up, FinchAPI::BooleanModel, nil?: true

#company_contributionFinchAPI::Models::HRIS::BenefitContribution?



61
# File 'lib/finch-api/models/hris/benefits/individual_benefit.rb', line 61

optional :company_contribution, -> { FinchAPI::Models::HRIS::BenefitContribution }, nil?: true

#employee_deductionFinchAPI::Models::HRIS::BenefitContribution?



66
# File 'lib/finch-api/models/hris/benefits/individual_benefit.rb', line 66

optional :employee_deduction, -> { FinchAPI::Models::HRIS::BenefitContribution }, nil?: true

#hsa_contribution_limitSymbol, ...

Type for HSA contribution limit if the benefit is a HSA.



72
73
74
# File 'lib/finch-api/models/hris/benefits/individual_benefit.rb', line 72

optional :hsa_contribution_limit,
enum: -> { FinchAPI::Models::HRIS::Benefits::IndividualBenefit::Body::HsaContributionLimit },
nil?: true