Class: FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(configuration: nil, individual_id: nil) ⇒ Object

Parameters:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 32

class Individual < FinchAPI::Internal::Type::BaseModel
  # @!attribute configuration
  #
  #   @return [FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration, nil]
  optional :configuration,
           -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration }

  # @!attribute individual_id
  #   Finch id (uuidv4) for the individual to enroll
  #
  #   @return [String, nil]
  optional :individual_id, String

  # @!method initialize(configuration: nil, individual_id: nil)
  #   @param configuration [FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration]
  #
  #   @param individual_id [String] Finch id (uuidv4) for the individual to enroll

  # @see FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual#configuration
  class Configuration < FinchAPI::Internal::Type::BaseModel
    # @!attribute annual_contribution_limit
    #   For HSA benefits only - whether the contribution limit is for an individual or
    #   family
    #
    #   @return [Symbol, FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::AnnualContributionLimit, nil]
    optional :annual_contribution_limit,
             enum: -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::AnnualContributionLimit }

    # @!attribute annual_maximum
    #   Maximum annual amount in cents
    #
    #   @return [Integer, nil]
    optional :annual_maximum, Integer, nil?: true

    # @!attribute catch_up
    #   For retirement benefits only - whether catch up contributions are enabled
    #
    #   @return [Boolean, nil]
    optional :catch_up, FinchAPI::Internal::Type::Boolean

    # @!attribute company_contribution
    #
    #   @return [FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution, nil]
    optional :company_contribution,
             -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution }

    # @!attribute effective_date
    #   The date the enrollment will take effect
    #
    #   @return [Date, nil]
    optional :effective_date, Date

    # @!attribute employee_deduction
    #
    #   @return [FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction, nil]
    optional :employee_deduction,
             -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction }

    # @!method initialize(annual_contribution_limit: nil, annual_maximum: nil, catch_up: nil, company_contribution: nil, effective_date: nil, employee_deduction: nil)
    #   Some parameter documentations has been truncated, see
    #   {FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration}
    #   for more details.
    #
    #   @param annual_contribution_limit [Symbol, FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::AnnualContributionLimit] For HSA benefits only - whether the contribution limit is for an individual or f
    #
    #   @param annual_maximum [Integer, nil] Maximum annual amount in cents
    #
    #   @param catch_up [Boolean] For retirement benefits only - whether catch up contributions are enabled
    #
    #   @param company_contribution [FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution]
    #
    #   @param effective_date [Date] The date the enrollment will take effect
    #
    #   @param employee_deduction [FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction]

    # For HSA benefits only - whether the contribution limit is for an individual or
    # family
    #
    # @see FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration#annual_contribution_limit
    module AnnualContributionLimit
      extend FinchAPI::Internal::Type::Enum

      INDIVIDUAL = :individual
      FAMILY = :family

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration#company_contribution
    class CompanyContribution < FinchAPI::Internal::Type::BaseModel
      # @!attribute amount
      #   Amount in cents for fixed type or basis points (1/100th of a percent) for
      #   percent type
      #
      #   @return [Integer, nil]
      optional :amount, Integer

      # @!attribute tiers
      #   Array of tier objects for tiered contribution matching (required when type is
      #   tiered)
      #
      #   @return [Array<FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Tier>, nil]
      optional :tiers,
               -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Tier] }

      # @!attribute type
      #
      #   @return [Symbol, FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Type, nil]
      optional :type,
               enum: -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Type }

      # @!method initialize(amount: nil, tiers: nil, type: nil)
      #   Some parameter documentations has been truncated, see
      #   {FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution}
      #   for more details.
      #
      #   @param amount [Integer] Amount in cents for fixed type or basis points (1/100th of a percent) for percen
      #
      #   @param tiers [Array<FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Tier>] Array of tier objects for tiered contribution matching (required when type is ti
      #
      #   @param type [Symbol, FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Type]

      class Tier < FinchAPI::Internal::Type::BaseModel
        # @!attribute match
        #   The employer match percentage in basis points (0-10000 = 0-100%)
        #
        #   @return [Integer]
        required :match, Integer

        # @!attribute threshold
        #   The employee contribution threshold in basis points (0-10000 = 0-100%)
        #
        #   @return [Integer]
        required :threshold, Integer

        # @!method initialize(match:, threshold:)
        #   @param match [Integer] The employer match percentage in basis points (0-10000 = 0-100%)
        #
        #   @param threshold [Integer] The employee contribution threshold in basis points (0-10000 = 0-100%)
      end

      # @see FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution#type
      module Type
        extend FinchAPI::Internal::Type::Enum

        FIXED = :fixed
        PERCENT = :percent
        TIERED = :tiered

        # @!method self.values
        #   @return [Array<Symbol>]
      end
    end

    # @see FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration#employee_deduction
    class EmployeeDeduction < FinchAPI::Internal::Type::BaseModel
      # @!attribute amount
      #   Amount in cents for fixed type or basis points (1/100th of a percent) for
      #   percent type
      #
      #   @return [Integer, nil]
      optional :amount, Integer

      # @!attribute type
      #
      #   @return [Symbol, FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction::Type, nil]
      optional :type,
               enum: -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction::Type }

      # @!method initialize(amount: nil, type: nil)
      #   Some parameter documentations has been truncated, see
      #   {FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction}
      #   for more details.
      #
      #   @param amount [Integer] Amount in cents for fixed type or basis points (1/100th of a percent) for percen
      #
      #   @param type [Symbol, FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction::Type]

      # @see FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction#type
      module Type
        extend FinchAPI::Internal::Type::Enum

        FIXED = :fixed
        PERCENT = :percent

        # @!method self.values
        #   @return [Array<Symbol>]
      end
    end
  end
end

Instance Attribute Details

#configurationFinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration?



36
37
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 36

optional :configuration,
-> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration }

#individual_idString?

Finch id (uuidv4) for the individual to enroll

Returns:

  • (String, nil)


43
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 43

optional :individual_id, String