Class: FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration
- Defined in:
- lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb
Overview
Defined Under Namespace
Modules: AnnualContributionLimit Classes: CompanyContribution, EmployeeDeduction
Instance Attribute Summary collapse
-
#annual_contribution_limit ⇒ Symbol, ...
For HSA benefits only - whether the contribution limit is for an individual or family.
-
#annual_maximum ⇒ Integer?
Maximum annual amount in cents.
-
#catch_up ⇒ Boolean?
For retirement benefits only - whether catch up contributions are enabled.
- #company_contribution ⇒ FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution?
-
#effective_date ⇒ Date?
The date the enrollment will take effect.
- #employee_deduction ⇒ FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(annual_contribution_limit: nil, annual_maximum: nil, catch_up: nil, company_contribution: nil, effective_date: nil, employee_deduction: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Configuration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(annual_contribution_limit: nil, annual_maximum: nil, catch_up: nil, company_contribution: nil, effective_date: nil, employee_deduction: nil) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration for more details.
|
|
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 90
|
Instance Attribute Details
#annual_contribution_limit ⇒ Symbol, ...
For HSA benefits only - whether the contribution limit is for an individual or family
57 58 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 57 optional :annual_contribution_limit, enum: -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::AnnualContributionLimit } |
#annual_maximum ⇒ Integer?
Maximum annual amount in cents
64 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 64 optional :annual_maximum, Integer, nil?: true |
#catch_up ⇒ Boolean?
For retirement benefits only - whether catch up contributions are enabled
70 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 70 optional :catch_up, FinchAPI::Internal::Type::Boolean |
#company_contribution ⇒ FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution?
75 76 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 75 optional :company_contribution, -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution } |
#effective_date ⇒ Date?
The date the enrollment will take effect
82 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 82 optional :effective_date, Date |
#employee_deduction ⇒ FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction?
87 88 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 87 optional :employee_deduction, -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 117
|