Class: FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb

Overview

Defined Under Namespace

Modules: Type Classes: Tier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(match: , threshold: ) ⇒ Object

Parameters:

  • match (Integer) (defaults to: )

    The employer match percentage in basis points (0-10000 = 0-100%)

  • threshold (Integer) (defaults to: )

    The employee contribution threshold in basis points (0-10000 = 0-100%)



# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 168

Instance Attribute Details

#amountInteger?

Amount in cents for fixed type or basis points (1/100th of a percent) for percent type

Returns:

  • (Integer, nil)


128
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 128

optional :amount, Integer

#tiersArray<FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Tier>?

Array of tier objects for tiered contribution matching (required when type is tiered)



135
136
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 135

optional :tiers,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Tier] }

#typeSymbol, ...



141
142
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 141

optional :type,
enum: -> { FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Type }