Class: FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb

Overview

See Also:

  • HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration#employee_deduction

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(amount: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction for more details.

Parameters:

  • amount (Integer) (defaults to: nil)

    Amount in cents for fixed type or basis points (1/100th of a percent) for percen

  • type (Symbol, FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction::Type) (defaults to: nil)


# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 176

Instance Attribute Details

#amountInteger?

Amount in cents for fixed type or basis points (1/100th of a percent) for percent type

Returns:

  • (Integer, nil)


166
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 166

optional :amount, Integer

#typeSymbol, ...

Returns:

  • (Symbol, FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction::Type, nil)


171
172
173
174
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 171

optional :type,
enum: -> {
  FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction::Type
}