Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb

Overview

Defined Under Namespace

Modules: EntityType Classes: Attributes, Condition

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

#initialize(metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see Attributes for more details.

Specifies the fields to be applied when the condition is met.

Parameters:

  • metadata (Hash{Symbol=>Object}) (defaults to: nil)

    The metadata to be attached in the entity. It is a key-value pairs where the val



# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 66

Instance Attribute Details

#attributesFinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams::Attributes?

Specifies the fields to be applied when the condition is met.



17
18
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 17

optional :attributes,
-> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams::Attributes }

#conditionsArray<FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams::Condition>?



23
24
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 23

optional :conditions,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams::Condition] }

#effective_end_dateString?

Specifies when the rules should stop applying rules based on the date.

Returns:

  • (String, nil)


30
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 30

optional :effective_end_date, String, nil?: true

#effective_start_dateString?

Specifies when the rule should begin applying based on the date.

Returns:

  • (String, nil)


36
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 36

optional :effective_start_date, String, nil?: true

#entity_typeSymbol, ...

The entity type to which the rule is applied.



42
43
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 42

optional :entity_type,
enum: -> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams::EntityType }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 112