Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams::Condition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams::Condition
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb
Defined Under Namespace
Modules: Operator
Instance Attribute Summary collapse
-
#field ⇒ String?
The field to be checked in the rule.
-
#operator ⇒ Symbol, ...
The operator to be used in the rule.
-
#value ⇒ String?
The value of the field to be checked in the rule.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(field: nil, operator: nil, value: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 102
|
Instance Attribute Details
#field ⇒ String?
The field to be checked in the rule.
85 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 85 optional :field, String |
#operator ⇒ Symbol, ...
The operator to be used in the rule.
91 92 93 94 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 91 optional :operator, enum: -> { FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Condition::Operator } |
#value ⇒ String?
The value of the field to be checked in the rule.
100 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 100 optional :value, String |