Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb
Overview
Defined Under Namespace
Modules: EntityType Classes: Attributes, Condition
Instance Attribute Summary collapse
-
#attributes ⇒ FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Attributes?
Specifies the fields to be applied when the condition is met.
- #conditions ⇒ Array<FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Condition>?
-
#created_at ⇒ Time?
The datetime when the rule was created.
-
#effective_end_date ⇒ String?
Specifies when the rules should stop applying rules based on the date.
-
#effective_start_date ⇒ String?
Specifies when the rule should begin applying based on the date.
-
#entity_type ⇒ Symbol, ...
The entity type to which the rule is applied.
-
#id ⇒ String?
Finch id (uuidv4) for the rule.
-
#priority ⇒ Integer?
The priority of the rule.
-
#updated_at ⇒ Time?
The datetime when the rule was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Attributes for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see Attributes for more details.
Specifies the fields to be applied when the condition is met.
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 66
|
Instance Attribute Details
#attributes ⇒ FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Attributes?
Specifies the fields to be applied when the condition is met.
20 21 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 20 optional :attributes, -> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Attributes } |
#conditions ⇒ Array<FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Condition>?
26 27 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 26 optional :conditions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Condition] } |
#created_at ⇒ Time?
The datetime when the rule was created.
33 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 33 optional :created_at, Time |
#effective_end_date ⇒ String?
Specifies when the rules should stop applying rules based on the date.
39 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 39 optional :effective_end_date, String, nil?: true |
#effective_start_date ⇒ String?
Specifies when the rule should begin applying based on the date.
45 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 45 optional :effective_start_date, String, nil?: true |
#entity_type ⇒ Symbol, ...
The entity type to which the rule is applied.
51 52 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 51 optional :entity_type, enum: -> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::EntityType } |
#id ⇒ String?
Finch id (uuidv4) for the rule.
14 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 14 optional :id, String |
#priority ⇒ Integer?
The priority of the rule.
58 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 58 optional :priority, Integer |
#updated_at ⇒ Time?
The datetime when the rule was last updated.
64 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 64 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 139
|