Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Condition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Condition
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb
Defined Under Namespace
Modules: Operator
Instance Attribute Summary collapse
-
#field ⇒ String?
The field to be checked in the rule.
-
#operator ⇒ Symbol, ...
The operator to be used in the rule.
-
#value ⇒ String?
The value of the field to be checked in the rule.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(field: nil, operator: nil, value: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 124
|
Instance Attribute Details
#field ⇒ String?
The field to be checked in the rule.
109 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 109 optional :field, String |
#operator ⇒ Symbol, ...
The operator to be used in the rule.
115 116 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 115 optional :operator, enum: -> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateResponse::Condition::Operator } |
#value ⇒ String?
The value of the field to be checked in the rule.
122 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_response.rb', line 122 optional :value, String |