Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb

Overview

Defined Under Namespace

Modules: EntityType Classes: Attributes, Condition

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see Attributes for more details.

Specifies the fields to be applied when the condition is met.

Parameters:

  • metadata (Hash{Symbol=>Object}) (defaults to: nil)

    The metadata to be attached in the entity. It is a key-value pairs where the val



# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 72

Instance Attribute Details

#attributesFinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse::Attributes?

Specifies the fields to be applied when the condition is met.



20
21
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 20

optional :attributes,
-> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse::Attributes }

#conditionsArray<FinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse::Condition>?



26
27
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 26

optional :conditions,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse::Condition] }

#created_atTime?

The datetime when the rule was created.

Returns:

  • (Time, nil)


33
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 33

optional :created_at, Time

#deleted_atTime?

The datetime when the rule was deleted.

Returns:

  • (Time, nil)


39
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 39

optional :deleted_at, Time

#effective_end_dateString?

Specifies when the rules should stop applying rules based on the date.

Returns:

  • (String, nil)


45
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 45

optional :effective_end_date, String, nil?: true

#effective_start_dateString?

Specifies when the rule should begin applying based on the date.

Returns:

  • (String, nil)


51
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 51

optional :effective_start_date, String, nil?: true

#entity_typeSymbol, ...

The entity type to which the rule is applied.



57
58
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 57

optional :entity_type,
enum: -> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse::EntityType }

#idString?

Finch id (uuidv4) for the rule.

Returns:

  • (String, nil)


14
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 14

optional :id, String

#priorityInteger?

The priority of the rule.

Returns:

  • (Integer, nil)


64
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 64

optional :priority, Integer

#updated_atTime?

The datetime when the rule was last updated.

Returns:

  • (Time, nil)


70
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 70

optional :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 147