Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse::Condition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse::Condition
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb
Defined Under Namespace
Modules: Operator
Instance Attribute Summary collapse
-
#field ⇒ String?
The field to be checked in the rule.
-
#operator ⇒ Symbol, ...
The operator to be used in the rule.
-
#value ⇒ String?
The value of the field to be checked in the rule.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(field: nil, operator: nil, value: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 132
|
Instance Attribute Details
#field ⇒ String?
The field to be checked in the rule.
117 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 117 optional :field, String |
#operator ⇒ Symbol, ...
The operator to be used in the rule.
123 124 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 123 optional :operator, enum: -> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleDeleteResponse::Condition::Operator } |
#value ⇒ String?
The value of the field to be checked in the rule.
130 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_delete_response.rb', line 130 optional :value, String |