Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleUpdateResponse::Condition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItem::RuleUpdateResponse::Condition
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item/rule_update_response.rb
Defined Under Namespace
Modules: Operator
Instance Attribute Summary collapse
-
#field ⇒ String?
The field to be checked in the rule.
-
#operator ⇒ Symbol, ...
The operator to be used in the rule.
-
#value ⇒ String?
The value of the field to be checked in the rule.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field: nil, operator: nil, value: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_update_response.rb', line 124
|
Instance Attribute Details
#field ⇒ String?
The field to be checked in the rule.
109 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_update_response.rb', line 109 optional :field, String |
#operator ⇒ Symbol, ...
The operator to be used in the rule.
115 116 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_update_response.rb', line 115 optional :operator, enum: -> { FinchAPI::Models::HRIS::Company::PayStatementItem::RuleUpdateResponse::Condition::Operator } |
#value ⇒ String?
The value of the field to be checked in the rule.
122 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_update_response.rb', line 122 optional :value, String |