Class: FinchAPI::Models::HRIS::Company::PayStatementItemListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/hris/company/pay_statement_item_list_params.rb

Overview

Defined Under Namespace

Modules: Category

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#categoriesArray<Symbol, FinchAPI::Models::HRIS::Company::PayStatementItemListParams::Category>?

Comma-delimited list of pay statement item categories to filter on. If empty, defaults to all categories.



17
18
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 17

optional :categories,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::Company::PayStatementItemListParams::Category] }

#end_dateDate?

The end date to retrieve pay statement items by via their last seen pay date in ‘YYYY-MM-DD` format.

Returns:

  • (Date, nil)


25
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 25

optional :end_date, Date

#entity_idsArray<String>?

The entity IDs to specify which entities’ data to access.

Returns:

  • (Array<String>, nil)


31
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 31

optional :entity_ids, FinchAPI::Internal::Type::ArrayOf[String]

#nameString?

Case-insensitive partial match search by pay statement item name.

Returns:

  • (String, nil)


37
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 37

optional :name, String

#start_dateDate?

The start date to retrieve pay statement items by via their last seen pay date (inclusive) in ‘YYYY-MM-DD` format.

Returns:

  • (Date, nil)


44
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 44

optional :start_date, Date

#typeString?

String search by pay statement item type.

Returns:

  • (String, nil)


50
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 50

optional :type, String