Module: FinchAPI::Models::HRIS::Company::PayStatementItemListParams::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/finch_api/models/hris/company/pay_statement_item_list_params.rb

Constant Summary collapse

EARNINGS =
:earnings
TAXES =
:taxes
EMPLOYEE_DEDUCTIONS =
:employee_deductions
EMPLOYER_CONTRIBUTIONS =
:employer_contributions

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 78

Instance Method Details

#initialize(categories: nil, end_date: nil, entity_ids: nil, name: nil, start_date: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::Company::PayStatementItemListParams for more details.

Parameters:

  • categories (Array<Symbol, FinchAPI::Models::HRIS::Company::PayStatementItemListParams::Category>) (defaults to: nil)

    Comma-delimited list of pay statement item categories to filter on. If empty, de

  • end_date (Date) (defaults to: nil)

    The end date to retrieve pay statement items by via their last seen pay date in

  • entity_ids (Array<String>) (defaults to: nil)

    The entity IDs to specify which entities’ data to access.

  • name (String) (defaults to: nil)

    Case-insensitive partial match search by pay statement item name.

  • start_date (Date) (defaults to: nil)

    The start date to retrieve pay statement items by via their last seen pay date (

  • type (String) (defaults to: nil)

    String search by pay statement item type.

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


70
71
72
73
74
75
76
77
78
79
80
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 70

module Category
  extend FinchAPI::Internal::Type::Enum

  EARNINGS = :earnings
  TAXES = :taxes
  EMPLOYEE_DEDUCTIONS = :employee_deductions
  EMPLOYER_CONTRIBUTIONS = :employer_contributions

  # @!method self.values
  #   @return [Array<Symbol>]
end