Class: FinchAPI::Models::HRIS::Company::PayStatementItemListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItemListResponse
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item_list_response.rb
Overview
Defined Under Namespace
Modules: Category Classes: Attributes
Instance Attribute Summary collapse
-
#attributes ⇒ FinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Attributes?
The attributes of the pay statement item.
-
#category ⇒ Symbol, ...
The category of the pay statement item.
-
#name ⇒ String?
The name of the pay statement item.
Instance Method Summary collapse
-
#initialize(employer: nil, metadata: nil, pre_tax: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Attributes for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(employer: nil, metadata: nil, pre_tax: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see Attributes for more details.
The attributes of the pay statement item.
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 27
|
Instance Attribute Details
#attributes ⇒ FinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Attributes?
The attributes of the pay statement item.
13 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 13 optional :attributes, -> { FinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Attributes } |
#category ⇒ Symbol, ...
The category of the pay statement item.
19 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 19 optional :category, enum: -> { FinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Category } |
#name ⇒ String?
The name of the pay statement item.
25 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 25 optional :name, String |