Class: FinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Attributes
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Attributes
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item_list_response.rb
Overview
Instance Attribute Summary collapse
-
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
-
#metadata ⇒ Hash{Symbol=>Object, nil}?
The metadata of the pay statement item derived by the rules engine if available.
-
#pre_tax ⇒ Boolean?
‘true` if the pay statement item is pre-tax.
-
#type ⇒ String?
The type of the pay statement item.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers. This field is only available for taxes.
41 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 41 optional :employer, FinchAPI::Internal::Type::Boolean, nil?: true |
#metadata ⇒ Hash{Symbol=>Object, nil}?
The metadata of the pay statement item derived by the rules engine if available. Each attribute will be a key-value pair defined by a rule.
48 49 50 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 48 optional :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true], nil?: true |
#pre_tax ⇒ Boolean?
‘true` if the pay statement item is pre-tax. This field is only available for employee deductions.
57 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 57 optional :pre_tax, FinchAPI::Internal::Type::Boolean, nil?: true |
#type ⇒ String?
The type of the pay statement item.
63 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 63 optional :type, String, nil?: true |