Class: FinchAPI::Models::HRIS::DocumentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::DocumentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/hris/document_list_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#individual_ids ⇒ Array<String>?
Comma-delimited list of stable Finch uuids for each individual.
-
#limit ⇒ Integer?
Number of documents to return (defaults to all).
-
#offset ⇒ Integer?
Index to start from (defaults to 0).
-
#types ⇒ Array<Symbol, FinchAPI::Models::HRIS::DocumentListParams::Type>?
Comma-delimited list of document types to filter on.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#individual_ids ⇒ Array<String>?
Comma-delimited list of stable Finch uuids for each individual. If empty, defaults to all individuals
16 |
# File 'lib/finch_api/models/hris/document_list_params.rb', line 16 optional :individual_ids, FinchAPI::Internal::Type::ArrayOf[String] |
#limit ⇒ Integer?
Number of documents to return (defaults to all)
22 |
# File 'lib/finch_api/models/hris/document_list_params.rb', line 22 optional :limit, Integer |
#offset ⇒ Integer?
Index to start from (defaults to 0)
28 |
# File 'lib/finch_api/models/hris/document_list_params.rb', line 28 optional :offset, Integer |
#types ⇒ Array<Symbol, FinchAPI::Models::HRIS::DocumentListParams::Type>?
Comma-delimited list of document types to filter on. If empty, defaults to all types
35 |
# File 'lib/finch_api/models/hris/document_list_params.rb', line 35 optional :types, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::DocumentListParams::Type] } |