Module: FinchAPI::Models::HRIS::EmploymentData
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/finch_api/models/hris/employment_data.rb
Defined Under Namespace
Classes: BatchError, UnionMember0
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
The manager object representing the manager of the individual within the org.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, variants
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Class Method Details
.variants ⇒ Array(FinchAPI::HRIS::EmploymentData::UnionMember0, FinchAPI::HRIS::EmploymentData::BatchError)
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 368
|
Instance Method Details
#initialize(id: ) ⇒ Object
The manager object representing the manager of the individual within the org.
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 333
|