Class: FinchAPI::Models::HRIS::EmploymentData::Department
- Defined in:
- lib/finch-api/models/hris/employment_data.rb
Instance Attribute Summary collapse
-
#name ⇒ String?
The name of the department associated with the individual.
Instance Attribute Details
#name ⇒ String?
The name of the department associated with the individual.
218 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 218 optional :name, String, nil?: true |