Class: FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/employment_data.rb,
sig/finch_api/models/hris/employment_data.rbs

Defined Under Namespace

Modules: EmploymentStatus, FlsaStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

The manager object representing the manager of the individual within the org.

Parameters:

  • id (String)

    A stable Finch id (UUID v4) for an individual in the company.



# File 'lib/finch_api/models/hris/employment_data.rb', line 188

Instance Attribute Details

#class_codeString?

Worker's compensation classification code for this employee

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


24
# File 'lib/finch_api/models/hris/employment_data.rb', line 24

required :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.

Parameters:

  • value (::Array[FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::CustomField], nil)

Returns:



152
153
154
155
156
# File 'lib/finch_api/models/hris/employment_data.rb', line 152

optional :custom_fields,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::CustomField]
},
nil?: true

#departmentFinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Department?

The department object.

Parameters:

  • value (FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Department, nil)

Returns:



30
31
32
# File 'lib/finch_api/models/hris/employment_data.rb', line 30

required :department,
-> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Department },
nil?: true

#employmentFinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Employment?

The employment object.

Parameters:

  • value (FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Employment, nil)

Returns:



38
39
40
# File 'lib/finch_api/models/hris/employment_data.rb', line 38

required :employment,
-> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Employment },
nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual.

Parameters:

  • value (FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::employment_status, nil)

Returns:



46
47
48
# File 'lib/finch_api/models/hris/employment_data.rb', line 46

required :employment_status,
enum: -> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::EmploymentStatus },
nil?: true

#end_dateString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


53
# File 'lib/finch_api/models/hris/employment_data.rb', line 53

required :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


59
# File 'lib/finch_api/models/hris/employment_data.rb', line 59

required :first_name, String, nil?: true

#flsa_statusSymbol, ...

The FLSA status of the individual. Available options: exempt, non_exempt, unknown.

Parameters:

  • value (FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::flsa_status, nil)

Returns:



66
67
68
# File 'lib/finch_api/models/hris/employment_data.rb', line 66

required :flsa_status,
enum: -> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::FlsaStatus },
nil?: true

#highly_compensated_employeeBoolean?

IRS flag indicating whether the employee is classified as a Highly Compensated Employee for nondiscrimination testing purposes (ADP/ACP tests). US-only.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


75
# File 'lib/finch_api/models/hris/employment_data.rb', line 75

required :highly_compensated_employee, FinchAPI::Internal::Type::Boolean, nil?: true

#idString

A stable Finch id (UUID v4) for an individual in the company.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/finch_api/models/hris/employment_data.rb', line 18

required :id, String

#incomeFinchAPI::Models::Income?

The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Parameters:

Returns:



164
# File 'lib/finch_api/models/hris/employment_data.rb', line 164

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Models::Income, nil>?

The array of income history.

Parameters:

Returns:



170
171
172
# File 'lib/finch_api/models/hris/employment_data.rb', line 170

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#is_activeBoolean?

true if the individual an an active employee or contractor at the company.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


81
# File 'lib/finch_api/models/hris/employment_data.rb', line 81

required :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#key_employeeBoolean?

IRS flag indicating whether the employee is classified as a Key Employee for top-heavy testing purposes. US-only.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


88
# File 'lib/finch_api/models/hris/employment_data.rb', line 88

required :key_employee, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


94
# File 'lib/finch_api/models/hris/employment_data.rb', line 94

required :last_name, String, nil?: true

#latest_rehire_dateString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


99
# File 'lib/finch_api/models/hris/employment_data.rb', line 99

required :latest_rehire_date, String, nil?: true

#locationFinchAPI::Models::Location?

Parameters:

Returns:



104
# File 'lib/finch_api/models/hris/employment_data.rb', line 104

required :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Manager?

The manager object representing the manager of the individual within the org.

Parameters:

  • value (FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Manager, nil)

Returns:



110
111
112
113
114
# File 'lib/finch_api/models/hris/employment_data.rb', line 110

required :manager,
-> {
  FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Manager
},
nil?: true

#middle_nameString?

The legal middle name of the individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


120
# File 'lib/finch_api/models/hris/employment_data.rb', line 120

required :middle_name, String, nil?: true

#source_idString?

The source system's unique employment identifier for this individual

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


178
# File 'lib/finch_api/models/hris/employment_data.rb', line 178

optional :source_id, String, nil?: true

#start_dateString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


125
# File 'lib/finch_api/models/hris/employment_data.rb', line 125

required :start_date, String, nil?: true

#titleString?

The current title of the individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


131
# File 'lib/finch_api/models/hris/employment_data.rb', line 131

required :title, String, nil?: true

#union_codeString?

The code identifying the union the employee is a member of, as configured in the payroll system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


138
# File 'lib/finch_api/models/hris/employment_data.rb', line 138

required :union_code, String, nil?: true

#union_localString?

The local chapter or local number within the employee's union.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


144
# File 'lib/finch_api/models/hris/employment_data.rb', line 144

required :union_local, String, nil?: true

#work_idString?

Deprecated.

This field is deprecated in favour of source_id

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


186
# File 'lib/finch_api/models/hris/employment_data.rb', line 186

optional :work_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/employment_data.rb', line 318

Instance Method Details

#to_hash{

Returns:

  • ({)


119
# File 'sig/finch_api/models/hris/employment_data.rbs', line 119

def to_hash: -> {