Class: FinchAPI::Models::HRIS::EmploymentData::UnionMember0

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/employment_data.rb

Defined Under Namespace

Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

#initialize(name: ) ⇒ Object

The department object.

Parameters:

  • name (String, nil) (defaults to: )

    The name of the department associated with the individual.



# File 'lib/finch_api/models/hris/employment_data.rb', line 237

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


24
# File 'lib/finch_api/models/hris/employment_data.rb', line 24

required :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system.

Returns:

  • (Array<FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField>, nil)


31
32
33
34
35
# File 'lib/finch_api/models/hris/employment_data.rb', line 31

required :custom_fields,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField]
},
nil?: true

#departmentFinchAPI::HRIS::EmploymentData::UnionMember0::Department?

The department object.

Returns:

  • (FinchAPI::HRIS::EmploymentData::UnionMember0::Department, nil)


41
# File 'lib/finch_api/models/hris/employment_data.rb', line 41

required :department, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Department }, nil?: true

#employmentFinchAPI::HRIS::EmploymentData::UnionMember0::Employment?

The employment object.

Returns:

  • (FinchAPI::HRIS::EmploymentData::UnionMember0::Employment, nil)


47
# File 'lib/finch_api/models/hris/employment_data.rb', line 47

required :employment, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.

Returns:

  • (Symbol, FinchAPI::HRIS::EmploymentData::UnionMember0::EmploymentStatus, nil)


54
55
56
# File 'lib/finch_api/models/hris/employment_data.rb', line 54

required :employment_status,
enum: -> { FinchAPI::HRIS::EmploymentData::UnionMember0::EmploymentStatus },
nil?: true

#end_dateString?

Returns:

  • (String, nil)


61
# File 'lib/finch_api/models/hris/employment_data.rb', line 61

required :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


67
# File 'lib/finch_api/models/hris/employment_data.rb', line 67

required :first_name, String, nil?: true

#idString

A stable Finch ‘id` (UUID v4) for an individual in the company.

Returns:

  • (String)


18
# File 'lib/finch_api/models/hris/employment_data.rb', line 18

required :id, String

#incomeFinchAPI::Income?

The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Returns:



134
# File 'lib/finch_api/models/hris/employment_data.rb', line 134

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Income, nil>?

The array of income history.

Returns:



140
141
142
# File 'lib/finch_api/models/hris/employment_data.rb', line 140

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


73
# File 'lib/finch_api/models/hris/employment_data.rb', line 73

required :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


79
# File 'lib/finch_api/models/hris/employment_data.rb', line 79

required :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


84
# File 'lib/finch_api/models/hris/employment_data.rb', line 84

required :latest_rehire_date, String, nil?: true

#locationFinchAPI::Location?

Returns:



89
# File 'lib/finch_api/models/hris/employment_data.rb', line 89

required :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::HRIS::EmploymentData::UnionMember0::Manager?

The manager object representing the manager of the individual within the org.

Returns:

  • (FinchAPI::HRIS::EmploymentData::UnionMember0::Manager, nil)


95
# File 'lib/finch_api/models/hris/employment_data.rb', line 95

required :manager, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


101
# File 'lib/finch_api/models/hris/employment_data.rb', line 101

required :middle_name, String, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


107
# File 'lib/finch_api/models/hris/employment_data.rb', line 107

required :source_id, String, nil?: true

#start_dateString?

Returns:

  • (String, nil)


112
# File 'lib/finch_api/models/hris/employment_data.rb', line 112

required :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


118
# File 'lib/finch_api/models/hris/employment_data.rb', line 118

required :title, String, nil?: true

#work_idString?

Deprecated.

This field is deprecated in favour of ‘source_id`

Returns:

  • (String, nil)


126
# File 'lib/finch_api/models/hris/employment_data.rb', line 126

required :work_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/employment_data.rb', line 301