Class: FinchAPI::Models::HRIS::HRISCompany

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/company.rb

Overview

Defined Under Namespace

Classes: Account, Department, Entity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

#initialize(name: ) ⇒ Object

The parent department, if present.

Parameters:

  • name (String, nil) (defaults to: )

    The parent department’s name.



# File 'lib/finch_api/models/hris/company.rb', line 178

Instance Attribute Details

#accountsArray<FinchAPI::Models::HRIS::HRISCompany::Account>?

An array of bank account objects associated with the payroll/HRIS system.



18
19
20
# File 'lib/finch_api/models/hris/company.rb', line 18

required :accounts,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::HRIS::HRISCompany::Account] },
nil?: true

#departmentsArray<FinchAPI::Models::HRIS::HRISCompany::Department, nil>?

The array of company departments.



26
27
28
# File 'lib/finch_api/models/hris/company.rb', line 26

required :departments,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::HRIS::HRISCompany::Department, nil?: true] },
nil?: true

#einString?

The employer identification number.

Returns:

  • (String, nil)


34
# File 'lib/finch_api/models/hris/company.rb', line 34

required :ein, String, nil?: true

#entityFinchAPI::Models::HRIS::HRISCompany::Entity?

The entity type object.



40
# File 'lib/finch_api/models/hris/company.rb', line 40

required :entity, -> { FinchAPI::Models::HRIS::HRISCompany::Entity }, nil?: true

#idString

A stable Finch ‘id` (UUID v4) for the company.

Returns:

  • (String)


12
# File 'lib/finch_api/models/hris/company.rb', line 12

required :id, String

The legal name of the company.

Returns:

  • (String, nil)


46
# File 'lib/finch_api/models/hris/company.rb', line 46

required :legal_name, String, nil?: true

#locationsArray<FinchAPI::Models::Location, nil>?

Returns:



51
52
53
# File 'lib/finch_api/models/hris/company.rb', line 51

required :locations,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Location, nil?: true] },
nil?: true

#primary_emailString?

The email of the main administrator on the account.

Returns:

  • (String, nil)


59
# File 'lib/finch_api/models/hris/company.rb', line 59

required :primary_email, String, nil?: true

#primary_phone_numberString?

The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g. ‘+NNNNNNNNNNN xExtension`

Returns:

  • (String, nil)


66
# File 'lib/finch_api/models/hris/company.rb', line 66

required :primary_phone_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/company.rb', line 147