Class: FinchAPI::Models::HRIS::Individual
- Defined in:
- lib/finch-api/models/hris/individual.rb
Defined Under Namespace
Modules: Ethnicity, Gender Classes: Email, PhoneNumber
Instance Attribute Summary collapse
- #dob ⇒ String?
- #emails ⇒ Array<FinchAPI::Models::HRIS::Individual::Email>?
-
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format.
-
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
-
#first_name ⇒ String?
The legal first name of the individual.
-
#gender ⇒ Symbol, ...
The gender of the individual.
-
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#last_name ⇒ String?
The legal last name of the individual.
-
#middle_name ⇒ String?
The legal middle name of the individual.
- #phone_numbers ⇒ Array<FinchAPI::Models::HRIS::Individual::PhoneNumber, nil>?
-
#preferred_name ⇒ String?
The preferred name of the individual.
- #residence ⇒ FinchAPI::Models::Location?
-
#ssn ⇒ String?
Social Security Number of the individual.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, dob: nil, emails: nil, encrypted_ssn: nil, ethnicity: nil, first_name: nil, gender: nil, last_name: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, ssn: nil) ⇒ Individual
constructor
A new instance of Individual.
Constructor Details
#initialize(id: nil, dob: nil, emails: nil, encrypted_ssn: nil, ethnicity: nil, first_name: nil, gender: nil, last_name: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, ssn: nil) ⇒ Individual
Returns a new instance of Individual.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/finch-api/models/hris/individual.rb', line 15 def initialize( id: nil, dob: nil, emails: nil, encrypted_ssn: nil, ethnicity: nil, first_name: nil, gender: nil, last_name: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, ssn: nil, ** ) super end |
Instance Attribute Details
#dob ⇒ String?
20 |
# File 'lib/finch-api/models/hris/individual.rb', line 20 optional :dob, String, nil?: true |
#emails ⇒ Array<FinchAPI::Models::HRIS::Individual::Email>?
25 |
# File 'lib/finch-api/models/hris/individual.rb', line 25 optional :emails, -> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::Individual::Email] }, nil?: true |
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format. This field is
only available with the `ssn` scope enabled and the
`options: { include: ['ssn'] }` param set in the body.
33 |
# File 'lib/finch-api/models/hris/individual.rb', line 33 optional :encrypted_ssn, String, nil?: true |
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
39 |
# File 'lib/finch-api/models/hris/individual.rb', line 39 optional :ethnicity, enum: -> { FinchAPI::Models::HRIS::Individual::Ethnicity }, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
45 |
# File 'lib/finch-api/models/hris/individual.rb', line 45 optional :first_name, String, nil?: true |
#gender ⇒ Symbol, ...
The gender of the individual.
51 |
# File 'lib/finch-api/models/hris/individual.rb', line 51 optional :gender, enum: -> { FinchAPI::Models::HRIS::Individual::Gender }, nil?: true |
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
11 |
# File 'lib/finch-api/models/hris/individual.rb', line 11 optional :id, String |
#last_name ⇒ String?
The legal last name of the individual.
57 |
# File 'lib/finch-api/models/hris/individual.rb', line 57 optional :last_name, String, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
63 |
# File 'lib/finch-api/models/hris/individual.rb', line 63 optional :middle_name, String, nil?: true |
#phone_numbers ⇒ Array<FinchAPI::Models::HRIS::Individual::PhoneNumber, nil>?
68 69 70 |
# File 'lib/finch-api/models/hris/individual.rb', line 68 optional :phone_numbers, -> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::Individual::PhoneNumber, nil?: true] }, nil?: true |
#preferred_name ⇒ String?
The preferred name of the individual.
76 |
# File 'lib/finch-api/models/hris/individual.rb', line 76 optional :preferred_name, String, nil?: true |
#residence ⇒ FinchAPI::Models::Location?
81 |
# File 'lib/finch-api/models/hris/individual.rb', line 81 optional :residence, -> { FinchAPI::Models::Location }, nil?: true |
#ssn ⇒ String?
Social Security Number of the individual. This field is only available with the
`ssn` scope enabled and the `options: { include: ['ssn'] }` param set in the
body.
[Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).
90 |
# File 'lib/finch-api/models/hris/individual.rb', line 90 optional :ssn, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/hris/individual.rb', line 2 def self.values; end |