Class: FinchAPI::Models::HRIS::IndividualInDirectory
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::IndividualInDirectory
- Defined in:
- lib/finch_api/models/hris/individual_in_directory.rb,
sig/finch_api/models/hris/individual_in_directory.rbs
Overview
Defined Under Namespace
Classes: Department, Manager
Instance Attribute Summary collapse
-
#department ⇒ FinchAPI::Models::HRIS::IndividualInDirectory::Department?
The department object.
-
#first_name ⇒ String?
The legal first name of the individual.
-
#id ⇒ String
A stable Finch
id(UUID v4) for an individual in the company. -
#is_active ⇒ Boolean?
trueif the individual is an active employee or contractor at the company. -
#last_name ⇒ String?
The legal last name of the individual.
-
#manager ⇒ FinchAPI::Models::HRIS::IndividualInDirectory::Manager?
The manager object.
-
#middle_name ⇒ String?
The legal middle name of the individual.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The department object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/hris/individual_in_directory.rb', line 50
|
Instance Attribute Details
#department ⇒ FinchAPI::Models::HRIS::IndividualInDirectory::Department?
The department object.
18 |
# File 'lib/finch_api/models/hris/individual_in_directory.rb', line 18 required :department, -> { FinchAPI::HRIS::IndividualInDirectory::Department }, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
24 |
# File 'lib/finch_api/models/hris/individual_in_directory.rb', line 24 required :first_name, String, nil?: true |
#id ⇒ String
A stable Finch id (UUID v4) for an individual in the company.
12 |
# File 'lib/finch_api/models/hris/individual_in_directory.rb', line 12 required :id, String |
#is_active ⇒ Boolean?
true if the individual is an active employee or contractor at the company.
30 |
# File 'lib/finch_api/models/hris/individual_in_directory.rb', line 30 required :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
36 |
# File 'lib/finch_api/models/hris/individual_in_directory.rb', line 36 required :last_name, String, nil?: true |
#manager ⇒ FinchAPI::Models::HRIS::IndividualInDirectory::Manager?
The manager object.
42 |
# File 'lib/finch_api/models/hris/individual_in_directory.rb', line 42 required :manager, -> { FinchAPI::HRIS::IndividualInDirectory::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
48 |
# File 'lib/finch_api/models/hris/individual_in_directory.rb', line 48 required :middle_name, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/finch_api/models/hris/individual_in_directory.rbs', line 40
def to_hash: -> {
|