Class: FinchAPI::Models::HRIS::PayStatement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/pay_statement.rb

Defined Under Namespace

Modules: PaymentMethod, Type Classes: Earning, EmployeeDeduction, EmployerContribution, Tax

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see HRIS::PayStatement::EmployerContribution::Attributes::Metadata for more details.

Parameters:

  • metadata (Hash{Symbol=>Object, nil}) (defaults to: nil)

    The metadata to be attached to the entity by existing rules. It is a key-value p



# File 'lib/finch_api/models/hris/pay_statement.rb', line 276

Instance Attribute Details

#earningsArray<FinchAPI::HRIS::PayStatement::Earning, nil>?

The array of earnings objects associated with this pay statement

Returns:

  • (Array<FinchAPI::HRIS::PayStatement::Earning, nil>, nil)


11
12
13
# File 'lib/finch_api/models/hris/pay_statement.rb', line 11

optional :earnings,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::Earning, nil?: true] },
nil?: true

#employee_deductionsArray<FinchAPI::HRIS::PayStatement::EmployeeDeduction, nil>?

The array of deductions objects associated with this pay statement.

Returns:

  • (Array<FinchAPI::HRIS::PayStatement::EmployeeDeduction, nil>, nil)


19
20
21
22
23
24
# File 'lib/finch_api/models/hris/pay_statement.rb', line 19

optional :employee_deductions,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::EmployeeDeduction,
                                    nil?: true]
},
nil?: true

#employer_contributionsArray<FinchAPI::HRIS::PayStatement::EmployerContribution, nil>?

Returns:

  • (Array<FinchAPI::HRIS::PayStatement::EmployerContribution, nil>, nil)


29
30
31
32
33
34
# File 'lib/finch_api/models/hris/pay_statement.rb', line 29

optional :employer_contributions,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::EmployerContribution,
                                    nil?: true]
},
nil?: true

#gross_payFinchAPI::Money?

Returns:



39
# File 'lib/finch_api/models/hris/pay_statement.rb', line 39

optional :gross_pay, -> { FinchAPI::Money }, nil?: true

#individual_idString?

A stable Finch ‘id` (UUID v4) for an individual in the company

Returns:

  • (String, nil)


45
# File 'lib/finch_api/models/hris/pay_statement.rb', line 45

optional :individual_id, String

#net_payFinchAPI::Money?

Returns:



50
# File 'lib/finch_api/models/hris/pay_statement.rb', line 50

optional :net_pay, -> { FinchAPI::Money }, nil?: true

#payment_methodSymbol, ...

The payment method.

Returns:

  • (Symbol, FinchAPI::HRIS::PayStatement::PaymentMethod, nil)


56
# File 'lib/finch_api/models/hris/pay_statement.rb', line 56

optional :payment_method, enum: -> { FinchAPI::HRIS::PayStatement::PaymentMethod }, nil?: true

#taxesArray<FinchAPI::HRIS::PayStatement::Tax, nil>?

The array of taxes objects associated with this pay statement.

Returns:

  • (Array<FinchAPI::HRIS::PayStatement::Tax, nil>, nil)


62
63
64
# File 'lib/finch_api/models/hris/pay_statement.rb', line 62

optional :taxes,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::Tax, nil?: true] },
nil?: true

#total_hoursFloat?

The number of hours worked for this pay period

Returns:

  • (Float, nil)


70
# File 'lib/finch_api/models/hris/pay_statement.rb', line 70

optional :total_hours, Float, nil?: true

#typeSymbol, ...

The type of the payment associated with the pay statement.

Returns:

  • (Symbol, FinchAPI::HRIS::PayStatement::Type, nil)


76
# File 'lib/finch_api/models/hris/pay_statement.rb', line 76

optional :type, enum: -> { FinchAPI::HRIS::PayStatement::Type }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/pay_statement.rb', line 201