Class: FinchAPI::Models::HRIS::PayStatement::EmployeeDeduction::Attributes::Metadata

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/hris/pay_statement.rb

Overview

def initialize: (Hash | FinchAPI::BaseModel) -> void

Instance Attribute Summary collapse

Instance Attribute Details

#metadataHash{Symbol=>Object}? (readonly)

The metadata to be attached to the entity by existing rules. It is a key-value

pairs where the values can be of any type (string, number, boolean, object,
array, etc.).

Returns:

  • (Hash{Symbol=>Object}, nil)


294
# File 'lib/finch-api/models/hris/pay_statement.rb', line 294

optional :metadata, FinchAPI::HashOf[FinchAPI::Unknown]