Class: FinchAPI::Models::HRIS::PayStatement::EmployerContribution::Attributes

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/pay_statement.rb,
sig/finch_api/models/hris/pay_statement.rbs

Overview

See Also:

  • FinchAPI::Models::HRIS::PayStatement::EmployerContribution#attributes

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeAttributes

Returns a new instance of Attributes.

Parameters:

  • metadata: (::Hash[Symbol, top?])


245
# File 'sig/finch_api/models/hris/pay_statement.rbs', line 245

def initialize: (metadata: ::Hash[Symbol, top?]) -> void

Instance Attribute Details

#metadataHash{Symbol=>Object, nil}

The metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).

Parameters:

  • value (::Hash[Symbol, top?])

Returns:

  • (Hash{Symbol=>Object, nil})


313
314
# File 'lib/finch_api/models/hris/pay_statement.rb', line 313

required :metadata,
FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true]

Instance Method Details

#to_hash{ metadata: ::Hash[Symbol, top?] }

Returns:

  • ({ metadata: ::Hash[Symbol, top?] })


247
# File 'sig/finch_api/models/hris/pay_statement.rbs', line 247

def to_hash: -> { metadata: ::Hash[Symbol, top?] }