Class: FinchAPI::Models::HRIS::PayStatement::Tax::Attributes::Metadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/pay_statement.rb

Overview

See Also:

  • HRIS::PayStatement::Tax::Attributes#metadata

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#metadataHash{Symbol=>Object, nil}?

The metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).

Returns:

  • (Hash{Symbol=>Object, nil}, nil)


446
447
# File 'lib/finch_api/models/hris/pay_statement.rb', line 446

optional :metadata,
FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true]