Class: FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse
- Defined in:
- lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb
Overview
Defined Under Namespace
Modules: EntityType Classes: Attributes, Condition
Instance Attribute Summary collapse
-
#attributes ⇒ FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse::Attributes?
Specifies the fields to be applied when the condition is met.
- #conditions ⇒ Array<FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse::Condition>?
-
#created_at ⇒ Time?
The datetime when the rule was created.
-
#effective_end_date ⇒ String?
Specifies when the rules should stop applying rules based on the date.
-
#effective_start_date ⇒ String?
Specifies when the rule should begin applying based on the date.
-
#entity_type ⇒ Symbol, ...
The entity type to which the rule is applied.
-
#id ⇒ String?
Finch id (uuidv4) for the rule.
-
#priority ⇒ Integer?
The priority of the rule.
-
#updated_at ⇒ Time?
The datetime when the rule was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Attributes for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see Attributes for more details.
Specifies the fields to be applied when the condition is met.
|
|
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 64
|
Instance Attribute Details
#attributes ⇒ FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse::Attributes?
Specifies the fields to be applied when the condition is met.
19 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 19 optional :attributes, -> { FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse::Attributes } |
#conditions ⇒ Array<FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse::Condition>?
24 25 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 24 optional :conditions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse::Condition] } |
#created_at ⇒ Time?
The datetime when the rule was created.
31 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 31 optional :created_at, Time |
#effective_end_date ⇒ String?
Specifies when the rules should stop applying rules based on the date.
37 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 37 optional :effective_end_date, String, nil?: true |
#effective_start_date ⇒ String?
Specifies when the rule should begin applying based on the date.
43 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 43 optional :effective_start_date, String, nil?: true |
#entity_type ⇒ Symbol, ...
The entity type to which the rule is applied.
49 50 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 49 optional :entity_type, enum: -> { FinchAPI::Models::HRIS::PayStatementItem::RuleCreateResponse::EntityType } |
#id ⇒ String?
Finch id (uuidv4) for the rule.
13 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 13 optional :id, String |
#priority ⇒ Integer?
The priority of the rule.
56 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 56 optional :priority, Integer |
#updated_at ⇒ Time?
The datetime when the rule was last updated.
62 |
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 62 optional :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/pay_statement_item/rule_create_response.rb', line 137
|