Class: FinchAPI::Models::HRIS::PaymentListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/hris/payment_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(end_date: , start_date: , request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::PaymentListParams for more details.

Parameters:

  • end_date (Date) (defaults to: )

    The end date to retrieve payments by a company (inclusive) in ‘YYYY-MM-DD` forma

  • start_date (Date) (defaults to: )

    The start date to retrieve payments by a company (inclusive) in ‘YYYY-MM-DD` for

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/finch_api/models/hris/payment_list_params.rb', line 25

Instance Attribute Details

#end_dateDate

The end date to retrieve payments by a company (inclusive) in ‘YYYY-MM-DD` format.

Returns:

  • (Date)


16
# File 'lib/finch_api/models/hris/payment_list_params.rb', line 16

required :end_date, Date

#start_dateDate

The start date to retrieve payments by a company (inclusive) in ‘YYYY-MM-DD` format.

Returns:

  • (Date)


23
# File 'lib/finch_api/models/hris/payment_list_params.rb', line 23

required :start_date, Date