Class: FinchAPI::Models::HRIS::SupportedBenefit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/supported_benefit.rb,
sig/finch_api/models/hris/supported_benefit.rbs

Overview

See Also:

  • FinchAPI::Resources::HRIS::Benefits#list_supported_benefits

Defined Under Namespace

Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



30
# File 'sig/finch_api/models/hris/supported_benefit.rbs', line 30

def initialize: (

Instance Attribute Details

#annual_maximumBoolean?

Whether the provider supports an annual maximum for this benefit.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


12
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 12

required :annual_maximum, FinchAPI::Internal::Type::Boolean, nil?: true

#catch_upBoolean?

Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


55
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 55

optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true

#company_contributionArray<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::CompanyContribution, nil>?

Supported contribution types. An empty array indicates contributions are not supported.

Parameters:

  • value (::Array[FinchAPI::Models::HRIS::SupportedBenefit::company_contribution?], nil)

Returns:



19
20
21
22
23
24
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 19

required :company_contribution,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::CompanyContribution,
                                    nil?: true]
},
nil?: true

#descriptionString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


29
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 29

required :description, String, nil?: true

#employee_deductionArray<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::EmployeeDeduction, nil>?

Supported deduction types. An empty array indicates deductions are not supported.

Parameters:

  • value (::Array[FinchAPI::Models::HRIS::SupportedBenefit::employee_deduction?], nil)

Returns:



36
37
38
39
40
41
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 36

required :employee_deduction,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::EmployeeDeduction,
                                    nil?: true]
},
nil?: true

#frequenciesArray<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>

The list of frequencies supported by the provider for this benefit

Parameters:

  • value (::Array[FinchAPI::Models::HRIS::benefit_frequency?])

Returns:



47
48
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 47

required :frequencies,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFrequency, nil?: true] }

#hsa_contribution_limitArray<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::HsaContributionLimit, nil>?

Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.

Parameters:

  • value (::Array[FinchAPI::Models::HRIS::SupportedBenefit::hsa_contribution_limit?], nil)

Returns:



62
63
64
65
66
67
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 62

optional :hsa_contribution_limit,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::HsaContributionLimit,
                                    nil?: true]
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/supported_benefit.rb', line 94

Instance Method Details

#to_hash{

Returns:

  • ({)


40
# File 'sig/finch_api/models/hris/supported_benefit.rbs', line 40

def to_hash: -> {