Class: FinchAPI::Models::HRIS::W42005
- Defined in:
- lib/finch-api/models/hris/w42005.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#data ⇒ FinchAPI::Models::HRIS::W42005::Data?
Detailed information specific to the 2005 W4 form.
-
#type ⇒ Symbol, ...
Specifies the form type, indicating that this document is a 2005 W4 form.
-
#year ⇒ Float?
The tax year this W4 document applies to.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(data: nil, type: nil, year: nil) ⇒ W42005
constructor
A 2005 version of the W-4 tax form containing information on an individual’s filing status, dependents, and withholding details.
Constructor Details
#initialize(data: nil, type: nil, year: nil) ⇒ W42005
A 2005 version of the W-4 tax form containing information on an individual’s
filing status, dependents, and withholding details.
8 |
# File 'lib/finch-api/models/hris/w42005.rb', line 8 def initialize(data: nil, type: nil, year: nil, **) = super |
Instance Attribute Details
#data ⇒ FinchAPI::Models::HRIS::W42005::Data?
Detailed information specific to the 2005 W4 form.
11 |
# File 'lib/finch-api/models/hris/w42005.rb', line 11 optional :data, -> { FinchAPI::Models::HRIS::W42005::Data } |
#type ⇒ Symbol, ...
Specifies the form type, indicating that this document is a 2005 W4 form.
21 |
# File 'lib/finch-api/models/hris/w42005.rb', line 21 optional :type, enum: -> { FinchAPI::Models::HRIS::W42005::Type } |
#year ⇒ Float?
The tax year this W4 document applies to.
31 |
# File 'lib/finch-api/models/hris/w42005.rb', line 31 optional :year, Float, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/hris/w42005.rb', line 2 def self.values; end |