Class: FinchAPI::Models::HRIS::W42020
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::W42020
- Defined in:
- lib/finch_api/models/hris/w42020.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#data ⇒ FinchAPI::HRIS::W42020::Data?
Detailed information specific to the 2020 W4 form.
-
#type ⇒ Symbol, ...
Specifies the form type, indicating that this document is a 2020 W4 form.
-
#year ⇒ Float?
The tax year this W4 document applies to.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(data: nil, type: nil, year: nil) ⇒ Object
constructor
A 2020 version of the W-4 tax form containing information on an individual’s filing status, dependents, and withholding details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(data: nil, type: nil, year: nil) ⇒ Object
A 2020 version of the W-4 tax form containing information on an individual’s filing status, dependents, and withholding details.
|
|
# File 'lib/finch_api/models/hris/w42020.rb', line 25
|
Instance Attribute Details
#data ⇒ FinchAPI::HRIS::W42020::Data?
Detailed information specific to the 2020 W4 form.
11 |
# File 'lib/finch_api/models/hris/w42020.rb', line 11 optional :data, -> { FinchAPI::HRIS::W42020::Data } |
#type ⇒ Symbol, ...
Specifies the form type, indicating that this document is a 2020 W4 form.
17 |
# File 'lib/finch_api/models/hris/w42020.rb', line 17 optional :type, enum: -> { FinchAPI::HRIS::W42020::Type } |
#year ⇒ Float?
The tax year this W4 document applies to.
23 |
# File 'lib/finch_api/models/hris/w42020.rb', line 23 optional :year, Float, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/w42020.rb', line 119
|