Class: FinchAPI::Models::HRIS::W42020::Data

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/hris/w42020.rb

Overview

def initialize: (Hash | FinchAPI::BaseModel) -> void

Defined Under Namespace

Modules: FilingStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(amount_for_other_dependents: nil, amount_for_qualifying_children_under_17: nil, deductions: nil, extra_withholding: nil, filing_status: nil, individual_id: nil, other_income: nil, total_claim_dependent_and_other_credits: nil) ⇒ Data

Detailed information specific to the 2020 W4 form.

Parameters:

  • amount_for_other_dependents (Integer, nil) (defaults to: nil)
  • amount_for_qualifying_children_under_17 (Integer, nil) (defaults to: nil)
  • deductions (Integer, nil) (defaults to: nil)
  • extra_withholding (Integer, nil) (defaults to: nil)
  • filing_status (Symbol, FinchAPI::Models::HRIS::W42020::Data::FilingStatus, nil) (defaults to: nil)
  • individual_id (String) (defaults to: nil)
  • other_income (Integer, nil) (defaults to: nil)
  • total_claim_dependent_and_other_credits (Integer, nil) (defaults to: nil)


12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/finch-api/models/hris/w42020.rb', line 12

def initialize(
  amount_for_other_dependents: nil,
  amount_for_qualifying_children_under_17: nil,
  deductions: nil,
  extra_withholding: nil,
  filing_status: nil,
  individual_id: nil,
  other_income: nil,
  total_claim_dependent_and_other_credits: nil,
  **
)
  super
end

Instance Attribute Details

#amount_for_other_dependentsInteger?

Amount claimed for dependents other than qualifying children under 17 (in

cents).

Returns:

  • (Integer, nil)


51
# File 'lib/finch-api/models/hris/w42020.rb', line 51

optional :amount_for_other_dependents, Integer, nil?: true

#amount_for_qualifying_children_under_17Integer?

Amount claimed for dependents under 17 years old (in cents).

Returns:

  • (Integer, nil)


57
# File 'lib/finch-api/models/hris/w42020.rb', line 57

optional :amount_for_qualifying_children_under_17, Integer, nil?: true

#deductionsInteger?

Deductible expenses (in cents).

Returns:

  • (Integer, nil)


63
# File 'lib/finch-api/models/hris/w42020.rb', line 63

optional :deductions, Integer, nil?: true

#extra_withholdingInteger?

Additional withholding amount (in cents).

Returns:

  • (Integer, nil)


69
# File 'lib/finch-api/models/hris/w42020.rb', line 69

optional :extra_withholding, Integer, nil?: true

#filing_statusSymbol, ...

The individual’s filing status for tax purposes.



75
# File 'lib/finch-api/models/hris/w42020.rb', line 75

optional :filing_status, enum: -> { FinchAPI::Models::HRIS::W42020::Data::FilingStatus }, nil?: true

#individual_idString?

The unique identifier for the individual associated with this document.

Returns:

  • (String, nil)


81
# File 'lib/finch-api/models/hris/w42020.rb', line 81

optional :individual_id, String

#other_incomeInteger?

Additional income from sources outside of primary employment (in cents).

Returns:

  • (Integer, nil)


91
# File 'lib/finch-api/models/hris/w42020.rb', line 91

optional :other_income, Integer, nil?: true

#total_claim_dependent_and_other_creditsInteger?

Total amount claimed for dependents and other credits (in cents).

Returns:

  • (Integer, nil)


97
# File 'lib/finch-api/models/hris/w42020.rb', line 97

optional :total_claim_dependent_and_other_credits, Integer, nil?: true