Class: FinchAPI::Models::Introspection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Introspection
- Defined in:
- lib/finch_api/models/introspection.rb,
sig/finch_api/models/introspection.rbs
Overview
Defined Under Namespace
Modules: ClientType, ConnectionType Classes: AuthenticationMethod, ConnectionStatus, Entity
Instance Attribute Summary collapse
- #account_id ⇒ String? deprecated Deprecated.
- #authentication_methods ⇒ Array<FinchAPI::Models::Introspection::AuthenticationMethod>?
-
#client_id ⇒ String
The client ID of the application associated with the
access_token. -
#client_type ⇒ Symbol, FinchAPI::Models::Introspection::ClientType
The type of application associated with a token.
- #company_id ⇒ String? deprecated Deprecated.
-
#connection_id ⇒ String
The Finch UUID of the connection associated with the
access_token. - #connection_status ⇒ FinchAPI::Models::Introspection::ConnectionStatus
-
#connection_type ⇒ Symbol, FinchAPI::Models::Introspection::ConnectionType
The type of the connection associated with the token.
-
#customer_email ⇒ String?
The email of your customer you provided to Finch when a connect session was created for this connection.
-
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created for this connection.
-
#customer_name ⇒ String?
The name of your customer you provided to Finch when a connect session was created for this connection.
-
#entities ⇒ Array<FinchAPI::Models::Introspection::Entity>?
Array of detailed entity information for each connected account in multi-account mode.
-
#id ⇒ String
The Finch UUID of the token being introspected.
-
#manual ⇒ Boolean?
Whether the connection associated with the
access_tokenuses the Assisted Connect Flow. - #payroll_provider_id ⇒ String? deprecated Deprecated.
-
#products ⇒ Array<String>
An array of the authorized products associated with the
access_token. -
#provider_id ⇒ String
The ID of the provider associated with the
access_token. -
#username ⇒ String?
The account username used for login associated with the
access_token.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, client_id:, client_type:, connection_id:, connection_status:, connection_type:, products:, provider_id:, account_id: nil, authentication_methods: nil, company_id: nil, customer_email: nil, customer_id: nil, customer_name: nil, entities: nil, manual: nil, payroll_provider_id: nil, username: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Introspection for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, client_id:, client_type:, connection_id:, connection_status:, connection_type:, products:, provider_id:, account_id: nil, authentication_methods: nil, company_id: nil, customer_email: nil, customer_id: nil, customer_name: nil, entities: nil, manual: nil, payroll_provider_id: nil, username: nil) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::Introspection for more details.
|
|
# File 'lib/finch_api/models/introspection.rb', line 132
|
Instance Attribute Details
#account_id ⇒ String?
[DEPRECATED] Use connection_id to associate tokens with a Finch connection
instead of this account ID
64 |
# File 'lib/finch_api/models/introspection.rb', line 64 optional :account_id, String |
#authentication_methods ⇒ Array<FinchAPI::Models::Introspection::AuthenticationMethod>?
69 70 |
# File 'lib/finch_api/models/introspection.rb', line 69 optional :authentication_methods, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Introspection::AuthenticationMethod] } |
#client_id ⇒ String
The client ID of the application associated with the access_token
17 |
# File 'lib/finch_api/models/introspection.rb', line 17 required :client_id, String |
#client_type ⇒ Symbol, FinchAPI::Models::Introspection::ClientType
The type of application associated with a token.
23 |
# File 'lib/finch_api/models/introspection.rb', line 23 required :client_type, enum: -> { FinchAPI::Introspection::ClientType } |
#company_id ⇒ String?
[DEPRECATED] Use connection_id to associate tokens with a Finch connection
instead of this company ID
79 |
# File 'lib/finch_api/models/introspection.rb', line 79 optional :company_id, String |
#connection_id ⇒ String
The Finch UUID of the connection associated with the access_token
29 |
# File 'lib/finch_api/models/introspection.rb', line 29 required :connection_id, String |
#connection_status ⇒ FinchAPI::Models::Introspection::ConnectionStatus
34 |
# File 'lib/finch_api/models/introspection.rb', line 34 required :connection_status, -> { FinchAPI::Introspection::ConnectionStatus } |
#connection_type ⇒ Symbol, FinchAPI::Models::Introspection::ConnectionType
The type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
43 |
# File 'lib/finch_api/models/introspection.rb', line 43 required :connection_type, enum: -> { FinchAPI::Introspection::ConnectionType } |
#customer_email ⇒ String?
The email of your customer you provided to Finch when a connect session was created for this connection
86 |
# File 'lib/finch_api/models/introspection.rb', line 86 optional :customer_email, String, nil?: true |
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created for this connection
93 |
# File 'lib/finch_api/models/introspection.rb', line 93 optional :customer_id, String, nil?: true |
#customer_name ⇒ String?
The name of your customer you provided to Finch when a connect session was created for this connection
100 |
# File 'lib/finch_api/models/introspection.rb', line 100 optional :customer_name, String, nil?: true |
#entities ⇒ Array<FinchAPI::Models::Introspection::Entity>?
Array of detailed entity information for each connected account in multi-account mode
107 |
# File 'lib/finch_api/models/introspection.rb', line 107 optional :entities, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Introspection::Entity] } |
#id ⇒ String
The Finch UUID of the token being introspected
11 |
# File 'lib/finch_api/models/introspection.rb', line 11 required :id, String |
#manual ⇒ Boolean?
Whether the connection associated with the access_token uses the Assisted
Connect Flow. (true if using Assisted Connect, false if connection is
automated)
115 |
# File 'lib/finch_api/models/introspection.rb', line 115 optional :manual, FinchAPI::Internal::Type::Boolean |
#payroll_provider_id ⇒ String?
[DEPRECATED] Use provider_id to identify the provider instead of this payroll
provider ID.
124 |
# File 'lib/finch_api/models/introspection.rb', line 124 optional :payroll_provider_id, String |
#products ⇒ Array<String>
An array of the authorized products associated with the access_token.
49 |
# File 'lib/finch_api/models/introspection.rb', line 49 required :products, FinchAPI::Internal::Type::ArrayOf[String] |
#provider_id ⇒ String
The ID of the provider associated with the access_token.
55 |
# File 'lib/finch_api/models/introspection.rb', line 55 required :provider_id, String |
#username ⇒ String?
The account username used for login associated with the access_token.
130 |
# File 'lib/finch_api/models/introspection.rb', line 130 optional :username, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/introspection.rb', line 182
|
.variants ⇒ Array(Time, String)
|
|
# File 'lib/finch_api/models/introspection.rb', line 223
|
Instance Method Details
#to_hash ⇒ {
99 |
# File 'sig/finch_api/models/introspection.rbs', line 99
def to_hash: -> {
|