Class: FinchAPI::Models::Introspection::AuthenticationMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/introspection.rb

Defined Under Namespace

Modules: Type Classes: ConnectionStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

#initialize(message: nil, status: nil) ⇒ Object

Parameters:



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/finch_api/models/introspection.rb', line 170

class AuthenticationMethod < FinchAPI::Internal::Type::BaseModel
  # @!attribute connection_status
  #
  #   @return [FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus, nil]
  optional :connection_status,
           -> { FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus }

  # @!attribute products
  #   An array of the authorized products associated with the `access_token`.
  #
  #   @return [Array<String>, nil]
  optional :products, FinchAPI::Internal::Type::ArrayOf[String]

  # @!attribute type
  #   The type of authentication method.
  #
  #   @return [Symbol, FinchAPI::Models::Introspection::AuthenticationMethod::Type, nil]
  optional :type, enum: -> { FinchAPI::Models::Introspection::AuthenticationMethod::Type }

  # @!method initialize(connection_status: nil, products: nil, type: nil)
  #   @param connection_status [FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus]
  #
  #   @param products [Array<String>] An array of the authorized products associated with the `access_token`.
  #
  #   @param type [Symbol, FinchAPI::Models::Introspection::AuthenticationMethod::Type] The type of authentication method.

  # @see FinchAPI::Models::Introspection::AuthenticationMethod#connection_status
  class ConnectionStatus < FinchAPI::Internal::Type::BaseModel
    # @!attribute message
    #
    #   @return [String, nil]
    optional :message, String

    # @!attribute status
    #
    #   @return [Symbol, FinchAPI::Models::ConnectionStatusType, nil]
    optional :status, enum: -> { FinchAPI::Models::ConnectionStatusType }

    # @!method initialize(message: nil, status: nil)
    #   @param message [String]
    #   @param status [Symbol, FinchAPI::Models::ConnectionStatusType]
  end

  # The type of authentication method.
  #
  # @see FinchAPI::Models::Introspection::AuthenticationMethod#type
  module Type
    extend FinchAPI::Internal::Type::Enum

    ASSISTED = :assisted
    CREDENTIAL = :credential
    API_TOKEN = :api_token
    API_CREDENTIAL = :api_credential
    OAUTH = :oauth

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#connection_statusFinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus?



174
175
# File 'lib/finch_api/models/introspection.rb', line 174

optional :connection_status,
-> { FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus }

#productsArray<String>?

An array of the authorized products associated with the ‘access_token`.

Returns:

  • (Array<String>, nil)


181
# File 'lib/finch_api/models/introspection.rb', line 181

optional :products, FinchAPI::Internal::Type::ArrayOf[String]

#typeSymbol, ...

The type of authentication method.



187
# File 'lib/finch_api/models/introspection.rb', line 187

optional :type, enum: -> { FinchAPI::Models::Introspection::AuthenticationMethod::Type }