Class: FinchAPI::Models::Introspection::ConnectionStatus
- Defined in:
- lib/finch-api/models/introspection.rb
Instance Attribute Summary collapse
-
#last_successful_sync ⇒ Time?
The datetime when the connection was last successfully synced.
- #message ⇒ String?
- #status ⇒ Symbol, ... readonly
Method Summary
Methods inherited from BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, #initialize, #inspect, known_fields, optional, required, #to_h
Methods included from Converter
#coerce, coerce, #dump, dump, type_info
Constructor Details
This class inherits a constructor from FinchAPI::BaseModel
Instance Attribute Details
#last_successful_sync ⇒ Time?
The datetime when the connection was last successfully synced.
260 |
# File 'lib/finch-api/models/introspection.rb', line 260 optional :last_successful_sync, Time |
#message ⇒ String?
269 |
# File 'lib/finch-api/models/introspection.rb', line 269 optional :message, String |
#status ⇒ Symbol, ... (readonly)
278 |
# File 'lib/finch-api/models/introspection.rb', line 278 optional :status, enum: -> { FinchAPI::Models::ConnectionStatusType } |