Class: FinchAPI::Models::JobCompletionEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/job_completion_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(data: nil, event_type: nil) ⇒ Object

Parameters:



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
# File 'lib/finch_api/models/job_completion_event.rb', line 20

class Data < FinchAPI::Internal::Type::BaseModel
  # @!attribute job_id
  #   The id of the job which has completed.
  #
  #   @return [String]
  required :job_id, String

  # @!attribute job_url
  #   The url to query the result of the job.
  #
  #   @return [String]
  required :job_url, String

  # @!method initialize(job_id:, job_url:)
  #   @param job_id [String] The id of the job which has completed.
  #
  #   @param job_url [String] The url to query the result of the job.
end

Instance Attribute Details

#job_idString

The id of the job which has completed.

Returns:

  • (String)


25
# File 'lib/finch_api/models/job_completion_event.rb', line 25

required :job_id, String

#job_urlString

The url to query the result of the job.

Returns:

  • (String)


31
# File 'lib/finch_api/models/job_completion_event.rb', line 31

required :job_url, String