Class: FinchAPI::Models::Jobs::AutomatedAsyncJob

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/jobs/automated_async_job.rb

Overview

Defined Under Namespace

Modules: Status, Type Classes: Params

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(individual_id: nil) ⇒ Object

The input parameters for the job.

Parameters:

  • individual_id (String) (defaults to: nil)

    The ID of the individual that the job was completed for.



# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 65

Instance Attribute Details

#completed_atTime?

The datetime the job completed.

Returns:

  • (Time, nil)


12
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 12

required :completed_at, Time, nil?: true

#created_atTime

The datetime when the job was created. for scheduled jobs, this will be the initial connection time. For ad-hoc jobs, this will be the time the creation request was received.

Returns:

  • (Time)


20
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 20

required :created_at, Time

#job_idString

The id of the job that has been created.

Returns:

  • (String)


26
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 26

required :job_id, String

#job_urlString

The url that can be used to retrieve the job status

Returns:

  • (String)


32
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 32

required :job_url, String

#paramsFinchAPI::Jobs::AutomatedAsyncJob::Params?

The input parameters for the job.

Returns:

  • (FinchAPI::Jobs::AutomatedAsyncJob::Params, nil)


38
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 38

required :params, -> { FinchAPI::Jobs::AutomatedAsyncJob::Params }, nil?: true

#scheduled_atTime?

The datetime a job is scheduled to be run. For scheduled jobs, this datetime can be in the future if the job has not yet been enqueued. For ad-hoc jobs, this field will be null.

Returns:

  • (Time, nil)


46
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 46

required :scheduled_at, Time, nil?: true

#started_atTime?

The datetime a job entered into the job queue.

Returns:

  • (Time, nil)


52
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 52

required :started_at, Time, nil?: true

#statusSymbol, FinchAPI::Jobs::AutomatedAsyncJob::Status

Returns:

  • (Symbol, FinchAPI::Jobs::AutomatedAsyncJob::Status)


57
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 57

required :status, enum: -> { FinchAPI::Jobs::AutomatedAsyncJob::Status }

#typeSymbol, FinchAPI::Jobs::AutomatedAsyncJob::Type

The type of automated job

Returns:

  • (Symbol, FinchAPI::Jobs::AutomatedAsyncJob::Type)


63
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 63

required :type, enum: -> { FinchAPI::Jobs::AutomatedAsyncJob::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 112