Class: FinchAPI::Models::Jobs::AutomatedAsyncJob::Params
- Defined in:
- lib/finch-api/models/jobs/automated_async_job.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Instance Attribute Summary collapse
-
#individual_id ⇒ String?
readonly
The ID of the individual that the job was completed for.
Instance Attribute Details
#individual_id ⇒ String? (readonly)
The ID of the individual that the job was completed for.
84 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 84 optional :individual_id, String |