Class: FinchAPI::Models::Jobs::AutomatedCreateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/jobs/automated_create_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allowed_refreshes:, job_id:, job_url:, remaining_refreshes:) ⇒ AutomatedCreateResponse

Returns a new instance of AutomatedCreateResponse.

Parameters:

  • allowed_refreshes (Integer)
  • job_id (String)
  • job_url (String)
  • remaining_refreshes (Integer)


6
# File 'lib/finch-api/models/jobs/automated_create_response.rb', line 6

def initialize(allowed_refreshes:, job_id:, job_url:, remaining_refreshes:, **) = super

Instance Attribute Details

#allowed_refreshesInteger

The number of allowed refreshes per hour (per hour, fixed window)

Returns:

  • (Integer)


11
# File 'lib/finch-api/models/jobs/automated_create_response.rb', line 11

required :allowed_refreshes, Integer

#job_idString

The id of the job that has been created.

Returns:

  • (String)


17
# File 'lib/finch-api/models/jobs/automated_create_response.rb', line 17

required :job_id, String

#job_urlString

The url that can be used to retrieve the job status

Returns:

  • (String)


23
# File 'lib/finch-api/models/jobs/automated_create_response.rb', line 23

required :job_url, String

#remaining_refreshesInteger

The number of remaining refreshes available (per hour, fixed window)

Returns:

  • (Integer)


29
# File 'lib/finch-api/models/jobs/automated_create_response.rb', line 29

required :remaining_refreshes, Integer