Class: FinchAPI::Models::Jobs::AutomatedListResponse::Meta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Jobs::AutomatedListResponse::Meta
- Defined in:
- lib/finch_api/models/jobs/automated_list_response.rb
Overview
Defined Under Namespace
Classes: Quotas
Instance Attribute Summary collapse
-
#quotas ⇒ FinchAPI::Models::Jobs::AutomatedListResponse::Meta::Quotas?
Information about remaining quotas for this connection.
Instance Method Summary collapse
-
#initialize(quotas: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Meta for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(quotas: nil) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::Jobs::AutomatedListResponse::Meta for more details.
|
|
# File 'lib/finch_api/models/jobs/automated_list_response.rb', line 33
|
Instance Attribute Details
#quotas ⇒ FinchAPI::Models::Jobs::AutomatedListResponse::Meta::Quotas?
Information about remaining quotas for this connection. Only applicable for customers opted in to use Finch’s Data Sync Refresh endpoint (‘POST /jobs/automated`). Please contact a Finch representative for more details.
31 |
# File 'lib/finch_api/models/jobs/automated_list_response.rb', line 31 optional :quotas, -> { FinchAPI::Models::Jobs::AutomatedListResponse::Meta::Quotas } |