Module: FinchAPI::Models::OperationSupport

Extended by:
Internal::Type::Enum
Defined in:
lib/finch_api/models/operation_support.rb,
sig/finch_api/models/operation_support.rbs

Overview

  • supported: This operation is supported by both the provider and Finch
  • not_supported_by_finch: This operation is not supported by Finch but supported by the provider
  • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support
  • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch

Constant Summary collapse

SUPPORTED =

Returns:

  • (:supported)
:supported
NOT_SUPPORTED_BY_FINCH =

Returns:

  • (:not_supported_by_finch)
:not_supported_by_finch
NOT_SUPPORTED_BY_PROVIDER =

Returns:

  • (:not_supported_by_provider)
:not_supported_by_provider
CLIENT_ACCESS_ONLY =

Returns:

  • (:client_access_only)
:client_access_only

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/operation_support.rb', line 20

Instance Method Details

#self?.values::Array[FinchAPI::Models::operation_support]

Returns:

  • (::Array[FinchAPI::Models::operation_support])


17
# File 'sig/finch_api/models/operation_support.rbs', line 17

def self?.values: -> ::Array[FinchAPI::Models::operation_support]