Class: FinchAPI::Models::Paging

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/paging.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(offset: , count: nil) ⇒ Object

Parameters:

  • offset (Integer) (defaults to: )

    The current start index of the returned list of elements

  • count (Integer) (defaults to: nil)

    The total number of elements for the entire query (not just the given page)



# File 'lib/finch_api/models/paging.rb', line 18

Instance Attribute Details

#countInteger?

The total number of elements for the entire query (not just the given page)

Returns:

  • (Integer, nil)


16
# File 'lib/finch_api/models/paging.rb', line 16

optional :count, Integer

#offsetInteger

The current start index of the returned list of elements

Returns:

  • (Integer)


10
# File 'lib/finch_api/models/paging.rb', line 10

required :offset, Integer