Class: FinchAPI::Models::PayStatementEvent::Data

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/pay_statement_event.rb

Overview

def initialize: (Hash | FinchAPI::BaseModel) -> void

Instance Attribute Summary collapse

Method Summary

Methods inherited from BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, #initialize, #inspect, known_fields, optional, required, #to_h

Methods included from Converter

#coerce, coerce, #dump, dump, type_info

Constructor Details

This class inherits a constructor from FinchAPI::BaseModel

Instance Attribute Details

#individual_idString?

The ID of the individual associated with the pay statement.

Returns:

  • (String, nil)


37
# File 'lib/finch-api/models/pay_statement_event.rb', line 37

optional :individual_id, String

#payment_idString? (readonly)

The ID of the payment associated with the pay statement.

Returns:

  • (String, nil)


47
# File 'lib/finch-api/models/pay_statement_event.rb', line 47

optional :payment_id, String