Class: FinchAPI::Models::Payroll::PayGroupListResponse
- Defined in:
- lib/finch-api/models/payroll/pay_group_list_response.rb
Defined Under Namespace
Modules: PayFrequency
Instance Attribute Summary collapse
-
#id ⇒ String?
Finch id (uuidv4) for the pay group.
-
#name ⇒ String?
Name of the pay group.
-
#pay_frequencies ⇒ Array<Symbol, FinchAPI::Models::Payroll::PayGroupListResponse::PayFrequency>?
List of pay frequencies associated with this pay group.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, pay_frequencies: nil) ⇒ PayGroupListResponse
constructor
A new instance of PayGroupListResponse.
Constructor Details
#initialize(id: nil, name: nil, pay_frequencies: nil) ⇒ PayGroupListResponse
Returns a new instance of PayGroupListResponse.
5 |
# File 'lib/finch-api/models/payroll/pay_group_list_response.rb', line 5 def initialize(id: nil, name: nil, pay_frequencies: nil, **) = super |
Instance Attribute Details
#id ⇒ String?
Finch id (uuidv4) for the pay group
11 |
# File 'lib/finch-api/models/payroll/pay_group_list_response.rb', line 11 optional :id, String |
#name ⇒ String?
Name of the pay group
21 |
# File 'lib/finch-api/models/payroll/pay_group_list_response.rb', line 21 optional :name, String |
#pay_frequencies ⇒ Array<Symbol, FinchAPI::Models::Payroll::PayGroupListResponse::PayFrequency>?
List of pay frequencies associated with this pay group
31 32 |
# File 'lib/finch-api/models/payroll/pay_group_list_response.rb', line 31 optional :pay_frequencies, -> { FinchAPI::ArrayOf[enum: FinchAPI::Models::Payroll::PayGroupListResponse::PayFrequency] } |