Class: FinchAPI::Models::Payroll::PayGroupRetrieveResponse
- Defined in:
- lib/finch-api/models/payroll/pay_group_retrieve_response.rb
Defined Under Namespace
Modules: PayFrequency
Instance Attribute Summary collapse
-
#id ⇒ String
Finch id (uuidv4) for the pay group.
- #individual_ids ⇒ Array<String>
-
#name ⇒ String
Name of the pay group.
-
#pay_frequencies ⇒ Array<Symbol, FinchAPI::Models::Payroll::PayGroupRetrieveResponse::PayFrequency>
List of pay frequencies associated with this pay group.
Instance Method Summary collapse
-
#initialize(id:, individual_ids:, name:, pay_frequencies:) ⇒ PayGroupRetrieveResponse
constructor
A new instance of PayGroupRetrieveResponse.
Constructor Details
#initialize(id:, individual_ids:, name:, pay_frequencies:) ⇒ PayGroupRetrieveResponse
Returns a new instance of PayGroupRetrieveResponse.
6 |
# File 'lib/finch-api/models/payroll/pay_group_retrieve_response.rb', line 6 def initialize(id:, individual_ids:, name:, pay_frequencies:, **) = super |
Instance Attribute Details
#id ⇒ String
Finch id (uuidv4) for the pay group
11 |
# File 'lib/finch-api/models/payroll/pay_group_retrieve_response.rb', line 11 required :id, String |
#individual_ids ⇒ Array<String>
16 |
# File 'lib/finch-api/models/payroll/pay_group_retrieve_response.rb', line 16 required :individual_ids, FinchAPI::ArrayOf[String] |
#name ⇒ String
Name of the pay group
22 |
# File 'lib/finch-api/models/payroll/pay_group_retrieve_response.rb', line 22 required :name, String |
#pay_frequencies ⇒ Array<Symbol, FinchAPI::Models::Payroll::PayGroupRetrieveResponse::PayFrequency>
List of pay frequencies associated with this pay group
28 29 |
# File 'lib/finch-api/models/payroll/pay_group_retrieve_response.rb', line 28 required :pay_frequencies, -> { FinchAPI::ArrayOf[enum: FinchAPI::Models::Payroll::PayGroupRetrieveResponse::PayFrequency] } |