Class: FinchAPI::Models::Provider

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/provider.rb,
sig/finch_api/models/provider.rbs

Defined Under Namespace

Classes: AuthenticationMethod

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



54
# File 'sig/finch_api/models/provider.rbs', line 54

def initialize: (

Instance Attribute Details

#authentication_methodsArray<FinchAPI::Models::Provider::AuthenticationMethod>?

The authentication methods supported by the provider.



28
29
# File 'lib/finch_api/models/provider.rb', line 28

optional :authentication_methods,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Provider::AuthenticationMethod] }

#betaBoolean?

true if the integration is in a beta state, false otherwise

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


35
# File 'lib/finch_api/models/provider.rb', line 35

optional :beta, FinchAPI::Internal::Type::Boolean

#display_nameString

The display name of the payroll provider.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/finch_api/models/provider.rb', line 16

required :display_name, String

#iconString?

The url to the official icon of the payroll provider.

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/finch_api/models/provider.rb', line 41

optional :icon, String

#idString

The id of the payroll provider used in Connect.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/finch_api/models/provider.rb', line 10

required :id, String

#logoString?

The url to the official logo of the payroll provider.

Parameters:

  • (String)

Returns:

  • (String, nil)


47
# File 'lib/finch_api/models/provider.rb', line 47

optional :logo, String

#manualBoolean?

Deprecated.

[DEPRECATED] Whether the Finch integration with this provider uses the Assisted Connect Flow by default. This field is now deprecated. Please check for a type of assisted in the authentication_methods field instead.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


57
# File 'lib/finch_api/models/provider.rb', line 57

optional :manual, FinchAPI::Internal::Type::Boolean

#mfa_requiredBoolean?

whether MFA is required for the provider.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


63
# File 'lib/finch_api/models/provider.rb', line 63

optional :mfa_required, FinchAPI::Internal::Type::Boolean

#primary_colorString?

The hex code for the primary color of the payroll provider.

Parameters:

  • (String)

Returns:

  • (String, nil)


69
# File 'lib/finch_api/models/provider.rb', line 69

optional :primary_color, String

#productsArray<String>

The list of Finch products supported on this payroll provider.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


22
# File 'lib/finch_api/models/provider.rb', line 22

required :products, FinchAPI::Internal::Type::ArrayOf[String]

Instance Method Details

#to_hash{

Returns:

  • ({)


67
# File 'sig/finch_api/models/provider.rbs', line 67

def to_hash: -> {