Class: FinchAPI::Models::ProviderListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/provider_list_response.rb

Overview

Defined Under Namespace

Classes: AuthenticationMethod

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#authentication_methodsArray<FinchAPI::Models::ProviderListResponse::AuthenticationMethod>?

The authentication methods supported by the provider.



29
30
# File 'lib/finch_api/models/provider_list_response.rb', line 29

optional :authentication_methods,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::ProviderListResponse::AuthenticationMethod] }

#betaBoolean?

‘true` if the integration is in a beta state, `false` otherwise

Returns:

  • (Boolean, nil)


36
# File 'lib/finch_api/models/provider_list_response.rb', line 36

optional :beta, FinchAPI::Internal::Type::Boolean

#display_nameString

The display name of the payroll provider.

Returns:

  • (String)


17
# File 'lib/finch_api/models/provider_list_response.rb', line 17

required :display_name, String

#iconString?

The url to the official icon of the payroll provider.

Returns:

  • (String, nil)


42
# File 'lib/finch_api/models/provider_list_response.rb', line 42

optional :icon, String

#idString

The id of the payroll provider used in Connect.

Returns:

  • (String)


11
# File 'lib/finch_api/models/provider_list_response.rb', line 11

required :id, String

#logoString?

The url to the official logo of the payroll provider.

Returns:

  • (String, nil)


48
# File 'lib/finch_api/models/provider_list_response.rb', line 48

optional :logo, String

#manualBoolean?

Deprecated.
DEPRECATED

Whether the Finch integration with this provider uses the Assisted

Connect Flow by default. This field is now deprecated. Please check for a ‘type` of `assisted` in the `authentication_methods` field instead.

Returns:

  • (Boolean, nil)


58
# File 'lib/finch_api/models/provider_list_response.rb', line 58

optional :manual, FinchAPI::Internal::Type::Boolean

#mfa_requiredBoolean?

whether MFA is required for the provider.

Returns:

  • (Boolean, nil)


64
# File 'lib/finch_api/models/provider_list_response.rb', line 64

optional :mfa_required, FinchAPI::Internal::Type::Boolean

#primary_colorString?

The hex code for the primary color of the payroll provider.

Returns:

  • (String, nil)


70
# File 'lib/finch_api/models/provider_list_response.rb', line 70

optional :primary_color, String

#productsArray<String>

The list of Finch products supported on this payroll provider.

Returns:

  • (Array<String>)


23
# File 'lib/finch_api/models/provider_list_response.rb', line 23

required :products, FinchAPI::Internal::Type::ArrayOf[String]