Class: FinchAPI::Models::RequestForwardingForwardParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/request_forwarding_forward_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(method_: , route: , data: nil, headers: nil, params: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::RequestForwardingForwardParams for more details.

Parameters:

  • method_ (String) (defaults to: )

    The HTTP method for the forwarded request. Valid values include: ‘GET` , `POST`

  • route (String) (defaults to: )

    The URL route path for the forwarded request. This value must begin with a forwa

  • data (String, nil) (defaults to: nil)

    The body for the forwarded request. This value must be specified as either a str

  • headers (Object, nil) (defaults to: nil)

    The HTTP headers to include on the forwarded request. This value must be specifi

  • params (Object, nil) (defaults to: nil)

    The query parameters for the forwarded request. This value must be specified as

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 47

Instance Attribute Details

#dataString?

The body for the forwarded request. This value must be specified as either a string or a valid JSON object.

Returns:

  • (String, nil)


30
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 30

optional :data, String, nil?: true

#headersObject?

The HTTP headers to include on the forwarded request. This value must be specified as an object of key-value pairs. Example: ‘{“Content-Type”: “application/xml”, “X-API-Version”: “v1” }`

Returns:

  • (Object, nil)


38
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 38

optional :headers, FinchAPI::Internal::Type::Unknown, nil?: true

#method_String

The HTTP method for the forwarded request. Valid values include: ‘GET` , `POST` , `PUT` , `DELETE` , and `PATCH`.

Returns:

  • (String)


15
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 15

required :method_, String, api_name: :method

#paramsObject?

The query parameters for the forwarded request. This value must be specified as a valid JSON object rather than a query string.

Returns:

  • (Object, nil)


45
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 45

optional :params, FinchAPI::Internal::Type::Unknown, nil?: true

#routeString

The URL route path for the forwarded request. This value must begin with a forward-slash ( / ) and may only contain alphanumeric characters, hyphens, and underscores.

Returns:

  • (String)


23
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 23

required :route, String