Class: FinchAPI::Models::RequestForwardingForwardResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/request_forwarding_forward_response.rb

Overview

Defined Under Namespace

Classes: Request

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(data: , headers: , request: , status_code: ) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::RequestForwardingForwardResponse for more details.

Parameters:

  • data (String, nil) (defaults to: )

    A string representation of the HTTP response body of the forwarded request’s res

  • headers (Object, nil) (defaults to: )

    The HTTP headers of the forwarded request’s response, exactly as received from t

  • request (FinchAPI::Models::RequestForwardingForwardResponse::Request) (defaults to: )

    An object containing details of your original forwarded request, for your ease o

  • status_code (Integer) (defaults to: )

    The HTTP status code of the forwarded request’s response, exactly received from



# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 36

Instance Attribute Details

#dataString?

A string representation of the HTTP response body of the forwarded request’s response received from the underlying integration’s API. This field may be null in the case where the upstream system’s response is empty.

Returns:

  • (String, nil)


13
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 13

required :data, String, nil?: true

#headersObject?

The HTTP headers of the forwarded request’s response, exactly as received from the underlying integration’s API.

Returns:

  • (Object, nil)


20
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 20

required :headers, FinchAPI::Internal::Type::Unknown, nil?: true

#requestFinchAPI::Models::RequestForwardingForwardResponse::Request

An object containing details of your original forwarded request, for your ease of reference.



27
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 27

required :request, -> { FinchAPI::Models::RequestForwardingForwardResponse::Request }

#status_codeInteger

The HTTP status code of the forwarded request’s response, exactly received from the underlying integration’s API. This value will be returned as an integer.

Returns:

  • (Integer)


34
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 34

required :status_code, Integer, api_name: :statusCode