Class: FinchAPI::Models::RequestForwardingForwardResponse::Request

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/request_forwarding_forward_response.rb

Overview

def initialize: (Hash | FinchAPI::BaseModel) -> void

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data:, headers:, method_:, params:, route:) ⇒ Request

An object containing details of your original forwarded request, for your ease

of reference.

Parameters:

  • data (String, nil)
  • headers (Object, nil)
  • method_ (String)
  • params (Object, nil)
  • route (String)


10
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 10

def initialize(data:, headers:, method_:, params:, route:, **) = super

Instance Attribute Details

#dataString?

The body that was specified for the forwarded request. If a value was not

specified in the original request, this value will be returned as null ;
otherwise, this value will always be returned as a string.

Returns:

  • (String, nil)


52
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 52

required :data, String, nil?: true

#headersObject?

The specified HTTP headers that were included in the forwarded request. If no

headers were specified, this will be returned as `null`.

Returns:

  • (Object, nil)


59
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 59

required :headers, FinchAPI::Unknown, nil?: true

#method_String

The HTTP method that was specified for the forwarded request. Valid values

include: `GET` , `POST` , `PUT` , `DELETE` , and `PATCH`.

Returns:

  • (String)


66
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 66

required :method_, String, api_name: :method

#paramsObject?

The query parameters that were included in the forwarded request. If no query

parameters were specified, this will be returned as `null`.

Returns:

  • (Object, nil)


73
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 73

required :params, FinchAPI::Unknown, nil?: true

#routeString

The URL route path that was specified for the forwarded request.

Returns:

  • (String)


79
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 79

required :route, String