Class: FinchAPI::Models::Sandbox::CompanyUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/sandbox/company_update_params.rb

Overview

Defined Under Namespace

Classes: Account, Department, Entity

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

#initialize(name: nil) ⇒ Object

The parent department, if present.

Parameters:

  • name (String, nil) (defaults to: nil)

    The parent department’s name.



# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 177

Instance Attribute Details

#accountsArray<FinchAPI::Models::Sandbox::CompanyUpdateParams::Account>?

An array of bank account objects associated with the payroll/HRIS system.



15
16
17
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 15

required :accounts,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateParams::Account] },
nil?: true

#departmentsArray<FinchAPI::Models::Sandbox::CompanyUpdateParams::Department, nil>?

The array of company departments.



23
24
25
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 23

required :departments,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateParams::Department, nil?: true] },
nil?: true

#einString?

The employer identification number.

Returns:

  • (String, nil)


31
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 31

required :ein, String, nil?: true

#entityFinchAPI::Models::Sandbox::CompanyUpdateParams::Entity?

The entity type object.



37
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 37

required :entity, -> { FinchAPI::Models::Sandbox::CompanyUpdateParams::Entity }, nil?: true

The legal name of the company.

Returns:

  • (String, nil)


43
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 43

required :legal_name, String, nil?: true

#locationsArray<FinchAPI::Models::Location, nil>?

Returns:



48
49
50
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 48

required :locations,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Location, nil?: true] },
nil?: true

#primary_emailString?

The email of the main administrator on the account.

Returns:

  • (String, nil)


56
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 56

required :primary_email, String, nil?: true

#primary_phone_numberString?

The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g. ‘+NNNNNNNNNNN xExtension`

Returns:

  • (String, nil)


63
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 63

required :primary_phone_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 146