Class: FinchAPI::Models::Sandbox::CompanyUpdateParams::Account

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/company_update_params.rb

Defined Under Namespace

Modules: AccountType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(account_name: nil, account_number: nil, account_type: nil, institution_name: nil, routing_number: nil) ⇒ Object

Some parameter documentations has been truncated, see Sandbox::CompanyUpdateParams::Account for more details.

Parameters:

  • account_name (String, nil) (defaults to: nil)

    The name of the bank associated in the payroll/HRIS system.

  • account_number (String, nil) (defaults to: nil)

    10-12 digit number to specify the bank account

  • account_type (Symbol, FinchAPI::Sandbox::CompanyUpdateParams::Account::AccountType, nil) (defaults to: nil)

    The type of bank account.

  • institution_name (String, nil) (defaults to: nil)

    Name of the banking institution.

  • routing_number (String, nil) (defaults to: nil)

    A nine-digit code that’s based on the U.S. Bank location where your account was



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 92

class Account < FinchAPI::Internal::Type::BaseModel
  # @!attribute account_name
  #   The name of the bank associated in the payroll/HRIS system.
  #
  #   @return [String, nil]
  optional :account_name, String, nil?: true

  # @!attribute account_number
  #   10-12 digit number to specify the bank account
  #
  #   @return [String, nil]
  optional :account_number, String, nil?: true

  # @!attribute account_type
  #   The type of bank account.
  #
  #   @return [Symbol, FinchAPI::Sandbox::CompanyUpdateParams::Account::AccountType, nil]
  optional :account_type,
           enum: -> { FinchAPI::Sandbox::CompanyUpdateParams::Account::AccountType },
           nil?: true

  # @!attribute institution_name
  #   Name of the banking institution.
  #
  #   @return [String, nil]
  optional :institution_name, String, nil?: true

  # @!attribute routing_number
  #   A nine-digit code that's based on the U.S. Bank location where your account was
  #   opened.
  #
  #   @return [String, nil]
  optional :routing_number, String, nil?: true

  # @!method initialize(account_name: nil, account_number: nil, account_type: nil, institution_name: nil, routing_number: nil)
  #   Some parameter documentations has been truncated, see
  #   {FinchAPI::Sandbox::CompanyUpdateParams::Account} for more details.
  #
  #   @param account_name [String, nil] The name of the bank associated in the payroll/HRIS system.
  #
  #   @param account_number [String, nil] 10-12 digit number to specify the bank account
  #
  #   @param account_type [Symbol, FinchAPI::Sandbox::CompanyUpdateParams::Account::AccountType, nil] The type of bank account.
  #
  #   @param institution_name [String, nil] Name of the banking institution.
  #
  #   @param routing_number [String, nil] A nine-digit code that's based on the U.S. Bank location where your account was

  # The type of bank account.
  #
  # @see FinchAPI::Sandbox::CompanyUpdateParams::Account#account_type
  module AccountType
    extend FinchAPI::Internal::Type::Enum

    CHECKING = :checking
    SAVINGS = :savings

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#account_nameString?

The name of the bank associated in the payroll/HRIS system.

Returns:

  • (String, nil)


97
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 97

optional :account_name, String, nil?: true

#account_numberString?

10-12 digit number to specify the bank account

Returns:

  • (String, nil)


103
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 103

optional :account_number, String, nil?: true

#account_typeSymbol, ...

The type of bank account.

Returns:

  • (Symbol, FinchAPI::Sandbox::CompanyUpdateParams::Account::AccountType, nil)


109
110
111
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 109

optional :account_type,
enum: -> { FinchAPI::Sandbox::CompanyUpdateParams::Account::AccountType },
nil?: true

#institution_nameString?

Name of the banking institution.

Returns:

  • (String, nil)


117
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 117

optional :institution_name, String, nil?: true

#routing_numberString?

A nine-digit code that’s based on the U.S. Bank location where your account was opened.

Returns:

  • (String, nil)


124
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 124

optional :routing_number, String, nil?: true