Class: FinchAPI::Models::Sandbox::CompanyUpdateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/sandbox/company_update_response.rb

Defined Under Namespace

Classes: Account, Department, Entity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name: nil) ⇒ CompanyUpdateResponse

The parent department, if present.

Parameters:

  • name (String, nil) (defaults to: nil)


10
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 10

def initialize(accounts:, departments:, ein:, entity:, legal_name:, locations:, primary_email:, primary_phone_number:, **) = super

Instance Attribute Details

#accountsArray<FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account>?

An array of bank account objects associated with the payroll/HRIS system.



11
12
13
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 11

required :accounts,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account] },
nil?: true

#departmentsArray<FinchAPI::Models::Sandbox::CompanyUpdateResponse::Department, nil>?

The array of company departments.



19
20
21
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 19

required :departments,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateResponse::Department, nil?: true] },
nil?: true

#einString?

The employer identification number.

Returns:

  • (String, nil)


27
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 27

required :ein, String, nil?: true

#entityFinchAPI::Models::Sandbox::CompanyUpdateResponse::Entity?

The entity type object.



33
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 33

required :entity, -> { FinchAPI::Models::Sandbox::CompanyUpdateResponse::Entity }, nil?: true

The legal name of the company.

Returns:

  • (String, nil)


39
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 39

required :legal_name, String, nil?: true

#locationsArray<FinchAPI::Models::Location, nil>?

Returns:



44
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 44

required :locations, -> { FinchAPI::ArrayOf[FinchAPI::Models::Location, nil?: true] }, nil?: true

#primary_emailString?

The email of the main administrator on the account.

Returns:

  • (String, nil)


50
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 50

required :primary_email, String, nil?: true

#primary_phone_numberString?

The phone number of the main administrator on the account. Format: ‘XXXXXXXXXX`

Returns:

  • (String, nil)


56
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 56

required :primary_phone_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 2

def self.values; end