Class: FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/company_update_response.rb

Defined Under Namespace

Modules: AccountType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(account_name: nil, account_number: nil, account_type: nil, institution_name: nil, routing_number: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account for more details.

Parameters:

  • account_name (String, nil) (defaults to: nil)

    The name of the bank associated in the payroll/HRIS system.

  • account_number (String, nil) (defaults to: nil)

    10-12 digit number to specify the bank account

  • account_type (Symbol, FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account::AccountType, nil) (defaults to: nil)

    The type of bank account.

  • institution_name (String, nil) (defaults to: nil)

    Name of the banking institution.

  • routing_number (String, nil) (defaults to: nil)

    A nine-digit code that’s based on the U.S. Bank location where your account was



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 84

class Account < FinchAPI::Internal::Type::BaseModel
  # @!attribute account_name
  #   The name of the bank associated in the payroll/HRIS system.
  #
  #   @return [String, nil]
  optional :account_name, String, nil?: true

  # @!attribute account_number
  #   10-12 digit number to specify the bank account
  #
  #   @return [String, nil]
  optional :account_number, String, nil?: true

  # @!attribute account_type
  #   The type of bank account.
  #
  #   @return [Symbol, FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account::AccountType, nil]
  optional :account_type,
           enum: -> { FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account::AccountType },
           nil?: true

  # @!attribute institution_name
  #   Name of the banking institution.
  #
  #   @return [String, nil]
  optional :institution_name, String, nil?: true

  # @!attribute routing_number
  #   A nine-digit code that's based on the U.S. Bank location where your account was
  #   opened.
  #
  #   @return [String, nil]
  optional :routing_number, String, nil?: true

  # @!method initialize(account_name: nil, account_number: nil, account_type: nil, institution_name: nil, routing_number: nil)
  #   Some parameter documentations has been truncated, see
  #   {FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account} for more details.
  #
  #   @param account_name [String, nil] The name of the bank associated in the payroll/HRIS system.
  #
  #   @param account_number [String, nil] 10-12 digit number to specify the bank account
  #
  #   @param account_type [Symbol, FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account::AccountType, nil] The type of bank account.
  #
  #   @param institution_name [String, nil] Name of the banking institution.
  #
  #   @param routing_number [String, nil] A nine-digit code that's based on the U.S. Bank location where your account was

  # The type of bank account.
  #
  # @see FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account#account_type
  module AccountType
    extend FinchAPI::Internal::Type::Enum

    CHECKING = :checking
    SAVINGS = :savings

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#account_nameString?

The name of the bank associated in the payroll/HRIS system.

Returns:

  • (String, nil)


89
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 89

optional :account_name, String, nil?: true

#account_numberString?

10-12 digit number to specify the bank account

Returns:

  • (String, nil)


95
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 95

optional :account_number, String, nil?: true

#account_typeSymbol, ...

The type of bank account.



101
102
103
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 101

optional :account_type,
enum: -> { FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account::AccountType },
nil?: true

#institution_nameString?

Name of the banking institution.

Returns:

  • (String, nil)


109
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 109

optional :institution_name, String, nil?: true

#routing_numberString?

A nine-digit code that’s based on the U.S. Bank location where your account was opened.

Returns:

  • (String, nil)


116
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 116

optional :routing_number, String, nil?: true