Class: FinchAPI::Models::Sandbox::ConnectionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::ConnectionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/sandbox/connection_create_params.rb,
sig/finch_api/models/sandbox/connection_create_params.rbs
Overview
Defined Under Namespace
Modules: AuthenticationType
Instance Attribute Summary collapse
- #authentication_type ⇒ Symbol, ...
-
#employee_size ⇒ Integer?
Optional: the size of the employer to be created with this connection.
- #products ⇒ Array<String>?
-
#provider_id ⇒ String
The provider associated with the connection.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
33 |
# File 'sig/finch_api/models/sandbox/connection_create_params.rbs', line 33
def initialize: (
|
Instance Attribute Details
#authentication_type ⇒ Symbol, ...
20 |
# File 'lib/finch_api/models/sandbox/connection_create_params.rb', line 20 optional :authentication_type, enum: -> { FinchAPI::Sandbox::ConnectionCreateParams::AuthenticationType } |
#employee_size ⇒ Integer?
Optional: the size of the employer to be created with this connection. Defaults to 20. Note that if this is higher than 100, historical payroll data will not be generated, and instead only one pay period will be created.
28 |
# File 'lib/finch_api/models/sandbox/connection_create_params.rb', line 28 optional :employee_size, Integer |
#products ⇒ Array<String>?
33 |
# File 'lib/finch_api/models/sandbox/connection_create_params.rb', line 33 optional :products, FinchAPI::Internal::Type::ArrayOf[String] |
#provider_id ⇒ String
The provider associated with the connection
15 |
# File 'lib/finch_api/models/sandbox/connection_create_params.rb', line 15 required :provider_id, String |
Instance Method Details
#to_hash ⇒ {
41 |
# File 'sig/finch_api/models/sandbox/connection_create_params.rbs', line 41
def to_hash: -> {
|