Class: FinchAPI::Models::Sandbox::Connections::AccountCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/connections/account_create_response.rb,
sig/finch_api/models/sandbox/connections/account_create_response.rbs

Overview

See Also:

  • FinchAPI::Resources::Sandbox::Connections::Accounts#create

Defined Under Namespace

Modules: AuthenticationType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_token:, account_id:, authentication_type:, company_id:, connection_id:, entity_id:, products:, provider_id:) ⇒ Object

Parameters:

  • access_token (String)
  • account_id (String)

    [DEPRECATED] Use connection_id to associate a connection with an access token

  • authentication_type (Symbol, FinchAPI::Models::Sandbox::Connections::AccountCreateResponse::AuthenticationType)
  • company_id (String)

    [DEPRECATED] Use connection_id to associate a connection with an access token

  • connection_id (String)

    The ID of the new connection

  • entity_id (String)

    The ID of the entity for this connection

  • products (Array<String>)
  • provider_id (String)

    The ID of the provider associated with the access_token



# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 59

Instance Attribute Details

#access_tokenString

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 12

required :access_token, String

#account_idString

Deprecated.

[DEPRECATED] Use connection_id to associate a connection with an access token

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 20

required :account_id, String

#authentication_typeSymbol, FinchAPI::Models::Sandbox::Connections::AccountCreateResponse::AuthenticationType

Parameters:

  • value (FinchAPI::Models::Sandbox::Connections::AccountCreateResponse::authentication_type)

Returns:



25
26
# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 25

required :authentication_type,
enum: -> { FinchAPI::Models::Sandbox::Connections::AccountCreateResponse::AuthenticationType }

#company_idString

Deprecated.

[DEPRECATED] Use connection_id to associate a connection with an access token

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 34

required :company_id, String

#connection_idString

The ID of the new connection

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 40

required :connection_id, String

#entity_idString

The ID of the entity for this connection

Parameters:

  • value (String)

Returns:

  • (String)


46
# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 46

required :entity_id, String

#productsArray<String>

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


51
# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 51

required :products, FinchAPI::Internal::Type::ArrayOf[String]

#provider_idString

The ID of the provider associated with the access_token

Parameters:

  • value (String)

Returns:

  • (String)


57
# File 'lib/finch_api/models/sandbox/connections/account_create_response.rb', line 57

required :provider_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


45
# File 'sig/finch_api/models/sandbox/connections/account_create_response.rbs', line 45

def to_hash: -> {