Class: FinchAPI::Models::Sandbox::DirectoryCreateParams::Body
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::DirectoryCreateParams::Body
- Defined in:
- lib/finch_api/models/sandbox/directory_create_params.rb,
sig/finch_api/models/sandbox/directory_create_params.rbs
Defined Under Namespace
Modules: EmploymentStatus, Ethnicity, FlsaStatus, Gender, MaritalStatus Classes: CustomField, Department, Email, Employment, Manager, PhoneNumber
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker's compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department?
The department object.
- #dob ⇒ String?
- #emails ⇒ Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email>?
-
#employment ⇒ FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
-
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format.
- #end_date ⇒ String?
-
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
-
#first_name ⇒ String?
The legal first name of the individual.
-
#flsa_status ⇒ Symbol, ...
The FLSA status of the individual.
-
#gender ⇒ Symbol, ...
The gender of the individual.
-
#highly_compensated_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Highly Compensated Employee for nondiscrimination testing purposes (ADP/ACP tests).
-
#income ⇒ FinchAPI::Models::Income?
The employee's income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
trueif the individual an an active employee or contractor at the company. -
#key_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Key Employee for top-heavy testing purposes.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Models::Location?
-
#manager ⇒ FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Manager?
The manager object representing the manager of the individual within the org.
-
#marital_status ⇒ Symbol, ...
The employee's marital status, used for beneficiary designation and spousal consent workflows.
-
#middle_name ⇒ String?
The legal middle name of the individual.
- #phone_numbers ⇒ Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>?
-
#preferred_name ⇒ String?
The preferred name of the individual.
- #residence ⇒ FinchAPI::Models::Location?
-
#source_id ⇒ String?
The source system's unique employment identifier for this individual.
-
#ssn ⇒ String?
Social Security Number of the individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
-
#union_code ⇒ String?
The code identifying the union the employee is a member of, as configured in the payroll system.
-
#union_local ⇒ String?
The local chapter or local number within the employee's union.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ Object
constructor
The manager object representing the manager of the individual within the org.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil) ⇒ Object
The manager object representing the manager of the individual within the org.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 26 class Body < FinchAPI::Internal::Type::BaseModel # @!attribute class_code # Worker's compensation classification code for this employee # # @return [String, nil] optional :class_code, String, nil?: true # @!attribute custom_fields # Custom fields for the individual. These are fields which are defined by the # employer in the system. Custom fields are not currently supported for assisted # connections. # # @return [Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField>, nil] optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField] }, nil?: true # @!attribute department # The department object. # # @return [FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department, nil] optional :department, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Department }, nil?: true # @!attribute dob # # @return [String, nil] optional :dob, String, nil?: true # @!attribute emails # # @return [Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email>, nil] optional :emails, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::Email] }, nil?: true # @!attribute employment # The employment object. # # @return [FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment, nil] optional :employment, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment }, nil?: true # @!attribute employment_status # The detailed employment status of the individual. # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::EmploymentStatus, nil] optional :employment_status, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::EmploymentStatus }, nil?: true # @!attribute encrypted_ssn # Social Security Number of the individual in **encrypted** format. This field is # only available with the `ssn` scope enabled and the # `options: { include: ['ssn'] }` param set in the body. # # @return [String, nil] optional :encrypted_ssn, String, nil?: true # @!attribute end_date # # @return [String, nil] optional :end_date, String, nil?: true # @!attribute ethnicity # The EEOC-defined ethnicity of the individual. # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Ethnicity, nil] optional :ethnicity, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Ethnicity }, nil?: true # @!attribute first_name # The legal first name of the individual. # # @return [String, nil] optional :first_name, String, nil?: true # @!attribute flsa_status # The FLSA status of the individual. Available options: `exempt`, `non_exempt`, # `unknown`. # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::FlsaStatus, nil] optional :flsa_status, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::FlsaStatus }, nil?: true # @!attribute gender # The gender of the individual. # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Gender, nil] optional :gender, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Gender }, nil?: true # @!attribute highly_compensated_employee # IRS flag indicating whether the employee is classified as a Highly Compensated # Employee for nondiscrimination testing purposes (ADP/ACP tests). US-only. # # @return [Boolean, nil] optional :highly_compensated_employee, FinchAPI::Internal::Type::Boolean, nil?: true # @!attribute income # The employee's income as reported by the provider. This may not always be # annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, # depending on what information the provider returns. # # @return [FinchAPI::Models::Income, nil] optional :income, -> { FinchAPI::Income }, nil?: true # @!attribute income_history # The array of income history. # # @return [Array<FinchAPI::Models::Income, nil>, nil] optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true # @!attribute is_active # `true` if the individual an an active employee or contractor at the company. # # @return [Boolean, nil] optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true # @!attribute key_employee # IRS flag indicating whether the employee is classified as a Key Employee for # top-heavy testing purposes. US-only. # # @return [Boolean, nil] optional :key_employee, FinchAPI::Internal::Type::Boolean, nil?: true # @!attribute last_name # The legal last name of the individual. # # @return [String, nil] optional :last_name, String, nil?: true # @!attribute latest_rehire_date # # @return [String, nil] optional :latest_rehire_date, String, nil?: true # @!attribute location # # @return [FinchAPI::Models::Location, nil] optional :location, -> { FinchAPI::Location }, nil?: true # @!attribute manager # The manager object representing the manager of the individual within the org. # # @return [FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Manager, nil] optional :manager, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Manager }, nil?: true # @!attribute marital_status # The employee's marital status, used for beneficiary designation and spousal # consent workflows. # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::MaritalStatus, nil] optional :marital_status, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::MaritalStatus }, nil?: true # @!attribute middle_name # The legal middle name of the individual. # # @return [String, nil] optional :middle_name, String, nil?: true # @!attribute phone_numbers # # @return [Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>, nil] optional :phone_numbers, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil?: true] }, nil?: true # @!attribute preferred_name # The preferred name of the individual. # # @return [String, nil] optional :preferred_name, String, nil?: true # @!attribute residence # # @return [FinchAPI::Models::Location, nil] optional :residence, -> { FinchAPI::Location }, nil?: true # @!attribute source_id # The source system's unique employment identifier for this individual # # @return [String, nil] optional :source_id, String, nil?: true # @!attribute ssn # Social Security Number of the individual. This field is only available with the # `ssn` scope enabled and the `options: { include: ['ssn'] }` param set in the # body. # [Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field). # # @return [String, nil] optional :ssn, String, nil?: true # @!attribute start_date # # @return [String, nil] optional :start_date, String, nil?: true # @!attribute title # The current title of the individual. # # @return [String, nil] optional :title, String, nil?: true # @!attribute union_code # The code identifying the union the employee is a member of, as configured in the # payroll system. # # @return [String, nil] optional :union_code, String, nil?: true # @!attribute union_local # The local chapter or local number within the employee's union. # # @return [String, nil] optional :union_local, String, nil?: true # @!method initialize(class_code: nil, custom_fields: nil, department: nil, dob: nil, emails: nil, employment: nil, employment_status: nil, encrypted_ssn: nil, end_date: nil, ethnicity: nil, first_name: nil, flsa_status: nil, gender: nil, highly_compensated_employee: nil, income: nil, income_history: nil, is_active: nil, key_employee: nil, last_name: nil, latest_rehire_date: nil, location: nil, manager: nil, marital_status: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, source_id: nil, ssn: nil, start_date: nil, title: nil, union_code: nil, union_local: nil) # Some parameter documentations has been truncated, see # {FinchAPI::Models::Sandbox::DirectoryCreateParams::Body} for more details. # # @param class_code [String, nil] Worker's compensation classification code for this employee # # @param custom_fields [Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField>, nil] Custom fields for the individual. These are fields which are defined by the empl # # @param department [FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department, nil] The department object. # # @param dob [String, nil] # # @param emails [Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email>, nil] # # @param employment [FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment, nil] The employment object. # # @param employment_status [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::EmploymentStatus, nil] The detailed employment status of the individual. # # @param encrypted_ssn [String, nil] Social Security Number of the individual in **encrypted** format. This field is # # @param end_date [String, nil] # # @param ethnicity [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Ethnicity, nil] The EEOC-defined ethnicity of the individual. # # @param first_name [String, nil] The legal first name of the individual. # # @param flsa_status [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::FlsaStatus, nil] The FLSA status of the individual. Available options: `exempt`, `non_exempt`, `u # # @param gender [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Gender, nil] The gender of the individual. # # @param highly_compensated_employee [Boolean, nil] IRS flag indicating whether the employee is classified as a Highly Compensated E # # @param income [FinchAPI::Models::Income, nil] The employee's income as reported by the provider. This may not always be annual # # @param income_history [Array<FinchAPI::Models::Income, nil>, nil] The array of income history. # # @param is_active [Boolean, nil] `true` if the individual an an active employee or contractor at the company. # # @param key_employee [Boolean, nil] IRS flag indicating whether the employee is classified as a Key Employee for top # # @param last_name [String, nil] The legal last name of the individual. # # @param latest_rehire_date [String, nil] # # @param location [FinchAPI::Models::Location, nil] # # @param manager [FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Manager, nil] The manager object representing the manager of the individual within the org. # # @param marital_status [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::MaritalStatus, nil] The employee's marital status, used for beneficiary designation and spousal cons # # @param middle_name [String, nil] The legal middle name of the individual. # # @param phone_numbers [Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>, nil] # # @param preferred_name [String, nil] The preferred name of the individual. # # @param residence [FinchAPI::Models::Location, nil] # # @param source_id [String, nil] The source system's unique employment identifier for this individual # # @param ssn [String, nil] Social Security Number of the individual. This field is only available with the # # @param start_date [String, nil] # # @param title [String, nil] The current title of the individual. # # @param union_code [String, nil] The code identifying the union the employee is a member of, as configured in the # # @param union_local [String, nil] The local chapter or local number within the employee's union. class CustomField < FinchAPI::Internal::Type::BaseModel # @!attribute name # # @return [String, nil] optional :name, String, nil?: true # @!attribute value # # @return [String, Array<Object>, Object, Float, Boolean, nil] optional :value, union: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField::Value }, nil?: true # @!method initialize(name: nil, value: nil) # @param name [String, nil] # @param value [String, Array<Object>, Object, Float, Boolean, nil] # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField#value module Value extend FinchAPI::Internal::Type::Union variant String variant -> { FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField::Value::UnionMember1Array } variant FinchAPI::Internal::Type::Unknown variant Float variant FinchAPI::Internal::Type::Boolean # @!method self.variants # @return [Array(String, Array<Object>, Object, Float, Boolean)] # @type [FinchAPI::Internal::Type::Converter] UnionMember1Array = FinchAPI::Internal::Type::ArrayOf[FinchAPI::Internal::Type::Unknown] end end # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body#department class Department < FinchAPI::Internal::Type::BaseModel # @!attribute name # The name of the department associated with the individual. # # @return [String, nil] optional :name, String, nil?: true # @!method initialize(name: nil) # The department object. # # @param name [String, nil] The name of the department associated with the individual. end class Email < FinchAPI::Internal::Type::BaseModel # @!attribute data # # @return [String, nil] optional :data, String # @!attribute type # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email::Type, nil] optional :type, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Email::Type }, nil?: true # @!method initialize(data: nil, type: nil) # @param data [String] # @param type [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email::Type, nil] # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email#type module Type extend FinchAPI::Internal::Type::Enum WORK = :work PERSONAL = :personal # @!method self.values # @return [Array<Symbol>] end end # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body#employment class Employment < FinchAPI::Internal::Type::BaseModel # @!attribute subtype # The secondary employment type of the individual. Options: `full_time`, # `part_time`, `intern`, `temp`, `seasonal` and `individual_contractor`. # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment::Subtype, nil] optional :subtype, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment::Subtype }, nil?: true # @!attribute type # The main employment type of the individual. # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment::Type, nil] optional :type, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment::Type }, nil?: true # @!method initialize(subtype: nil, type: nil) # Some parameter documentations has been truncated, see # {FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment} for more # details. # # The employment object. # # @param subtype [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment::Subtype, nil] The secondary employment type of the individual. Options: `full_time`, `part_tim # # @param type [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment::Type, nil] The main employment type of the individual. # The secondary employment type of the individual. Options: `full_time`, # `part_time`, `intern`, `temp`, `seasonal` and `individual_contractor`. # # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment#subtype module Subtype extend FinchAPI::Internal::Type::Enum FULL_TIME = :full_time INTERN = :intern PART_TIME = :part_time TEMP = :temp SEASONAL = :seasonal INDIVIDUAL_CONTRACTOR = :individual_contractor # @!method self.values # @return [Array<Symbol>] end # The main employment type of the individual. # # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment#type module Type extend FinchAPI::Internal::Type::Enum EMPLOYEE = :employee CONTRACTOR = :contractor # @!method self.values # @return [Array<Symbol>] end end # The detailed employment status of the individual. # # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body#employment_status module EmploymentStatus extend FinchAPI::Internal::Type::Enum ACTIVE = :active DECEASED = :deceased LEAVE = :leave ONBOARDING = :onboarding PREHIRE = :prehire RETIRED = :retired TERMINATED = :terminated # @!method self.values # @return [Array<Symbol>] end # The EEOC-defined ethnicity of the individual. # # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body#ethnicity module Ethnicity extend FinchAPI::Internal::Type::Enum ASIAN = :asian WHITE = :white BLACK_OR_AFRICAN_AMERICAN = :black_or_african_american NATIVE_HAWAIIAN_OR_PACIFIC_ISLANDER = :native_hawaiian_or_pacific_islander AMERICAN_INDIAN_OR_ALASKA_NATIVE = :american_indian_or_alaska_native HISPANIC_OR_LATINO = :hispanic_or_latino TWO_OR_MORE_RACES = :two_or_more_races DECLINE_TO_SPECIFY = :decline_to_specify # @!method self.values # @return [Array<Symbol>] end # The FLSA status of the individual. Available options: `exempt`, `non_exempt`, # `unknown`. # # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body#flsa_status module FlsaStatus extend FinchAPI::Internal::Type::Enum EXEMPT = :exempt NON_EXEMPT = :non_exempt UNKNOWN = :unknown # @!method self.values # @return [Array<Symbol>] end # The gender of the individual. # # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body#gender module Gender extend FinchAPI::Internal::Type::Enum FEMALE = :female MALE = :male OTHER = :other DECLINE_TO_SPECIFY = :decline_to_specify # @!method self.values # @return [Array<Symbol>] end # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body#manager class Manager < FinchAPI::Internal::Type::BaseModel # @!attribute id # A stable Finch `id` (UUID v4) for an individual in the company. # # @return [String, nil] optional :id, String # @!method initialize(id: nil) # The manager object representing the manager of the individual within the org. # # @param id [String] A stable Finch `id` (UUID v4) for an individual in the company. end # The employee's marital status, used for beneficiary designation and spousal # consent workflows. # # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body#marital_status module MaritalStatus extend FinchAPI::Internal::Type::Enum SINGLE = :single MARRIED = :married DIVORCED = :divorced WIDOWED = :widowed DOMESTIC_PARTNER = :domestic_partner UNKNOWN = :unknown # @!method self.values # @return [Array<Symbol>] end class PhoneNumber < FinchAPI::Internal::Type::BaseModel # @!attribute data # # @return [String, nil] optional :data, String, nil?: true # @!attribute type # # @return [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber::Type, nil] optional :type, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber::Type }, nil?: true # @!method initialize(data: nil, type: nil) # @param data [String, nil] # @param type [Symbol, FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber::Type, nil] # @see FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber#type module Type extend FinchAPI::Internal::Type::Enum WORK = :work PERSONAL = :personal # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#class_code ⇒ String?
Worker's compensation classification code for this employee
31 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 31 optional :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
39 40 41 42 43 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 39 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField] }, nil?: true |
#department ⇒ FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department?
The department object.
49 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 49 optional :department, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Department }, nil?: true |
#dob ⇒ String?
54 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 54 optional :dob, String, nil?: true |
#emails ⇒ Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email>?
59 60 61 62 63 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 59 optional :emails, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::Email] }, nil?: true |
#employment ⇒ FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment?
The employment object.
69 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 69 optional :employment, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
75 76 77 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 75 optional :employment_status, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::EmploymentStatus }, nil?: true |
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format. This field is
only available with the ssn scope enabled and the
options: { include: ['ssn'] } param set in the body.
85 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 85 optional :encrypted_ssn, String, nil?: true |
#end_date ⇒ String?
90 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 90 optional :end_date, String, nil?: true |
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
96 97 98 99 100 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 96 optional :ethnicity, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Ethnicity }, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
106 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 106 optional :first_name, String, nil?: true |
#flsa_status ⇒ Symbol, ...
The FLSA status of the individual. Available options: exempt, non_exempt,
unknown.
113 114 115 116 117 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 113 optional :flsa_status, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::FlsaStatus }, nil?: true |
#gender ⇒ Symbol, ...
The gender of the individual.
123 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 123 optional :gender, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Gender }, nil?: true |
#highly_compensated_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Highly Compensated Employee for nondiscrimination testing purposes (ADP/ACP tests). US-only.
130 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 130 optional :highly_compensated_employee, FinchAPI::Internal::Type::Boolean, nil?: true |
#income ⇒ FinchAPI::Models::Income?
The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
138 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 138 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
144 145 146 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 144 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
true if the individual an an active employee or contractor at the company.
152 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 152 optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#key_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Key Employee for top-heavy testing purposes. US-only.
159 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 159 optional :key_employee, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
165 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 165 optional :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
170 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 170 optional :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Models::Location?
175 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 175 optional :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Manager?
The manager object representing the manager of the individual within the org.
181 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 181 optional :manager, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Manager }, nil?: true |
#marital_status ⇒ Symbol, ...
The employee's marital status, used for beneficiary designation and spousal consent workflows.
188 189 190 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 188 optional :marital_status, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::MaritalStatus }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
196 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 196 optional :middle_name, String, nil?: true |
#phone_numbers ⇒ Array<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>?
201 202 203 204 205 206 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 201 optional :phone_numbers, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil?: true] }, nil?: true |
#preferred_name ⇒ String?
The preferred name of the individual.
212 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 212 optional :preferred_name, String, nil?: true |
#residence ⇒ FinchAPI::Models::Location?
217 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 217 optional :residence, -> { FinchAPI::Location }, nil?: true |
#source_id ⇒ String?
The source system's unique employment identifier for this individual
223 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 223 optional :source_id, String, nil?: true |
#ssn ⇒ String?
Social Security Number of the individual. This field is only available with the
ssn scope enabled and the options: { include: ['ssn'] } param set in the
body.
Click here to learn more about enabling the SSN field.
232 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 232 optional :ssn, String, nil?: true |
#start_date ⇒ String?
237 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 237 optional :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
243 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 243 optional :title, String, nil?: true |
#union_code ⇒ String?
The code identifying the union the employee is a member of, as configured in the payroll system.
250 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 250 optional :union_code, String, nil?: true |
#union_local ⇒ String?
The local chapter or local number within the employee's union.
256 |
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 256 optional :union_local, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 407
|
Instance Method Details
#to_hash ⇒ {
168 |
# File 'sig/finch_api/models/sandbox/directory_create_params.rbs', line 168
def to_hash: -> {
|