Class: FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/directory_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(class_code: nil, custom_fields: nil, department: nil, dob: nil, emails: nil, employment: nil, employment_status: nil, encrypted_ssn: nil, end_date: nil, ethnicity: nil, first_name: nil, gender: nil, income: nil, income_history: nil, is_active: nil, last_name: nil, latest_rehire_date: nil, location: nil, manager: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, source_id: nil, ssn: nil, start_date: nil, title: nil) ⇒ Object

Some parameter documentations has been truncated, see Sandbox::DirectoryCreateParams::Body for more details.

Parameters:

  • class_code (String, nil) (defaults to: nil)

    Worker’s compensation classification code for this employee

  • custom_fields (Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField>, nil) (defaults to: nil)

    Custom fields for the individual. These are fields which are defined by the empl

  • department (FinchAPI::Sandbox::DirectoryCreateParams::Body::Department, nil) (defaults to: nil)

    The department object.

  • dob (String, nil) (defaults to: nil)
  • emails (Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::Email>, nil) (defaults to: nil)
  • employment (FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment, nil) (defaults to: nil)

    The employment object.

  • employment_status (Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::EmploymentStatus, nil) (defaults to: nil)

    The detailed employment status of the individual. Available options: ‘active`, `

  • encrypted_ssn (String, nil) (defaults to: nil)

    Social Security Number of the individual in encrypted format. This field is

  • end_date (String, nil) (defaults to: nil)
  • ethnicity (Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Ethnicity, nil) (defaults to: nil)

    The EEOC-defined ethnicity of the individual.

  • first_name (String, nil) (defaults to: nil)

    The legal first name of the individual.

  • gender (Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Gender, nil) (defaults to: nil)

    The gender of the individual.

  • income (FinchAPI::Income, nil) (defaults to: nil)

    The employee’s income as reported by the provider. This may not always be annual

  • income_history (Array<FinchAPI::Income, nil>, nil) (defaults to: nil)

    The array of income history.

  • is_active (Boolean, nil) (defaults to: nil)

    ‘true` if the individual an an active employee or contractor at the company.

  • last_name (String, nil) (defaults to: nil)

    The legal last name of the individual.

  • latest_rehire_date (String, nil) (defaults to: nil)
  • location (FinchAPI::Location, nil) (defaults to: nil)
  • manager (FinchAPI::Sandbox::DirectoryCreateParams::Body::Manager, nil) (defaults to: nil)

    The manager object representing the manager of the individual within the org.

  • middle_name (String, nil) (defaults to: nil)

    The legal middle name of the individual.

  • phone_numbers (Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>, nil) (defaults to: nil)
  • preferred_name (String, nil) (defaults to: nil)

    The preferred name of the individual.

  • residence (FinchAPI::Location, nil) (defaults to: nil)
  • source_id (String, nil) (defaults to: nil)

    The source system’s unique employment identifier for this individual

  • ssn (String, nil) (defaults to: nil)

    Social Security Number of the individual. This field is only available with the

  • start_date (String, nil) (defaults to: nil)
  • title (String, nil) (defaults to: nil)

    The current title of the individual.



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 273

class CustomField < FinchAPI::Internal::Type::BaseModel
  # @!attribute name
  #
  #   @return [String, nil]
  optional :name, String, nil?: true

  # @!attribute value
  #
  #   @return [Object, nil]
  optional :value, FinchAPI::Internal::Type::Unknown

  # @!method initialize(name: nil, value: nil)
  #   @param name [String, nil]
  #   @param value [Object]
end

Instance Attribute Details

#nameString?

Returns:

  • (String, nil)


277
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 277

optional :name, String, nil?: true

#valueObject?

Returns:

  • (Object, nil)


282
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 282

optional :value, FinchAPI::Internal::Type::Unknown