Class: FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department
- Inherits:
-
BaseModel
- Object
- BaseModel
- FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department
- Defined in:
- lib/finch-api/models/sandbox/directory_create_params.rb
Instance Attribute Summary collapse
-
#name ⇒ String?
The name of the department associated with the individual.
Method Summary
Methods inherited from BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, #initialize, #inspect, known_fields, optional, required, #to_h
Methods included from Converter
#coerce, coerce, #dump, dump, type_info
Constructor Details
This class inherits a constructor from FinchAPI::BaseModel
Instance Attribute Details
#name ⇒ String?
The name of the department associated with the individual.
308 |
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 308 optional :name, String, nil?: true |