Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department
- Defined in:
- lib/finch_api/models/sandbox/employment_update_params.rb,
sig/finch_api/models/sandbox/employment_update_params.rbs
Instance Attribute Summary collapse
-
#name ⇒ String?
The name of the department associated with the individual.
Instance Method Summary collapse
-
#initialize ⇒ Department
constructor
A new instance of Department.
- #to_hash ⇒ { name: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Department
Returns a new instance of Department.
158 |
# File 'sig/finch_api/models/sandbox/employment_update_params.rbs', line 158
def initialize: (?name: String?) -> void
|
Instance Attribute Details
#name ⇒ String?
The name of the department associated with the individual.
231 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 231 optional :name, String, nil?: true |
Instance Method Details
#to_hash ⇒ { name: String? }
160 |
# File 'sig/finch_api/models/sandbox/employment_update_params.rbs', line 160
def to_hash: -> { name: String? }
|