Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager
- Defined in:
- lib/finch_api/models/sandbox/employment_update_params.rb
Instance Attribute Summary collapse
-
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ Object
constructor
The manager object representing the manager of the individual within the org.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(id: nil) ⇒ Object
The manager object representing the manager of the individual within the org.
|
|
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 280
|
Instance Attribute Details
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
278 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 278 optional :id, String |