Class: FinchAPI::Models::Sandbox::EmploymentUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateResponse
- Defined in:
- lib/finch_api/models/sandbox/employment_update_response.rb,
sig/finch_api/models/sandbox/employment_update_response.rbs
Overview
Defined Under Namespace
Modules: EmploymentStatus, FlsaStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker's compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department?
The department object.
-
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#flsa_status ⇒ Symbol, ...
The FLSA status of the individual.
-
#highly_compensated_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Highly Compensated Employee for nondiscrimination testing purposes (ADP/ACP tests).
-
#id ⇒ String?
A stable Finch
id(UUID v4) for an individual in the company. -
#income ⇒ FinchAPI::Models::Income?
The employee's income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
trueif the individual an an active employee or contractor at the company. -
#key_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Key Employee for top-heavy testing purposes.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Models::Location?
-
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system's unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
-
#union_code ⇒ String?
The code identifying the union the employee is a member of, as configured in the payroll system.
-
#union_local ⇒ String?
The local chapter or local number within the employee's union.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The department object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 263
|
Instance Attribute Details
#class_code ⇒ String?
Worker's compensation classification code for this employee
18 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 18 optional :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
26 27 28 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 26 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField] }, nil?: true |
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department?
The department object.
34 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 34 optional :department, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department }, nil?: true |
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment?
The employment object.
40 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 40 optional :employment, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
46 47 48 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 46 optional :employment_status, enum: -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
53 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 53 optional :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
59 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 59 optional :first_name, String, nil?: true |
#flsa_status ⇒ Symbol, ...
The FLSA status of the individual. Available options: exempt, non_exempt,
unknown.
66 67 68 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 66 optional :flsa_status, enum: -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::FlsaStatus }, nil?: true |
#highly_compensated_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Highly Compensated Employee for nondiscrimination testing purposes (ADP/ACP tests). US-only.
75 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 75 optional :highly_compensated_employee, FinchAPI::Internal::Type::Boolean, nil?: true |
#id ⇒ String?
A stable Finch id (UUID v4) for an individual in the company.
12 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 12 optional :id, String |
#income ⇒ FinchAPI::Models::Income?
The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
83 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 83 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
89 90 91 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 89 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
true if the individual an an active employee or contractor at the company.
97 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 97 optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#key_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Key Employee for top-heavy testing purposes. US-only.
104 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 104 optional :key_employee, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
110 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 110 optional :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
115 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 115 optional :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Models::Location?
120 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 120 optional :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager?
The manager object representing the manager of the individual within the org.
126 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 126 optional :manager, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
132 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 132 optional :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system's unique employment identifier for this individual
138 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 138 optional :source_id, String, nil?: true |
#start_date ⇒ String?
143 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 143 optional :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
149 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 149 optional :title, String, nil?: true |
#union_code ⇒ String?
The code identifying the union the employee is a member of, as configured in the payroll system.
156 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 156 optional :union_code, String, nil?: true |
#union_local ⇒ String?
The local chapter or local number within the employee's union.
162 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 162 optional :union_local, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 326
|
Instance Method Details
#to_hash ⇒ {
110 |
# File 'sig/finch_api/models/sandbox/employment_update_response.rbs', line 110
def to_hash: -> {
|