Class: FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/employment_update_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(id: nil, class_code: nil, custom_fields: nil, department: nil, employment: nil, employment_status: nil, end_date: nil, first_name: nil, income: nil, income_history: nil, is_active: nil, last_name: nil, latest_rehire_date: nil, location: nil, manager: nil, middle_name: nil, source_id: nil, start_date: nil, title: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::Sandbox::EmploymentUpdateResponse for more details.

Parameters:

  • id (String) (defaults to: nil)

    A stable Finch ‘id` (UUID v4) for an individual in the company.

  • class_code (String, nil) (defaults to: nil)

    Worker’s compensation classification code for this employee

  • custom_fields (Array<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>, nil) (defaults to: nil)

    Custom fields for the individual. These are fields which are defined by the empl

  • department (FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department, nil) (defaults to: nil)

    The department object.

  • employment (FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment, nil) (defaults to: nil)

    The employment object.

  • employment_status (Symbol, FinchAPI::Models::Sandbox::EmploymentUpdateResponse::EmploymentStatus, nil) (defaults to: nil)

    The detailed employment status of the individual. Available options: ‘active`, `

  • end_date (String, nil) (defaults to: nil)
  • first_name (String, nil) (defaults to: nil)

    The legal first name of the individual.

  • income (FinchAPI::Income, nil) (defaults to: nil)

    The employee’s income as reported by the provider. This may not always be annual

  • income_history (Array<FinchAPI::Income, nil>, nil) (defaults to: nil)

    The array of income history.

  • is_active (Boolean, nil) (defaults to: nil)

    ‘true` if the individual an an active employee or contractor at the company.

  • last_name (String, nil) (defaults to: nil)

    The legal last name of the individual.

  • latest_rehire_date (String, nil) (defaults to: nil)
  • location (FinchAPI::Location, nil) (defaults to: nil)
  • manager (FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager, nil) (defaults to: nil)

    The manager object representing the manager of the individual within the org.

  • middle_name (String, nil) (defaults to: nil)

    The legal middle name of the individual.

  • source_id (String, nil) (defaults to: nil)

    The source system’s unique employment identifier for this individual

  • start_date (String, nil) (defaults to: nil)
  • title (String, nil) (defaults to: nil)

    The current title of the individual.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 171

class CustomField < FinchAPI::Internal::Type::BaseModel
  # @!attribute name
  #
  #   @return [String, nil]
  optional :name, String, nil?: true

  # @!attribute value
  #
  #   @return [Object, nil]
  optional :value, FinchAPI::Internal::Type::Unknown

  # @!method initialize(name: nil, value: nil)
  #   @param name [String, nil]
  #   @param value [Object]
end

Instance Attribute Details

#nameString?

Returns:

  • (String, nil)


175
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 175

optional :name, String, nil?: true

#valueObject?

Returns:

  • (Object, nil)


180
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 180

optional :value, FinchAPI::Internal::Type::Unknown