Class: FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department
- Inherits:
-
BaseModel
- Object
- BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department
- Defined in:
- lib/finch-api/models/sandbox/employment_update_response.rb
Instance Attribute Summary collapse
-
#name ⇒ String?
The name of the department associated with the individual.
Method Summary
Methods inherited from BaseModel
#==, #[], coerce, #deconstruct_keys, defaults, dump, fields, #initialize, #inspect, known_fields, optional, required, reverse_map, #to_h, #to_s, try_strict_coerce
Methods included from Converter
#coerce, coerce, #dump, dump, #try_strict_coerce, try_strict_coerce, type_info
Constructor Details
This class inherits a constructor from FinchAPI::BaseModel
Instance Attribute Details
#name ⇒ String?
The name of the department associated with the individual.
213 |
# File 'lib/finch-api/models/sandbox/employment_update_response.rb', line 213 optional :name, String, nil?: true |