Class: FinchAPI::Models::Sandbox::IndividualUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/sandbox/individual_update_params.rb

Overview

Defined Under Namespace

Modules: Ethnicity, Gender Classes: Email, PhoneNumber

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#dobString?

Returns:

  • (String, nil)


19
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 19

optional :dob, String, nil?: true

#emailsArray<FinchAPI::Models::Sandbox::IndividualUpdateParams::Email>?



24
25
26
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 24

optional :emails,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::IndividualUpdateParams::Email] },
nil?: true

#encrypted_ssnString?

Social Security Number of the individual in encrypted format. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body.

Returns:

  • (String, nil)


34
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 34

optional :encrypted_ssn, String, nil?: true

#ethnicitySymbol, ...

The EEOC-defined ethnicity of the individual.



40
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 40

optional :ethnicity, enum: -> { FinchAPI::Sandbox::IndividualUpdateParams::Ethnicity }, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


46
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 46

optional :first_name, String, nil?: true

#genderSymbol, ...

The gender of the individual.



52
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 52

optional :gender, enum: -> { FinchAPI::Sandbox::IndividualUpdateParams::Gender }, nil?: true

#individual_idString

Returns:

  • (String)


14
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 14

required :individual_id, String

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


58
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 58

optional :last_name, String, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


64
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 64

optional :middle_name, String, nil?: true

#phone_numbersArray<FinchAPI::Models::Sandbox::IndividualUpdateParams::PhoneNumber, nil>?



69
70
71
72
73
74
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 69

optional :phone_numbers,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::IndividualUpdateParams::PhoneNumber,
                                    nil?: true]
},
nil?: true

#preferred_nameString?

The preferred name of the individual.

Returns:

  • (String, nil)


80
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 80

optional :preferred_name, String, nil?: true

#residenceFinchAPI::Models::Location?

Returns:



85
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 85

optional :residence, -> { FinchAPI::Location }, nil?: true

#ssnString?

Social Security Number of the individual. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body. [Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).

Returns:

  • (String, nil)


94
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 94

optional :ssn, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 150