Class: FinchAPI::Models::Sandbox::IndividualUpdateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/individual_update_response.rb

Overview

Defined Under Namespace

Modules: Ethnicity, Gender Classes: Email, PhoneNumber

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#dobString?

Returns:

  • (String, nil)


17
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 17

optional :dob, String, nil?: true

#emailsArray<FinchAPI::Models::Sandbox::IndividualUpdateResponse::Email>?



22
23
24
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 22

optional :emails,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateResponse::Email] },
nil?: true

#encrypted_ssnString?

Social Security Number of the individual in encrypted format. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body.

Returns:

  • (String, nil)


32
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 32

optional :encrypted_ssn, String, nil?: true

#ethnicitySymbol, ...

The EEOC-defined ethnicity of the individual.



38
39
40
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 38

optional :ethnicity,
enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateResponse::Ethnicity },
nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


46
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 46

optional :first_name, String, nil?: true

#genderSymbol, ...

The gender of the individual.



52
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 52

optional :gender, enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateResponse::Gender }, nil?: true

#idString?

A stable Finch ‘id` (UUID v4) for an individual in the company.

Returns:

  • (String, nil)


12
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 12

optional :id, String

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


58
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 58

optional :last_name, String, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


64
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 64

optional :middle_name, String, nil?: true

#phone_numbersArray<FinchAPI::Models::Sandbox::IndividualUpdateResponse::PhoneNumber, nil>?



69
70
71
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 69

optional :phone_numbers,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateResponse::PhoneNumber, nil?: true] },
nil?: true

#preferred_nameString?

The preferred name of the individual.

Returns:

  • (String, nil)


77
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 77

optional :preferred_name, String, nil?: true

#residenceFinchAPI::Location?

Returns:



82
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 82

optional :residence, -> { FinchAPI::Location }, nil?: true

#ssnString?

Social Security Number of the individual. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body. [Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).

Returns:

  • (String, nil)


91
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 91

optional :ssn, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 145