Class: FinchAPI::Models::Sandbox::JobCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::JobCreateResponse
- Defined in:
- lib/finch_api/models/sandbox/job_create_response.rb
Overview
Instance Attribute Summary collapse
-
#allowed_refreshes ⇒ Integer
The number of allowed refreshes per hour (per hour, fixed window).
-
#job_id ⇒ String
The id of the job that has been created.
-
#job_url ⇒ String
The url that can be used to retrieve the job status.
-
#remaining_refreshes ⇒ Integer
The number of remaining refreshes available (per hour, fixed window).
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(allowed_refreshes: , job_id: , job_url: , remaining_refreshes: ) ⇒ Object
|
|
# File 'lib/finch_api/models/sandbox/job_create_response.rb', line 32
|
Instance Attribute Details
#allowed_refreshes ⇒ Integer
The number of allowed refreshes per hour (per hour, fixed window)
12 |
# File 'lib/finch_api/models/sandbox/job_create_response.rb', line 12 required :allowed_refreshes, Integer |
#job_id ⇒ String
The id of the job that has been created.
18 |
# File 'lib/finch_api/models/sandbox/job_create_response.rb', line 18 required :job_id, String |
#job_url ⇒ String
The url that can be used to retrieve the job status
24 |
# File 'lib/finch_api/models/sandbox/job_create_response.rb', line 24 required :job_url, String |
#remaining_refreshes ⇒ Integer
The number of remaining refreshes available (per hour, fixed window)
30 |
# File 'lib/finch_api/models/sandbox/job_create_response.rb', line 30 required :remaining_refreshes, Integer |