Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/payment_create_params.rb

Defined Under Namespace

Modules: Type Classes: Attributes

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata for more details.

Parameters:

  • metadata (Hash{Symbol=>Object, nil}) (defaults to: nil)

    The metadata to be attached to the entity by existing rules. It is a key-value p



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 136

class Earning < FinchAPI::Internal::Type::BaseModel
  # @!attribute amount
  #   The earnings amount in cents.
  #
  #   @return [Integer, nil]
  optional :amount, Integer, nil?: true

  # @!attribute attributes
  #
  #   @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes, nil]
  optional :attributes,
           -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes },
           nil?: true

  # @!attribute currency
  #   The earnings currency code.
  #
  #   @return [String, nil]
  optional :currency, String, nil?: true

  # @!attribute hours
  #   The number of hours associated with this earning. (For salaried employees, this
  #   could be hours per pay period, `0` or `null`, depending on the provider).
  #
  #   @return [Float, nil]
  optional :hours, Float, nil?: true

  # @!attribute name
  #   The exact name of the deduction from the pay statement.
  #
  #   @return [String, nil]
  optional :name, String, nil?: true

  # @!attribute type
  #   The type of earning.
  #
  #   @return [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Type, nil]
  optional :type,
           enum: -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Type },
           nil?: true

  # @!method initialize(amount: nil, attributes: nil, currency: nil, hours: nil, name: nil, type: nil)
  #   Some parameter documentations has been truncated, see
  #   {FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning} for more
  #   details.
  #
  #   @param amount [Integer, nil] The earnings amount in cents.
  #
  #   @param attributes [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes, nil]
  #
  #   @param currency [String, nil] The earnings currency code.
  #
  #   @param hours [Float, nil] The number of hours associated with this earning. (For salaried employees, this
  #
  #   @param name [String, nil] The exact name of the deduction from the pay statement.
  #
  #   @param type [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Type, nil] The type of earning.

  # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning#attributes
  class Attributes < FinchAPI::Internal::Type::BaseModel
    # @!attribute metadata
    #
    #   @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata, nil]
    optional :metadata,
             -> {
               FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata
             }

    # @!method initialize(metadata: nil)
    #   @param metadata [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata]

    # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes#metadata
    class Metadata < FinchAPI::Internal::Type::BaseModel
      # @!attribute metadata
      #   The metadata to be attached to the entity by existing rules. It is a key-value
      #   pairs where the values can be of any type (string, number, boolean, object,
      #   array, etc.).
      #
      #   @return [Hash{Symbol=>Object, nil}, nil]
      optional :metadata,
               FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true]

      # @!method initialize(metadata: nil)
      #   Some parameter documentations has been truncated, see
      #   {FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata}
      #   for more details.
      #
      #   @param metadata [Hash{Symbol=>Object, nil}] The metadata to be attached to the entity by existing rules. It is a key-value p
    end
  end

  # The type of earning.
  #
  # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning#type
  module Type
    extend FinchAPI::Internal::Type::Enum

    SALARY = :salary
    WAGE = :wage
    REIMBURSEMENT = :reimbursement
    OVERTIME = :overtime
    SEVERANCE = :severance
    DOUBLE_OVERTIME = :double_overtime
    PTO = :pto
    SICK = :sick
    BONUS = :bonus
    COMMISSION = :commission
    TIPS = :tips
    TYPE_1099 = :"1099"
    OTHER = :other

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#amountInteger?

The earnings amount in cents.

Returns:

  • (Integer, nil)


141
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 141

optional :amount, Integer, nil?: true

#attributesFinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes?

Returns:

  • (FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes, nil)


146
147
148
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 146

optional :attributes,
-> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes },
nil?: true

#currencyString?

The earnings currency code.

Returns:

  • (String, nil)


154
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 154

optional :currency, String, nil?: true

#hoursFloat?

The number of hours associated with this earning. (For salaried employees, this could be hours per pay period, ‘0` or `null`, depending on the provider).

Returns:

  • (Float, nil)


161
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 161

optional :hours, Float, nil?: true

#nameString?

The exact name of the deduction from the pay statement.

Returns:

  • (String, nil)


167
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 167

optional :name, String, nil?: true

#typeSymbol, ...

The type of earning.

Returns:

  • (Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Type, nil)


173
174
175
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 173

optional :type,
enum: -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Type },
nil?: true