Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata
- Inherits:
-
BaseModel
- Object
- FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata
- Defined in:
- lib/finch-api/models/sandbox/payment_create_params.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Instance Attribute Summary collapse
-
#metadata ⇒ Hash{Symbol=>Object}?
readonly
The metadata to be attached to the entity by existing rules.
Instance Attribute Details
#metadata ⇒ Hash{Symbol=>Object}? (readonly)
The metadata to be attached to the entity by existing rules. It is a key-value
pairs where the values can be of any type (string, number, boolean, object,
array, etc.).
231 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 231 optional :metadata, FinchAPI::HashOf[FinchAPI::Unknown] |