Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes::Metadata

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/sandbox/payment_create_params.rb

Overview

def initialize: (Hash | FinchAPI::BaseModel) -> void

Instance Attribute Summary collapse

Method Summary

Methods inherited from BaseModel

#==, #[], coerce, #deconstruct_keys, defaults, dump, fields, #initialize, #inspect, known_fields, optional, required, reverse_map, #to_h, #to_s, try_strict_coerce

Methods included from Converter

#coerce, coerce, #dump, dump, #try_strict_coerce, try_strict_coerce, type_info

Constructor Details

This class inherits a constructor from FinchAPI::BaseModel

Instance Attribute Details

#metadataHash{Symbol=>Object}? (readonly)

The metadata to be attached to the entity by existing rules. It is a key-value

pairs where the values can be of any type (string, number, boolean, object,
array, etc.).

Returns:

  • (Hash{Symbol=>Object}, nil)


431
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 431

optional :metadata, FinchAPI::HashOf[FinchAPI::Unknown]