Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/payment_create_params.rb

Defined Under Namespace

Modules: Type Classes: Attributes

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

#initialize(metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata for more details.

Parameters:

  • metadata (Hash{Symbol=>Object}) (defaults to: nil)

    The metadata to be attached to the entity by existing rules. It is a key-value p



# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 450

Instance Attribute Details

#amountInteger?

The tax amount in cents.

Returns:

  • (Integer, nil)


415
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 415

optional :amount, Integer, nil?: true

#attributesFinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes?



420
421
422
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 420

optional :attributes,
-> { FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes },
nil?: true

#currencyString?

The currency code.

Returns:

  • (String, nil)


428
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 428

optional :currency, String, nil?: true

#employerBoolean?

‘true` if the amount is paid by the employers.

Returns:

  • (Boolean, nil)


434
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 434

optional :employer, FinchAPI::Internal::Type::Boolean, nil?: true

#nameString?

The exact name of tax from the pay statement.

Returns:

  • (String, nil)


440
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 440

optional :name, String, nil?: true

#typeSymbol, ...

The type of taxes.



446
447
448
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 446

optional :type,
enum: -> { FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax::Type },
nil?: true