Class: FinchAPI::Resources::HRIS::Company::PayStatementItem

Inherits:
Object
  • Object
show all
Defined in:
lib/finch_api/resources/hris/company/pay_statement_item.rb,
lib/finch_api/resources/hris/company/pay_statement_item/rules.rb

Defined Under Namespace

Classes: Rules

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ PayStatementItem

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of PayStatementItem.

Parameters:



53
54
55
56
# File 'lib/finch_api/resources/hris/company/pay_statement_item.rb', line 53

def initialize(client:)
  @client = client
  @rules = FinchAPI::Resources::HRIS::Company::PayStatementItem::Rules.new(client: client)
end

Instance Attribute Details

#rulesFinchAPI::Resources::HRIS::Company::PayStatementItem::Rules (readonly)



9
10
11
# File 'lib/finch_api/resources/hris/company/pay_statement_item.rb', line 9

def rules
  @rules
end

Instance Method Details

#list(categories: nil, end_date: nil, entity_ids: nil, name: nil, start_date: nil, type: nil, request_options: {}) ⇒ FinchAPI::Internal::ResponsesPage<FinchAPI::Models::HRIS::Company::PayStatementItemListResponse>

Some parameter documentations has been truncated, see Models::HRIS::Company::PayStatementItemListParams for more details.

Retrieve a list of detailed pay statement items for the access token’s connection account.

Parameters:

  • categories (Array<Symbol, FinchAPI::Models::HRIS::Company::PayStatementItemListParams::Category>)

    Comma-delimited list of pay statement item categories to filter on. If empty, de

  • end_date (Date)

    The end date to retrieve pay statement items by via their last seen pay date in

  • entity_ids (Array<String>)

    The entity IDs to specify which entities’ data to access.

  • name (String)

    Case-insensitive partial match search by pay statement item name.

  • start_date (Date)

    The start date to retrieve pay statement items by via their last seen pay date (

  • type (String)

    String search by pay statement item type.

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/finch_api/resources/hris/company/pay_statement_item.rb', line 36

def list(params = {})
  parsed, options = FinchAPI::HRIS::Company::PayStatementItemListParams.dump_request(params)
  query = FinchAPI::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "employer/pay-statement-item",
    query: query,
    page: FinchAPI::Internal::ResponsesPage,
    model: FinchAPI::Models::HRIS::Company::PayStatementItemListResponse,
    security: {bearer_auth: true},
    options: options
  )
end