Class: FinchAPI::Resources::RequestForwarding
- Inherits:
-
Object
- Object
- FinchAPI::Resources::RequestForwarding
- Defined in:
- lib/finch_api/resources/request_forwarding.rb
Instance Method Summary collapse
-
#forward(method_: , route: , data: nil, headers: nil, params: nil, request_options: {}) ⇒ FinchAPI::Models::RequestForwardingForwardResponse
Some parameter documentations has been truncated, see Models::RequestForwardingForwardParams for more details.
-
#initialize(client:) ⇒ RequestForwarding
constructor
private
A new instance of RequestForwarding.
Constructor Details
#initialize(client:) ⇒ RequestForwarding
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of RequestForwarding.
50 51 52 |
# File 'lib/finch_api/resources/request_forwarding.rb', line 50 def initialize(client:) @client = client end |
Instance Method Details
#forward(method_: , route: , data: nil, headers: nil, params: nil, request_options: {}) ⇒ FinchAPI::Models::RequestForwardingForwardResponse
Some parameter documentations has been truncated, see Models::RequestForwardingForwardParams for more details.
The Forward API allows you to make direct requests to an employment system. If Finch’s unified API doesn’t have a data model that cleanly fits your needs, then Forward allows you to push or pull data models directly against an integration’s API.
…
…
…
…
…
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/finch_api/resources/request_forwarding.rb', line 36 def forward(params) parsed, = FinchAPI::Models::RequestForwardingForwardParams.dump_request(params) @client.request( method: :post, path: "forward", body: parsed, model: FinchAPI::Models::RequestForwardingForwardResponse, options: ) end |