Class: FinchAPI::Client
Constant Summary
collapse
- DEFAULT_MAX_RETRIES =
Default max number of retries to attempt after a failed retryable request.
2
- DEFAULT_TIMEOUT_IN_SECONDS =
Default per-request timeout.
60.0
- DEFAULT_INITIAL_RETRY_DELAY =
Default initial retry delay in seconds. Overall delay is calculated using exponential backoff + jitter.
0.5
- DEFAULT_MAX_RETRY_DELAY =
Default max retry delay in seconds.
8.0
Transport::BaseClient::MAX_REDIRECTS, Transport::BaseClient::PLATFORM_HEADERS
Instance Attribute Summary collapse
#requester
Instance Method Summary
collapse
follow_redirect, #inspect, reap_connection!, #request, should_retry?, validate!
Constructor Details
#initialize(base_url: nil, access_token: nil, client_id: , client_secret: , max_retries: DEFAULT_MAX_RETRIES, timeout: DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: DEFAULT_MAX_RETRY_DELAY) ⇒ Client
Creates and returns a new client for interacting with the API.
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
|
# File 'lib/finch-api/client.rb', line 100
def initialize(
base_url: nil,
access_token: nil,
client_id: ENV["FINCH_CLIENT_ID"],
client_secret: ENV["FINCH_CLIENT_SECRET"],
max_retries: DEFAULT_MAX_RETRIES,
timeout: DEFAULT_TIMEOUT_IN_SECONDS,
initial_retry_delay: DEFAULT_INITIAL_RETRY_DELAY,
max_retry_delay: DEFAULT_MAX_RETRY_DELAY
)
base_url ||= "https://api.tryfinch.com"
= {
"finch-api-version" => "2020-09-17"
}
@access_token = access_token&.to_s
@client_id = client_id&.to_s
@client_secret = client_secret&.to_s
super(
base_url: base_url,
timeout: timeout,
max_retries: max_retries,
initial_retry_delay: initial_retry_delay,
max_retry_delay: max_retry_delay,
headers:
)
@access_tokens = FinchAPI::Resources::AccessTokens.new(client: self)
@hris = FinchAPI::Resources::HRIS.new(client: self)
@providers = FinchAPI::Resources::Providers.new(client: self)
@account = FinchAPI::Resources::Account.new(client: self)
@webhooks = FinchAPI::Resources::Webhooks.new(client: self)
@request_forwarding = FinchAPI::Resources::RequestForwarding.new(client: self)
@jobs = FinchAPI::Resources::Jobs.new(client: self)
@sandbox = FinchAPI::Resources::Sandbox.new(client: self)
@payroll = FinchAPI::Resources::Payroll.new(client: self)
@connect = FinchAPI::Resources::Connect.new(client: self)
end
|
Instance Attribute Details
#access_token ⇒ String?
19
20
21
|
# File 'lib/finch-api/client.rb', line 19
def access_token
@access_token
end
|
28
29
30
|
# File 'lib/finch-api/client.rb', line 28
def access_tokens
@access_tokens
end
|
37
38
39
|
# File 'lib/finch-api/client.rb', line 37
def account
@account
end
|
#client_id ⇒ String?
22
23
24
|
# File 'lib/finch-api/client.rb', line 22
def client_id
@client_id
end
|
#client_secret ⇒ String?
25
26
27
|
# File 'lib/finch-api/client.rb', line 25
def client_secret
@client_secret
end
|
55
56
57
|
# File 'lib/finch-api/client.rb', line 55
def connect
@connect
end
|
31
32
33
|
# File 'lib/finch-api/client.rb', line 31
def hris
@hris
end
|
46
47
48
|
# File 'lib/finch-api/client.rb', line 46
def jobs
@jobs
end
|
52
53
54
|
# File 'lib/finch-api/client.rb', line 52
def payroll
@payroll
end
|
34
35
36
|
# File 'lib/finch-api/client.rb', line 34
def providers
@providers
end
|
43
44
45
|
# File 'lib/finch-api/client.rb', line 43
def request_forwarding
@request_forwarding
end
|
49
50
51
|
# File 'lib/finch-api/client.rb', line 49
def sandbox
@sandbox
end
|
40
41
42
|
# File 'lib/finch-api/client.rb', line 40
def webhooks
@webhooks
end
|