Class: FinchAPI::Internal::Transport::BaseClient Abstract Private
- Inherits:
-
Object
- Object
- FinchAPI::Internal::Transport::BaseClient
- Defined in:
- lib/finch_api/internal/transport/base_client.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Direct Known Subclasses
Constant Summary collapse
- MAX_REDIRECTS =
This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.
from whatwg fetch spec
20- PLATFORM_HEADERS =
This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.
rubocop:disable Style/MutableConstant
{ "x-stainless-arch" => FinchAPI::Internal::Util.arch, "x-stainless-lang" => "ruby", "x-stainless-os" => FinchAPI::Internal::Util.os, "x-stainless-package-version" => FinchAPI::VERSION, "x-stainless-runtime" => ::RUBY_ENGINE, "x-stainless-runtime-version" => ::RUBY_ENGINE_VERSION }
Instance Attribute Summary collapse
- #requester ⇒ FinchAPI::Internal::Transport::PooledNetRequester readonly private
Class Method Summary collapse
- .follow_redirect(request, status:, response_headers:) ⇒ Hash{Symbol=>Object} private
- .reap_connection!(status, stream:) ⇒ Object private
- .should_retry?(status, headers:) ⇒ Boolean private
- .validate!(req) ⇒ Object private
Instance Method Summary collapse
-
#initialize(base_url:, timeout: 0.0, max_retries: 0, initial_retry_delay: 0.0, max_retry_delay: 0.0, headers: {}, idempotency_header: nil) ⇒ BaseClient
constructor
private
A new instance of BaseClient.
- #inspect ⇒ String private
-
#request(method, path, query: {}, headers: {}, body: nil, unwrap: nil, page: nil, stream: nil, model: FinchAPI::Internal::Type::Unknown, options: {}) ⇒ Object
private
Execute the request specified by ‘req`.
Constructor Details
#initialize(base_url:, timeout: 0.0, max_retries: 0, initial_retry_delay: 0.0, max_retry_delay: 0.0, headers: {}, idempotency_header: nil) ⇒ BaseClient
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of BaseClient.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/finch_api/internal/transport/base_client.rb', line 167 def initialize( base_url:, timeout: 0.0, max_retries: 0, initial_retry_delay: 0.0, max_retry_delay: 0.0, headers: {}, idempotency_header: nil ) @requester = FinchAPI::Internal::Transport::PooledNetRequester.new @headers = FinchAPI::Internal::Util.normalized_headers( self.class::PLATFORM_HEADERS, { "accept" => "application/json", "content-type" => "application/json" }, headers ) @base_url = FinchAPI::Internal::Util.parse_uri(base_url) @idempotency_header = idempotency_header&.to_s&.downcase @max_retries = max_retries @timeout = timeout @initial_retry_delay = initial_retry_delay @max_retry_delay = max_retry_delay end |
Instance Attribute Details
#requester ⇒ FinchAPI::Internal::Transport::PooledNetRequester (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
156 157 158 |
# File 'lib/finch_api/internal/transport/base_client.rb', line 156 def requester @requester end |
Class Method Details
.follow_redirect(request, status:, response_headers:) ⇒ Hash{Symbol=>Object}
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/finch_api/internal/transport/base_client.rb', line 89 def follow_redirect(request, status:, response_headers:) method, url, headers = request.fetch_values(:method, :url, :headers) location = Kernel.then do URI.join(url, response_headers["location"]) rescue ArgumentError = "Server responded with status #{status} but no valid location header." raise FinchAPI::Errors::APIConnectionError.new( url: url, response: response_headers, message: ) end request = {**request, url: location} case [url.scheme, location.scheme] in ["https", "http"] = "Tried to redirect to a insecure URL" raise FinchAPI::Errors::APIConnectionError.new( url: url, response: response_headers, message: ) else nil end # from whatwg fetch spec case [status, method] in [301 | 302, :post] | [303, _] drop = %w[content-encoding content-language content-length content-location content-type] request = { **request, method: method == :head ? :head : :get, headers: headers.except(*drop), body: nil } else end # from undici if FinchAPI::Internal::Util.uri_origin(url) != FinchAPI::Internal::Util.uri_origin(location) drop = %w[authorization cookie host proxy-authorization] request = {**request, headers: request.fetch(:headers).except(*drop)} end request end |
.reap_connection!(status, stream:) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
143 144 145 146 147 148 149 150 151 |
# File 'lib/finch_api/internal/transport/base_client.rb', line 143 def reap_connection!(status, stream:) case status in (..199) | (300..499) stream&.each { next } in FinchAPI::Errors::APIConnectionError | (500..) FinchAPI::Internal::Util.close_fused!(stream) else end end |
.should_retry?(status, headers:) ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/finch_api/internal/transport/base_client.rb', line 51 def should_retry?(status, headers:) coerced = FinchAPI::Internal::Util.coerce_boolean(headers["x-should-retry"]) case [coerced, status] in [true | false, _] coerced in [_, 408 | 409 | 429 | (500..)] # retry on: # 408: timeouts # 409: locks # 429: rate limits # 500+: unknown errors true else false end end |
.validate!(req) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/finch_api/internal/transport/base_client.rb', line 31 def validate!(req) keys = [:method, :path, :query, :headers, :body, :unwrap, :page, :stream, :model, :options] case req in Hash req.each_key do |k| unless keys.include?(k) raise ArgumentError.new("Request `req` keys must be one of #{keys}, got #{k.inspect}") end end else raise ArgumentError.new("Request `req` must be a Hash or RequestOptions, got #{req.inspect}") end end |
Instance Method Details
#inspect ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
474 475 476 477 478 479 |
# File 'lib/finch_api/internal/transport/base_client.rb', line 474 def inspect # rubocop:disable Layout/LineLength base_url = FinchAPI::Internal::Util.unparse_uri(@base_url) "#<#{self.class.name}:0x#{object_id.to_s(16)} base_url=#{base_url} max_retries=#{@max_retries} timeout=#{@timeout}>" # rubocop:enable Layout/LineLength end |
#request(method, path, query: {}, headers: {}, body: nil, unwrap: nil, page: nil, stream: nil, model: FinchAPI::Internal::Type::Unknown, options: {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Execute the request specified by ‘req`. This is the method that all resource methods call into.
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/finch_api/internal/transport/base_client.rb', line 442 def request(req) self.class.validate!(req) model = req.fetch(:model) { FinchAPI::Internal::Type::Unknown } opts = req[:options].to_h FinchAPI::RequestOptions.validate!(opts) request = build_request(req.except(:options), opts) url = request.fetch(:url) # Don't send the current retry count in the headers if the caller modified the header defaults. send_retry_header = request.fetch(:headers)["x-stainless-retry-count"] == "0" status, response, stream = send_request( request, redirect_count: 0, retry_count: 0, send_retry_header: send_retry_header ) decoded = FinchAPI::Internal::Util.decode_content(response, stream: stream) case req in {stream: Class => st} st.new(model: model, url: url, status: status, response: response, stream: decoded) in {page: Class => page} page.new(client: self, req: req, headers: response, page_data: decoded) else unwrapped = FinchAPI::Internal::Util.dig(decoded, req[:unwrap]) FinchAPI::Internal::Type::Converter.coerce(model, unwrapped) end end |