Class: FinchAPI::Models::BaseWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/base_webhook_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id: , company_id: , connection_id: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::BaseWebhookEvent for more details.

Parameters:

  • account_id (String) (defaults to: )
    DEPRECATED

    Unique Finch ID of the employer account used to make this connectio

  • company_id (String) (defaults to: )
    DEPRECATED

    Unique Finch ID of the company for which data has been updated. Use

  • connection_id (String) (defaults to: nil)

    Unique Finch ID of the connection associated with the webhook event.



# File 'lib/finch_api/models/base_webhook_event.rb', line 31

Instance Attribute Details

#account_idString

Deprecated.
DEPRECATED

Unique Finch ID of the employer account used to make this

connection. Use ‘connection_id` instead to identify the connection associated with this event.

Returns:

  • (String)


14
# File 'lib/finch_api/models/base_webhook_event.rb', line 14

required :account_id, String

#company_idString

Deprecated.
DEPRECATED

Unique Finch ID of the company for which data has been updated. Use

‘connection_id` instead to identify the connection associated with this event.

Returns:

  • (String)


23
# File 'lib/finch_api/models/base_webhook_event.rb', line 23

required :company_id, String

#connection_idString?

Unique Finch ID of the connection associated with the webhook event.

Returns:

  • (String, nil)


29
# File 'lib/finch_api/models/base_webhook_event.rb', line 29

optional :connection_id, String