Class: FinchAPI::Models::BaseWebhookEvent
- Defined in:
- lib/finch-api/models/base_webhook_event.rb
Direct Known Subclasses
AccountUpdateEvent, CompanyEvent, DirectoryEvent, EmploymentEvent, IndividualEvent, JobCompletionEvent, PayStatementEvent, PaymentEvent
Instance Attribute Summary collapse
-
#account_id ⇒ String
- DEPRECATED
-
Unique Finch ID of the employer account used to make this connection.
-
#company_id ⇒ String
- DEPRECATED
-
Unique Finch ID of the company for which data has been updated.
-
#connection_id ⇒ String?
Unique Finch ID of the connection associated with the webhook event.
Instance Method Summary collapse
-
#initialize(account_id:, company_id:, connection_id: nil) ⇒ BaseWebhookEvent
constructor
A new instance of BaseWebhookEvent.
Constructor Details
#initialize(account_id:, company_id:, connection_id: nil) ⇒ BaseWebhookEvent
Returns a new instance of BaseWebhookEvent.
5 |
# File 'lib/finch-api/models/base_webhook_event.rb', line 5 def initialize(account_id:, company_id:, connection_id: nil, **) = super |
Instance Attribute Details
#account_id ⇒ String
- DEPRECATED
-
Unique Finch ID of the employer account used to make this
connection. Use `connection_id` instead to identify the connection associated
with this event.
12 |
# File 'lib/finch-api/models/base_webhook_event.rb', line 12 required :account_id, String |
#company_id ⇒ String
- DEPRECATED
-
Unique Finch ID of the company for which data has been updated. Use
`connection_id` instead to identify the connection associated with this event.
19 |
# File 'lib/finch-api/models/base_webhook_event.rb', line 19 required :company_id, String |
#connection_id ⇒ String?
Unique Finch ID of the connection associated with the webhook event.
25 |
# File 'lib/finch-api/models/base_webhook_event.rb', line 25 optional :connection_id, String |