Class: FinchAPI::Models::BaseWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::BaseWebhookEvent
- Defined in:
- lib/finch_api/models/base_webhook_event.rb
Direct Known Subclasses
AccountUpdateEvent, CompanyEvent, DirectoryEvent, EmploymentEvent, IndividualEvent, JobCompletionEvent, PayStatementEvent, PaymentEvent
Instance Attribute Summary collapse
- #account_id ⇒ String deprecated Deprecated.
- #company_id ⇒ String deprecated Deprecated.
-
#connection_id ⇒ String?
Unique Finch ID of the connection associated with the webhook event.
Instance Method Summary collapse
-
#initialize(account_id: , company_id: , connection_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BaseWebhookEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id: , company_id: , connection_id: nil) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::BaseWebhookEvent for more details.
|
|
# File 'lib/finch_api/models/base_webhook_event.rb', line 31
|
Instance Attribute Details
#account_id ⇒ String
- DEPRECATED
-
Unique Finch ID of the employer account used to make this
connection. Use ‘connection_id` instead to identify the connection associated with this event.
14 |
# File 'lib/finch_api/models/base_webhook_event.rb', line 14 required :account_id, String |
#company_id ⇒ String
- DEPRECATED
-
Unique Finch ID of the company for which data has been updated. Use
‘connection_id` instead to identify the connection associated with this event.
23 |
# File 'lib/finch_api/models/base_webhook_event.rb', line 23 required :company_id, String |
#connection_id ⇒ String?
Unique Finch ID of the connection associated with the webhook event.
29 |
# File 'lib/finch_api/models/base_webhook_event.rb', line 29 optional :connection_id, String |