Class: FinchAPI::Models::Connect::SessionNewParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Connect::SessionNewParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/connect/session_new_params.rb
Overview
Defined Under Namespace
Modules: Product, Sandbox Classes: Integration
Instance Attribute Summary collapse
- #customer_email ⇒ String?
- #customer_id ⇒ String
- #customer_name ⇒ String
- #integration ⇒ FinchAPI::Models::Connect::SessionNewParams::Integration?
- #manual ⇒ Boolean?
-
#minutes_to_expire ⇒ Float?
The number of minutes until the session expires (defaults to 43,200, which is 30 days).
- #products ⇒ Array<Symbol, FinchAPI::Models::Connect::SessionNewParams::Product>
- #redirect_uri ⇒ String?
- #sandbox ⇒ Symbol, ...
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(customer_id: , customer_name: , products: , customer_email: nil, integration: nil, manual: nil, minutes_to_expire: nil, redirect_uri: nil, sandbox: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SessionNewParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(customer_id: , customer_name: , products: , customer_email: nil, integration: nil, manual: nil, minutes_to_expire: nil, redirect_uri: nil, sandbox: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::Connect::SessionNewParams for more details.
…
|
|
# File 'lib/finch_api/models/connect/session_new_params.rb', line 59
|
Instance Attribute Details
#customer_email ⇒ String?
30 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 30 optional :customer_email, String, nil?: true |
#customer_id ⇒ String
14 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 14 required :customer_id, String |
#customer_name ⇒ String
19 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 19 required :customer_name, String |
#integration ⇒ FinchAPI::Models::Connect::SessionNewParams::Integration?
35 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 35 optional :integration, -> { FinchAPI::Models::Connect::SessionNewParams::Integration }, nil?: true |
#manual ⇒ Boolean?
40 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 40 optional :manual, FinchAPI::Internal::Type::Boolean, nil?: true |
#minutes_to_expire ⇒ Float?
The number of minutes until the session expires (defaults to 43,200, which is 30 days)
47 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 47 optional :minutes_to_expire, Float, nil?: true |
#products ⇒ Array<Symbol, FinchAPI::Models::Connect::SessionNewParams::Product>
24 25 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 24 required :products, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Models::Connect::SessionNewParams::Product] } |
#redirect_uri ⇒ String?
52 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 52 optional :redirect_uri, String, nil?: true |
#sandbox ⇒ Symbol, ...
57 |
# File 'lib/finch_api/models/connect/session_new_params.rb', line 57 optional :sandbox, enum: -> { FinchAPI::Models::Connect::SessionNewParams::Sandbox }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/connect/session_new_params.rb', line 99
|