Class: FinchAPI::Models::Connect::SessionNewParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/connect/session_new_params.rb

Overview

Defined Under Namespace

Modules: Product, Sandbox Classes: Integration

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(customer_id: , customer_name: , products: , customer_email: nil, integration: nil, manual: nil, minutes_to_expire: nil, redirect_uri: nil, sandbox: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::Connect::SessionNewParams for more details.

Parameters:

  • customer_id (String) (defaults to: )

    Unique identifier for the customer

  • customer_name (String) (defaults to: )

    Name of the customer

  • products (Array<Symbol, FinchAPI::Models::Connect::SessionNewParams::Product>) (defaults to: )

    The Finch products to request access to

  • customer_email (String, nil) (defaults to: nil)

    Email address of the customer

  • integration (FinchAPI::Models::Connect::SessionNewParams::Integration, nil) (defaults to: nil)

    Integration configuration for the connect session

  • manual (Boolean, nil) (defaults to: nil)

    Enable manual authentication mode

  • minutes_to_expire (Float, nil) (defaults to: nil)

    The number of minutes until the session expires (defaults to 129,600, which is 9

  • redirect_uri (String, nil) (defaults to: nil)

    The URI to redirect to after the Connect flow is completed

  • sandbox (Symbol, FinchAPI::Models::Connect::SessionNewParams::Sandbox, nil) (defaults to: nil)

    Sandbox mode for testing

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/finch_api/models/connect/session_new_params.rb', line 67

Instance Attribute Details

#customer_emailString?

Email address of the customer

Returns:

  • (String, nil)


34
# File 'lib/finch_api/models/connect/session_new_params.rb', line 34

optional :customer_email, String, nil?: true

#customer_idString

Unique identifier for the customer

Returns:

  • (String)


15
# File 'lib/finch_api/models/connect/session_new_params.rb', line 15

required :customer_id, String

#customer_nameString

Name of the customer

Returns:

  • (String)


21
# File 'lib/finch_api/models/connect/session_new_params.rb', line 21

required :customer_name, String

#integrationFinchAPI::Models::Connect::SessionNewParams::Integration?

Integration configuration for the connect session



40
# File 'lib/finch_api/models/connect/session_new_params.rb', line 40

optional :integration, -> { FinchAPI::Connect::SessionNewParams::Integration }, nil?: true

#manualBoolean?

Enable manual authentication mode

Returns:

  • (Boolean, nil)


46
# File 'lib/finch_api/models/connect/session_new_params.rb', line 46

optional :manual, FinchAPI::Internal::Type::Boolean, nil?: true

#minutes_to_expireFloat?

The number of minutes until the session expires (defaults to 129,600, which is 90 days)

Returns:

  • (Float, nil)


53
# File 'lib/finch_api/models/connect/session_new_params.rb', line 53

optional :minutes_to_expire, Float, nil?: true

#productsArray<Symbol, FinchAPI::Models::Connect::SessionNewParams::Product>

The Finch products to request access to



27
28
# File 'lib/finch_api/models/connect/session_new_params.rb', line 27

required :products,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Connect::SessionNewParams::Product] }

#redirect_uriString?

The URI to redirect to after the Connect flow is completed

Returns:

  • (String, nil)


59
# File 'lib/finch_api/models/connect/session_new_params.rb', line 59

optional :redirect_uri, String, nil?: true

#sandboxSymbol, ...

Sandbox mode for testing



65
# File 'lib/finch_api/models/connect/session_new_params.rb', line 65

optional :sandbox, enum: -> { FinchAPI::Connect::SessionNewParams::Sandbox }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/connect/session_new_params.rb', line 106