Class: FinchAPI::Models::Connect::SessionReauthenticateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/connect/session_reauthenticate_params.rb

Overview

Defined Under Namespace

Modules: Product

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(connection_id: , minutes_to_expire: nil, products: nil, redirect_uri: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::Connect::SessionReauthenticateParams for more details.

Parameters:

  • connection_id (String) (defaults to: )

    The ID of the existing connection to reauthenticate

  • minutes_to_expire (Integer, nil) (defaults to: nil)

    The number of minutes until the session expires (defaults to 43,200, which is 30

  • products (Array<Symbol, FinchAPI::Connect::SessionReauthenticateParams::Product>, nil) (defaults to: nil)

    The products to request access to (optional for reauthentication)

  • redirect_uri (String, nil) (defaults to: nil)

    The URI to redirect to after the Connect flow is completed

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 40

Instance Attribute Details

#connection_idString

The ID of the existing connection to reauthenticate

Returns:

  • (String)


15
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 15

required :connection_id, String

#minutes_to_expireInteger?

The number of minutes until the session expires (defaults to 43,200, which is 30 days)

Returns:

  • (Integer, nil)


22
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 22

optional :minutes_to_expire, Integer, nil?: true

#productsArray<Symbol, FinchAPI::Connect::SessionReauthenticateParams::Product>?

The products to request access to (optional for reauthentication)

Returns:

  • (Array<Symbol, FinchAPI::Connect::SessionReauthenticateParams::Product>, nil)


28
29
30
31
32
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 28

optional :products,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Connect::SessionReauthenticateParams::Product]
},
nil?: true

#redirect_uriString?

The URI to redirect to after the Connect flow is completed

Returns:

  • (String, nil)


38
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 38

optional :redirect_uri, String, nil?: true