Class: FinchAPI::Models::Connect::SessionReauthenticateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Connect::SessionReauthenticateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/connect/session_reauthenticate_params.rb
Overview
Defined Under Namespace
Modules: Product
Instance Attribute Summary collapse
-
#connection_id ⇒ String
The ID of the existing connection to reauthenticate.
-
#minutes_to_expire ⇒ Integer?
The number of minutes until the session expires (defaults to 43,200, which is 30 days).
-
#products ⇒ Array<Symbol, FinchAPI::Connect::SessionReauthenticateParams::Product>?
The products to request access to (optional for reauthentication).
-
#redirect_uri ⇒ String?
The URI to redirect to after the Connect flow is completed.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(connection_id: , minutes_to_expire: nil, products: nil, redirect_uri: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SessionReauthenticateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(connection_id: , minutes_to_expire: nil, products: nil, redirect_uri: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::Connect::SessionReauthenticateParams for more details.
|
|
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 40
|
Instance Attribute Details
#connection_id ⇒ String
The ID of the existing connection to reauthenticate
15 |
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 15 required :connection_id, String |
#minutes_to_expire ⇒ Integer?
The number of minutes until the session expires (defaults to 43,200, which is 30 days)
22 |
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 22 optional :minutes_to_expire, Integer, nil?: true |
#products ⇒ Array<Symbol, FinchAPI::Connect::SessionReauthenticateParams::Product>?
The products to request access to (optional for reauthentication)
28 29 30 31 32 |
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 28 optional :products, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Connect::SessionReauthenticateParams::Product] }, nil?: true |
#redirect_uri ⇒ String?
The URI to redirect to after the Connect flow is completed
38 |
# File 'lib/finch_api/models/connect/session_reauthenticate_params.rb', line 38 optional :redirect_uri, String, nil?: true |