Class: FinchAPI::Models::CreateAccessTokenResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/create_access_token_response.rb

Overview

Defined Under Namespace

Modules: ClientType, ConnectionType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_token: , account_id: , client_type: , company_id: , connection_id: , connection_type: , products: , provider_id: , customer_id: nil, token_type: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::CreateAccessTokenResponse for more details.

Parameters:

  • access_token (String) (defaults to: )

    The access token for the connection.

  • account_id (String) (defaults to: )
    DEPRECATED

    Use ‘connection_id` to identify the connection instead of this acco

  • client_type (Symbol, FinchAPI::Models::CreateAccessTokenResponse::ClientType) (defaults to: )

    The type of application associated with a token.

  • company_id (String) (defaults to: )
    DEPRECATED

    Use ‘connection_id` to identify the connection instead of this comp

  • connection_id (String) (defaults to: )

    The Finch UUID of the connection associated with the ‘access_token`.

  • connection_type (Symbol, FinchAPI::Models::CreateAccessTokenResponse::ConnectionType) (defaults to: )

    The type of the connection associated with the token.

  • products (Array<String>) (defaults to: )

    An array of the authorized products associated with the ‘access_token`.

  • provider_id (String) (defaults to: )

    The ID of the provider associated with the ‘access_token`.

  • customer_id (String, nil) (defaults to: nil)

    The ID of your customer you provided to Finch when a connect session was created

  • token_type (String) (defaults to: nil)

    The RFC 8693 token type (Finch uses ‘bearer` tokens)



# File 'lib/finch_api/models/create_access_token_response.rb', line 77

Instance Attribute Details

#access_tokenString

The access token for the connection.

Returns:

  • (String)


11
# File 'lib/finch_api/models/create_access_token_response.rb', line 11

required :access_token, String

#account_idString

Deprecated.
DEPRECATED

Use ‘connection_id` to identify the connection instead of this

account ID.

Returns:

  • (String)


20
# File 'lib/finch_api/models/create_access_token_response.rb', line 20

required :account_id, String

#client_typeSymbol, FinchAPI::Models::CreateAccessTokenResponse::ClientType

The type of application associated with a token.



26
# File 'lib/finch_api/models/create_access_token_response.rb', line 26

required :client_type, enum: -> { FinchAPI::CreateAccessTokenResponse::ClientType }

#company_idString

Deprecated.
DEPRECATED

Use ‘connection_id` to identify the connection instead of this

company ID.

Returns:

  • (String)


35
# File 'lib/finch_api/models/create_access_token_response.rb', line 35

required :company_id, String

#connection_idString

The Finch UUID of the connection associated with the ‘access_token`.

Returns:

  • (String)


41
# File 'lib/finch_api/models/create_access_token_response.rb', line 41

required :connection_id, String

#connection_typeSymbol, FinchAPI::Models::CreateAccessTokenResponse::ConnectionType

The type of the connection associated with the token.

  • ‘provider` - connection to an external provider

  • ‘finch` - finch-generated data.



50
# File 'lib/finch_api/models/create_access_token_response.rb', line 50

required :connection_type, enum: -> { FinchAPI::CreateAccessTokenResponse::ConnectionType }

#customer_idString?

The ID of your customer you provided to Finch when a connect session was created for this connection.

Returns:

  • (String, nil)


69
# File 'lib/finch_api/models/create_access_token_response.rb', line 69

optional :customer_id, String, nil?: true

#productsArray<String>

An array of the authorized products associated with the ‘access_token`.

Returns:

  • (Array<String>)


56
# File 'lib/finch_api/models/create_access_token_response.rb', line 56

required :products, FinchAPI::Internal::Type::ArrayOf[String]

#provider_idString

The ID of the provider associated with the ‘access_token`.

Returns:

  • (String)


62
# File 'lib/finch_api/models/create_access_token_response.rb', line 62

required :provider_id, String

#token_typeString?

The RFC 8693 token type (Finch uses ‘bearer` tokens)

Returns:

  • (String, nil)


75
# File 'lib/finch_api/models/create_access_token_response.rb', line 75

optional :token_type, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/create_access_token_response.rb', line 111