Class: FinchAPI::Models::CreateAccessTokenResponse
- Defined in:
- lib/finch-api/models/create_access_token_response.rb
Defined Under Namespace
Modules: ClientType, ConnectionType
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token for the connection.
-
#account_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to identify the connection instead of this account ID.
-
#client_type ⇒ Symbol, FinchAPI::Models::CreateAccessTokenResponse::ClientType
The type of application associated with a token.
-
#company_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to identify the connection instead of this company ID.
-
#connection_id ⇒ String
The Finch UUID of the connection associated with the ‘access_token`.
-
#connection_type ⇒ Symbol, FinchAPI::Models::CreateAccessTokenResponse::ConnectionType
The type of the connection associated with the token.
-
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created for this connection.
-
#products ⇒ Array<String>
An array of the authorized products associated with the ‘access_token`.
-
#provider_id ⇒ String
The ID of the provider associated with the ‘access_token`.
-
#token_type ⇒ String?
The RFC 8693 token type (Finch uses ‘bearer` tokens).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(access_token:, account_id:, client_type:, company_id:, connection_id:, connection_type:, products:, provider_id:, customer_id: nil, token_type: nil) ⇒ CreateAccessTokenResponse
constructor
A new instance of CreateAccessTokenResponse.
Constructor Details
#initialize(access_token:, account_id:, client_type:, company_id:, connection_id:, connection_type:, products:, provider_id:, customer_id: nil, token_type: nil) ⇒ CreateAccessTokenResponse
Returns a new instance of CreateAccessTokenResponse.
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 12 def initialize( access_token:, account_id:, client_type:, company_id:, connection_id:, connection_type:, products:, provider_id:, customer_id: nil, token_type: nil, ** ) super end |
Instance Attribute Details
#access_token ⇒ String
The access token for the connection.
10 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 10 required :access_token, String |
#account_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to identify the connection instead of this
account ID.
17 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 17 required :account_id, String |
#client_type ⇒ Symbol, FinchAPI::Models::CreateAccessTokenResponse::ClientType
The type of application associated with a token.
23 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 23 required :client_type, enum: -> { FinchAPI::Models::CreateAccessTokenResponse::ClientType } |
#company_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to identify the connection instead of this
company ID.
30 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 30 required :company_id, String |
#connection_id ⇒ String
The Finch UUID of the connection associated with the ‘access_token`.
36 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 36 required :connection_id, String |
#connection_type ⇒ Symbol, FinchAPI::Models::CreateAccessTokenResponse::ConnectionType
The type of the connection associated with the token.
- `provider` - connection to an external provider
- `finch` - finch-generated data.
45 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 45 required :connection_type, enum: -> { FinchAPI::Models::CreateAccessTokenResponse::ConnectionType } |
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created
for this connection.
64 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 64 optional :customer_id, String, nil?: true |
#products ⇒ Array<String>
An array of the authorized products associated with the ‘access_token`.
51 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 51 required :products, FinchAPI::ArrayOf[String] |
#provider_id ⇒ String
The ID of the provider associated with the ‘access_token`.
57 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 57 required :provider_id, String |
#token_type ⇒ String?
The RFC 8693 token type (Finch uses ‘bearer` tokens)
70 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 70 optional :token_type, String |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/create_access_token_response.rb', line 2 def self.values; end |