Class: FinchAPI::Models::CreateAccessTokenResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::CreateAccessTokenResponse
- Defined in:
- lib/finch_api/models/create_access_token_response.rb
Overview
Defined Under Namespace
Modules: ClientType, ConnectionType
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token for the connection.
- #account_id ⇒ String? deprecated Deprecated.
-
#client_type ⇒ Symbol, FinchAPI::Models::CreateAccessTokenResponse::ClientType
The type of application associated with a token.
- #company_id ⇒ String? deprecated Deprecated.
-
#connection_id ⇒ String
The Finch UUID of the connection associated with the ‘access_token`.
-
#connection_type ⇒ Symbol, FinchAPI::Models::CreateAccessTokenResponse::ConnectionType
The type of the connection associated with the token.
-
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created for this connection.
-
#entity_ids ⇒ Array<String>
An array of entity IDs that can be accessed with this access token.
-
#products ⇒ Array<String>
An array of the authorized products associated with the ‘access_token`.
-
#provider_id ⇒ String
The ID of the provider associated with the ‘access_token`.
-
#token_type ⇒ String
The RFC 8693 token type (Finch uses ‘bearer` tokens).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(access_token: , client_type: , connection_id: , connection_type: , entity_ids: , products: , provider_id: , token_type: , account_id: nil, company_id: nil, customer_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CreateAccessTokenResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_token: , client_type: , connection_id: , connection_type: , entity_ids: , products: , provider_id: , token_type: , account_id: nil, company_id: nil, customer_id: nil) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::CreateAccessTokenResponse for more details.
|
|
# File 'lib/finch_api/models/create_access_token_response.rb', line 83
|
Instance Attribute Details
#access_token ⇒ String
The access token for the connection
11 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 11 required :access_token, String |
#account_id ⇒ String?
- DEPRECATED
-
Use ‘connection_id` to identify the connection instead of this
account ID
65 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 65 optional :account_id, String |
#client_type ⇒ Symbol, FinchAPI::Models::CreateAccessTokenResponse::ClientType
The type of application associated with a token.
17 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 17 required :client_type, enum: -> { FinchAPI::CreateAccessTokenResponse::ClientType } |
#company_id ⇒ String?
- DEPRECATED
-
Use ‘connection_id` to identify the connection instead of this
company ID
74 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 74 optional :company_id, String |
#connection_id ⇒ String
The Finch UUID of the connection associated with the ‘access_token`
23 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 23 required :connection_id, String |
#connection_type ⇒ Symbol, FinchAPI::Models::CreateAccessTokenResponse::ConnectionType
The type of the connection associated with the token.
-
‘provider` - connection to an external provider
-
‘finch` - finch-generated data.
32 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 32 required :connection_type, enum: -> { FinchAPI::CreateAccessTokenResponse::ConnectionType } |
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created for this connection
81 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 81 optional :customer_id, String, nil?: true |
#entity_ids ⇒ Array<String>
An array of entity IDs that can be accessed with this access token
38 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 38 required :entity_ids, FinchAPI::Internal::Type::ArrayOf[String] |
#products ⇒ Array<String>
An array of the authorized products associated with the ‘access_token`
44 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 44 required :products, FinchAPI::Internal::Type::ArrayOf[String] |
#provider_id ⇒ String
The ID of the provider associated with the ‘access_token`
50 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 50 required :provider_id, String |
#token_type ⇒ String
The RFC 8693 token type (Finch uses ‘bearer` tokens)
56 |
# File 'lib/finch_api/models/create_access_token_response.rb', line 56 required :token_type, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/create_access_token_response.rb', line 119
|