Class: FinchAPI::Models::HRIS::BenefitCreateParams
- Includes:
- Type::RequestParameters
- Defined in:
- lib/finch-api/models/hris/benefit_create_params.rb
Instance Attribute Summary collapse
-
#description ⇒ String?
Name of the benefit as it appears in the provider and pay statements.
- #frequency ⇒ Symbol, ...
-
#type ⇒ Symbol, ...
Type of benefit.
Attributes included from Type::RequestParameters
Instance Method Summary collapse
-
#initialize(description: nil, frequency: nil, type: nil, request_options: {}) ⇒ BenefitCreateParams
constructor
A new instance of BenefitCreateParams.
Methods included from Type::RequestParameters
Constructor Details
#initialize(description: nil, frequency: nil, type: nil, request_options: {}) ⇒ BenefitCreateParams
Returns a new instance of BenefitCreateParams.
6 |
# File 'lib/finch-api/models/hris/benefit_create_params.rb', line 6 def initialize(description: nil, frequency: nil, type: nil, request_options: {}, **) = super |
Instance Attribute Details
#description ⇒ String?
Name of the benefit as it appears in the provider and pay statements. Recommend
limiting this to <30 characters due to limitations in specific providers (e.g.
Justworks).
17 |
# File 'lib/finch-api/models/hris/benefit_create_params.rb', line 17 optional :description, String |
#frequency ⇒ Symbol, ...
26 |
# File 'lib/finch-api/models/hris/benefit_create_params.rb', line 26 optional :frequency, enum: -> { FinchAPI::Models::HRIS::BenefitFrequency }, nil?: true |
#type ⇒ Symbol, ...
Type of benefit.
32 |
# File 'lib/finch-api/models/hris/benefit_create_params.rb', line 32 optional :type, enum: -> { FinchAPI::Models::HRIS::BenefitType }, nil?: true |