Class: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures
- Defined in:
- lib/finch_api/models/hris/benefit_features_and_operations.rb
Overview
Defined Under Namespace
Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit
Instance Attribute Summary collapse
-
#annual_maximum ⇒ Boolean?
Whether the provider supports an annual maximum for this benefit.
-
#catch_up ⇒ Boolean?
Whether the provider supports catch up for this benefit.
-
#company_contribution ⇒ Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution, nil>?
Supported contribution types.
- #description ⇒ String?
-
#employee_deduction ⇒ Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil>?
Supported deduction types.
-
#frequencies ⇒ Array<Symbol, FinchAPI::HRIS::BenefitFrequency, nil>?
The list of frequencies supported by the provider for this benefit.
-
#hsa_contribution_limit ⇒ Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit, nil>?
Whether the provider supports HSA contribution limits.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#annual_maximum ⇒ Boolean?
Whether the provider supports an annual maximum for this benefit.
27 |
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 27 optional :annual_maximum, FinchAPI::Internal::Type::Boolean, nil?: true |
#catch_up ⇒ Boolean?
Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.
34 |
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 34 optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true |
#company_contribution ⇒ Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution, nil>?
Supported contribution types. An empty array indicates contributions are not supported.
41 42 43 44 45 46 |
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 41 optional :company_contribution, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution, nil?: true] }, nil?: true |
#description ⇒ String?
51 |
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 51 optional :description, String, nil?: true |
#employee_deduction ⇒ Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil>?
Supported deduction types. An empty array indicates deductions are not supported.
58 59 60 61 62 63 |
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 58 optional :employee_deduction, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil?: true] }, nil?: true |
#frequencies ⇒ Array<Symbol, FinchAPI::HRIS::BenefitFrequency, nil>?
The list of frequencies supported by the provider for this benefit
69 70 71 72 |
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 69 optional :frequencies, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFrequency, nil?: true] } |
#hsa_contribution_limit ⇒ Array<Symbol, FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit, nil>?
Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.
79 80 81 82 83 84 |
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 79 optional :hsa_contribution_limit, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit, nil?: true] }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/benefit_features_and_operations.rb', line 111
|