Class: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures
- Inherits:
-
BaseModel
- Object
- FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures
- Defined in:
- lib/finch-api/models/hris/benefit_features_and_operations.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Defined Under Namespace
Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit
Instance Attribute Summary collapse
-
#annual_maximum ⇒ Boolean?
Whether the provider supports an annual maximum for this benefit.
-
#catch_up ⇒ Boolean?
Whether the provider supports catch up for this benefit.
-
#company_contribution ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution, nil>?
Supported contribution types.
- #description ⇒ String?
-
#employee_deduction ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil>?
Supported deduction types.
-
#frequencies ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>?
The list of frequencies supported by the provider for this benefit.
-
#hsa_contribution_limit ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit, nil>?
Whether the provider supports HSA contribution limits.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, description: nil, employee_deduction: nil, frequencies: nil, hsa_contribution_limit: nil) ⇒ SupportedFeatures
constructor
A new instance of SupportedFeatures.
Constructor Details
#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, description: nil, employee_deduction: nil, frequencies: nil, hsa_contribution_limit: nil) ⇒ SupportedFeatures
Returns a new instance of SupportedFeatures.
9 10 11 12 13 14 15 16 17 18 19 20 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 9 def initialize( annual_maximum: nil, catch_up: nil, company_contribution: nil, description: nil, employee_deduction: nil, frequencies: nil, hsa_contribution_limit: nil, ** ) super end |
Instance Attribute Details
#annual_maximum ⇒ Boolean?
Whether the provider supports an annual maximum for this benefit.
39 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 39 optional :annual_maximum, FinchAPI::BooleanModel, nil?: true |
#catch_up ⇒ Boolean?
Whether the provider supports catch up for this benefit. This field will only be
true for retirement benefits.
46 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 46 optional :catch_up, FinchAPI::BooleanModel, nil?: true |
#company_contribution ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution, nil>?
Supported contribution types. An empty array indicates contributions are not
supported.
53 54 55 56 57 58 59 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 53 optional :company_contribution, -> do FinchAPI::ArrayOf[ enum: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::CompanyContribution, nil?: true ] end, nil?: true |
#description ⇒ String?
64 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 64 optional :description, String, nil?: true |
#employee_deduction ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil>?
Supported deduction types. An empty array indicates deductions are not
supported.
71 72 73 74 75 76 77 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 71 optional :employee_deduction, -> do FinchAPI::ArrayOf[ enum: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::EmployeeDeduction, nil?: true ] end, nil?: true |
#frequencies ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>?
The list of frequencies supported by the provider for this benefit
83 84 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 83 optional :frequencies, -> { FinchAPI::ArrayOf[enum: FinchAPI::Models::HRIS::BenefitFrequency, nil?: true] } |
#hsa_contribution_limit ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit, nil>?
Whether the provider supports HSA contribution limits. Empty if this feature is
not supported for the benefit. This array only has values for HSA benefits.
95 96 97 98 99 100 101 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 95 optional :hsa_contribution_limit, -> do FinchAPI::ArrayOf[ enum: FinchAPI::Models::HRIS::BenefitFeaturesAndOperations::SupportedFeatures::HsaContributionLimit, nil?: true ] end, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/hris/benefit_features_and_operations.rb', line 2 def self.values; end |