Class: FinchAPI::Models::HRIS::Benefits::EnrolledIndividual::Body
- Inherits:
-
BaseModel
- Object
- BaseModel
- FinchAPI::Models::HRIS::Benefits::EnrolledIndividual::Body
- Defined in:
- lib/finch-api/models/hris/benefits/enrolled_individual.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Instance Attribute Summary collapse
-
#finch_code ⇒ String?
A descriptive identifier for the response.
-
#message ⇒ String?
Short description in English that provides more information about the response.
-
#name ⇒ String?
Identifier indicating whether the benefit was newly enrolled or updated.
Method Summary
Methods inherited from BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, #initialize, #inspect, known_fields, optional, required, #to_h
Methods included from Converter
#coerce, coerce, #dump, dump, type_info
Constructor Details
This class inherits a constructor from FinchAPI::BaseModel
Instance Attribute Details
#finch_code ⇒ String?
A descriptive identifier for the response
50 |
# File 'lib/finch-api/models/hris/benefits/enrolled_individual.rb', line 50 optional :finch_code, String, nil?: true |
#message ⇒ String?
Short description in English that provides more information about the response.
56 |
# File 'lib/finch-api/models/hris/benefits/enrolled_individual.rb', line 56 optional :message, String, nil?: true |
#name ⇒ String?
Identifier indicating whether the benefit was newly enrolled or updated.
62 |
# File 'lib/finch-api/models/hris/benefits/enrolled_individual.rb', line 62 optional :name, String, nil?: true |