Class: FinchAPI::Models::HRIS::Benefits::EnrolledIndividual::Body

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/hris/benefits/enrolled_individual.rb

Overview

def initialize: (Hash | FinchAPI::BaseModel) -> void

Instance Attribute Summary collapse

Instance Attribute Details

#finch_codeString?

A descriptive identifier for the response

Returns:

  • (String, nil)


50
# File 'lib/finch-api/models/hris/benefits/enrolled_individual.rb', line 50

optional :finch_code, String, nil?: true

#messageString?

Short description in English that provides more information about the response.

Returns:

  • (String, nil)


56
# File 'lib/finch-api/models/hris/benefits/enrolled_individual.rb', line 56

optional :message, String, nil?: true

#nameString?

Identifier indicating whether the benefit was newly enrolled or updated.

Returns:

  • (String, nil)


62
# File 'lib/finch-api/models/hris/benefits/enrolled_individual.rb', line 62

optional :name, String, nil?: true