Class: FinchAPI::Models::HRIS::Benefits::IndividualBenefit::Body

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/benefits/individual_benefit.rb

Overview

See Also:

  • HRIS::Benefits::IndividualBenefit#body

Defined Under Namespace

Modules: HsaContributionLimit

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, employee_deduction: nil, hsa_contribution_limit: nil) ⇒ Object

Some parameter documentations has been truncated, see HRIS::Benefits::IndividualBenefit::Body for more details.

Parameters:

  • annual_maximum (Integer, nil) (defaults to: nil)

    If the benefit supports annual maximum, the amount in cents for this individual.

  • catch_up (Boolean, nil) (defaults to: nil)

    If the benefit supports catch up (401k, 403b, etc.), whether catch up is enabled

  • company_contribution (FinchAPI::HRIS::BenefitContribution, nil) (defaults to: nil)
  • employee_deduction (FinchAPI::HRIS::BenefitContribution, nil) (defaults to: nil)
  • hsa_contribution_limit (Symbol, FinchAPI::HRIS::Benefits::IndividualBenefit::Body::HsaContributionLimit, nil) (defaults to: nil)

    Type for HSA contribution limit if the benefit is a HSA.



# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 62

Instance Attribute Details

#annual_maximumInteger?

If the benefit supports annual maximum, the amount in cents for this individual.

Returns:

  • (Integer, nil)


35
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 35

optional :annual_maximum, Integer, nil?: true

#catch_upBoolean?

If the benefit supports catch up (401k, 403b, etc.), whether catch up is enabled for this individual.

Returns:

  • (Boolean, nil)


42
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 42

optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true

#company_contributionFinchAPI::HRIS::BenefitContribution?



47
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 47

optional :company_contribution, -> { FinchAPI::HRIS::BenefitContribution }, nil?: true

#employee_deductionFinchAPI::HRIS::BenefitContribution?



52
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 52

optional :employee_deduction, -> { FinchAPI::HRIS::BenefitContribution }, nil?: true

#hsa_contribution_limitSymbol, ...

Type for HSA contribution limit if the benefit is a HSA.

Returns:

  • (Symbol, FinchAPI::HRIS::Benefits::IndividualBenefit::Body::HsaContributionLimit, nil)


58
59
60
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 58

optional :hsa_contribution_limit,
enum: -> { FinchAPI::HRIS::Benefits::IndividualBenefit::Body::HsaContributionLimit },
nil?: true