Class: FinchAPI::Models::HRIS::Benefits::IndividualBenefit::Body
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Benefits::IndividualBenefit::Body
- Defined in:
- lib/finch_api/models/hris/benefits/individual_benefit.rb
Overview
Defined Under Namespace
Modules: HsaContributionLimit
Instance Attribute Summary collapse
-
#annual_maximum ⇒ Integer?
If the benefit supports annual maximum, the amount in cents for this individual.
-
#catch_up ⇒ Boolean?
If the benefit supports catch up (401k, 403b, etc.), whether catch up is enabled for this individual.
- #company_contribution ⇒ FinchAPI::HRIS::BenefitContribution?
- #employee_deduction ⇒ FinchAPI::HRIS::BenefitContribution?
-
#hsa_contribution_limit ⇒ Symbol, ...
Type for HSA contribution limit if the benefit is a HSA.
Instance Method Summary collapse
-
#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, employee_deduction: nil, hsa_contribution_limit: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see HRIS::Benefits::IndividualBenefit::Body for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, employee_deduction: nil, hsa_contribution_limit: nil) ⇒ Object
Some parameter documentations has been truncated, see HRIS::Benefits::IndividualBenefit::Body for more details.
|
|
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 62
|
Instance Attribute Details
#annual_maximum ⇒ Integer?
If the benefit supports annual maximum, the amount in cents for this individual.
35 |
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 35 optional :annual_maximum, Integer, nil?: true |
#catch_up ⇒ Boolean?
If the benefit supports catch up (401k, 403b, etc.), whether catch up is enabled for this individual.
42 |
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 42 optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true |
#company_contribution ⇒ FinchAPI::HRIS::BenefitContribution?
47 |
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 47 optional :company_contribution, -> { FinchAPI::HRIS::BenefitContribution }, nil?: true |
#employee_deduction ⇒ FinchAPI::HRIS::BenefitContribution?
52 |
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 52 optional :employee_deduction, -> { FinchAPI::HRIS::BenefitContribution }, nil?: true |
#hsa_contribution_limit ⇒ Symbol, ...
Type for HSA contribution limit if the benefit is a HSA.
58 59 60 |
# File 'lib/finch_api/models/hris/benefits/individual_benefit.rb', line 58 optional :hsa_contribution_limit, enum: -> { FinchAPI::HRIS::Benefits::IndividualBenefit::Body::HsaContributionLimit }, nil?: true |