Class: FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution
- Inherits:
-
BaseModel
- Object
- FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution
- Defined in:
- lib/finch-api/models/hris/benefits/individual_enroll_many_params.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
Amount in cents for fixed type or basis points (1/100th of a percent) for percent type.
- #type ⇒ Symbol, ...
Instance Method Summary collapse
-
#initialize(amount: nil, type: nil) ⇒ CompanyContribution
constructor
A new instance of CompanyContribution.
Constructor Details
#initialize(amount: nil, type: nil) ⇒ CompanyContribution
Returns a new instance of CompanyContribution.
4 |
# File 'lib/finch-api/models/hris/benefits/individual_enroll_many_params.rb', line 4 def initialize(amount: nil, type: nil, **) = super |
Instance Attribute Details
#amount ⇒ Integer?
Amount in cents for fixed type or basis points (1/100th of a percent) for
percent type
150 |
# File 'lib/finch-api/models/hris/benefits/individual_enroll_many_params.rb', line 150 optional :amount, Integer |
#type ⇒ Symbol, ...
159 160 |
# File 'lib/finch-api/models/hris/benefits/individual_enroll_many_params.rb', line 159 optional :type, enum: -> { FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Type } |