Class: FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution
- Defined in:
- lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
Amount in cents for fixed type or basis points (1/100th of a percent) for percent type.
-
#tiers ⇒ Array<FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Tier>?
Array of tier objects for tiered contribution matching (required when type is tiered).
- #type ⇒ Symbol, ...
Instance Method Summary collapse
- #initialize(match: , threshold: ) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(match: , threshold: ) ⇒ Object
|
|
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 168
|
Instance Attribute Details
#amount ⇒ Integer?
Amount in cents for fixed type or basis points (1/100th of a percent) for percent type
128 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 128 optional :amount, Integer |
#tiers ⇒ Array<FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Tier>?
Array of tier objects for tiered contribution matching (required when type is tiered)
135 136 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 135 optional :tiers, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::CompanyContribution::Tier] } |