Class: FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction
- Inherits:
-
BaseModel
- Object
- FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction
- Defined in:
- lib/finch-api/models/hris/benefits/individual_enroll_many_params.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
Amount in cents for fixed type or basis points (1/100th of a percent) for percent type.
- #type ⇒ Symbol, ...
Instance Method Summary collapse
-
#initialize(amount: nil, type: nil) ⇒ EmployeeDeduction
constructor
A new instance of EmployeeDeduction.
Constructor Details
#initialize(amount: nil, type: nil) ⇒ EmployeeDeduction
Returns a new instance of EmployeeDeduction.
4 |
# File 'lib/finch-api/models/hris/benefits/individual_enroll_many_params.rb', line 4 def initialize(amount: nil, type: nil, **) = super |
Instance Attribute Details
#amount ⇒ Integer?
Amount in cents for fixed type or basis points (1/100th of a percent) for
percent type
194 |
# File 'lib/finch-api/models/hris/benefits/individual_enroll_many_params.rb', line 194 optional :amount, Integer |
#type ⇒ Symbol, ...
203 204 |
# File 'lib/finch-api/models/hris/benefits/individual_enroll_many_params.rb', line 203 optional :type, enum: -> { FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction::Type } |