Class: FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction
- Defined in:
- lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
Amount in cents for fixed type or basis points (1/100th of a percent) for percent type.
- #type ⇒ Symbol, ...
Instance Method Summary collapse
-
#initialize(amount: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EmployeeDeduction for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::Benefits::IndividualEnrollManyParams::Individual::Configuration::EmployeeDeduction for more details.
|
|
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 202
|
Instance Attribute Details
#amount ⇒ Integer?
Amount in cents for fixed type or basis points (1/100th of a percent) for percent type
194 |
# File 'lib/finch_api/models/hris/benefits/individual_enroll_many_params.rb', line 194 optional :amount, Integer |