Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb
Overview
Defined Under Namespace
Modules: EntityType Classes: Attributes, Condition
Instance Attribute Summary collapse
-
#attributes ⇒ FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Attributes?
Specifies the fields to be applied when the condition is met.
- #conditions ⇒ Array<FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Condition>?
-
#effective_end_date ⇒ String?
Specifies when the rules should stop applying rules based on the date.
-
#effective_start_date ⇒ String?
Specifies when the rule should begin applying based on the date.
-
#entity_type ⇒ Symbol, ...
The entity type to which the rule is applied.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see HRIS::Company::PayStatementItem::RuleCreateParams::Attributes for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see HRIS::Company::PayStatementItem::RuleCreateParams::Attributes for more details.
Specifies the fields to be applied when the condition is met.
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 70
|
Instance Attribute Details
#attributes ⇒ FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Attributes?
Specifies the fields to be applied when the condition is met.
17 18 19 20 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 17 optional :attributes, -> { FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Attributes } |
#conditions ⇒ Array<FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Condition>?
25 26 27 28 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 25 optional :conditions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Condition] } |
#effective_end_date ⇒ String?
Specifies when the rules should stop applying rules based on the date.
34 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 34 optional :effective_end_date, String, nil?: true |
#effective_start_date ⇒ String?
Specifies when the rule should begin applying based on the date.
40 |
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 40 optional :effective_start_date, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 117
|