Class: FinchAPI::Models::HRIS::Company::PayStatementItem::RuleCreateParams::Attributes

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(attributes: nil, conditions: nil, effective_end_date: nil, effective_start_date: nil, entity_type: nil, request_options: {}) ⇒ Object

Parameters:

  • attributes (FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Attributes) (defaults to: nil)

    Specifies the fields to be applied when the condition is met.

  • conditions (Array<FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Condition>) (defaults to: nil)
  • effective_end_date (String, nil) (defaults to: nil)

    Specifies when the rules should stop applying rules based on the date.

  • effective_start_date (String, nil) (defaults to: nil)

    Specifies when the rule should begin applying based on the date.

  • entity_type (Symbol, FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::EntityType) (defaults to: nil)

    The entity type to which the rule is applied.

  • request_options (FinchAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 62

class Attributes < FinchAPI::Internal::Type::BaseModel
  # @!attribute metadata
  #   The metadata to be attached in the entity. It is a key-value pairs where the
  #   values can be of any type (string, number, boolean, object, array, etc.).
  #
  #   @return [Hash{Symbol=>Object}, nil]
  optional :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown]

  # @!method initialize(metadata: nil)
  #   Some parameter documentations has been truncated, see
  #   {FinchAPI::HRIS::Company::PayStatementItem::RuleCreateParams::Attributes} for
  #   more details.
  #
  #   Specifies the fields to be applied when the condition is met.
  #
  #   @param metadata [Hash{Symbol=>Object}] The metadata to be attached in the entity. It is a key-value pairs where the val
end

Instance Attribute Details

#metadataHash{Symbol=>Object}?

The metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).

Returns:

  • (Hash{Symbol=>Object}, nil)


68
# File 'lib/finch_api/models/hris/company/pay_statement_item/rule_create_params.rb', line 68

optional :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown]