Class: FinchAPI::Models::HRIS::Company::PayStatementItemListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/hris/company/pay_statement_item_list_params.rb

Overview

Defined Under Namespace

Modules: Category

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#categoriesArray<Symbol, FinchAPI::HRIS::Company::PayStatementItemListParams::Category>?

Comma-delimited list of pay statement item categories to filter on. If empty, defaults to all categories.

Returns:

  • (Array<Symbol, FinchAPI::HRIS::Company::PayStatementItemListParams::Category>, nil)


17
18
19
20
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 17

optional :categories,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::Company::PayStatementItemListParams::Category]
}

#end_dateDate?

The end date to retrieve pay statement items by via their last seen pay date in ‘YYYY-MM-DD` format.

Returns:

  • (Date, nil)


27
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 27

optional :end_date, Date

#nameString?

Case-insensitive partial match search by pay statement item name.

Returns:

  • (String, nil)


33
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 33

optional :name, String

#start_dateDate?

The start date to retrieve pay statement items by via their last seen pay date (inclusive) in ‘YYYY-MM-DD` format.

Returns:

  • (Date, nil)


40
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 40

optional :start_date, Date

#typeString?

String search by pay statement item type.

Returns:

  • (String, nil)


46
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 46

optional :type, String