Class: FinchAPI::Models::HRIS::Company::PayStatementItemListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::Company::PayStatementItemListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/hris/company/pay_statement_item_list_params.rb
Overview
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#categories ⇒ Array<Symbol, FinchAPI::Models::HRIS::Company::PayStatementItemListParams::Category>?
Comma-delimited list of pay statement item categories to filter on.
-
#end_date ⇒ Date?
The end date to retrieve pay statement items by via their last seen pay date in ‘YYYY-MM-DD` format.
-
#name ⇒ String?
Case-insensitive partial match search by pay statement item name.
-
#start_date ⇒ Date?
The start date to retrieve pay statement items by via their last seen pay date (inclusive) in ‘YYYY-MM-DD` format.
-
#type ⇒ String?
String search by pay statement item type.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#categories ⇒ Array<Symbol, FinchAPI::Models::HRIS::Company::PayStatementItemListParams::Category>?
Comma-delimited list of pay statement item categories to filter on. If empty, defaults to all categories.
17 18 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 17 optional :categories, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::Company::PayStatementItemListParams::Category] } |
#end_date ⇒ Date?
The end date to retrieve pay statement items by via their last seen pay date in ‘YYYY-MM-DD` format.
25 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 25 optional :end_date, Date |
#name ⇒ String?
Case-insensitive partial match search by pay statement item name.
31 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 31 optional :name, String |
#start_date ⇒ Date?
The start date to retrieve pay statement items by via their last seen pay date (inclusive) in ‘YYYY-MM-DD` format.
38 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 38 optional :start_date, Date |
#type ⇒ String?
String search by pay statement item type.
44 |
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_params.rb', line 44 optional :type, String |