Class: FinchAPI::Models::HRIS::Company::PayStatementItemListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/company/pay_statement_item_list_response.rb

Overview

Defined Under Namespace

Modules: Category Classes: Attributes

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(employer: nil, metadata: nil, pre_tax: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see Attributes for more details.

The attributes of the pay statement item.

Parameters:

  • employer (Boolean, nil) (defaults to: nil)

    ‘true` if the amount is paid by the employers. This field is only available for

  • metadata (Hash{Symbol=>Object, nil}, nil) (defaults to: nil)

    The metadata of the pay statement item derived by the rules engine if available.

  • pre_tax (Boolean, nil) (defaults to: nil)

    ‘true` if the pay statement item is pre-tax. This field is only available for em

  • type (String, nil) (defaults to: nil)

    The type of the pay statement item.



# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 27

Instance Attribute Details

#attributesFinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Attributes?

The attributes of the pay statement item.



13
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 13

optional :attributes, -> { FinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Attributes }

#categorySymbol, ...

The category of the pay statement item.



19
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 19

optional :category, enum: -> { FinchAPI::Models::HRIS::Company::PayStatementItemListResponse::Category }

#nameString?

The name of the pay statement item.

Returns:

  • (String, nil)


25
# File 'lib/finch_api/models/hris/company/pay_statement_item_list_response.rb', line 25

optional :name, String