Class: FinchAPI::Models::HRIS::DocumentListParams
- Includes:
- Type::RequestParameters
- Defined in:
- lib/finch-api/models/hris/document_list_params.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#individual_ids ⇒ Array<String>?
Comma-delimited list of stable Finch uuids for each individual.
-
#limit ⇒ Integer?
Number of documents to return (defaults to all).
-
#offset ⇒ Integer?
Index to start from (defaults to 0).
-
#types ⇒ Array<Symbol, FinchAPI::Models::HRIS::DocumentListParams::Type>?
Comma-delimited list of document types to filter on.
Attributes included from Type::RequestParameters
Instance Method Summary collapse
-
#initialize(individual_ids: nil, limit: nil, offset: nil, types: nil, request_options: {}) ⇒ DocumentListParams
constructor
A new instance of DocumentListParams.
Methods included from Type::RequestParameters
Constructor Details
#initialize(individual_ids: nil, limit: nil, offset: nil, types: nil, request_options: {}) ⇒ DocumentListParams
Returns a new instance of DocumentListParams.
7 |
# File 'lib/finch-api/models/hris/document_list_params.rb', line 7 def initialize(individual_ids: nil, limit: nil, offset: nil, types: nil, request_options: {}, **) = super |
Instance Attribute Details
#individual_ids ⇒ Array<String>?
Comma-delimited list of stable Finch uuids for each individual. If empty,
defaults to all individuals
16 |
# File 'lib/finch-api/models/hris/document_list_params.rb', line 16 optional :individual_ids, FinchAPI::ArrayOf[String] |
#limit ⇒ Integer?
Number of documents to return (defaults to all)
26 |
# File 'lib/finch-api/models/hris/document_list_params.rb', line 26 optional :limit, Integer |
#offset ⇒ Integer?
Index to start from (defaults to 0)
36 |
# File 'lib/finch-api/models/hris/document_list_params.rb', line 36 optional :offset, Integer |
#types ⇒ Array<Symbol, FinchAPI::Models::HRIS::DocumentListParams::Type>?
Comma-delimited list of document types to filter on. If empty, defaults to all
types
47 |
# File 'lib/finch-api/models/hris/document_list_params.rb', line 47 optional :types, -> { FinchAPI::ArrayOf[enum: FinchAPI::Models::HRIS::DocumentListParams::Type] } |