Class: FinchAPI::Models::HRIS::EmploymentData
- Defined in:
- lib/finch-api/models/hris/employment_data.rb
Defined Under Namespace
Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::HRIS::EmploymentData::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::HRIS::EmploymentData::Department?
The department object.
-
#employment ⇒ FinchAPI::Models::HRIS::EmploymentData::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#id ⇒ String?
string A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#income ⇒ FinchAPI::Models::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Models::Location?
-
#manager ⇒ FinchAPI::Models::HRIS::EmploymentData::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
- #value ⇒ Object writeonly
-
#work_id ⇒ String?
This field is deprecated in favour of ‘source_id`.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ EmploymentData
constructor
The department object.
Constructor Details
#initialize(name: nil) ⇒ EmploymentData
The department object.
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 22 def initialize( id: nil, class_code: nil, custom_fields: nil, department: nil, employment: nil, employment_status: nil, end_date: nil, first_name: nil, income: nil, income_history: nil, is_active: nil, last_name: nil, latest_rehire_date: nil, location: nil, manager: nil, middle_name: nil, source_id: nil, start_date: nil, title: nil, work_id: nil, ** ) super end |
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
21 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 21 optional :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::HRIS::EmploymentData::CustomField>?
Custom fields for the individual. These are fields which are defined by the
employer in the system.
28 29 30 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 28 optional :custom_fields, -> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::EmploymentData::CustomField] }, nil?: true |
#department ⇒ FinchAPI::Models::HRIS::EmploymentData::Department?
The department object.
36 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 36 optional :department, -> { FinchAPI::Models::HRIS::EmploymentData::Department }, nil?: true |
#employment ⇒ FinchAPI::Models::HRIS::EmploymentData::Employment?
The employment object.
42 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 42 optional :employment, -> { FinchAPI::Models::HRIS::EmploymentData::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual. Available options: ‘active`,
`deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.
49 50 51 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 49 optional :employment_status, enum: -> { FinchAPI::Models::HRIS::EmploymentData::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
56 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 56 optional :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
62 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 62 optional :first_name, String, nil?: true |
#id ⇒ String?
string A stable Finch ‘id` (UUID v4) for an individual in the company.
11 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 11 optional :id, String |
#income ⇒ FinchAPI::Models::Income?
The employee’s income as reported by the provider. This may not always be
annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc,
depending on what information the provider returns.
70 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 70 optional :income, -> { FinchAPI::Models::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
76 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 76 optional :income_history, -> { FinchAPI::ArrayOf[FinchAPI::Models::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
82 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 82 optional :is_active, FinchAPI::BooleanModel, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
88 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 88 optional :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
93 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 93 optional :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Models::Location?
98 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 98 optional :location, -> { FinchAPI::Models::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::HRIS::EmploymentData::Manager?
The manager object representing the manager of the individual within the org.
104 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 104 optional :manager, -> { FinchAPI::Models::HRIS::EmploymentData::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
110 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 110 optional :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
116 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 116 optional :source_id, String, nil?: true |
#start_date ⇒ String?
121 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 121 optional :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
127 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 127 optional :title, String, nil?: true |
#value=(value) ⇒ Object (writeonly)
2 3 4 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 2 def value=(value) @value = value end |
#work_id ⇒ String?
This field is deprecated in favour of ‘source_id`
133 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 133 optional :work_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/hris/employment_data.rb', line 2 def self.values; end |