Class: FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody
- Defined in:
- lib/finch_api/models/hris/employment_data.rb
Defined Under Namespace
Modules: EmploymentStatus, FlsaStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Department?
The department object.
-
#employment ⇒ FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#flsa_status ⇒ Symbol, ...
The FLSA status of the individual.
-
#id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#income ⇒ FinchAPI::Models::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Models::Location?
-
#manager ⇒ FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
- #work_id ⇒ String? deprecated Deprecated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
The manager object representing the manager of the individual within the org.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
The manager object representing the manager of the individual within the org.
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 161
|
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
24 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 24 required :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
125 126 127 128 129 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 125 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::CustomField] }, nil?: true |
#department ⇒ FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Department?
The department object.
30 31 32 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 30 required :department, -> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Department }, nil?: true |
#employment ⇒ FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Employment?
The employment object.
38 39 40 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 38 required :employment, -> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
46 47 48 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 46 required :employment_status, enum: -> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
53 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 53 required :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
59 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 59 required :first_name, String, nil?: true |
#flsa_status ⇒ Symbol, ...
The FLSA status of the individual. Available options: ‘exempt`, `non_exempt`, `unknown`.
66 67 68 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 66 required :flsa_status, enum: -> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::FlsaStatus }, nil?: true |
#id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
18 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 18 required :id, String |
#income ⇒ FinchAPI::Models::Income?
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
137 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 137 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
143 144 145 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 143 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
74 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 74 required :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
80 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 80 required :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
85 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 85 required :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Models::Location?
90 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 90 required :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::HRIS::EmploymentData::EmploymentDataResponseBody::Manager?
The manager object representing the manager of the individual within the org.
96 97 98 99 100 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 96 required :manager, -> { FinchAPI::HRIS::EmploymentData::EmploymentDataResponseBody::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
106 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 106 required :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
151 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 151 optional :source_id, String, nil?: true |
#start_date ⇒ String?
111 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 111 required :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
117 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 117 required :title, String, nil?: true |
#work_id ⇒ String?
This field is deprecated in favour of ‘source_id`
159 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 159 optional :work_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 283
|