Class: FinchAPI::Models::HRIS::EmploymentData::UnionMember0
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::EmploymentData::UnionMember0
- Defined in:
- lib/finch_api/models/hris/employment_data.rb
Defined Under Namespace
Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Department?
The department object.
-
#employment ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Location?
-
#manager ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
- #work_id ⇒ String? deprecated Deprecated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: ) ⇒ Object
constructor
The department object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(name: ) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 237
|
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
24 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 24 required :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system.
31 32 33 34 35 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 31 required :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField] }, nil?: true |
#department ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Department?
The department object.
41 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 41 required :department, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Department }, nil?: true |
#employment ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Employment?
The employment object.
47 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 47 required :employment, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.
54 55 56 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 54 required :employment_status, enum: -> { FinchAPI::HRIS::EmploymentData::UnionMember0::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
61 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 61 required :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
67 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 67 required :first_name, String, nil?: true |
#id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
18 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 18 required :id, String |
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
134 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 134 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
140 141 142 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 140 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
73 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 73 required :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
79 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 79 required :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
84 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 84 required :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Location?
89 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 89 required :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Manager?
The manager object representing the manager of the individual within the org.
95 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 95 required :manager, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
101 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 101 required :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
107 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 107 required :source_id, String, nil?: true |
#start_date ⇒ String?
112 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 112 required :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
118 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 118 required :title, String, nil?: true |
#work_id ⇒ String?
This field is deprecated in favour of ‘source_id`
126 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 126 required :work_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 301
|