Class: FinchAPI::Models::HRIS::EmploymentData::UnionMember0

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/employment_data.rb

Defined Under Namespace

Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: ) ⇒ Object

The manager object representing the manager of the individual within the org.

Parameters:

  • id (String) (defaults to: )

    A stable Finch ‘id` (UUID v4) for an individual in the company.



# File 'lib/finch_api/models/hris/employment_data.rb', line 145

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


24
# File 'lib/finch_api/models/hris/employment_data.rb', line 24

required :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Models::HRIS::EmploymentData::UnionMember0::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.



109
110
111
112
113
# File 'lib/finch_api/models/hris/employment_data.rb', line 109

optional :custom_fields,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField]
},
nil?: true

#departmentFinchAPI::Models::HRIS::EmploymentData::UnionMember0::Department?

The department object.



30
# File 'lib/finch_api/models/hris/employment_data.rb', line 30

required :department, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Department }, nil?: true

#employmentFinchAPI::Models::HRIS::EmploymentData::UnionMember0::Employment?

The employment object.



36
# File 'lib/finch_api/models/hris/employment_data.rb', line 36

required :employment, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.



43
44
45
# File 'lib/finch_api/models/hris/employment_data.rb', line 43

required :employment_status,
enum: -> { FinchAPI::HRIS::EmploymentData::UnionMember0::EmploymentStatus },
nil?: true

#end_dateString?

Returns:

  • (String, nil)


50
# File 'lib/finch_api/models/hris/employment_data.rb', line 50

required :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


56
# File 'lib/finch_api/models/hris/employment_data.rb', line 56

required :first_name, String, nil?: true

#idString

A stable Finch ‘id` (UUID v4) for an individual in the company.

Returns:

  • (String)


18
# File 'lib/finch_api/models/hris/employment_data.rb', line 18

required :id, String

#incomeFinchAPI::Models::Income?

The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Returns:



121
# File 'lib/finch_api/models/hris/employment_data.rb', line 121

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Models::Income, nil>?

The array of income history.

Returns:



127
128
129
# File 'lib/finch_api/models/hris/employment_data.rb', line 127

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


62
# File 'lib/finch_api/models/hris/employment_data.rb', line 62

required :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


68
# File 'lib/finch_api/models/hris/employment_data.rb', line 68

required :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


73
# File 'lib/finch_api/models/hris/employment_data.rb', line 73

required :latest_rehire_date, String, nil?: true

#locationFinchAPI::Models::Location?

Returns:



78
# File 'lib/finch_api/models/hris/employment_data.rb', line 78

required :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::Models::HRIS::EmploymentData::UnionMember0::Manager?

The manager object representing the manager of the individual within the org.



84
# File 'lib/finch_api/models/hris/employment_data.rb', line 84

required :manager, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


90
# File 'lib/finch_api/models/hris/employment_data.rb', line 90

required :middle_name, String, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


135
# File 'lib/finch_api/models/hris/employment_data.rb', line 135

optional :source_id, String, nil?: true

#start_dateString?

Returns:

  • (String, nil)


95
# File 'lib/finch_api/models/hris/employment_data.rb', line 95

required :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


101
# File 'lib/finch_api/models/hris/employment_data.rb', line 101

required :title, String, nil?: true

#work_idString?

Deprecated.

This field is deprecated in favour of ‘source_id`

Returns:

  • (String, nil)


143
# File 'lib/finch_api/models/hris/employment_data.rb', line 143

optional :work_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/employment_data.rb', line 262