Class: FinchAPI::Models::HRIS::EmploymentData::UnionMember0
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::EmploymentData::UnionMember0
- Defined in:
- lib/finch_api/models/hris/employment_data.rb
Defined Under Namespace
Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::HRIS::EmploymentData::UnionMember0::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::HRIS::EmploymentData::UnionMember0::Department?
The department object.
-
#employment ⇒ FinchAPI::Models::HRIS::EmploymentData::UnionMember0::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#income ⇒ FinchAPI::Models::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Models::Location?
-
#manager ⇒ FinchAPI::Models::HRIS::EmploymentData::UnionMember0::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
- #work_id ⇒ String? deprecated Deprecated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
The manager object representing the manager of the individual within the org.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
The manager object representing the manager of the individual within the org.
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 145
|
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
24 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 24 required :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::HRIS::EmploymentData::UnionMember0::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
109 110 111 112 113 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 109 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField] }, nil?: true |
#department ⇒ FinchAPI::Models::HRIS::EmploymentData::UnionMember0::Department?
The department object.
30 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 30 required :department, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Department }, nil?: true |
#employment ⇒ FinchAPI::Models::HRIS::EmploymentData::UnionMember0::Employment?
The employment object.
36 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 36 required :employment, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.
43 44 45 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 43 required :employment_status, enum: -> { FinchAPI::HRIS::EmploymentData::UnionMember0::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
50 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 50 required :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
56 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 56 required :first_name, String, nil?: true |
#id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
18 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 18 required :id, String |
#income ⇒ FinchAPI::Models::Income?
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
121 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 121 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
127 128 129 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 127 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
62 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 62 required :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
68 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 68 required :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
73 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 73 required :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Models::Location?
78 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 78 required :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::HRIS::EmploymentData::UnionMember0::Manager?
The manager object representing the manager of the individual within the org.
84 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 84 required :manager, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
90 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 90 required :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
135 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 135 optional :source_id, String, nil?: true |
#start_date ⇒ String?
95 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 95 required :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
101 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 101 required :title, String, nil?: true |
#work_id ⇒ String?
This field is deprecated in favour of ‘source_id`
143 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 143 optional :work_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 262
|