Class: FinchAPI::Models::HRIS::EmploymentData::UnionMember0
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::EmploymentData::UnionMember0
- Defined in:
- lib/finch_api/models/hris/employment_data.rb
Defined Under Namespace
Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Department?
The department object.
-
#employment ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Location?
-
#manager ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
- #work_id ⇒ String? deprecated Deprecated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: ) ⇒ Object
constructor
The department object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(name: ) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 242
|
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
24 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 24 required :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
32 33 34 35 36 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 32 required :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::EmploymentData::UnionMember0::CustomField] }, nil?: true |
#department ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Department?
The department object.
42 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 42 required :department, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Department }, nil?: true |
#employment ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Employment?
The employment object.
48 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 48 required :employment, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.
55 56 57 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 55 required :employment_status, enum: -> { FinchAPI::HRIS::EmploymentData::UnionMember0::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
62 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 62 required :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
68 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 68 required :first_name, String, nil?: true |
#id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
18 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 18 required :id, String |
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
129 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 129 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
135 136 137 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 135 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
74 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 74 required :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
80 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 80 required :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
85 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 85 required :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Location?
90 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 90 required :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::HRIS::EmploymentData::UnionMember0::Manager?
The manager object representing the manager of the individual within the org.
96 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 96 required :manager, -> { FinchAPI::HRIS::EmploymentData::UnionMember0::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
102 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 102 required :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
143 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 143 optional :source_id, String, nil?: true |
#start_date ⇒ String?
107 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 107 required :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
113 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 113 required :title, String, nil?: true |
#work_id ⇒ String?
This field is deprecated in favour of ‘source_id`
121 |
# File 'lib/finch_api/models/hris/employment_data.rb', line 121 required :work_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/employment_data.rb', line 306
|