Class: FinchAPI::Models::HRIS::EmploymentRetrieveManyParams::Request
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::EmploymentRetrieveManyParams::Request
- Defined in:
- lib/finch_api/models/hris/employment_retrieve_many_params.rb
Instance Attribute Summary collapse
-
#individual_id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company.
Instance Method Summary collapse
-
#initialize(individual_id: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Request for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(individual_id: ) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::EmploymentRetrieveManyParams::Request for more details.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/finch_api/models/hris/employment_retrieve_many_params.rb', line 31 class Request < FinchAPI::Internal::Type::BaseModel # @!attribute individual_id # A stable Finch `id` (UUID v4) for an individual in the company. There is no # limit to the number of `individual_id` to send per request. It is preferantial # to send all ids in a single request for Finch to optimize provider rate-limits. # # @return [String] required :individual_id, String # @!method initialize(individual_id:) # Some parameter documentations has been truncated, see # {FinchAPI::Models::HRIS::EmploymentRetrieveManyParams::Request} for more # details. # # @param individual_id [String] A stable Finch `id` (UUID v4) for an individual in the company. There is no limi end |
Instance Attribute Details
#individual_id ⇒ String
A stable Finch ‘id` (UUID v4) for an individual in the company. There is no limit to the number of `individual_id` to send per request. It is preferantial to send all ids in a single request for Finch to optimize provider rate-limits.
38 |
# File 'lib/finch_api/models/hris/employment_retrieve_many_params.rb', line 38 required :individual_id, String |