Class: FinchAPI::Models::HRIS::HRISCompany

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/company.rb

Overview

Defined Under Namespace

Classes: Account, Department, Entity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(name: ) ⇒ Object

The parent department, if present.

Parameters:

  • name (String, nil) (defaults to: )

    The parent department’s name.



# File 'lib/finch_api/models/hris/company.rb', line 180

Instance Attribute Details

#accountsArray<FinchAPI::HRIS::HRISCompany::Account>?

An array of bank account objects associated with the payroll/HRIS system.

Returns:

  • (Array<FinchAPI::HRIS::HRISCompany::Account>, nil)


18
19
20
# File 'lib/finch_api/models/hris/company.rb', line 18

required :accounts,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::HRISCompany::Account] },
nil?: true

#departmentsArray<FinchAPI::HRIS::HRISCompany::Department, nil>?

The array of company departments.

Returns:

  • (Array<FinchAPI::HRIS::HRISCompany::Department, nil>, nil)


26
27
28
29
30
# File 'lib/finch_api/models/hris/company.rb', line 26

required :departments,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::HRISCompany::Department, nil?: true]
},
nil?: true

#einString?

The employer identification number.

Returns:

  • (String, nil)


36
# File 'lib/finch_api/models/hris/company.rb', line 36

required :ein, String, nil?: true

#entityFinchAPI::HRIS::HRISCompany::Entity?

The entity type object.

Returns:

  • (FinchAPI::HRIS::HRISCompany::Entity, nil)


42
# File 'lib/finch_api/models/hris/company.rb', line 42

required :entity, -> { FinchAPI::HRIS::HRISCompany::Entity }, nil?: true

#idString

A stable Finch ‘id` (UUID v4) for the company.

Returns:

  • (String)


12
# File 'lib/finch_api/models/hris/company.rb', line 12

required :id, String

The legal name of the company.

Returns:

  • (String, nil)


48
# File 'lib/finch_api/models/hris/company.rb', line 48

required :legal_name, String, nil?: true

#locationsArray<FinchAPI::Location, nil>?

Returns:



53
54
55
56
57
# File 'lib/finch_api/models/hris/company.rb', line 53

required :locations,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Location, nil?: true]
},
nil?: true

#primary_emailString?

The email of the main administrator on the account.

Returns:

  • (String, nil)


63
# File 'lib/finch_api/models/hris/company.rb', line 63

required :primary_email, String, nil?: true

#primary_phone_numberString?

The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g. ‘+NNNNNNNNNNN xExtension`

Returns:

  • (String, nil)


70
# File 'lib/finch_api/models/hris/company.rb', line 70

required :primary_phone_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/company.rb', line 149