Class: FinchAPI::Models::HRIS::HRISCompany

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/hris/company.rb

Defined Under Namespace

Classes: Account, Department, Entity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name: nil) ⇒ HRISCompany

The parent department, if present.

Parameters:

  • name (String, nil) (defaults to: nil)


11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/finch-api/models/hris/company.rb', line 11

def initialize(
  id:,
  accounts:,
  departments:,
  ein:,
  entity:,
  legal_name:,
  locations:,
  primary_email:,
  primary_phone_number:,
  **
)
  super
end

Instance Attribute Details

#accountsArray<FinchAPI::Models::HRIS::HRISCompany::Account>?

An array of bank account objects associated with the payroll/HRIS system.



17
# File 'lib/finch-api/models/hris/company.rb', line 17

required :accounts, -> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::HRISCompany::Account] }, nil?: true

#departmentsArray<FinchAPI::Models::HRIS::HRISCompany::Department, nil>?

The array of company departments.



23
24
25
# File 'lib/finch-api/models/hris/company.rb', line 23

required :departments,
-> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::HRISCompany::Department, nil?: true] },
nil?: true

#einString?

The employer identification number.

Returns:

  • (String, nil)


31
# File 'lib/finch-api/models/hris/company.rb', line 31

required :ein, String, nil?: true

#entityFinchAPI::Models::HRIS::HRISCompany::Entity?

The entity type object.



37
# File 'lib/finch-api/models/hris/company.rb', line 37

required :entity, -> { FinchAPI::Models::HRIS::HRISCompany::Entity }, nil?: true

#idString

A stable Finch ‘id` (UUID v4) for the company.

Returns:

  • (String)


11
# File 'lib/finch-api/models/hris/company.rb', line 11

required :id, String

The legal name of the company.

Returns:

  • (String, nil)


43
# File 'lib/finch-api/models/hris/company.rb', line 43

required :legal_name, String, nil?: true

#locationsArray<FinchAPI::Models::Location, nil>?

Returns:



48
# File 'lib/finch-api/models/hris/company.rb', line 48

required :locations, -> { FinchAPI::ArrayOf[FinchAPI::Models::Location, nil?: true] }, nil?: true

#primary_emailString?

The email of the main administrator on the account.

Returns:

  • (String, nil)


54
# File 'lib/finch-api/models/hris/company.rb', line 54

required :primary_email, String, nil?: true

#primary_phone_numberString?

The phone number of the main administrator on the account. Format: ‘XXXXXXXXXX`

Returns:

  • (String, nil)


60
# File 'lib/finch-api/models/hris/company.rb', line 60

required :primary_phone_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/hris/company.rb', line 2

def self.values; end