Class: FinchAPI::Models::HRIS::HRISCompany
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::HRISCompany
- Defined in:
- lib/finch_api/models/hris/company.rb
Overview
Defined Under Namespace
Classes: Account, Department, Entity
Instance Attribute Summary collapse
-
#accounts ⇒ Array<FinchAPI::Models::HRIS::HRISCompany::Account>?
An array of bank account objects associated with the payroll/HRIS system.
-
#departments ⇒ Array<FinchAPI::Models::HRIS::HRISCompany::Department, nil>?
The array of company departments.
-
#ein ⇒ String?
The employer identification number.
-
#entity ⇒ FinchAPI::Models::HRIS::HRISCompany::Entity?
The entity type object.
-
#id ⇒ String
A stable Finch ‘id` (UUID v4) for the company.
-
#legal_name ⇒ String?
The legal name of the company.
- #locations ⇒ Array<FinchAPI::Models::Location, nil>?
-
#primary_email ⇒ String?
The email of the main administrator on the account.
-
#primary_phone_number ⇒ String?
The phone number of the main administrator on the account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: ) ⇒ Object
constructor
The parent department, if present.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: ) ⇒ Object
The parent department, if present.
|
|
# File 'lib/finch_api/models/hris/company.rb', line 180
|
Instance Attribute Details
#accounts ⇒ Array<FinchAPI::Models::HRIS::HRISCompany::Account>?
An array of bank account objects associated with the payroll/HRIS system.
18 19 20 |
# File 'lib/finch_api/models/hris/company.rb', line 18 required :accounts, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::HRISCompany::Account] }, nil?: true |
#departments ⇒ Array<FinchAPI::Models::HRIS::HRISCompany::Department, nil>?
The array of company departments.
26 27 28 29 30 |
# File 'lib/finch_api/models/hris/company.rb', line 26 required :departments, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::HRISCompany::Department, nil?: true] }, nil?: true |
#ein ⇒ String?
The employer identification number.
36 |
# File 'lib/finch_api/models/hris/company.rb', line 36 required :ein, String, nil?: true |
#entity ⇒ FinchAPI::Models::HRIS::HRISCompany::Entity?
The entity type object.
42 |
# File 'lib/finch_api/models/hris/company.rb', line 42 required :entity, -> { FinchAPI::HRIS::HRISCompany::Entity }, nil?: true |
#id ⇒ String
A stable Finch ‘id` (UUID v4) for the company.
12 |
# File 'lib/finch_api/models/hris/company.rb', line 12 required :id, String |
#legal_name ⇒ String?
The legal name of the company.
48 |
# File 'lib/finch_api/models/hris/company.rb', line 48 required :legal_name, String, nil?: true |
#locations ⇒ Array<FinchAPI::Models::Location, nil>?
53 54 55 56 57 |
# File 'lib/finch_api/models/hris/company.rb', line 53 required :locations, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Location, nil?: true] }, nil?: true |
#primary_email ⇒ String?
The email of the main administrator on the account.
63 |
# File 'lib/finch_api/models/hris/company.rb', line 63 required :primary_email, String, nil?: true |
#primary_phone_number ⇒ String?
The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g. ‘+NNNNNNNNNNN xExtension`
70 |
# File 'lib/finch_api/models/hris/company.rb', line 70 required :primary_phone_number, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/company.rb', line 149
|