Class: FinchAPI::Models::HRIS::HRISCompany::Account
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::HRISCompany::Account
- Defined in:
- lib/finch_api/models/hris/company.rb
Defined Under Namespace
Modules: AccountType
Instance Attribute Summary collapse
-
#account_name ⇒ String?
The name of the bank associated in the payroll/HRIS system.
-
#account_number ⇒ String?
10-12 digit number to specify the bank account.
-
#account_type ⇒ Symbol, ...
The type of bank account.
-
#institution_name ⇒ String?
Name of the banking institution.
-
#routing_number ⇒ String?
A nine-digit code that’s based on the U.S.
Instance Method Summary collapse
-
#initialize(account_name: , account_number: , account_type: , institution_name: , routing_number: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see HRIS::HRISCompany::Account for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(account_name: , account_number: , account_type: , institution_name: , routing_number: ) ⇒ Object
Some parameter documentations has been truncated, see HRIS::HRISCompany::Account for more details.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/finch_api/models/hris/company.rb', line 94 class Account < FinchAPI::Internal::Type::BaseModel # @!attribute account_name # The name of the bank associated in the payroll/HRIS system. # # @return [String, nil] required :account_name, String, nil?: true # @!attribute account_number # 10-12 digit number to specify the bank account # # @return [String, nil] required :account_number, String, nil?: true # @!attribute account_type # The type of bank account. # # @return [Symbol, FinchAPI::HRIS::HRISCompany::Account::AccountType, nil] required :account_type, enum: -> { FinchAPI::HRIS::HRISCompany::Account::AccountType }, nil?: true # @!attribute institution_name # Name of the banking institution. # # @return [String, nil] required :institution_name, String, nil?: true # @!attribute routing_number # A nine-digit code that's based on the U.S. Bank location where your account was # opened. # # @return [String, nil] required :routing_number, String, nil?: true # @!method initialize(account_name:, account_number:, account_type:, institution_name:, routing_number:) # Some parameter documentations has been truncated, see # {FinchAPI::HRIS::HRISCompany::Account} for more details. # # @param account_name [String, nil] The name of the bank associated in the payroll/HRIS system. # # @param account_number [String, nil] 10-12 digit number to specify the bank account # # @param account_type [Symbol, FinchAPI::HRIS::HRISCompany::Account::AccountType, nil] The type of bank account. # # @param institution_name [String, nil] Name of the banking institution. # # @param routing_number [String, nil] A nine-digit code that's based on the U.S. Bank location where your account was # The type of bank account. # # @see FinchAPI::HRIS::HRISCompany::Account#account_type module AccountType extend FinchAPI::Internal::Type::Enum CHECKING = :checking SAVINGS = :savings # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#account_name ⇒ String?
The name of the bank associated in the payroll/HRIS system.
99 |
# File 'lib/finch_api/models/hris/company.rb', line 99 required :account_name, String, nil?: true |
#account_number ⇒ String?
10-12 digit number to specify the bank account
105 |
# File 'lib/finch_api/models/hris/company.rb', line 105 required :account_number, String, nil?: true |
#account_type ⇒ Symbol, ...
The type of bank account.
111 |
# File 'lib/finch_api/models/hris/company.rb', line 111 required :account_type, enum: -> { FinchAPI::HRIS::HRISCompany::Account::AccountType }, nil?: true |
#institution_name ⇒ String?
Name of the banking institution.
117 |
# File 'lib/finch_api/models/hris/company.rb', line 117 required :institution_name, String, nil?: true |
#routing_number ⇒ String?
A nine-digit code that’s based on the U.S. Bank location where your account was opened.
124 |
# File 'lib/finch_api/models/hris/company.rb', line 124 required :routing_number, String, nil?: true |