Class: FinchAPI::Models::HRIS::Individual::UnionMember0

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/individual.rb

Defined Under Namespace

Modules: Ethnicity, Gender Classes: Email, PhoneNumber

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , dob: , ethnicity: , first_name: , gender: , last_name: , middle_name: , phone_numbers: , preferred_name: , residence: , emails: nil, encrypted_ssn: nil, ssn: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::Individual::UnionMember0 for more details.

Parameters:



# File 'lib/finch_api/models/hris/individual.rb', line 100

Instance Attribute Details

#dobString?

Returns:

  • (String, nil)


23
# File 'lib/finch_api/models/hris/individual.rb', line 23

required :dob, String, nil?: true

#emailsArray<FinchAPI::Models::HRIS::Individual::UnionMember0::Email>?



79
80
81
# File 'lib/finch_api/models/hris/individual.rb', line 79

optional :emails,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::Individual::UnionMember0::Email] },
nil?: true

#encrypted_ssnString?

Social Security Number of the individual in encrypted format. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body.

Returns:

  • (String, nil)


89
# File 'lib/finch_api/models/hris/individual.rb', line 89

optional :encrypted_ssn, String, nil?: true

#ethnicitySymbol, ...

The EEOC-defined ethnicity of the individual.



29
# File 'lib/finch_api/models/hris/individual.rb', line 29

required :ethnicity, enum: -> { FinchAPI::HRIS::Individual::UnionMember0::Ethnicity }, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


35
# File 'lib/finch_api/models/hris/individual.rb', line 35

required :first_name, String, nil?: true

#genderSymbol, ...

The gender of the individual.



41
# File 'lib/finch_api/models/hris/individual.rb', line 41

required :gender, enum: -> { FinchAPI::HRIS::Individual::UnionMember0::Gender }, nil?: true

#idString

A stable Finch ‘id` (UUID v4) for an individual in the company.

Returns:

  • (String)


18
# File 'lib/finch_api/models/hris/individual.rb', line 18

required :id, String

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


47
# File 'lib/finch_api/models/hris/individual.rb', line 47

required :last_name, String, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


53
# File 'lib/finch_api/models/hris/individual.rb', line 53

required :middle_name, String, nil?: true

#phone_numbersArray<FinchAPI::Models::HRIS::Individual::UnionMember0::PhoneNumber, nil>?



58
59
60
61
62
63
# File 'lib/finch_api/models/hris/individual.rb', line 58

required :phone_numbers,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::Individual::UnionMember0::PhoneNumber,
                                    nil?: true]
},
nil?: true

#preferred_nameString?

The preferred name of the individual.

Returns:

  • (String, nil)


69
# File 'lib/finch_api/models/hris/individual.rb', line 69

required :preferred_name, String, nil?: true

#residenceFinchAPI::Models::Location?

Returns:



74
# File 'lib/finch_api/models/hris/individual.rb', line 74

required :residence, -> { FinchAPI::Location }, nil?: true

#ssnString?

Social Security Number of the individual. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body. [Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).

Returns:

  • (String, nil)


98
# File 'lib/finch_api/models/hris/individual.rb', line 98

optional :ssn, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/individual.rb', line 145