Class: FinchAPI::Models::HRIS::IndividualInDirectory
- Defined in:
- lib/finch-api/models/hris/individual_in_directory.rb
Defined Under Namespace
Classes: Department, Manager
Instance Attribute Summary collapse
-
#department ⇒ FinchAPI::Models::HRIS::IndividualInDirectory::Department?
The department object.
-
#first_name ⇒ String?
The legal first name of the individual.
-
#id ⇒ String?
A stable Finch id (UUID v4) for an individual in the company.
-
#is_active ⇒ Boolean?
‘true` if the individual is an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
-
#manager ⇒ FinchAPI::Models::HRIS::IndividualInDirectory::Manager?
The manager object.
-
#middle_name ⇒ String?
The legal middle name of the individual.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ IndividualInDirectory
constructor
The department object.
Constructor Details
#initialize(name: nil) ⇒ IndividualInDirectory
The department object.
9 10 11 12 13 14 15 16 17 18 19 20 |
# File 'lib/finch-api/models/hris/individual_in_directory.rb', line 9 def initialize( id: nil, department: nil, first_name: nil, is_active: nil, last_name: nil, manager: nil, middle_name: nil, ** ) super end |
Instance Attribute Details
#department ⇒ FinchAPI::Models::HRIS::IndividualInDirectory::Department?
The department object.
21 |
# File 'lib/finch-api/models/hris/individual_in_directory.rb', line 21 optional :department, -> { FinchAPI::Models::HRIS::IndividualInDirectory::Department }, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
27 |
# File 'lib/finch-api/models/hris/individual_in_directory.rb', line 27 optional :first_name, String, nil?: true |
#id ⇒ String?
A stable Finch id (UUID v4) for an individual in the company.
11 |
# File 'lib/finch-api/models/hris/individual_in_directory.rb', line 11 optional :id, String |
#is_active ⇒ Boolean?
‘true` if the individual is an active employee or contractor at the company.
33 |
# File 'lib/finch-api/models/hris/individual_in_directory.rb', line 33 optional :is_active, FinchAPI::BooleanModel, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
39 |
# File 'lib/finch-api/models/hris/individual_in_directory.rb', line 39 optional :last_name, String, nil?: true |
#manager ⇒ FinchAPI::Models::HRIS::IndividualInDirectory::Manager?
The manager object.
45 |
# File 'lib/finch-api/models/hris/individual_in_directory.rb', line 45 optional :manager, -> { FinchAPI::Models::HRIS::IndividualInDirectory::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
51 |
# File 'lib/finch-api/models/hris/individual_in_directory.rb', line 51 optional :middle_name, String, nil?: true |