Class: FinchAPI::Models::HRIS::PayStatement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/pay_statement.rb

Defined Under Namespace

Modules: PaymentMethod, Type Classes: Earning, EmployeeDeduction, EmployerContribution, Tax

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(metadata: ) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::PayStatement::Tax::Attributes for more details.

Parameters:

  • metadata (Hash{Symbol=>Object, nil}) (defaults to: )

    The metadata to be attached to the entity by existing rules. It is a key-value p



# File 'lib/finch_api/models/hris/pay_statement.rb', line 183

Instance Attribute Details

#earningsArray<FinchAPI::Models::HRIS::PayStatement::Earning, nil>?

The array of earnings objects associated with this pay statement

Returns:



11
12
13
# File 'lib/finch_api/models/hris/pay_statement.rb', line 11

required :earnings,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::Earning, nil?: true] },
nil?: true

#employee_deductionsArray<FinchAPI::Models::HRIS::PayStatement::EmployeeDeduction>?

The array of deductions objects associated with this pay statement.



19
20
21
# File 'lib/finch_api/models/hris/pay_statement.rb', line 19

required :employee_deductions,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::EmployeeDeduction] },
nil?: true

#employer_contributionsArray<FinchAPI::Models::HRIS::PayStatement::EmployerContribution>?



26
27
28
# File 'lib/finch_api/models/hris/pay_statement.rb', line 26

required :employer_contributions,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::EmployerContribution] },
nil?: true

#gross_payFinchAPI::Models::Money?

Returns:



33
# File 'lib/finch_api/models/hris/pay_statement.rb', line 33

required :gross_pay, -> { FinchAPI::Money }, nil?: true

#individual_idString

A stable Finch ‘id` (UUID v4) for an individual in the company

Returns:

  • (String)


39
# File 'lib/finch_api/models/hris/pay_statement.rb', line 39

required :individual_id, String

#net_payFinchAPI::Models::Money?

Returns:



44
# File 'lib/finch_api/models/hris/pay_statement.rb', line 44

required :net_pay, -> { FinchAPI::Money }, nil?: true

#payment_methodSymbol, ...

The payment method.



50
# File 'lib/finch_api/models/hris/pay_statement.rb', line 50

required :payment_method, enum: -> { FinchAPI::HRIS::PayStatement::PaymentMethod }, nil?: true

#taxesArray<FinchAPI::Models::HRIS::PayStatement::Tax>?

The array of taxes objects associated with this pay statement.



56
57
58
59
60
# File 'lib/finch_api/models/hris/pay_statement.rb', line 56

required :taxes,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::Tax]
},
nil?: true

#total_hoursFloat?

The number of hours worked for this pay period

Returns:

  • (Float, nil)


66
# File 'lib/finch_api/models/hris/pay_statement.rb', line 66

required :total_hours, Float, nil?: true

#typeSymbol, ...

The type of the payment associated with the pay statement.



72
# File 'lib/finch_api/models/hris/pay_statement.rb', line 72

required :type, enum: -> { FinchAPI::HRIS::PayStatement::Type }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/pay_statement.rb', line 335