Class: FinchAPI::Models::HRIS::PayStatement

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/hris/pay_statement.rb

Defined Under Namespace

Modules: PaymentMethod, Type Classes: Earning, EmployeeDeduction, EmployerContribution, Tax

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(metadata: nil) ⇒ PayStatement

Returns a new instance of PayStatement.

Parameters:

  • metadata (Hash{Symbol=>Object}) (defaults to: nil)


12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
# File 'lib/finch-api/models/hris/pay_statement.rb', line 12

def initialize(
  earnings: nil,
  employee_deductions: nil,
  employer_contributions: nil,
  gross_pay: nil,
  individual_id: nil,
  net_pay: nil,
  payment_method: nil,
  taxes: nil,
  total_hours: nil,
  type: nil,
  **
)
  super
end

Instance Attribute Details

#earningsArray<FinchAPI::Models::HRIS::PayStatement::Earning, nil>?

The array of earnings objects associated with this pay statement

Returns:



11
12
13
# File 'lib/finch-api/models/hris/pay_statement.rb', line 11

optional :earnings,
-> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::PayStatement::Earning, nil?: true] },
nil?: true

#employee_deductionsArray<FinchAPI::Models::HRIS::PayStatement::EmployeeDeduction, nil>?

The array of deductions objects associated with this pay statement.



19
20
21
# File 'lib/finch-api/models/hris/pay_statement.rb', line 19

optional :employee_deductions,
-> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::PayStatement::EmployeeDeduction, nil?: true] },
nil?: true

#employer_contributionsArray<FinchAPI::Models::HRIS::PayStatement::EmployerContribution, nil>?



26
27
28
# File 'lib/finch-api/models/hris/pay_statement.rb', line 26

optional :employer_contributions,
-> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::PayStatement::EmployerContribution, nil?: true] },
nil?: true

#gross_payFinchAPI::Models::Money?

Returns:



33
# File 'lib/finch-api/models/hris/pay_statement.rb', line 33

optional :gross_pay, -> { FinchAPI::Models::Money }, nil?: true

#individual_idString?

A stable Finch ‘id` (UUID v4) for an individual in the company

Returns:

  • (String, nil)


39
# File 'lib/finch-api/models/hris/pay_statement.rb', line 39

optional :individual_id, String

#metadata=(value) ⇒ Hash{Symbol=>Object} (writeonly)

Returns:

  • (Hash{Symbol=>Object})


2
3
4
# File 'lib/finch-api/models/hris/pay_statement.rb', line 2

def metadata=(value)
  @metadata = value
end

#net_payFinchAPI::Models::Money?

Returns:



48
# File 'lib/finch-api/models/hris/pay_statement.rb', line 48

optional :net_pay, -> { FinchAPI::Models::Money }, nil?: true

#payment_methodSymbol, ...

The payment method.



54
# File 'lib/finch-api/models/hris/pay_statement.rb', line 54

optional :payment_method, enum: -> { FinchAPI::Models::HRIS::PayStatement::PaymentMethod }, nil?: true

#taxesArray<FinchAPI::Models::HRIS::PayStatement::Tax, nil>?

The array of taxes objects associated with this pay statement.

Returns:



60
61
62
# File 'lib/finch-api/models/hris/pay_statement.rb', line 60

optional :taxes,
-> { FinchAPI::ArrayOf[FinchAPI::Models::HRIS::PayStatement::Tax, nil?: true] },
nil?: true

#total_hoursFloat?

The number of hours worked for this pay period

Returns:

  • (Float, nil)


68
# File 'lib/finch-api/models/hris/pay_statement.rb', line 68

optional :total_hours, Float, nil?: true

#typeSymbol, ...

The type of the payment associated with the pay statement.



74
# File 'lib/finch-api/models/hris/pay_statement.rb', line 74

optional :type, enum: -> { FinchAPI::Models::HRIS::PayStatement::Type }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/hris/pay_statement.rb', line 2

def self.values; end