Class: FinchAPI::Models::HRIS::PayStatement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::PayStatement
- Defined in:
- lib/finch_api/models/hris/pay_statement.rb
Defined Under Namespace
Modules: PaymentMethod, Type Classes: Earning, EmployeeDeduction, EmployerContribution, Tax
Instance Attribute Summary collapse
-
#earnings ⇒ Array<FinchAPI::HRIS::PayStatement::Earning, nil>?
The array of earnings objects associated with this pay statement.
-
#employee_deductions ⇒ Array<FinchAPI::HRIS::PayStatement::EmployeeDeduction, nil>?
The array of deductions objects associated with this pay statement.
- #employer_contributions ⇒ Array<FinchAPI::HRIS::PayStatement::EmployerContribution, nil>?
- #gross_pay ⇒ FinchAPI::Money?
-
#individual_id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
- #net_pay ⇒ FinchAPI::Money?
-
#payment_method ⇒ Symbol, ...
The payment method.
-
#taxes ⇒ Array<FinchAPI::HRIS::PayStatement::Tax, nil>?
The array of taxes objects associated with this pay statement.
-
#total_hours ⇒ Float?
The number of hours worked for this pay period.
-
#type ⇒ Symbol, ...
The type of the payment associated with the pay statement.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see HRIS::PayStatement::EmployerContribution::Attributes::Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see HRIS::PayStatement::EmployerContribution::Attributes::Metadata for more details.
|
|
# File 'lib/finch_api/models/hris/pay_statement.rb', line 276
|
Instance Attribute Details
#earnings ⇒ Array<FinchAPI::HRIS::PayStatement::Earning, nil>?
The array of earnings objects associated with this pay statement
11 12 13 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 11 optional :earnings, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::Earning, nil?: true] }, nil?: true |
#employee_deductions ⇒ Array<FinchAPI::HRIS::PayStatement::EmployeeDeduction, nil>?
The array of deductions objects associated with this pay statement.
19 20 21 22 23 24 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 19 optional :employee_deductions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::EmployeeDeduction, nil?: true] }, nil?: true |
#employer_contributions ⇒ Array<FinchAPI::HRIS::PayStatement::EmployerContribution, nil>?
29 30 31 32 33 34 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 29 optional :employer_contributions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::EmployerContribution, nil?: true] }, nil?: true |
#gross_pay ⇒ FinchAPI::Money?
39 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 39 optional :gross_pay, -> { FinchAPI::Money }, nil?: true |
#individual_id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company
45 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 45 optional :individual_id, String |
#net_pay ⇒ FinchAPI::Money?
50 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 50 optional :net_pay, -> { FinchAPI::Money }, nil?: true |
#payment_method ⇒ Symbol, ...
The payment method.
56 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 56 optional :payment_method, enum: -> { FinchAPI::HRIS::PayStatement::PaymentMethod }, nil?: true |
#taxes ⇒ Array<FinchAPI::HRIS::PayStatement::Tax, nil>?
The array of taxes objects associated with this pay statement.
62 63 64 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 62 optional :taxes, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::HRIS::PayStatement::Tax, nil?: true] }, nil?: true |
#total_hours ⇒ Float?
The number of hours worked for this pay period
70 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 70 optional :total_hours, Float, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/pay_statement.rb', line 201
|