Class: FinchAPI::Models::HRIS::PayStatement::Earning
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::PayStatement::Earning
- Defined in:
- lib/finch_api/models/hris/pay_statement.rb
Defined Under Namespace
Modules: Type Classes: Attributes
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The earnings amount in cents.
- #attributes ⇒ FinchAPI::Models::HRIS::PayStatement::Earning::Attributes?
-
#currency ⇒ String?
The earnings currency code.
-
#hours ⇒ Float?
The number of hours associated with this earning.
-
#name ⇒ String?
The exact name of the deduction from the pay statement.
-
#type ⇒ Symbol, ...
The type of earning.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount: , currency: , hours: , name: , type: , attributes: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Earning for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: , currency: , hours: , name: , type: , attributes: nil) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::PayStatement::Earning for more details.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 95 class Earning < FinchAPI::Internal::Type::BaseModel # @!attribute amount # The earnings amount in cents. # # @return [Integer, nil] required :amount, Integer, nil?: true # @!attribute currency # The earnings currency code. # # @return [String, nil] required :currency, String, nil?: true # @!attribute hours # The number of hours associated with this earning. (For salaried employees, this # could be hours per pay period, `0` or `null`, depending on the provider). # # @return [Float, nil] required :hours, Float, nil?: true # @!attribute name # The exact name of the deduction from the pay statement. # # @return [String, nil] required :name, String, nil?: true # @!attribute type # The type of earning. # # @return [Symbol, FinchAPI::Models::HRIS::PayStatement::Earning::Type, nil] required :type, enum: -> { FinchAPI::HRIS::PayStatement::Earning::Type }, nil?: true # @!attribute attributes # # @return [FinchAPI::Models::HRIS::PayStatement::Earning::Attributes, nil] optional :attributes, -> { FinchAPI::HRIS::PayStatement::Earning::Attributes }, nil?: true # @!method initialize(amount:, currency:, hours:, name:, type:, attributes: nil) # Some parameter documentations has been truncated, see # {FinchAPI::Models::HRIS::PayStatement::Earning} for more details. # # @param amount [Integer, nil] The earnings amount in cents. # # @param currency [String, nil] The earnings currency code. # # @param hours [Float, nil] The number of hours associated with this earning. (For salaried employees, this # # @param name [String, nil] The exact name of the deduction from the pay statement. # # @param type [Symbol, FinchAPI::Models::HRIS::PayStatement::Earning::Type, nil] The type of earning. # # @param attributes [FinchAPI::Models::HRIS::PayStatement::Earning::Attributes, nil] # The type of earning. # # @see FinchAPI::Models::HRIS::PayStatement::Earning#type module Type extend FinchAPI::Internal::Type::Enum SALARY = :salary WAGE = :wage REIMBURSEMENT = :reimbursement OVERTIME = :overtime SEVERANCE = :severance DOUBLE_OVERTIME = :double_overtime PTO = :pto SICK = :sick BONUS = :bonus COMMISSION = :commission TIPS = :tips TYPE_1099 = :"1099" OTHER = :other # @!method self.values # @return [Array<Symbol>] end # @see FinchAPI::Models::HRIS::PayStatement::Earning#attributes class Attributes < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # The metadata to be attached to the entity by existing rules. It is a key-value # pairs where the values can be of any type (string, number, boolean, object, # array, etc.). # # @return [Hash{Symbol=>Object, nil}] required :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true] # @!method initialize(metadata:) # Some parameter documentations has been truncated, see # {FinchAPI::Models::HRIS::PayStatement::Earning::Attributes} for more details. # # @param metadata [Hash{Symbol=>Object, nil}] The metadata to be attached to the entity by existing rules. It is a key-value p end end |
Instance Attribute Details
#amount ⇒ Integer?
The earnings amount in cents.
100 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 100 required :amount, Integer, nil?: true |
#attributes ⇒ FinchAPI::Models::HRIS::PayStatement::Earning::Attributes?
130 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 130 optional :attributes, -> { FinchAPI::HRIS::PayStatement::Earning::Attributes }, nil?: true |
#currency ⇒ String?
The earnings currency code.
106 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 106 required :currency, String, nil?: true |
#hours ⇒ Float?
The number of hours associated with this earning. (For salaried employees, this could be hours per pay period, ‘0` or `null`, depending on the provider).
113 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 113 required :hours, Float, nil?: true |
#name ⇒ String?
The exact name of the deduction from the pay statement.
119 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 119 required :name, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/pay_statement.rb', line 168
|