Class: FinchAPI::Models::HRIS::PayStatement::EmployerContribution::Attributes
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::PayStatement::EmployerContribution::Attributes
- Defined in:
- lib/finch_api/models/hris/pay_statement.rb,
sig/finch_api/models/hris/pay_statement.rbs
Overview
Instance Attribute Summary collapse
-
#metadata ⇒ Hash{Symbol=>Object, nil}
The metadata to be attached to the entity by existing rules.
Instance Method Summary collapse
-
#initialize ⇒ Attributes
constructor
A new instance of Attributes.
- #to_hash ⇒ { metadata: ::Hash[Symbol, top?] }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Attributes
Returns a new instance of Attributes.
245 |
# File 'sig/finch_api/models/hris/pay_statement.rbs', line 245
def initialize: (metadata: ::Hash[Symbol, top?]) -> void
|
Instance Attribute Details
#metadata ⇒ Hash{Symbol=>Object, nil}
The metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
313 314 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 313 required :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true] |
Instance Method Details
#to_hash ⇒ { metadata: ::Hash[Symbol, top?] }
247 |
# File 'sig/finch_api/models/hris/pay_statement.rbs', line 247
def to_hash: -> { metadata: ::Hash[Symbol, top?] }
|