Class: FinchAPI::Models::HRIS::PayStatement::Tax

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/pay_statement.rb

Defined Under Namespace

Modules: Type Classes: Attributes

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see HRIS::PayStatement::Tax::Attributes::Metadata for more details.

Parameters:

  • metadata (Hash{Symbol=>Object, nil}) (defaults to: nil)

    The metadata to be attached to the entity by existing rules. It is a key-value p



# File 'lib/finch_api/models/hris/pay_statement.rb', line 415

Instance Attribute Details

#amountInteger?

The tax amount in cents.

Returns:

  • (Integer, nil)


384
# File 'lib/finch_api/models/hris/pay_statement.rb', line 384

optional :amount, Integer, nil?: true

#attributesFinchAPI::HRIS::PayStatement::Tax::Attributes?

Returns:

  • (FinchAPI::HRIS::PayStatement::Tax::Attributes, nil)


389
# File 'lib/finch_api/models/hris/pay_statement.rb', line 389

optional :attributes, -> { FinchAPI::HRIS::PayStatement::Tax::Attributes }, nil?: true

#currencyString?

The currency code.

Returns:

  • (String, nil)


395
# File 'lib/finch_api/models/hris/pay_statement.rb', line 395

optional :currency, String, nil?: true

#employerBoolean?

‘true` if the amount is paid by the employers.

Returns:

  • (Boolean, nil)


401
# File 'lib/finch_api/models/hris/pay_statement.rb', line 401

optional :employer, FinchAPI::Internal::Type::Boolean, nil?: true

#nameString?

The exact name of tax from the pay statement.

Returns:

  • (String, nil)


407
# File 'lib/finch_api/models/hris/pay_statement.rb', line 407

optional :name, String, nil?: true

#typeSymbol, ...

The type of taxes.

Returns:

  • (Symbol, FinchAPI::HRIS::PayStatement::Tax::Type, nil)


413
# File 'lib/finch_api/models/hris/pay_statement.rb', line 413

optional :type, enum: -> { FinchAPI::HRIS::PayStatement::Tax::Type }, nil?: true