Class: FinchAPI::Models::HRIS::PayStatement::Tax

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/pay_statement.rb

Defined Under Namespace

Modules: Type Classes: Attributes

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(currency: , employer: , name: , type: , amount: nil, attributes: nil) ⇒ Object

Parameters:

  • currency (String, nil) (defaults to: )

    The currency code.

  • employer (Boolean, nil) (defaults to: )

    ‘true` if the amount is paid by the employers.

  • name (String, nil) (defaults to: )

    The exact name of tax from the pay statement.

  • type (Symbol, FinchAPI::Models::HRIS::PayStatement::Tax::Type, nil) (defaults to: )

    The type of taxes.

  • amount (Integer, nil) (defaults to: nil)

    The tax amount in cents.

  • attributes (FinchAPI::Models::HRIS::PayStatement::Tax::Attributes, nil) (defaults to: nil)


# File 'lib/finch_api/models/hris/pay_statement.rb', line 413

Instance Attribute Details

#amountInteger?

The tax amount in cents.

Returns:

  • (Integer, nil)


406
# File 'lib/finch_api/models/hris/pay_statement.rb', line 406

optional :amount, Integer, nil?: true

#attributesFinchAPI::Models::HRIS::PayStatement::Tax::Attributes?



411
# File 'lib/finch_api/models/hris/pay_statement.rb', line 411

optional :attributes, -> { FinchAPI::HRIS::PayStatement::Tax::Attributes }, nil?: true

#currencyString?

The currency code.

Returns:

  • (String, nil)


382
# File 'lib/finch_api/models/hris/pay_statement.rb', line 382

required :currency, String, nil?: true

#employerBoolean?

‘true` if the amount is paid by the employers.

Returns:

  • (Boolean, nil)


388
# File 'lib/finch_api/models/hris/pay_statement.rb', line 388

required :employer, FinchAPI::Internal::Type::Boolean, nil?: true

#nameString?

The exact name of tax from the pay statement.

Returns:

  • (String, nil)


394
# File 'lib/finch_api/models/hris/pay_statement.rb', line 394

required :name, String, nil?: true

#typeSymbol, ...

The type of taxes.



400
# File 'lib/finch_api/models/hris/pay_statement.rb', line 400

required :type, enum: -> { FinchAPI::HRIS::PayStatement::Tax::Type }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/pay_statement.rb', line 437