Class: FinchAPI::Models::HRIS::PayStatement::Tax
- Defined in:
- lib/finch-api/models/hris/pay_statement.rb
Defined Under Namespace
Modules: Type Classes: Attributes
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The tax amount in cents.
- #attributes ⇒ FinchAPI::Models::HRIS::PayStatement::Tax::Attributes?
-
#currency ⇒ String?
The currency code.
-
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
- #metadata ⇒ Hash{Symbol=>Object} writeonly
-
#name ⇒ String?
The exact name of tax from the pay statement.
-
#type ⇒ Symbol, ...
The type of taxes.
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Tax
constructor
A new instance of Tax.
Constructor Details
#initialize(metadata: nil) ⇒ Tax
Returns a new instance of Tax.
8 |
# File 'lib/finch-api/models/hris/pay_statement.rb', line 8 def initialize(amount: nil, attributes: nil, currency: nil, employer: nil, name: nil, type: nil, **) = super |
Instance Attribute Details
#amount ⇒ Integer?
The tax amount in cents.
413 |
# File 'lib/finch-api/models/hris/pay_statement.rb', line 413 optional :amount, Integer, nil?: true |
#attributes ⇒ FinchAPI::Models::HRIS::PayStatement::Tax::Attributes?
418 |
# File 'lib/finch-api/models/hris/pay_statement.rb', line 418 optional :attributes, -> { FinchAPI::Models::HRIS::PayStatement::Tax::Attributes }, nil?: true |
#currency ⇒ String?
The currency code.
424 |
# File 'lib/finch-api/models/hris/pay_statement.rb', line 424 optional :currency, String, nil?: true |
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
430 |
# File 'lib/finch-api/models/hris/pay_statement.rb', line 430 optional :employer, FinchAPI::BooleanModel, nil?: true |
#metadata=(value) ⇒ Hash{Symbol=>Object} (writeonly)
2 3 4 |
# File 'lib/finch-api/models/hris/pay_statement.rb', line 2 def (value) @metadata = value end |
#name ⇒ String?
The exact name of tax from the pay statement.
436 |
# File 'lib/finch-api/models/hris/pay_statement.rb', line 436 optional :name, String, nil?: true |