Class: FinchAPI::Models::HRIS::PayStatement::Tax
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::PayStatement::Tax
- Defined in:
- lib/finch_api/models/hris/pay_statement.rb
Defined Under Namespace
Modules: Type Classes: Attributes
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The tax amount in cents.
- #attributes ⇒ FinchAPI::Models::HRIS::PayStatement::Tax::Attributes?
-
#currency ⇒ String?
The currency code.
-
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
-
#name ⇒ String?
The exact name of tax from the pay statement.
-
#type ⇒ Symbol, ...
The type of taxes.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(currency: , employer: , name: , type: , amount: nil, attributes: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency: , employer: , name: , type: , amount: nil, attributes: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/hris/pay_statement.rb', line 413
|
Instance Attribute Details
#amount ⇒ Integer?
The tax amount in cents.
406 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 406 optional :amount, Integer, nil?: true |
#attributes ⇒ FinchAPI::Models::HRIS::PayStatement::Tax::Attributes?
411 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 411 optional :attributes, -> { FinchAPI::HRIS::PayStatement::Tax::Attributes }, nil?: true |
#currency ⇒ String?
The currency code.
382 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 382 required :currency, String, nil?: true |
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
388 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 388 required :employer, FinchAPI::Internal::Type::Boolean, nil?: true |
#name ⇒ String?
The exact name of tax from the pay statement.
394 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 394 required :name, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/pay_statement.rb', line 437
|