Class: FinchAPI::Models::HRIS::PayStatement::Tax
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::PayStatement::Tax
- Defined in:
- lib/finch_api/models/hris/pay_statement.rb
Defined Under Namespace
Modules: Type Classes: Attributes
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The tax amount in cents.
- #attributes ⇒ FinchAPI::HRIS::PayStatement::Tax::Attributes?
-
#currency ⇒ String?
The currency code.
-
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
-
#name ⇒ String?
The exact name of tax from the pay statement.
-
#type ⇒ Symbol, ...
The type of taxes.
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see HRIS::PayStatement::Tax::Attributes::Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see HRIS::PayStatement::Tax::Attributes::Metadata for more details.
|
|
# File 'lib/finch_api/models/hris/pay_statement.rb', line 415
|
Instance Attribute Details
#amount ⇒ Integer?
The tax amount in cents.
384 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 384 optional :amount, Integer, nil?: true |
#attributes ⇒ FinchAPI::HRIS::PayStatement::Tax::Attributes?
389 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 389 optional :attributes, -> { FinchAPI::HRIS::PayStatement::Tax::Attributes }, nil?: true |
#currency ⇒ String?
The currency code.
395 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 395 optional :currency, String, nil?: true |
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
401 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 401 optional :employer, FinchAPI::Internal::Type::Boolean, nil?: true |
#name ⇒ String?
The exact name of tax from the pay statement.
407 |
# File 'lib/finch_api/models/hris/pay_statement.rb', line 407 optional :name, String, nil?: true |