Class: FinchAPI::Models::HRIS::PayStatement::Tax::Attributes::Metadata
- Defined in:
- lib/finch-api/models/hris/pay_statement.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Instance Attribute Summary collapse
-
#metadata ⇒ Hash{Symbol=>Object}?
readonly
The metadata to be attached to the entity by existing rules.
Instance Attribute Details
#metadata ⇒ Hash{Symbol=>Object}? (readonly)
The metadata to be attached to the entity by existing rules. It is a key-value
pairs where the values can be of any type (string, number, boolean, object,
array, etc.).
480 |
# File 'lib/finch-api/models/hris/pay_statement.rb', line 480 optional :metadata, FinchAPI::HashOf[FinchAPI::Unknown] |