Class: FinchAPI::Models::HRIS::SupportedBenefit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::SupportedBenefit
- Defined in:
- lib/finch_api/models/hris/supported_benefit.rb,
sig/finch_api/models/hris/supported_benefit.rbs
Overview
Defined Under Namespace
Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit
Instance Attribute Summary collapse
-
#annual_maximum ⇒ Boolean?
Whether the provider supports an annual maximum for this benefit.
-
#catch_up ⇒ Boolean?
Whether the provider supports catch up for this benefit.
-
#company_contribution ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::CompanyContribution, nil>?
Supported contribution types.
- #description ⇒ String?
-
#employee_deduction ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::EmployeeDeduction, nil>?
Supported deduction types.
-
#frequencies ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>
The list of frequencies supported by the provider for this benefit.
-
#hsa_contribution_limit ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::HsaContributionLimit, nil>?
Whether the provider supports HSA contribution limits.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
30 |
# File 'sig/finch_api/models/hris/supported_benefit.rbs', line 30
def initialize: (
|
Instance Attribute Details
#annual_maximum ⇒ Boolean?
Whether the provider supports an annual maximum for this benefit.
12 |
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 12 required :annual_maximum, FinchAPI::Internal::Type::Boolean, nil?: true |
#catch_up ⇒ Boolean?
Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.
55 |
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 55 optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true |
#company_contribution ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::CompanyContribution, nil>?
Supported contribution types. An empty array indicates contributions are not supported.
19 20 21 22 23 24 |
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 19 required :company_contribution, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::CompanyContribution, nil?: true] }, nil?: true |
#description ⇒ String?
29 |
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 29 required :description, String, nil?: true |
#employee_deduction ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::EmployeeDeduction, nil>?
Supported deduction types. An empty array indicates deductions are not supported.
36 37 38 39 40 41 |
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 36 required :employee_deduction, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::EmployeeDeduction, nil?: true] }, nil?: true |
#frequencies ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>
The list of frequencies supported by the provider for this benefit
47 48 |
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 47 required :frequencies, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFrequency, nil?: true] } |
#hsa_contribution_limit ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::HsaContributionLimit, nil>?
Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.
62 63 64 65 66 67 |
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 62 optional :hsa_contribution_limit, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::HsaContributionLimit, nil?: true] }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 94
|
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/finch_api/models/hris/supported_benefit.rbs', line 40
def to_hash: -> {
|