Class: FinchAPI::Models::HRIS::SupportedBenefit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/supported_benefit.rb

Overview

Defined Under Namespace

Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#annual_maximumBoolean?

Whether the provider supports an annual maximum for this benefit.

Returns:

  • (Boolean, nil)


12
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 12

optional :annual_maximum, FinchAPI::Internal::Type::Boolean, nil?: true

#catch_upBoolean?

Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.

Returns:

  • (Boolean, nil)


19
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 19

optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true

#company_contributionArray<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::CompanyContribution, nil>?

Supported contribution types. An empty array indicates contributions are not supported.



26
27
28
29
30
31
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 26

optional :company_contribution,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::CompanyContribution,
                                    nil?: true]
},
nil?: true

#descriptionString?

Returns:

  • (String, nil)


36
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 36

optional :description, String, nil?: true

#employee_deductionArray<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::EmployeeDeduction, nil>?

Supported deduction types. An empty array indicates deductions are not supported.



43
44
45
46
47
48
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 43

optional :employee_deduction,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::EmployeeDeduction,
                                    nil?: true]
},
nil?: true

#frequenciesArray<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>?

The list of frequencies supported by the provider for this benefit

Returns:



54
55
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 54

optional :frequencies,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFrequency, nil?: true] }

#hsa_contribution_limitArray<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::HsaContributionLimit, nil>?

Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.



62
63
64
65
66
67
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 62

optional :hsa_contribution_limit,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::HsaContributionLimit,
                                    nil?: true]
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/supported_benefit.rb', line 93