Class: FinchAPI::Models::HRIS::SupportedBenefit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/supported_benefit.rb

Defined Under Namespace

Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#annual_maximumBoolean?

Whether the provider supports an annual maximum for this benefit.

Returns:

  • (Boolean, nil)


11
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 11

optional :annual_maximum, FinchAPI::Internal::Type::Boolean, nil?: true

#catch_upBoolean?

Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.

Returns:

  • (Boolean, nil)


18
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 18

optional :catch_up, FinchAPI::Internal::Type::Boolean, nil?: true

#company_contributionArray<Symbol, FinchAPI::HRIS::SupportedBenefit::CompanyContribution, nil>?

Supported contribution types. An empty array indicates contributions are not supported.

Returns:

  • (Array<Symbol, FinchAPI::HRIS::SupportedBenefit::CompanyContribution, nil>, nil)


25
26
27
28
29
30
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 25

optional :company_contribution,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::CompanyContribution,
                                    nil?: true]
},
nil?: true

#descriptionString?

Returns:

  • (String, nil)


35
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 35

optional :description, String, nil?: true

#employee_deductionArray<Symbol, FinchAPI::HRIS::SupportedBenefit::EmployeeDeduction, nil>?

Supported deduction types. An empty array indicates deductions are not supported.

Returns:

  • (Array<Symbol, FinchAPI::HRIS::SupportedBenefit::EmployeeDeduction, nil>, nil)


42
43
44
45
46
47
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 42

optional :employee_deduction,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::EmployeeDeduction,
                                    nil?: true]
},
nil?: true

#frequenciesArray<Symbol, FinchAPI::HRIS::BenefitFrequency, nil>?

The list of frequencies supported by the provider for this benefit

Returns:



53
54
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 53

optional :frequencies,
-> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::BenefitFrequency, nil?: true] }

#hsa_contribution_limitArray<Symbol, FinchAPI::HRIS::SupportedBenefit::HsaContributionLimit, nil>?

Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.

Returns:

  • (Array<Symbol, FinchAPI::HRIS::SupportedBenefit::HsaContributionLimit, nil>, nil)


61
62
63
64
65
66
# File 'lib/finch_api/models/hris/supported_benefit.rb', line 61

optional :hsa_contribution_limit,
-> {
  FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::HRIS::SupportedBenefit::HsaContributionLimit,
                                    nil?: true]
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/supported_benefit.rb', line 92