Class: FinchAPI::Models::HRIS::SupportedBenefit
- Defined in:
- lib/finch-api/models/hris/supported_benefit.rb
Defined Under Namespace
Modules: CompanyContribution, EmployeeDeduction, HsaContributionLimit
Instance Attribute Summary collapse
-
#annual_maximum ⇒ Boolean?
Whether the provider supports an annual maximum for this benefit.
-
#catch_up ⇒ Boolean?
Whether the provider supports catch up for this benefit.
-
#company_contribution ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::CompanyContribution, nil>?
Supported contribution types.
- #description ⇒ String?
-
#employee_deduction ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::EmployeeDeduction, nil>?
Supported deduction types.
-
#frequencies ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>?
The list of frequencies supported by the provider for this benefit.
-
#hsa_contribution_limit ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::HsaContributionLimit, nil>?
Whether the provider supports HSA contribution limits.
-
#type ⇒ Symbol, ...
Type of benefit.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, description: nil, employee_deduction: nil, frequencies: nil, hsa_contribution_limit: nil, type: nil) ⇒ SupportedBenefit
constructor
A new instance of SupportedBenefit.
Constructor Details
#initialize(annual_maximum: nil, catch_up: nil, company_contribution: nil, description: nil, employee_deduction: nil, frequencies: nil, hsa_contribution_limit: nil, type: nil) ⇒ SupportedBenefit
Returns a new instance of SupportedBenefit.
10 11 12 13 14 15 16 17 18 19 20 21 22 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 10 def initialize( annual_maximum: nil, catch_up: nil, company_contribution: nil, description: nil, employee_deduction: nil, frequencies: nil, hsa_contribution_limit: nil, type: nil, ** ) super end |
Instance Attribute Details
#annual_maximum ⇒ Boolean?
Whether the provider supports an annual maximum for this benefit.
11 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 11 optional :annual_maximum, FinchAPI::BooleanModel, nil?: true |
#catch_up ⇒ Boolean?
Whether the provider supports catch up for this benefit. This field will only be
true for retirement benefits.
18 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 18 optional :catch_up, FinchAPI::BooleanModel, nil?: true |
#company_contribution ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::CompanyContribution, nil>?
Supported contribution types. An empty array indicates contributions are not
supported.
25 26 27 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 25 optional :company_contribution, -> { FinchAPI::ArrayOf[enum: FinchAPI::Models::HRIS::SupportedBenefit::CompanyContribution, nil?: true] }, nil?: true |
#description ⇒ String?
32 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 32 optional :description, String, nil?: true |
#employee_deduction ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::EmployeeDeduction, nil>?
Supported deduction types. An empty array indicates deductions are not
supported.
39 40 41 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 39 optional :employee_deduction, -> { FinchAPI::ArrayOf[enum: FinchAPI::Models::HRIS::SupportedBenefit::EmployeeDeduction, nil?: true] }, nil?: true |
#frequencies ⇒ Array<Symbol, FinchAPI::Models::HRIS::BenefitFrequency, nil>?
The list of frequencies supported by the provider for this benefit
47 48 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 47 optional :frequencies, -> { FinchAPI::ArrayOf[enum: FinchAPI::Models::HRIS::BenefitFrequency, nil?: true] } |
#hsa_contribution_limit ⇒ Array<Symbol, FinchAPI::Models::HRIS::SupportedBenefit::HsaContributionLimit, nil>?
Whether the provider supports HSA contribution limits. Empty if this feature is
not supported for the benefit. This array only has values for HSA benefits.
59 60 61 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 59 optional :hsa_contribution_limit, -> { FinchAPI::ArrayOf[enum: FinchAPI::Models::HRIS::SupportedBenefit::HsaContributionLimit, nil?: true] }, nil?: true |
#type ⇒ Symbol, ...
Type of benefit.
67 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 67 optional :type, enum: -> { FinchAPI::Models::HRIS::BenefitType }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/hris/supported_benefit.rb', line 2 def self.values; end |