Class: FinchAPI::Models::HRIS::W42005::Data
- Defined in:
- lib/finch-api/models/hris/w42005.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Defined Under Namespace
Modules: Exemption, FilingStatus
Instance Attribute Summary collapse
-
#additional_withholding ⇒ Integer?
Additional withholding amount (in cents).
-
#exemption ⇒ Symbol, ...
Indicates exemption status from federal tax withholding.
-
#filing_status ⇒ Symbol, ...
The individual’s filing status for tax purposes.
-
#individual_id ⇒ String?
The unique identifier for the individual associated with this 2005 W4 form.
-
#total_number_of_allowances ⇒ Integer?
Total number of allowances claimed (in cents).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_withholding: nil, exemption: nil, filing_status: nil, individual_id: nil, total_number_of_allowances: nil) ⇒ Data
constructor
Detailed information specific to the 2005 W4 form.
Constructor Details
#initialize(additional_withholding: nil, exemption: nil, filing_status: nil, individual_id: nil, total_number_of_allowances: nil) ⇒ Data
Detailed information specific to the 2005 W4 form.
9 10 11 12 13 14 15 16 17 18 |
# File 'lib/finch-api/models/hris/w42005.rb', line 9 def initialize( additional_withholding: nil, exemption: nil, filing_status: nil, individual_id: nil, total_number_of_allowances: nil, ** ) super end |
Instance Attribute Details
#additional_withholding ⇒ Integer?
Additional withholding amount (in cents).
50 |
# File 'lib/finch-api/models/hris/w42005.rb', line 50 optional :additional_withholding, Integer, nil?: true |
#exemption ⇒ Symbol, ...
Indicates exemption status from federal tax withholding.
56 |
# File 'lib/finch-api/models/hris/w42005.rb', line 56 optional :exemption, enum: -> { FinchAPI::Models::HRIS::W42005::Data::Exemption } |
#filing_status ⇒ Symbol, ...
The individual’s filing status for tax purposes.
66 |
# File 'lib/finch-api/models/hris/w42005.rb', line 66 optional :filing_status, enum: -> { FinchAPI::Models::HRIS::W42005::Data::FilingStatus }, nil?: true |
#individual_id ⇒ String?
The unique identifier for the individual associated with this 2005 W4 form.
72 |
# File 'lib/finch-api/models/hris/w42005.rb', line 72 optional :individual_id, String |
#total_number_of_allowances ⇒ Integer?
Total number of allowances claimed (in cents).
82 |
# File 'lib/finch-api/models/hris/w42005.rb', line 82 optional :total_number_of_allowances, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/hris/w42005.rb', line 2 def self.values; end |