Class: FinchAPI::Models::HRIS::W42005::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::W42005::Data
- Defined in:
- lib/finch_api/models/hris/w42005.rb
Overview
Defined Under Namespace
Modules: Exemption, FilingStatus
Instance Attribute Summary collapse
-
#additional_withholding ⇒ Integer?
Additional withholding amount (in cents).
-
#exemption ⇒ Symbol, ...
Indicates exemption status from federal tax withholding.
-
#filing_status ⇒ Symbol, ...
The individual’s filing status for tax purposes.
-
#individual_id ⇒ String?
The unique identifier for the individual associated with this 2005 W4 form.
-
#total_number_of_allowances ⇒ Integer?
Total number of allowances claimed (in cents).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_withholding: nil, exemption: nil, filing_status: nil, individual_id: nil, total_number_of_allowances: nil) ⇒ Object
constructor
Detailed information specific to the 2005 W4 form.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(additional_withholding: nil, exemption: nil, filing_status: nil, individual_id: nil, total_number_of_allowances: nil) ⇒ Object
Detailed information specific to the 2005 W4 form.
|
|
# File 'lib/finch_api/models/hris/w42005.rb', line 67
|
Instance Attribute Details
#additional_withholding ⇒ Integer?
Additional withholding amount (in cents).
41 |
# File 'lib/finch_api/models/hris/w42005.rb', line 41 optional :additional_withholding, Integer, nil?: true |
#exemption ⇒ Symbol, ...
Indicates exemption status from federal tax withholding.
47 |
# File 'lib/finch_api/models/hris/w42005.rb', line 47 optional :exemption, enum: -> { FinchAPI::HRIS::W42005::Data::Exemption } |
#filing_status ⇒ Symbol, ...
The individual’s filing status for tax purposes.
53 |
# File 'lib/finch_api/models/hris/w42005.rb', line 53 optional :filing_status, enum: -> { FinchAPI::HRIS::W42005::Data::FilingStatus }, nil?: true |
#individual_id ⇒ String?
The unique identifier for the individual associated with this 2005 W4 form.
59 |
# File 'lib/finch_api/models/hris/w42005.rb', line 59 optional :individual_id, String |
#total_number_of_allowances ⇒ Integer?
Total number of allowances claimed (in cents).
65 |
# File 'lib/finch_api/models/hris/w42005.rb', line 65 optional :total_number_of_allowances, Integer, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/hris/w42005.rb', line 89
|