Class: FinchAPI::Models::HRIS::W42020

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/w42020.rb

Defined Under Namespace

Modules: Type Classes: Data

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(data: nil, type: nil, year: nil) ⇒ Object

A 2020 version of the W-4 tax form containing information on an individual’s filing status, dependents, and withholding details.

Parameters:

  • data (FinchAPI::HRIS::W42020::Data) (defaults to: nil)

    Detailed information specific to the 2020 W4 form.

  • type (Symbol, FinchAPI::HRIS::W42020::Type) (defaults to: nil)

    Specifies the form type, indicating that this document is a 2020 W4 form.

  • year (Float, nil) (defaults to: nil)

    The tax year this W4 document applies to.



# File 'lib/finch_api/models/hris/w42020.rb', line 25

Instance Attribute Details

#dataFinchAPI::HRIS::W42020::Data?

Detailed information specific to the 2020 W4 form.

Returns:

  • (FinchAPI::HRIS::W42020::Data, nil)


11
# File 'lib/finch_api/models/hris/w42020.rb', line 11

optional :data, -> { FinchAPI::HRIS::W42020::Data }

#typeSymbol, ...

Specifies the form type, indicating that this document is a 2020 W4 form.

Returns:

  • (Symbol, FinchAPI::HRIS::W42020::Type, nil)


17
# File 'lib/finch_api/models/hris/w42020.rb', line 17

optional :type, enum: -> { FinchAPI::HRIS::W42020::Type }

#yearFloat?

The tax year this W4 document applies to.

Returns:

  • (Float, nil)


23
# File 'lib/finch_api/models/hris/w42020.rb', line 23

optional :year, Float, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/hris/w42020.rb', line 119