Class: FinchAPI::Models::HRIS::W42020::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/w42020.rb

Overview

See Also:

  • HRIS::W42020#data

Defined Under Namespace

Modules: FilingStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(amount_for_other_dependents: nil, amount_for_qualifying_children_under_17: nil, deductions: nil, extra_withholding: nil, filing_status: nil, individual_id: nil, other_income: nil, total_claim_dependent_and_other_credits: nil) ⇒ Object

Some parameter documentations has been truncated, see HRIS::W42020::Data for more details.

Detailed information specific to the 2020 W4 form.

Parameters:

  • amount_for_other_dependents (Integer, nil) (defaults to: nil)

    Amount claimed for dependents other than qualifying children under 17 (in cents)

  • amount_for_qualifying_children_under_17 (Integer, nil) (defaults to: nil)

    Amount claimed for dependents under 17 years old (in cents).

  • deductions (Integer, nil) (defaults to: nil)

    Deductible expenses (in cents).

  • extra_withholding (Integer, nil) (defaults to: nil)

    Additional withholding amount (in cents).

  • filing_status (Symbol, FinchAPI::HRIS::W42020::Data::FilingStatus, nil) (defaults to: nil)

    The individual’s filing status for tax purposes.

  • individual_id (String) (defaults to: nil)

    The unique identifier for the individual associated with this document.

  • other_income (Integer, nil) (defaults to: nil)

    Additional income from sources outside of primary employment (in cents).

  • total_claim_dependent_and_other_credits (Integer, nil) (defaults to: nil)

    Total amount claimed for dependents and other credits (in cents).



# File 'lib/finch_api/models/hris/w42020.rb', line 86

Instance Attribute Details

#amount_for_other_dependentsInteger?

Amount claimed for dependents other than qualifying children under 17 (in cents).

Returns:

  • (Integer, nil)


42
# File 'lib/finch_api/models/hris/w42020.rb', line 42

optional :amount_for_other_dependents, Integer, nil?: true

#amount_for_qualifying_children_under_17Integer?

Amount claimed for dependents under 17 years old (in cents).

Returns:

  • (Integer, nil)


48
# File 'lib/finch_api/models/hris/w42020.rb', line 48

optional :amount_for_qualifying_children_under_17, Integer, nil?: true

#deductionsInteger?

Deductible expenses (in cents).

Returns:

  • (Integer, nil)


54
# File 'lib/finch_api/models/hris/w42020.rb', line 54

optional :deductions, Integer, nil?: true

#extra_withholdingInteger?

Additional withholding amount (in cents).

Returns:

  • (Integer, nil)


60
# File 'lib/finch_api/models/hris/w42020.rb', line 60

optional :extra_withholding, Integer, nil?: true

#filing_statusSymbol, ...

The individual’s filing status for tax purposes.

Returns:

  • (Symbol, FinchAPI::HRIS::W42020::Data::FilingStatus, nil)


66
# File 'lib/finch_api/models/hris/w42020.rb', line 66

optional :filing_status, enum: -> { FinchAPI::HRIS::W42020::Data::FilingStatus }, nil?: true

#individual_idString?

The unique identifier for the individual associated with this document.

Returns:

  • (String, nil)


72
# File 'lib/finch_api/models/hris/w42020.rb', line 72

optional :individual_id, String

#other_incomeInteger?

Additional income from sources outside of primary employment (in cents).

Returns:

  • (Integer, nil)


78
# File 'lib/finch_api/models/hris/w42020.rb', line 78

optional :other_income, Integer, nil?: true

#total_claim_dependent_and_other_creditsInteger?

Total amount claimed for dependents and other credits (in cents).

Returns:

  • (Integer, nil)


84
# File 'lib/finch_api/models/hris/w42020.rb', line 84

optional :total_claim_dependent_and_other_credits, Integer, nil?: true