Class: FinchAPI::Models::HRIS::W42020::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/hris/w42020.rb

Overview

See Also:

Defined Under Namespace

Modules: FilingStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount_for_other_dependents: , amount_for_qualifying_children_under_17: , deductions: , extra_withholding: , filing_status: , individual_id: , other_income: , total_claim_dependent_and_other_credits: ) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::W42020::Data for more details.

Detailed information specific to the 2020 W4 form.

Parameters:

  • amount_for_other_dependents (Integer) (defaults to: )

    Amount claimed for dependents other than qualifying children under 17 (in cents)

  • amount_for_qualifying_children_under_17 (Integer) (defaults to: )

    Amount claimed for dependents under 17 years old (in cents).

  • deductions (Integer) (defaults to: )

    Deductible expenses (in cents).

  • extra_withholding (Integer) (defaults to: )

    Additional withholding amount (in cents).

  • filing_status (Symbol, FinchAPI::Models::HRIS::W42020::Data::FilingStatus, nil) (defaults to: )

    The individual’s filing status for tax purposes.

  • individual_id (String) (defaults to: )

    The unique identifier for the individual associated with this document.

  • other_income (Integer) (defaults to: )

    Additional income from sources outside of primary employment (in cents).

  • total_claim_dependent_and_other_credits (Integer) (defaults to: )

    Total amount claimed for dependents and other credits (in cents).



# File 'lib/finch_api/models/hris/w42020.rb', line 86

Instance Attribute Details

#amount_for_other_dependentsInteger

Amount claimed for dependents other than qualifying children under 17 (in cents).

Returns:

  • (Integer)


42
# File 'lib/finch_api/models/hris/w42020.rb', line 42

required :amount_for_other_dependents, Integer

#amount_for_qualifying_children_under_17Integer

Amount claimed for dependents under 17 years old (in cents).

Returns:

  • (Integer)


48
# File 'lib/finch_api/models/hris/w42020.rb', line 48

required :amount_for_qualifying_children_under_17, Integer

#deductionsInteger

Deductible expenses (in cents).

Returns:

  • (Integer)


54
# File 'lib/finch_api/models/hris/w42020.rb', line 54

required :deductions, Integer

#extra_withholdingInteger

Additional withholding amount (in cents).

Returns:

  • (Integer)


60
# File 'lib/finch_api/models/hris/w42020.rb', line 60

required :extra_withholding, Integer

#filing_statusSymbol, ...

The individual’s filing status for tax purposes.



66
# File 'lib/finch_api/models/hris/w42020.rb', line 66

required :filing_status, enum: -> { FinchAPI::HRIS::W42020::Data::FilingStatus }, nil?: true

#individual_idString

The unique identifier for the individual associated with this document.

Returns:

  • (String)


72
# File 'lib/finch_api/models/hris/w42020.rb', line 72

required :individual_id, String

#other_incomeInteger

Additional income from sources outside of primary employment (in cents).

Returns:

  • (Integer)


78
# File 'lib/finch_api/models/hris/w42020.rb', line 78

required :other_income, Integer

#total_claim_dependent_and_other_creditsInteger

Total amount claimed for dependents and other credits (in cents).

Returns:

  • (Integer)


84
# File 'lib/finch_api/models/hris/w42020.rb', line 84

required :total_claim_dependent_and_other_credits, Integer