Class: FinchAPI::Models::HRIS::W42020::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::HRIS::W42020::Data
- Defined in:
- lib/finch_api/models/hris/w42020.rb
Overview
Defined Under Namespace
Modules: FilingStatus
Instance Attribute Summary collapse
-
#amount_for_other_dependents ⇒ Integer
Amount claimed for dependents other than qualifying children under 17 (in cents).
-
#amount_for_qualifying_children_under_17 ⇒ Integer
Amount claimed for dependents under 17 years old (in cents).
-
#deductions ⇒ Integer
Deductible expenses (in cents).
-
#extra_withholding ⇒ Integer
Additional withholding amount (in cents).
-
#filing_status ⇒ Symbol, ...
The individual’s filing status for tax purposes.
-
#individual_id ⇒ String
The unique identifier for the individual associated with this document.
-
#other_income ⇒ Integer
Additional income from sources outside of primary employment (in cents).
-
#total_claim_dependent_and_other_credits ⇒ Integer
Total amount claimed for dependents and other credits (in cents).
Instance Method Summary collapse
-
#initialize(amount_for_other_dependents: , amount_for_qualifying_children_under_17: , deductions: , extra_withholding: , filing_status: , individual_id: , other_income: , total_claim_dependent_and_other_credits: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount_for_other_dependents: , amount_for_qualifying_children_under_17: , deductions: , extra_withholding: , filing_status: , individual_id: , other_income: , total_claim_dependent_and_other_credits: ) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::HRIS::W42020::Data for more details.
Detailed information specific to the 2020 W4 form.
|
|
# File 'lib/finch_api/models/hris/w42020.rb', line 86
|
Instance Attribute Details
#amount_for_other_dependents ⇒ Integer
Amount claimed for dependents other than qualifying children under 17 (in cents).
42 |
# File 'lib/finch_api/models/hris/w42020.rb', line 42 required :amount_for_other_dependents, Integer |
#amount_for_qualifying_children_under_17 ⇒ Integer
Amount claimed for dependents under 17 years old (in cents).
48 |
# File 'lib/finch_api/models/hris/w42020.rb', line 48 required :amount_for_qualifying_children_under_17, Integer |
#deductions ⇒ Integer
Deductible expenses (in cents).
54 |
# File 'lib/finch_api/models/hris/w42020.rb', line 54 required :deductions, Integer |
#extra_withholding ⇒ Integer
Additional withholding amount (in cents).
60 |
# File 'lib/finch_api/models/hris/w42020.rb', line 60 required :extra_withholding, Integer |
#filing_status ⇒ Symbol, ...
The individual’s filing status for tax purposes.
66 |
# File 'lib/finch_api/models/hris/w42020.rb', line 66 required :filing_status, enum: -> { FinchAPI::HRIS::W42020::Data::FilingStatus }, nil?: true |
#individual_id ⇒ String
The unique identifier for the individual associated with this document.
72 |
# File 'lib/finch_api/models/hris/w42020.rb', line 72 required :individual_id, String |
#other_income ⇒ Integer
Additional income from sources outside of primary employment (in cents).
78 |
# File 'lib/finch_api/models/hris/w42020.rb', line 78 required :other_income, Integer |
#total_claim_dependent_and_other_credits ⇒ Integer
Total amount claimed for dependents and other credits (in cents).
84 |
# File 'lib/finch_api/models/hris/w42020.rb', line 84 required :total_claim_dependent_and_other_credits, Integer |