Class: FinchAPI::Models::HRIS::W42020::Data
- Defined in:
- lib/finch-api/models/hris/w42020.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Defined Under Namespace
Modules: FilingStatus
Instance Attribute Summary collapse
-
#amount_for_other_dependents ⇒ Integer?
Amount claimed for dependents other than qualifying children under 17 (in cents).
-
#amount_for_qualifying_children_under_17 ⇒ Integer?
Amount claimed for dependents under 17 years old (in cents).
-
#deductions ⇒ Integer?
Deductible expenses (in cents).
-
#extra_withholding ⇒ Integer?
Additional withholding amount (in cents).
-
#filing_status ⇒ Symbol, ...
The individual’s filing status for tax purposes.
-
#individual_id ⇒ String?
The unique identifier for the individual associated with this document.
-
#other_income ⇒ Integer?
Additional income from sources outside of primary employment (in cents).
-
#total_claim_dependent_and_other_credits ⇒ Integer?
Total amount claimed for dependents and other credits (in cents).
Instance Method Summary collapse
-
#initialize(amount_for_other_dependents: nil, amount_for_qualifying_children_under_17: nil, deductions: nil, extra_withholding: nil, filing_status: nil, individual_id: nil, other_income: nil, total_claim_dependent_and_other_credits: nil) ⇒ Data
constructor
Detailed information specific to the 2020 W4 form.
Constructor Details
#initialize(amount_for_other_dependents: nil, amount_for_qualifying_children_under_17: nil, deductions: nil, extra_withholding: nil, filing_status: nil, individual_id: nil, other_income: nil, total_claim_dependent_and_other_credits: nil) ⇒ Data
Detailed information specific to the 2020 W4 form.
12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/finch-api/models/hris/w42020.rb', line 12 def initialize( amount_for_other_dependents: nil, amount_for_qualifying_children_under_17: nil, deductions: nil, extra_withholding: nil, filing_status: nil, individual_id: nil, other_income: nil, total_claim_dependent_and_other_credits: nil, ** ) super end |
Instance Attribute Details
#amount_for_other_dependents ⇒ Integer?
Amount claimed for dependents other than qualifying children under 17 (in
cents).
51 |
# File 'lib/finch-api/models/hris/w42020.rb', line 51 optional :amount_for_other_dependents, Integer, nil?: true |
#amount_for_qualifying_children_under_17 ⇒ Integer?
Amount claimed for dependents under 17 years old (in cents).
57 |
# File 'lib/finch-api/models/hris/w42020.rb', line 57 optional :amount_for_qualifying_children_under_17, Integer, nil?: true |
#deductions ⇒ Integer?
Deductible expenses (in cents).
63 |
# File 'lib/finch-api/models/hris/w42020.rb', line 63 optional :deductions, Integer, nil?: true |
#extra_withholding ⇒ Integer?
Additional withholding amount (in cents).
69 |
# File 'lib/finch-api/models/hris/w42020.rb', line 69 optional :extra_withholding, Integer, nil?: true |
#filing_status ⇒ Symbol, ...
The individual’s filing status for tax purposes.
75 |
# File 'lib/finch-api/models/hris/w42020.rb', line 75 optional :filing_status, enum: -> { FinchAPI::Models::HRIS::W42020::Data::FilingStatus }, nil?: true |
#individual_id ⇒ String?
The unique identifier for the individual associated with this document.
81 |
# File 'lib/finch-api/models/hris/w42020.rb', line 81 optional :individual_id, String |
#other_income ⇒ Integer?
Additional income from sources outside of primary employment (in cents).
91 |
# File 'lib/finch-api/models/hris/w42020.rb', line 91 optional :other_income, Integer, nil?: true |
#total_claim_dependent_and_other_credits ⇒ Integer?
Total amount claimed for dependents and other credits (in cents).
97 |
# File 'lib/finch-api/models/hris/w42020.rb', line 97 optional :total_claim_dependent_and_other_credits, Integer, nil?: true |