Class: FinchAPI::Models::Income
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Income
- Defined in:
- lib/finch_api/models/income.rb
Defined Under Namespace
Modules: Unit
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The income amount in cents.
-
#currency ⇒ String?
The currency code.
-
#effective_date ⇒ Date?
The date the income amount went into effect.
-
#unit ⇒ Symbol, ...
The income unit of payment.
Instance Method Summary collapse
-
#initialize(amount: , currency: , effective_date: , unit: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Income for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: , currency: , effective_date: , unit: ) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::Income for more details.
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
|
|
# File 'lib/finch_api/models/income.rb', line 31
|
Instance Attribute Details
#amount ⇒ Integer?
The income amount in cents.
10 |
# File 'lib/finch_api/models/income.rb', line 10 required :amount, Integer, nil?: true |
#currency ⇒ String?
The currency code.
16 |
# File 'lib/finch_api/models/income.rb', line 16 required :currency, String, nil?: true |
#effective_date ⇒ Date?
The date the income amount went into effect.
22 |
# File 'lib/finch_api/models/income.rb', line 22 required :effective_date, Date, nil?: true |