Class: FinchAPI::Models::Introspection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/introspection.rb

Overview

Defined Under Namespace

Modules: ClientType, ConnectionType Classes: AuthenticationMethod, ConnectionStatus

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(last_successful_sync: nil, message: nil, status: nil) ⇒ Object

Parameters:

  • last_successful_sync (Time) (defaults to: nil)

    The datetime when the connection was last successfully synced.

  • message (String) (defaults to: nil)
  • status (Symbol, FinchAPI::Models::ConnectionStatusType) (defaults to: nil)


# File 'lib/finch_api/models/introspection.rb', line 254

Instance Attribute Details

#account_idString

Deprecated.
DEPRECATED

Use ‘connection_id` to associate tokens with a Finch connection

instead of this account ID.

Returns:

  • (String)


20
# File 'lib/finch_api/models/introspection.rb', line 20

required :account_id, String

#authentication_methodsArray<FinchAPI::Models::Introspection::AuthenticationMethod>



25
26
# File 'lib/finch_api/models/introspection.rb', line 25

required :authentication_methods,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Introspection::AuthenticationMethod] }

#client_idString

The client ID of the application associated with the ‘access_token`.

Returns:

  • (String)


32
# File 'lib/finch_api/models/introspection.rb', line 32

required :client_id, String

#client_typeSymbol, FinchAPI::Models::Introspection::ClientType

The type of application associated with a token.



38
# File 'lib/finch_api/models/introspection.rb', line 38

required :client_type, enum: -> { FinchAPI::Introspection::ClientType }

#company_idString

Deprecated.
DEPRECATED

Use ‘connection_id` to associate tokens with a Finch connection

instead of this company ID.

Returns:

  • (String)


47
# File 'lib/finch_api/models/introspection.rb', line 47

required :company_id, String

#connection_idString

The Finch UUID of the connection associated with the ‘access_token`.

Returns:

  • (String)


53
# File 'lib/finch_api/models/introspection.rb', line 53

required :connection_id, String

#connection_statusFinchAPI::Models::Introspection::ConnectionStatus



58
# File 'lib/finch_api/models/introspection.rb', line 58

required :connection_status, -> { FinchAPI::Introspection::ConnectionStatus }

#connection_typeSymbol, FinchAPI::Models::Introspection::ConnectionType

The type of the connection associated with the token.

  • ‘provider` - connection to an external provider

  • ‘finch` - finch-generated data.



67
# File 'lib/finch_api/models/introspection.rb', line 67

required :connection_type, enum: -> { FinchAPI::Introspection::ConnectionType }

#customer_emailString?

The email of your customer you provided to Finch when a connect session was created for this connection.

Returns:

  • (String, nil)


74
# File 'lib/finch_api/models/introspection.rb', line 74

required :customer_email, String, nil?: true

#customer_idString?

The ID of your customer you provided to Finch when a connect session was created for this connection.

Returns:

  • (String, nil)


81
# File 'lib/finch_api/models/introspection.rb', line 81

required :customer_id, String, nil?: true

#customer_nameString?

The name of your customer you provided to Finch when a connect session was created for this connection.

Returns:

  • (String, nil)


88
# File 'lib/finch_api/models/introspection.rb', line 88

required :customer_name, String, nil?: true

#idString

The Finch UUID of the token being introspected.

Returns:

  • (String)


11
# File 'lib/finch_api/models/introspection.rb', line 11

required :id, String

#manualBoolean

Whether the connection associated with the ‘access_token` uses the Assisted Connect Flow. (`true` if using Assisted Connect, `false` if connection is automated)

Returns:

  • (Boolean)


96
# File 'lib/finch_api/models/introspection.rb', line 96

required :manual, FinchAPI::Internal::Type::Boolean

#payroll_provider_idString

Deprecated.
DEPRECATED

Use ‘provider_id` to identify the provider instead of this payroll

provider ID.

Returns:

  • (String)


105
# File 'lib/finch_api/models/introspection.rb', line 105

required :payroll_provider_id, String

#productsArray<String>

An array of the authorized products associated with the ‘access_token`.

Returns:

  • (Array<String>)


111
# File 'lib/finch_api/models/introspection.rb', line 111

required :products, FinchAPI::Internal::Type::ArrayOf[String]

#provider_idString

The ID of the provider associated with the ‘access_token`.

Returns:

  • (String)


117
# File 'lib/finch_api/models/introspection.rb', line 117

required :provider_id, String

#usernameString

The account username used for login associated with the ‘access_token`.

Returns:

  • (String)


123
# File 'lib/finch_api/models/introspection.rb', line 123

required :username, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/introspection.rb', line 217