Class: FinchAPI::Models::Introspection

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/introspection.rb

Defined Under Namespace

Modules: ClientType, ConnectionType Classes: AuthenticationMethod, ConnectionStatus

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(last_successful_sync: nil, message: nil, status: nil) ⇒ Introspection

Returns a new instance of Introspection.

Parameters:



18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
# File 'lib/finch-api/models/introspection.rb', line 18

def initialize(
  account_id:,
  authentication_methods:,
  client_id:,
  client_type:,
  company_id:,
  connection_id:,
  connection_status:,
  connection_type:,
  customer_email:,
  customer_id:,
  customer_name:,
  manual:,
  payroll_provider_id:,
  products:,
  provider_id:,
  username:,
  **
)
  super
end

Instance Attribute Details

#account_idString

DEPRECATED

Use ‘connection_id` to associate tokens with a Finch connection

instead of this account ID.

Returns:

  • (String)


11
# File 'lib/finch-api/models/introspection.rb', line 11

required :account_id, String

#authentication_methodsArray<FinchAPI::Models::Introspection::AuthenticationMethod>



16
17
# File 'lib/finch-api/models/introspection.rb', line 16

required :authentication_methods,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Introspection::AuthenticationMethod] }

#client_idString

The client ID of the application associated with the ‘access_token`.

Returns:

  • (String)


23
# File 'lib/finch-api/models/introspection.rb', line 23

required :client_id, String

#client_typeSymbol, FinchAPI::Models::Introspection::ClientType

The type of application associated with a token.



29
# File 'lib/finch-api/models/introspection.rb', line 29

required :client_type, enum: -> { FinchAPI::Models::Introspection::ClientType }

#company_idString

DEPRECATED

Use ‘connection_id` to associate tokens with a Finch connection

instead of this company ID.

Returns:

  • (String)


36
# File 'lib/finch-api/models/introspection.rb', line 36

required :company_id, String

#connection_idString

The Finch UUID of the connection associated with the ‘access_token`.

Returns:

  • (String)


42
# File 'lib/finch-api/models/introspection.rb', line 42

required :connection_id, String

#connection_statusFinchAPI::Models::Introspection::ConnectionStatus



47
# File 'lib/finch-api/models/introspection.rb', line 47

required :connection_status, -> { FinchAPI::Models::Introspection::ConnectionStatus }

#connection_typeSymbol, FinchAPI::Models::Introspection::ConnectionType

The type of the connection associated with the token.

- `provider` - connection to an external provider
- `finch` - finch-generated data.


56
# File 'lib/finch-api/models/introspection.rb', line 56

required :connection_type, enum: -> { FinchAPI::Models::Introspection::ConnectionType }

#customer_emailString?

The email of your customer you provided to Finch when a connect session was

created for this connection.

Returns:

  • (String, nil)


63
# File 'lib/finch-api/models/introspection.rb', line 63

required :customer_email, String, nil?: true

#customer_idString?

The ID of your customer you provided to Finch when a connect session was created

for this connection.

Returns:

  • (String, nil)


70
# File 'lib/finch-api/models/introspection.rb', line 70

required :customer_id, String, nil?: true

#customer_nameString?

The name of your customer you provided to Finch when a connect session was

created for this connection.

Returns:

  • (String, nil)


77
# File 'lib/finch-api/models/introspection.rb', line 77

required :customer_name, String, nil?: true

#manualBoolean

Whether the connection associated with the ‘access_token` uses the Assisted

Connect Flow. (`true` if using Assisted Connect, `false` if connection is
automated)

Returns:

  • (Boolean)


85
# File 'lib/finch-api/models/introspection.rb', line 85

required :manual, FinchAPI::BooleanModel

#payroll_provider_idString

DEPRECATED

Use ‘provider_id` to identify the provider instead of this payroll

provider ID.

Returns:

  • (String)


92
# File 'lib/finch-api/models/introspection.rb', line 92

required :payroll_provider_id, String

#productsArray<String>

An array of the authorized products associated with the ‘access_token`.

Returns:

  • (Array<String>)


98
# File 'lib/finch-api/models/introspection.rb', line 98

required :products, FinchAPI::ArrayOf[String]

#provider_idString

The ID of the provider associated with the ‘access_token`.

Returns:

  • (String)


104
# File 'lib/finch-api/models/introspection.rb', line 104

required :provider_id, String

#status=(value) ⇒ Symbol, FinchAPI::Models::ConnectionStatusType (writeonly)



2
3
4
# File 'lib/finch-api/models/introspection.rb', line 2

def status=(value)
  @status = value
end

#usernameString

The account username used for login associated with the ‘access_token`.

Returns:

  • (String)


110
# File 'lib/finch-api/models/introspection.rb', line 110

required :username, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/introspection.rb', line 2

def self.values; end