Class: FinchAPI::Models::Introspection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/introspection.rb

Overview

Defined Under Namespace

Modules: ClientType, ConnectionType Classes: AuthenticationMethod, ConnectionStatus, Entity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , client_id: , client_type: , connection_id: , connection_status: , connection_type: , products: , provider_id: , account_id: nil, authentication_methods: nil, company_id: nil, customer_email: nil, customer_id: nil, customer_name: nil, entities: nil, manual: nil, payroll_provider_id: nil, username: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::Introspection for more details.

Parameters:

  • id (String) (defaults to: )

    The Finch UUID of the token being introspected

  • client_id (String) (defaults to: )

    The client ID of the application associated with the ‘access_token`

  • client_type (Symbol, FinchAPI::Models::Introspection::ClientType) (defaults to: )

    The type of application associated with a token.

  • connection_id (String) (defaults to: )

    The Finch UUID of the connection associated with the ‘access_token`

  • connection_status (FinchAPI::Models::Introspection::ConnectionStatus) (defaults to: )
  • connection_type (Symbol, FinchAPI::Models::Introspection::ConnectionType) (defaults to: )

    The type of the connection associated with the token.

  • products (Array<String>) (defaults to: )

    An array of the authorized products associated with the ‘access_token`.

  • provider_id (String) (defaults to: )

    The ID of the provider associated with the ‘access_token`.

  • account_id (String) (defaults to: nil)
    DEPRECATED

    Use ‘connection_id` to associate tokens with a Finch connection ins

  • authentication_methods (Array<FinchAPI::Models::Introspection::AuthenticationMethod>) (defaults to: nil)
  • company_id (String) (defaults to: nil)
    DEPRECATED

    Use ‘connection_id` to associate tokens with a Finch connection ins

  • customer_email (String, nil) (defaults to: nil)

    The email of your customer you provided to Finch when a connect session was crea

  • customer_id (String, nil) (defaults to: nil)

    The ID of your customer you provided to Finch when a connect session was created

  • customer_name (String, nil) (defaults to: nil)

    The name of your customer you provided to Finch when a connect session was creat

  • entities (Array<FinchAPI::Models::Introspection::Entity>) (defaults to: nil)

    Array of detailed entity information for each connected account in multi-account

  • manual (Boolean) (defaults to: nil)

    Whether the connection associated with the ‘access_token` uses the Assisted Conn

  • payroll_provider_id (String) (defaults to: nil)
    DEPRECATED

    Use ‘provider_id` to identify the provider instead of this payroll

  • username (String, nil) (defaults to: nil)

    The account username used for login associated with the ‘access_token`.



# File 'lib/finch_api/models/introspection.rb', line 132

Instance Attribute Details

#account_idString?

Deprecated.
DEPRECATED

Use ‘connection_id` to associate tokens with a Finch connection

instead of this account ID

Returns:

  • (String, nil)


64
# File 'lib/finch_api/models/introspection.rb', line 64

optional :account_id, String

#authentication_methodsArray<FinchAPI::Models::Introspection::AuthenticationMethod>?



69
70
# File 'lib/finch_api/models/introspection.rb', line 69

optional :authentication_methods,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Introspection::AuthenticationMethod] }

#client_idString

The client ID of the application associated with the ‘access_token`

Returns:

  • (String)


17
# File 'lib/finch_api/models/introspection.rb', line 17

required :client_id, String

#client_typeSymbol, FinchAPI::Models::Introspection::ClientType

The type of application associated with a token.



23
# File 'lib/finch_api/models/introspection.rb', line 23

required :client_type, enum: -> { FinchAPI::Introspection::ClientType }

#company_idString?

Deprecated.
DEPRECATED

Use ‘connection_id` to associate tokens with a Finch connection

instead of this company ID

Returns:

  • (String, nil)


79
# File 'lib/finch_api/models/introspection.rb', line 79

optional :company_id, String

#connection_idString

The Finch UUID of the connection associated with the ‘access_token`

Returns:

  • (String)


29
# File 'lib/finch_api/models/introspection.rb', line 29

required :connection_id, String

#connection_statusFinchAPI::Models::Introspection::ConnectionStatus



34
# File 'lib/finch_api/models/introspection.rb', line 34

required :connection_status, -> { FinchAPI::Introspection::ConnectionStatus }

#connection_typeSymbol, FinchAPI::Models::Introspection::ConnectionType

The type of the connection associated with the token.

  • ‘provider` - connection to an external provider

  • ‘finch` - finch-generated data.



43
# File 'lib/finch_api/models/introspection.rb', line 43

required :connection_type, enum: -> { FinchAPI::Introspection::ConnectionType }

#customer_emailString?

The email of your customer you provided to Finch when a connect session was created for this connection

Returns:

  • (String, nil)


86
# File 'lib/finch_api/models/introspection.rb', line 86

optional :customer_email, String, nil?: true

#customer_idString?

The ID of your customer you provided to Finch when a connect session was created for this connection

Returns:

  • (String, nil)


93
# File 'lib/finch_api/models/introspection.rb', line 93

optional :customer_id, String, nil?: true

#customer_nameString?

The name of your customer you provided to Finch when a connect session was created for this connection

Returns:

  • (String, nil)


100
# File 'lib/finch_api/models/introspection.rb', line 100

optional :customer_name, String, nil?: true

#entitiesArray<FinchAPI::Models::Introspection::Entity>?

Array of detailed entity information for each connected account in multi-account mode



107
# File 'lib/finch_api/models/introspection.rb', line 107

optional :entities, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Introspection::Entity] }

#idString

The Finch UUID of the token being introspected

Returns:

  • (String)


11
# File 'lib/finch_api/models/introspection.rb', line 11

required :id, String

#manualBoolean?

Whether the connection associated with the ‘access_token` uses the Assisted Connect Flow. (`true` if using Assisted Connect, `false` if connection is automated)

Returns:

  • (Boolean, nil)


115
# File 'lib/finch_api/models/introspection.rb', line 115

optional :manual, FinchAPI::Internal::Type::Boolean

#payroll_provider_idString?

Deprecated.
DEPRECATED

Use ‘provider_id` to identify the provider instead of this payroll

provider ID.

Returns:

  • (String, nil)


124
# File 'lib/finch_api/models/introspection.rb', line 124

optional :payroll_provider_id, String

#productsArray<String>

An array of the authorized products associated with the ‘access_token`.

Returns:

  • (Array<String>)


49
# File 'lib/finch_api/models/introspection.rb', line 49

required :products, FinchAPI::Internal::Type::ArrayOf[String]

#provider_idString

The ID of the provider associated with the ‘access_token`.

Returns:

  • (String)


55
# File 'lib/finch_api/models/introspection.rb', line 55

required :provider_id, String

#usernameString?

The account username used for login associated with the ‘access_token`.

Returns:

  • (String, nil)


130
# File 'lib/finch_api/models/introspection.rb', line 130

optional :username, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/introspection.rb', line 182

.variantsArray(Time, String)

Returns:

  • (Array(Time, String))


# File 'lib/finch_api/models/introspection.rb', line 223