Class: FinchAPI::Models::Introspection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Introspection
- Defined in:
- lib/finch_api/models/introspection.rb
Overview
Defined Under Namespace
Modules: ClientType, ConnectionType Classes: AuthenticationMethod, ConnectionStatus
Instance Attribute Summary collapse
- #account_id ⇒ String deprecated Deprecated.
- #authentication_methods ⇒ Array<FinchAPI::Models::Introspection::AuthenticationMethod>
-
#client_id ⇒ String
The client ID of the application associated with the ‘access_token`.
-
#client_type ⇒ Symbol, FinchAPI::Models::Introspection::ClientType
The type of application associated with a token.
- #company_id ⇒ String deprecated Deprecated.
-
#connection_id ⇒ String
The Finch UUID of the connection associated with the ‘access_token`.
- #connection_status ⇒ FinchAPI::Models::Introspection::ConnectionStatus
-
#connection_type ⇒ Symbol, FinchAPI::Models::Introspection::ConnectionType
The type of the connection associated with the token.
-
#customer_email ⇒ String?
The email of your customer you provided to Finch when a connect session was created for this connection.
-
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created for this connection.
-
#customer_name ⇒ String?
The name of your customer you provided to Finch when a connect session was created for this connection.
-
#id ⇒ String
The Finch UUID of the token being introspected.
-
#manual ⇒ Boolean
Whether the connection associated with the ‘access_token` uses the Assisted Connect Flow.
- #payroll_provider_id ⇒ String deprecated Deprecated.
-
#products ⇒ Array<String>
An array of the authorized products associated with the ‘access_token`.
-
#provider_id ⇒ String
The ID of the provider associated with the ‘access_token`.
-
#username ⇒ String
The account username used for login associated with the ‘access_token`.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(last_successful_sync: nil, message: nil, status: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/introspection.rb', line 254
|
Instance Attribute Details
#account_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to associate tokens with a Finch connection
instead of this account ID.
20 |
# File 'lib/finch_api/models/introspection.rb', line 20 required :account_id, String |
#authentication_methods ⇒ Array<FinchAPI::Models::Introspection::AuthenticationMethod>
25 26 |
# File 'lib/finch_api/models/introspection.rb', line 25 required :authentication_methods, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Introspection::AuthenticationMethod] } |
#client_id ⇒ String
The client ID of the application associated with the ‘access_token`.
32 |
# File 'lib/finch_api/models/introspection.rb', line 32 required :client_id, String |
#client_type ⇒ Symbol, FinchAPI::Models::Introspection::ClientType
The type of application associated with a token.
38 |
# File 'lib/finch_api/models/introspection.rb', line 38 required :client_type, enum: -> { FinchAPI::Introspection::ClientType } |
#company_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to associate tokens with a Finch connection
instead of this company ID.
47 |
# File 'lib/finch_api/models/introspection.rb', line 47 required :company_id, String |
#connection_id ⇒ String
The Finch UUID of the connection associated with the ‘access_token`.
53 |
# File 'lib/finch_api/models/introspection.rb', line 53 required :connection_id, String |
#connection_status ⇒ FinchAPI::Models::Introspection::ConnectionStatus
58 |
# File 'lib/finch_api/models/introspection.rb', line 58 required :connection_status, -> { FinchAPI::Introspection::ConnectionStatus } |
#connection_type ⇒ Symbol, FinchAPI::Models::Introspection::ConnectionType
The type of the connection associated with the token.
-
‘provider` - connection to an external provider
-
‘finch` - finch-generated data.
67 |
# File 'lib/finch_api/models/introspection.rb', line 67 required :connection_type, enum: -> { FinchAPI::Introspection::ConnectionType } |
#customer_email ⇒ String?
The email of your customer you provided to Finch when a connect session was created for this connection.
74 |
# File 'lib/finch_api/models/introspection.rb', line 74 required :customer_email, String, nil?: true |
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created for this connection.
81 |
# File 'lib/finch_api/models/introspection.rb', line 81 required :customer_id, String, nil?: true |
#customer_name ⇒ String?
The name of your customer you provided to Finch when a connect session was created for this connection.
88 |
# File 'lib/finch_api/models/introspection.rb', line 88 required :customer_name, String, nil?: true |
#id ⇒ String
The Finch UUID of the token being introspected.
11 |
# File 'lib/finch_api/models/introspection.rb', line 11 required :id, String |
#manual ⇒ Boolean
Whether the connection associated with the ‘access_token` uses the Assisted Connect Flow. (`true` if using Assisted Connect, `false` if connection is automated)
96 |
# File 'lib/finch_api/models/introspection.rb', line 96 required :manual, FinchAPI::Internal::Type::Boolean |
#payroll_provider_id ⇒ String
- DEPRECATED
-
Use ‘provider_id` to identify the provider instead of this payroll
provider ID.
105 |
# File 'lib/finch_api/models/introspection.rb', line 105 required :payroll_provider_id, String |
#products ⇒ Array<String>
An array of the authorized products associated with the ‘access_token`.
111 |
# File 'lib/finch_api/models/introspection.rb', line 111 required :products, FinchAPI::Internal::Type::ArrayOf[String] |
#provider_id ⇒ String
The ID of the provider associated with the ‘access_token`.
117 |
# File 'lib/finch_api/models/introspection.rb', line 117 required :provider_id, String |
#username ⇒ String
The account username used for login associated with the ‘access_token`.
123 |
# File 'lib/finch_api/models/introspection.rb', line 123 required :username, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/introspection.rb', line 217
|