Class: FinchAPI::Models::Introspection
- Defined in:
- lib/finch-api/models/introspection.rb
Defined Under Namespace
Modules: ClientType, ConnectionType Classes: AuthenticationMethod, ConnectionStatus
Instance Attribute Summary collapse
-
#account_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to associate tokens with a Finch connection instead of this account ID.
- #authentication_methods ⇒ Array<FinchAPI::Models::Introspection::AuthenticationMethod>
-
#client_id ⇒ String
The client ID of the application associated with the ‘access_token`.
-
#client_type ⇒ Symbol, FinchAPI::Models::Introspection::ClientType
The type of application associated with a token.
-
#company_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to associate tokens with a Finch connection instead of this company ID.
-
#connection_id ⇒ String
The Finch UUID of the connection associated with the ‘access_token`.
- #connection_status ⇒ FinchAPI::Models::Introspection::ConnectionStatus
-
#connection_type ⇒ Symbol, FinchAPI::Models::Introspection::ConnectionType
The type of the connection associated with the token.
-
#customer_email ⇒ String?
The email of your customer you provided to Finch when a connect session was created for this connection.
-
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created for this connection.
-
#customer_name ⇒ String?
The name of your customer you provided to Finch when a connect session was created for this connection.
-
#manual ⇒ Boolean
Whether the connection associated with the ‘access_token` uses the Assisted Connect Flow.
-
#payroll_provider_id ⇒ String
- DEPRECATED
-
Use ‘provider_id` to identify the provider instead of this payroll provider ID.
-
#products ⇒ Array<String>
An array of the authorized products associated with the ‘access_token`.
-
#provider_id ⇒ String
The ID of the provider associated with the ‘access_token`.
- #status ⇒ Symbol, FinchAPI::Models::ConnectionStatusType writeonly
-
#username ⇒ String
The account username used for login associated with the ‘access_token`.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(last_successful_sync: nil, message: nil, status: nil) ⇒ Introspection
constructor
A new instance of Introspection.
Constructor Details
#initialize(last_successful_sync: nil, message: nil, status: nil) ⇒ Introspection
Returns a new instance of Introspection.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/finch-api/models/introspection.rb', line 18 def initialize( account_id:, authentication_methods:, client_id:, client_type:, company_id:, connection_id:, connection_status:, connection_type:, customer_email:, customer_id:, customer_name:, manual:, payroll_provider_id:, products:, provider_id:, username:, ** ) super end |
Instance Attribute Details
#account_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to associate tokens with a Finch connection
instead of this account ID.
11 |
# File 'lib/finch-api/models/introspection.rb', line 11 required :account_id, String |
#authentication_methods ⇒ Array<FinchAPI::Models::Introspection::AuthenticationMethod>
16 17 |
# File 'lib/finch-api/models/introspection.rb', line 16 required :authentication_methods, -> { FinchAPI::ArrayOf[FinchAPI::Models::Introspection::AuthenticationMethod] } |
#client_id ⇒ String
The client ID of the application associated with the ‘access_token`.
23 |
# File 'lib/finch-api/models/introspection.rb', line 23 required :client_id, String |
#client_type ⇒ Symbol, FinchAPI::Models::Introspection::ClientType
The type of application associated with a token.
29 |
# File 'lib/finch-api/models/introspection.rb', line 29 required :client_type, enum: -> { FinchAPI::Models::Introspection::ClientType } |
#company_id ⇒ String
- DEPRECATED
-
Use ‘connection_id` to associate tokens with a Finch connection
instead of this company ID.
36 |
# File 'lib/finch-api/models/introspection.rb', line 36 required :company_id, String |
#connection_id ⇒ String
The Finch UUID of the connection associated with the ‘access_token`.
42 |
# File 'lib/finch-api/models/introspection.rb', line 42 required :connection_id, String |
#connection_status ⇒ FinchAPI::Models::Introspection::ConnectionStatus
47 |
# File 'lib/finch-api/models/introspection.rb', line 47 required :connection_status, -> { FinchAPI::Models::Introspection::ConnectionStatus } |
#connection_type ⇒ Symbol, FinchAPI::Models::Introspection::ConnectionType
The type of the connection associated with the token.
- `provider` - connection to an external provider
- `finch` - finch-generated data.
56 |
# File 'lib/finch-api/models/introspection.rb', line 56 required :connection_type, enum: -> { FinchAPI::Models::Introspection::ConnectionType } |
#customer_email ⇒ String?
The email of your customer you provided to Finch when a connect session was
created for this connection.
63 |
# File 'lib/finch-api/models/introspection.rb', line 63 required :customer_email, String, nil?: true |
#customer_id ⇒ String?
The ID of your customer you provided to Finch when a connect session was created
for this connection.
70 |
# File 'lib/finch-api/models/introspection.rb', line 70 required :customer_id, String, nil?: true |
#customer_name ⇒ String?
The name of your customer you provided to Finch when a connect session was
created for this connection.
77 |
# File 'lib/finch-api/models/introspection.rb', line 77 required :customer_name, String, nil?: true |
#manual ⇒ Boolean
Whether the connection associated with the ‘access_token` uses the Assisted
Connect Flow. (`true` if using Assisted Connect, `false` if connection is
automated)
85 |
# File 'lib/finch-api/models/introspection.rb', line 85 required :manual, FinchAPI::BooleanModel |
#payroll_provider_id ⇒ String
- DEPRECATED
-
Use ‘provider_id` to identify the provider instead of this payroll
provider ID.
92 |
# File 'lib/finch-api/models/introspection.rb', line 92 required :payroll_provider_id, String |
#products ⇒ Array<String>
An array of the authorized products associated with the ‘access_token`.
98 |
# File 'lib/finch-api/models/introspection.rb', line 98 required :products, FinchAPI::ArrayOf[String] |
#provider_id ⇒ String
The ID of the provider associated with the ‘access_token`.
104 |
# File 'lib/finch-api/models/introspection.rb', line 104 required :provider_id, String |
#status=(value) ⇒ Symbol, FinchAPI::Models::ConnectionStatusType (writeonly)
2 3 4 |
# File 'lib/finch-api/models/introspection.rb', line 2 def status=(value) @status = value end |
#username ⇒ String
The account username used for login associated with the ‘access_token`.
110 |
# File 'lib/finch-api/models/introspection.rb', line 110 required :username, String |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/introspection.rb', line 2 def self.values; end |