Class: FinchAPI::Models::Introspection::AuthenticationMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/introspection.rb

Defined Under Namespace

Modules: Type Classes: ConnectionStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(message: nil, status: nil) ⇒ Object

Parameters:



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/finch_api/models/introspection.rb', line 163

class AuthenticationMethod < FinchAPI::Internal::Type::BaseModel
  # @!attribute connection_status
  #
  #   @return [FinchAPI::Introspection::AuthenticationMethod::ConnectionStatus, nil]
  optional :connection_status, -> { FinchAPI::Introspection::AuthenticationMethod::ConnectionStatus }

  # @!attribute products
  #   An array of the authorized products associated with the `access_token`.
  #
  #   @return [Array<String>, nil]
  optional :products, FinchAPI::Internal::Type::ArrayOf[String]

  # @!attribute type
  #   The type of authentication method.
  #
  #   @return [Symbol, FinchAPI::Introspection::AuthenticationMethod::Type, nil]
  optional :type, enum: -> { FinchAPI::Introspection::AuthenticationMethod::Type }

  # @!method initialize(connection_status: nil, products: nil, type: nil)
  #   @param connection_status [FinchAPI::Introspection::AuthenticationMethod::ConnectionStatus]
  #
  #   @param products [Array<String>] An array of the authorized products associated with the `access_token`.
  #
  #   @param type [Symbol, FinchAPI::Introspection::AuthenticationMethod::Type] The type of authentication method.

  # @see FinchAPI::Introspection::AuthenticationMethod#connection_status
  class ConnectionStatus < FinchAPI::Internal::Type::BaseModel
    # @!attribute message
    #
    #   @return [String, nil]
    optional :message, String

    # @!attribute status
    #
    #   @return [Symbol, FinchAPI::ConnectionStatusType, nil]
    optional :status, enum: -> { FinchAPI::ConnectionStatusType }

    # @!method initialize(message: nil, status: nil)
    #   @param message [String]
    #   @param status [Symbol, FinchAPI::ConnectionStatusType]
  end

  # The type of authentication method.
  #
  # @see FinchAPI::Introspection::AuthenticationMethod#type
  module Type
    extend FinchAPI::Internal::Type::Enum

    ASSISTED = :assisted
    CREDENTIAL = :credential
    API_TOKEN = :api_token
    API_CREDENTIAL = :api_credential
    OAUTH = :oauth

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#connection_statusFinchAPI::Introspection::AuthenticationMethod::ConnectionStatus?

Returns:

  • (FinchAPI::Introspection::AuthenticationMethod::ConnectionStatus, nil)


167
# File 'lib/finch_api/models/introspection.rb', line 167

optional :connection_status, -> { FinchAPI::Introspection::AuthenticationMethod::ConnectionStatus }

#productsArray<String>?

An array of the authorized products associated with the ‘access_token`.

Returns:

  • (Array<String>, nil)


173
# File 'lib/finch_api/models/introspection.rb', line 173

optional :products, FinchAPI::Internal::Type::ArrayOf[String]

#typeSymbol, ...

The type of authentication method.

Returns:

  • (Symbol, FinchAPI::Introspection::AuthenticationMethod::Type, nil)


179
# File 'lib/finch_api/models/introspection.rb', line 179

optional :type, enum: -> { FinchAPI::Introspection::AuthenticationMethod::Type }