Class: FinchAPI::Models::Introspection::AuthenticationMethod
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Introspection::AuthenticationMethod
- Defined in:
- lib/finch_api/models/introspection.rb
Defined Under Namespace
Modules: Type Classes: ConnectionStatus
Instance Attribute Summary collapse
- #connection_status ⇒ FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus?
-
#products ⇒ Array<String>?
An array of the authorized products associated with the ‘access_token`.
-
#type ⇒ Symbol, FinchAPI::Models::Introspection::AuthenticationMethod::Type
The type of authentication method.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type: , connection_status: nil, products: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/introspection.rb', line 262
|
Instance Attribute Details
#connection_status ⇒ FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus?
254 |
# File 'lib/finch_api/models/introspection.rb', line 254 optional :connection_status, -> { FinchAPI::Introspection::AuthenticationMethod::ConnectionStatus } |
#products ⇒ Array<String>?
An array of the authorized products associated with the ‘access_token`
260 |
# File 'lib/finch_api/models/introspection.rb', line 260 optional :products, FinchAPI::Internal::Type::ArrayOf[String] |
#type ⇒ Symbol, FinchAPI::Models::Introspection::AuthenticationMethod::Type
The type of authentication method
249 |
# File 'lib/finch_api/models/introspection.rb', line 249 required :type, enum: -> { FinchAPI::Introspection::AuthenticationMethod::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/introspection.rb', line 281
|