Class: FinchAPI::Models::Introspection::AuthenticationMethod
- Defined in:
- lib/finch-api/models/introspection.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Defined Under Namespace
Modules: Type Classes: ConnectionStatus
Instance Attribute Summary collapse
- #connection_status ⇒ FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus?
-
#products ⇒ Array<String>?
An array of the authorized products associated with the ‘access_token`.
- #status ⇒ Symbol, FinchAPI::Models::ConnectionStatusType writeonly
-
#type ⇒ Symbol, ...
The type of authentication method.
Instance Method Summary collapse
-
#initialize(message: nil, status: nil) ⇒ AuthenticationMethod
constructor
A new instance of AuthenticationMethod.
Constructor Details
#initialize(message: nil, status: nil) ⇒ AuthenticationMethod
Returns a new instance of AuthenticationMethod.
5 |
# File 'lib/finch-api/models/introspection.rb', line 5 def initialize(connection_status: nil, products: nil, type: nil, **) = super |
Instance Attribute Details
#connection_status ⇒ FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus?
158 159 |
# File 'lib/finch-api/models/introspection.rb', line 158 optional :connection_status, -> { FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus } |
#products ⇒ Array<String>?
An array of the authorized products associated with the ‘access_token`.
169 |
# File 'lib/finch-api/models/introspection.rb', line 169 optional :products, FinchAPI::ArrayOf[String] |
#status=(value) ⇒ Symbol, FinchAPI::Models::ConnectionStatusType (writeonly)
2 3 4 |
# File 'lib/finch-api/models/introspection.rb', line 2 def status=(value) @status = value end |
#type ⇒ Symbol, ...
The type of authentication method.
179 |
# File 'lib/finch-api/models/introspection.rb', line 179 optional :type, enum: -> { FinchAPI::Models::Introspection::AuthenticationMethod::Type } |