Class: FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Introspection::AuthenticationMethod::ConnectionStatus
- Defined in:
- lib/finch_api/models/introspection.rb
Overview
Defined Under Namespace
Modules: LastSuccessfulSync
Instance Attribute Summary collapse
-
#last_successful_sync ⇒ Time, ...
The datetime when the connection was last successfully synced.
- #message ⇒ String?
- #status ⇒ Symbol, FinchAPI::Models::ConnectionStatusType
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(status: , last_successful_sync: nil, message: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/introspection.rb', line 307
|
Instance Attribute Details
#last_successful_sync ⇒ Time, ...
The datetime when the connection was last successfully synced
296 297 298 299 300 |
# File 'lib/finch_api/models/introspection.rb', line 296 optional :last_successful_sync, union: -> { FinchAPI::Introspection::AuthenticationMethod::ConnectionStatus::LastSuccessfulSync }, nil?: true |
#message ⇒ String?
305 |
# File 'lib/finch_api/models/introspection.rb', line 305 optional :message, String |
#status ⇒ Symbol, FinchAPI::Models::ConnectionStatusType
290 |
# File 'lib/finch_api/models/introspection.rb', line 290 required :status, enum: -> { FinchAPI::ConnectionStatusType } |