Class: FinchAPI::Models::JobCompletionEvent::Data
- Defined in:
- lib/finch-api/models/job_completion_event.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Instance Attribute Summary collapse
-
#job_id ⇒ String
The id of the job which has completed.
-
#job_url ⇒ String
The url to query the result of the job.
Instance Attribute Details
#job_id ⇒ String
The id of the job which has completed.
37 |
# File 'lib/finch-api/models/job_completion_event.rb', line 37 required :job_id, String |
#job_url ⇒ String
The url to query the result of the job.
43 |
# File 'lib/finch-api/models/job_completion_event.rb', line 43 required :job_url, String |