Class: FinchAPI::Models::Jobs::AutomatedAsyncJob
- Defined in:
- lib/finch-api/models/jobs/automated_async_job.rb
Defined Under Namespace
Modules: Status, Type Classes: Params
Instance Attribute Summary collapse
-
#completed_at ⇒ Time?
The datetime the job completed.
-
#created_at ⇒ Time
The datetime when the job was created.
- #individual_id ⇒ String writeonly
-
#job_id ⇒ String
The id of the job that has been created.
-
#job_url ⇒ String
The url that can be used to retrieve the job status.
-
#params ⇒ FinchAPI::Models::Jobs::AutomatedAsyncJob::Params?
The input parameters for the job.
-
#scheduled_at ⇒ Time?
The datetime a job is scheduled to be run.
-
#started_at ⇒ Time?
The datetime a job entered into the job queue.
- #status ⇒ Symbol, FinchAPI::Models::Jobs::AutomatedAsyncJob::Status
-
#type ⇒ Symbol, FinchAPI::Models::Jobs::AutomatedAsyncJob::Type
The type of automated job.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(individual_id: nil) ⇒ AutomatedAsyncJob
constructor
The input parameters for the job.
Constructor Details
#initialize(individual_id: nil) ⇒ AutomatedAsyncJob
The input parameters for the job.
11 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 11 def initialize(completed_at:, created_at:, job_id:, job_url:, params:, scheduled_at:, started_at:, status:, type:, **) = super |
Instance Attribute Details
#completed_at ⇒ Time?
The datetime the job completed.
11 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 11 required :completed_at, Time, nil?: true |
#created_at ⇒ Time
The datetime when the job was created. for scheduled jobs, this will be the
initial connection time. For ad-hoc jobs, this will be the time the creation
request was received.
19 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 19 required :created_at, Time |
#individual_id=(value) ⇒ String (writeonly)
2 3 4 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 2 def individual_id=(value) @individual_id = value end |
#job_id ⇒ String
The id of the job that has been created.
25 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 25 required :job_id, String |
#job_url ⇒ String
The url that can be used to retrieve the job status
31 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 31 required :job_url, String |
#params ⇒ FinchAPI::Models::Jobs::AutomatedAsyncJob::Params?
The input parameters for the job.
37 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 37 required :params, -> { FinchAPI::Models::Jobs::AutomatedAsyncJob::Params }, nil?: true |
#scheduled_at ⇒ Time?
The datetime a job is scheduled to be run. For scheduled jobs, this datetime can
be in the future if the job has not yet been enqueued. For ad-hoc jobs, this
field will be null.
45 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 45 required :scheduled_at, Time, nil?: true |
#started_at ⇒ Time?
The datetime a job entered into the job queue.
51 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 51 required :started_at, Time, nil?: true |
#status ⇒ Symbol, FinchAPI::Models::Jobs::AutomatedAsyncJob::Status
56 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 56 required :status, enum: -> { FinchAPI::Models::Jobs::AutomatedAsyncJob::Status } |
#type ⇒ Symbol, FinchAPI::Models::Jobs::AutomatedAsyncJob::Type
The type of automated job
62 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 62 required :type, enum: -> { FinchAPI::Models::Jobs::AutomatedAsyncJob::Type } |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/jobs/automated_async_job.rb', line 2 def self.values; end |