Class: FinchAPI::Models::Jobs::AutomatedAsyncJob
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Jobs::AutomatedAsyncJob
- Defined in:
- lib/finch_api/models/jobs/automated_async_job.rb
Overview
Defined Under Namespace
Modules: Status, Type Classes: Params
Instance Attribute Summary collapse
-
#completed_at ⇒ Time?
The datetime the job completed.
-
#created_at ⇒ Time
The datetime when the job was created.
-
#job_id ⇒ String
The id of the job that has been created.
-
#job_url ⇒ String
The url that can be used to retrieve the job status.
-
#params ⇒ FinchAPI::Models::Jobs::AutomatedAsyncJob::Params?
The input parameters for the job.
-
#scheduled_at ⇒ Time?
The datetime a job is scheduled to be run.
-
#started_at ⇒ Time?
The datetime a job entered into the job queue.
- #status ⇒ Symbol, FinchAPI::Models::Jobs::AutomatedAsyncJob::Status
-
#type ⇒ Symbol, FinchAPI::Models::Jobs::AutomatedAsyncJob::Type
The type of automated job.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(individual_id: nil) ⇒ Object
constructor
The input parameters for the job.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(individual_id: nil) ⇒ Object
The input parameters for the job.
|
|
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 65
|
Instance Attribute Details
#completed_at ⇒ Time?
The datetime the job completed.
12 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 12 required :completed_at, Time, nil?: true |
#created_at ⇒ Time
The datetime when the job was created. for scheduled jobs, this will be the initial connection time. For ad-hoc jobs, this will be the time the creation request was received.
20 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 20 required :created_at, Time |
#job_id ⇒ String
The id of the job that has been created.
26 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 26 required :job_id, String |
#job_url ⇒ String
The url that can be used to retrieve the job status
32 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 32 required :job_url, String |
#params ⇒ FinchAPI::Models::Jobs::AutomatedAsyncJob::Params?
The input parameters for the job.
38 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 38 required :params, -> { FinchAPI::Jobs::AutomatedAsyncJob::Params }, nil?: true |
#scheduled_at ⇒ Time?
The datetime a job is scheduled to be run. For scheduled jobs, this datetime can be in the future if the job has not yet been enqueued. For ad-hoc jobs, this field will be null.
46 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 46 required :scheduled_at, Time, nil?: true |
#started_at ⇒ Time?
The datetime a job entered into the job queue.
52 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 52 required :started_at, Time, nil?: true |
#status ⇒ Symbol, FinchAPI::Models::Jobs::AutomatedAsyncJob::Status
57 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 57 required :status, enum: -> { FinchAPI::Jobs::AutomatedAsyncJob::Status } |
#type ⇒ Symbol, FinchAPI::Models::Jobs::AutomatedAsyncJob::Type
The type of automated job
63 |
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 63 required :type, enum: -> { FinchAPI::Jobs::AutomatedAsyncJob::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/jobs/automated_async_job.rb', line 112
|