Class: FinchAPI::Models::Jobs::AutomatedCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/jobs/automated_create_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed_refreshes: , remaining_refreshes: , job_id: nil, job_url: nil, retry_at: nil) ⇒ Object

Parameters:

  • allowed_refreshes (Integer) (defaults to: )

    The number of allowed refreshes per hour (per hour, fixed window)

  • remaining_refreshes (Integer) (defaults to: )

    The number of remaining refreshes available (per hour, fixed window)

  • job_id (String) (defaults to: nil)

    The id of the job that has been created.

  • job_url (String) (defaults to: nil)

    The url that can be used to retrieve the job status

  • retry_at (String) (defaults to: nil)

    ISO 8601 timestamp indicating when to retry the request



# File 'lib/finch_api/models/jobs/automated_create_response.rb', line 38

Instance Attribute Details

#allowed_refreshesInteger

The number of allowed refreshes per hour (per hour, fixed window)

Returns:

  • (Integer)


12
# File 'lib/finch_api/models/jobs/automated_create_response.rb', line 12

required :allowed_refreshes, Integer

#job_idString?

The id of the job that has been created.

Returns:

  • (String, nil)


24
# File 'lib/finch_api/models/jobs/automated_create_response.rb', line 24

optional :job_id, String

#job_urlString?

The url that can be used to retrieve the job status

Returns:

  • (String, nil)


30
# File 'lib/finch_api/models/jobs/automated_create_response.rb', line 30

optional :job_url, String

#remaining_refreshesInteger

The number of remaining refreshes available (per hour, fixed window)

Returns:

  • (Integer)


18
# File 'lib/finch_api/models/jobs/automated_create_response.rb', line 18

required :remaining_refreshes, Integer

#retry_atString?

ISO 8601 timestamp indicating when to retry the request

Returns:

  • (String, nil)


36
# File 'lib/finch_api/models/jobs/automated_create_response.rb', line 36

optional :retry_at, String