Class: FinchAPI::Models::Jobs::ManualAsyncJob

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/jobs/manual_async_job.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(body: , job_id: , status: ) ⇒ Object

Parameters:

  • body (Array<Object>, nil) (defaults to: )

    Specific information about the job, such as individual statuses for batch jobs.

  • job_id (String) (defaults to: )
  • status (Symbol, FinchAPI::Jobs::ManualAsyncJob::Status) (defaults to: )


# File 'lib/finch_api/models/jobs/manual_async_job.rb', line 24

Instance Attribute Details

#bodyArray<Object>?

Specific information about the job, such as individual statuses for batch jobs.

Returns:

  • (Array<Object>, nil)


12
# File 'lib/finch_api/models/jobs/manual_async_job.rb', line 12

required :body, FinchAPI::Internal::Type::ArrayOf[FinchAPI::Internal::Type::Unknown], nil?: true

#job_idString

Returns:

  • (String)


17
# File 'lib/finch_api/models/jobs/manual_async_job.rb', line 17

required :job_id, String

#statusSymbol, FinchAPI::Jobs::ManualAsyncJob::Status

Returns:

  • (Symbol, FinchAPI::Jobs::ManualAsyncJob::Status)


22
# File 'lib/finch_api/models/jobs/manual_async_job.rb', line 22

required :status, enum: -> { FinchAPI::Jobs::ManualAsyncJob::Status }