Class: FinchAPI::Models::Jobs::ManualAsyncJob
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Jobs::ManualAsyncJob
- Defined in:
- lib/finch_api/models/jobs/manual_async_job.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#body ⇒ Array<Object, nil>?
Specific information about the job, such as individual statuses for batch jobs.
- #job_id ⇒ String
- #status ⇒ Symbol, FinchAPI::Models::Jobs::ManualAsyncJob::Status
Instance Method Summary collapse
- #initialize(body: , job_id: , status: ) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body: , job_id: , status: ) ⇒ Object
|
|
# File 'lib/finch_api/models/jobs/manual_async_job.rb', line 26
|
Instance Attribute Details
#body ⇒ Array<Object, nil>?
Specific information about the job, such as individual statuses for batch jobs.
12 13 14 |
# File 'lib/finch_api/models/jobs/manual_async_job.rb', line 12 required :body, FinchAPI::Internal::Type::ArrayOf[FinchAPI::Internal::Type::Unknown, nil?: true], nil?: true |
#job_id ⇒ String
19 |
# File 'lib/finch_api/models/jobs/manual_async_job.rb', line 19 required :job_id, String |
#status ⇒ Symbol, FinchAPI::Models::Jobs::ManualAsyncJob::Status
24 |
# File 'lib/finch_api/models/jobs/manual_async_job.rb', line 24 required :status, enum: -> { FinchAPI::Jobs::ManualAsyncJob::Status } |