Module: FinchAPI::Models::OperationSupport
- Extended by:
- Type::Enum
- Defined in:
- lib/finch-api/models/operation_support.rb
Overview
-
‘supported`: This operation is supported by both the provider and Finch
-
‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider
-
‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support
-
‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch
-
Constant Summary collapse
- SUPPORTED =
:supported- NOT_SUPPORTED_BY_FINCH =
:not_supported_by_finch- NOT_SUPPORTED_BY_PROVIDER =
:not_supported_by_provider- CLIENT_ACCESS_ONLY =
:client_access_only
Class Method Summary collapse
Methods included from Type::Enum
Methods included from Type::Converter
#coerce, coerce, #dump, dump, type_info
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/operation_support.rb', line 2 def self.values; end |