Class: FinchAPI::Models::OperationSupportMatrix

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/operation_support_matrix.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(create: nil, delete: nil, read: nil, update: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::OperationSupportMatrix for more details.

Parameters:



# File 'lib/finch_api/models/operation_support_matrix.rb', line 54

Instance Attribute Details

#createSymbol, ...

  • ‘supported`: This operation is supported by both the provider and Finch

  • ‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider

  • ‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support

  • ‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch

Returns:



16
# File 'lib/finch_api/models/operation_support_matrix.rb', line 16

optional :create, enum: -> { FinchAPI::OperationSupport }

#deleteSymbol, ...

  • ‘supported`: This operation is supported by both the provider and Finch

  • ‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider

  • ‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support

  • ‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch

Returns:



28
# File 'lib/finch_api/models/operation_support_matrix.rb', line 28

optional :delete, enum: -> { FinchAPI::OperationSupport }

#readSymbol, ...

  • ‘supported`: This operation is supported by both the provider and Finch

  • ‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider

  • ‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support

  • ‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch

Returns:



40
# File 'lib/finch_api/models/operation_support_matrix.rb', line 40

optional :read, enum: -> { FinchAPI::OperationSupport }

#updateSymbol, ...

  • ‘supported`: This operation is supported by both the provider and Finch

  • ‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider

  • ‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support

  • ‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch

Returns:



52
# File 'lib/finch_api/models/operation_support_matrix.rb', line 52

optional :update, enum: -> { FinchAPI::OperationSupport }