Class: FinchAPI::Models::OperationSupportMatrix

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/operation_support_matrix.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(create: nil, delete: nil, read: nil, update: nil) ⇒ OperationSupportMatrix

Returns a new instance of OperationSupportMatrix.

Parameters:



6
# File 'lib/finch-api/models/operation_support_matrix.rb', line 6

def initialize(create: nil, delete: nil, read: nil, update: nil, **) = super

Instance Attribute Details

#createSymbol, ...

  • ‘supported`: This operation is supported by both the provider and Finch

    • ‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider

    • ‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support

    • ‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch

Returns:



16
# File 'lib/finch-api/models/operation_support_matrix.rb', line 16

optional :create, enum: -> { FinchAPI::Models::OperationSupport }

#deleteSymbol, ...

  • ‘supported`: This operation is supported by both the provider and Finch

    • ‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider

    • ‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support

    • ‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch

Returns:



32
# File 'lib/finch-api/models/operation_support_matrix.rb', line 32

optional :delete, enum: -> { FinchAPI::Models::OperationSupport }

#readSymbol, ...

  • ‘supported`: This operation is supported by both the provider and Finch

    • ‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider

    • ‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support

    • ‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch

Returns:



48
# File 'lib/finch-api/models/operation_support_matrix.rb', line 48

optional :read, enum: -> { FinchAPI::Models::OperationSupport }

#updateSymbol, ...

  • ‘supported`: This operation is supported by both the provider and Finch

    • ‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider

    • ‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support

    • ‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch

Returns:



64
# File 'lib/finch-api/models/operation_support_matrix.rb', line 64

optional :update, enum: -> { FinchAPI::Models::OperationSupport }