Class: FinchAPI::Models::OperationSupportMatrix
- Defined in:
- lib/finch-api/models/operation_support_matrix.rb
Instance Attribute Summary collapse
-
#create ⇒ Symbol, ...
-
‘supported`: This operation is supported by both the provider and Finch - `not_supported_by_finch`: This operation is not supported by Finch but supported by the provider - `not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support - `client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch.
-
-
#delete ⇒ Symbol, ...
-
‘supported`: This operation is supported by both the provider and Finch - `not_supported_by_finch`: This operation is not supported by Finch but supported by the provider - `not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support - `client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch.
-
-
#read ⇒ Symbol, ...
-
‘supported`: This operation is supported by both the provider and Finch - `not_supported_by_finch`: This operation is not supported by Finch but supported by the provider - `not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support - `client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch.
-
-
#update ⇒ Symbol, ...
-
‘supported`: This operation is supported by both the provider and Finch - `not_supported_by_finch`: This operation is not supported by Finch but supported by the provider - `not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support - `client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch.
-
Instance Method Summary collapse
-
#initialize(create: nil, delete: nil, read: nil, update: nil) ⇒ OperationSupportMatrix
constructor
A new instance of OperationSupportMatrix.
Constructor Details
#initialize(create: nil, delete: nil, read: nil, update: nil) ⇒ OperationSupportMatrix
Returns a new instance of OperationSupportMatrix.
6 |
# File 'lib/finch-api/models/operation_support_matrix.rb', line 6 def initialize(create: nil, delete: nil, read: nil, update: nil, **) = super |
Instance Attribute Details
#create ⇒ Symbol, ...
-
‘supported`: This operation is supported by both the provider and Finch
-
‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider
-
‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support
-
‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch
-
16 |
# File 'lib/finch-api/models/operation_support_matrix.rb', line 16 optional :create, enum: -> { FinchAPI::Models::OperationSupport } |
#delete ⇒ Symbol, ...
-
‘supported`: This operation is supported by both the provider and Finch
-
‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider
-
‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support
-
‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch
-
32 |
# File 'lib/finch-api/models/operation_support_matrix.rb', line 32 optional :delete, enum: -> { FinchAPI::Models::OperationSupport } |
#read ⇒ Symbol, ...
-
‘supported`: This operation is supported by both the provider and Finch
-
‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider
-
‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support
-
‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch
-
48 |
# File 'lib/finch-api/models/operation_support_matrix.rb', line 48 optional :read, enum: -> { FinchAPI::Models::OperationSupport } |
#update ⇒ Symbol, ...
-
‘supported`: This operation is supported by both the provider and Finch
-
‘not_supported_by_finch`: This operation is not supported by Finch but supported by the provider
-
‘not_supported_by_provider`: This operation is not supported by the provider, so Finch cannot support
-
‘client_access_only`: This behavior is supported by the provider, but only available to the client and not to Finch
-
64 |
# File 'lib/finch-api/models/operation_support_matrix.rb', line 64 optional :update, enum: -> { FinchAPI::Models::OperationSupport } |