Class: FinchAPI::Models::Paging
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Paging
- Defined in:
- lib/finch_api/models/paging.rb
Instance Attribute Summary collapse
-
#count ⇒ Integer?
The total number of elements for the entire query (not just the given page).
-
#offset ⇒ Integer
The current start index of the returned list of elements.
Instance Method Summary collapse
- #initialize(offset: , count: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(offset: , count: nil) ⇒ Object
|
|
# File 'lib/finch_api/models/paging.rb', line 18
|
Instance Attribute Details
#count ⇒ Integer?
The total number of elements for the entire query (not just the given page)
16 |
# File 'lib/finch_api/models/paging.rb', line 16 optional :count, Integer |
#offset ⇒ Integer
The current start index of the returned list of elements
10 |
# File 'lib/finch_api/models/paging.rb', line 10 required :offset, Integer |