Class: FinchAPI::Models::Paging
- Defined in:
- lib/finch-api/models/paging.rb
Instance Attribute Summary collapse
-
#count ⇒ Integer?
The total number of elements for the entire query (not just the given page).
-
#offset ⇒ Integer?
The current start index of the returned list of elements.
Instance Method Summary collapse
-
#initialize(count: nil, offset: nil) ⇒ Paging
constructor
A new instance of Paging.
Constructor Details
#initialize(count: nil, offset: nil) ⇒ Paging
Returns a new instance of Paging.
4 |
# File 'lib/finch-api/models/paging.rb', line 4 def initialize(count: nil, offset: nil, **) = super |
Instance Attribute Details
#count ⇒ Integer?
The total number of elements for the entire query (not just the given page)
10 |
# File 'lib/finch-api/models/paging.rb', line 10 optional :count, Integer |
#offset ⇒ Integer?
The current start index of the returned list of elements
20 |
# File 'lib/finch-api/models/paging.rb', line 20 optional :offset, Integer |