Class: FinchAPI::Models::PayStatementEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/pay_statement_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(data: nil, event_type: nil) ⇒ Object

Parameters:



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
# File 'lib/finch_api/models/pay_statement_event.rb', line 20

class Data < FinchAPI::Internal::Type::BaseModel
  # @!attribute individual_id
  #   The ID of the individual associated with the pay statement.
  #
  #   @return [String, nil]
  optional :individual_id, String

  # @!attribute payment_id
  #   The ID of the payment associated with the pay statement.
  #
  #   @return [String, nil]
  optional :payment_id, String

  # @!method initialize(individual_id: nil, payment_id: nil)
  #   @param individual_id [String] The ID of the individual associated with the pay statement.
  #
  #   @param payment_id [String] The ID of the payment associated with the pay statement.
end

Instance Attribute Details

#individual_idString?

The ID of the individual associated with the pay statement.

Returns:

  • (String, nil)


25
# File 'lib/finch_api/models/pay_statement_event.rb', line 25

optional :individual_id, String

#payment_idString?

The ID of the payment associated with the pay statement.

Returns:

  • (String, nil)


31
# File 'lib/finch_api/models/pay_statement_event.rb', line 31

optional :payment_id, String