Class: FinchAPI::Models::PayStatementEvent::Data
- Defined in:
- lib/finch-api/models/pay_statement_event.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Instance Attribute Summary collapse
-
#individual_id ⇒ String?
The ID of the individual associated with the pay statement.
-
#payment_id ⇒ String?
readonly
The ID of the payment associated with the pay statement.
Instance Attribute Details
#individual_id ⇒ String?
The ID of the individual associated with the pay statement.
37 |
# File 'lib/finch-api/models/pay_statement_event.rb', line 37 optional :individual_id, String |
#payment_id ⇒ String? (readonly)
The ID of the payment associated with the pay statement.
47 |
# File 'lib/finch-api/models/pay_statement_event.rb', line 47 optional :payment_id, String |