Class: FinchAPI::Models::Payroll::PayGroupListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Payroll::PayGroupListResponse
- Defined in:
- lib/finch_api/models/payroll/pay_group_list_response.rb
Overview
Defined Under Namespace
Modules: PayFrequency
Instance Attribute Summary collapse
-
#id ⇒ String?
Finch id (uuidv4) for the pay group.
-
#name ⇒ String?
Name of the pay group.
-
#pay_frequencies ⇒ Array<Symbol, FinchAPI::Models::Payroll::PayGroupListResponse::PayFrequency>?
List of pay frequencies associated with this pay group.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#id ⇒ String?
Finch id (uuidv4) for the pay group
12 |
# File 'lib/finch_api/models/payroll/pay_group_list_response.rb', line 12 optional :id, String |
#name ⇒ String?
Name of the pay group
18 |
# File 'lib/finch_api/models/payroll/pay_group_list_response.rb', line 18 optional :name, String |
#pay_frequencies ⇒ Array<Symbol, FinchAPI::Models::Payroll::PayGroupListResponse::PayFrequency>?
List of pay frequencies associated with this pay group
24 25 |
# File 'lib/finch_api/models/payroll/pay_group_list_response.rb', line 24 optional :pay_frequencies, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Models::Payroll::PayGroupListResponse::PayFrequency] } |