Class: FinchAPI::Models::Payroll::PayGroupRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Payroll::PayGroupRetrieveResponse
- Defined in:
- lib/finch_api/models/payroll/pay_group_retrieve_response.rb
Overview
Defined Under Namespace
Modules: PayFrequency
Instance Attribute Summary collapse
-
#id ⇒ String
Finch id (uuidv4) for the pay group.
- #individual_ids ⇒ Array<String>
-
#name ⇒ String
Name of the pay group.
-
#pay_frequencies ⇒ Array<Symbol, FinchAPI::Models::Payroll::PayGroupRetrieveResponse::PayFrequency>
List of pay frequencies associated with this pay group.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#id ⇒ String
Finch id (uuidv4) for the pay group
12 |
# File 'lib/finch_api/models/payroll/pay_group_retrieve_response.rb', line 12 required :id, String |
#individual_ids ⇒ Array<String>
17 |
# File 'lib/finch_api/models/payroll/pay_group_retrieve_response.rb', line 17 required :individual_ids, FinchAPI::Internal::Type::ArrayOf[String] |
#name ⇒ String
Name of the pay group
23 |
# File 'lib/finch_api/models/payroll/pay_group_retrieve_response.rb', line 23 required :name, String |
#pay_frequencies ⇒ Array<Symbol, FinchAPI::Models::Payroll::PayGroupRetrieveResponse::PayFrequency>
List of pay frequencies associated with this pay group
29 30 |
# File 'lib/finch_api/models/payroll/pay_group_retrieve_response.rb', line 29 required :pay_frequencies, -> { FinchAPI::Internal::Type::ArrayOf[enum: FinchAPI::Models::Payroll::PayGroupRetrieveResponse::PayFrequency] } |