Class: FinchAPI::Models::Provider

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/provider.rb

Defined Under Namespace

Classes: AuthenticationMethod

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, authentication_methods: nil, beta: nil, display_name: nil, icon: nil, logo: nil, manual: nil, mfa_required: nil, primary_color: nil, products: nil) ⇒ Provider

Returns a new instance of Provider.

Parameters:

  • id (String) (defaults to: nil)
  • authentication_methods (Array<FinchAPI::Models::Provider::AuthenticationMethod>) (defaults to: nil)
  • beta (Boolean) (defaults to: nil)
  • display_name (String) (defaults to: nil)
  • icon (String) (defaults to: nil)
  • logo (String) (defaults to: nil)
  • manual (Boolean) (defaults to: nil)
  • mfa_required (Boolean) (defaults to: nil)
  • primary_color (String) (defaults to: nil)
  • products (Array<String>) (defaults to: nil)


12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
# File 'lib/finch-api/models/provider.rb', line 12

def initialize(
  id: nil,
  authentication_methods: nil,
  beta: nil,
  display_name: nil,
  icon: nil,
  logo: nil,
  manual: nil,
  mfa_required: nil,
  primary_color: nil,
  products: nil,
  **
)
  super
end

Instance Attribute Details

#authentication_methodsArray<FinchAPI::Models::Provider::AuthenticationMethod>?

The list of authentication methods supported by the provider.



20
21
# File 'lib/finch-api/models/provider.rb', line 20

optional :authentication_methods,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Provider::AuthenticationMethod] }

#betaBoolean?

‘true` if the integration is in a beta state, `false` otherwise

Returns:

  • (Boolean, nil)


31
# File 'lib/finch-api/models/provider.rb', line 31

optional :beta, FinchAPI::BooleanModel

#display_nameString?

The display name of the payroll provider.

Returns:

  • (String, nil)


41
# File 'lib/finch-api/models/provider.rb', line 41

optional :display_name, String

#iconString?

The url to the official icon of the payroll provider.

Returns:

  • (String, nil)


51
# File 'lib/finch-api/models/provider.rb', line 51

optional :icon, String

#idString?

The id of the payroll provider used in Connect.

Returns:

  • (String, nil)


10
# File 'lib/finch-api/models/provider.rb', line 10

optional :id, String

#logoString?

The url to the official logo of the payroll provider.

Returns:

  • (String, nil)


61
# File 'lib/finch-api/models/provider.rb', line 61

optional :logo, String

#manualBoolean?

DEPRECATED

Whether the Finch integration with this provider uses the Assisted

Connect Flow by default. This field is now deprecated. Please check for a `type`
of `assisted` in the `authentication_methods` field instead.

Returns:

  • (Boolean, nil)


73
# File 'lib/finch-api/models/provider.rb', line 73

optional :manual, FinchAPI::BooleanModel

#mfa_requiredBoolean?

whether MFA is required for the provider.

Returns:

  • (Boolean, nil)


83
# File 'lib/finch-api/models/provider.rb', line 83

optional :mfa_required, FinchAPI::BooleanModel

#primary_colorString?

The hex code for the primary color of the payroll provider.

Returns:

  • (String, nil)


93
# File 'lib/finch-api/models/provider.rb', line 93

optional :primary_color, String

#productsArray<String>?

The list of Finch products supported on this payroll provider.

Returns:

  • (Array<String>, nil)


103
# File 'lib/finch-api/models/provider.rb', line 103

optional :products, FinchAPI::ArrayOf[String]