Class: FinchAPI::Models::Provider

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/provider.rb

Overview

Defined Under Namespace

Classes: AuthenticationMethod

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

This class inherits a constructor from FinchAPI::Internal::Type::BaseModel

Instance Attribute Details

#authentication_methodsArray<FinchAPI::Provider::AuthenticationMethod>?

The list of authentication methods supported by the provider.



17
18
# File 'lib/finch_api/models/provider.rb', line 17

optional :authentication_methods,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Provider::AuthenticationMethod] }

#betaBoolean?

‘true` if the integration is in a beta state, `false` otherwise

Returns:

  • (Boolean, nil)


24
# File 'lib/finch_api/models/provider.rb', line 24

optional :beta, FinchAPI::Internal::Type::Boolean

#display_nameString?

The display name of the payroll provider.

Returns:

  • (String, nil)


30
# File 'lib/finch_api/models/provider.rb', line 30

optional :display_name, String

#iconString?

The url to the official icon of the payroll provider.

Returns:

  • (String, nil)


36
# File 'lib/finch_api/models/provider.rb', line 36

optional :icon, String

#idString?

The id of the payroll provider used in Connect.

Returns:

  • (String, nil)


11
# File 'lib/finch_api/models/provider.rb', line 11

optional :id, String

#logoString?

The url to the official logo of the payroll provider.

Returns:

  • (String, nil)


42
# File 'lib/finch_api/models/provider.rb', line 42

optional :logo, String

#manualBoolean?

DEPRECATED

Whether the Finch integration with this provider uses the Assisted

Connect Flow by default. This field is now deprecated. Please check for a ‘type` of `assisted` in the `authentication_methods` field instead.

Returns:

  • (Boolean, nil)


50
# File 'lib/finch_api/models/provider.rb', line 50

optional :manual, FinchAPI::Internal::Type::Boolean

#mfa_requiredBoolean?

whether MFA is required for the provider.

Returns:

  • (Boolean, nil)


56
# File 'lib/finch_api/models/provider.rb', line 56

optional :mfa_required, FinchAPI::Internal::Type::Boolean

#primary_colorString?

The hex code for the primary color of the payroll provider.

Returns:

  • (String, nil)


62
# File 'lib/finch_api/models/provider.rb', line 62

optional :primary_color, String

#productsArray<String>?

The list of Finch products supported on this payroll provider.

Returns:

  • (Array<String>, nil)


68
# File 'lib/finch_api/models/provider.rb', line 68

optional :products, FinchAPI::Internal::Type::ArrayOf[String]