Class: FinchAPI::Models::Provider
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Provider
- Defined in:
- lib/finch_api/models/provider.rb
Overview
Defined Under Namespace
Classes: AuthenticationMethod
Instance Attribute Summary collapse
-
#authentication_methods ⇒ Array<FinchAPI::Models::Provider::AuthenticationMethod>?
The list of authentication methods supported by the provider.
-
#beta ⇒ Boolean?
‘true` if the integration is in a beta state, `false` otherwise.
-
#display_name ⇒ String?
The display name of the payroll provider.
-
#icon ⇒ String?
The url to the official icon of the payroll provider.
-
#id ⇒ String?
The id of the payroll provider used in Connect.
-
#logo ⇒ String?
The url to the official logo of the payroll provider.
-
#manual ⇒ Boolean?
- DEPRECATED
-
Whether the Finch integration with this provider uses the Assisted Connect Flow by default.
-
#mfa_required ⇒ Boolean?
whether MFA is required for the provider.
-
#primary_color ⇒ String?
The hex code for the primary color of the payroll provider.
-
#products ⇒ Array<String>?
The list of Finch products supported on this payroll provider.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#authentication_methods ⇒ Array<FinchAPI::Models::Provider::AuthenticationMethod>?
The list of authentication methods supported by the provider.
17 18 |
# File 'lib/finch_api/models/provider.rb', line 17 optional :authentication_methods, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Provider::AuthenticationMethod] } |
#beta ⇒ Boolean?
‘true` if the integration is in a beta state, `false` otherwise
24 |
# File 'lib/finch_api/models/provider.rb', line 24 optional :beta, FinchAPI::Internal::Type::Boolean |
#display_name ⇒ String?
The display name of the payroll provider.
30 |
# File 'lib/finch_api/models/provider.rb', line 30 optional :display_name, String |
#icon ⇒ String?
The url to the official icon of the payroll provider.
36 |
# File 'lib/finch_api/models/provider.rb', line 36 optional :icon, String |
#id ⇒ String?
The id of the payroll provider used in Connect.
11 |
# File 'lib/finch_api/models/provider.rb', line 11 optional :id, String |
#logo ⇒ String?
The url to the official logo of the payroll provider.
42 |
# File 'lib/finch_api/models/provider.rb', line 42 optional :logo, String |
#manual ⇒ Boolean?
- DEPRECATED
-
Whether the Finch integration with this provider uses the Assisted
Connect Flow by default. This field is now deprecated. Please check for a ‘type` of `assisted` in the `authentication_methods` field instead.
50 |
# File 'lib/finch_api/models/provider.rb', line 50 optional :manual, FinchAPI::Internal::Type::Boolean |
#mfa_required ⇒ Boolean?
whether MFA is required for the provider.
56 |
# File 'lib/finch_api/models/provider.rb', line 56 optional :mfa_required, FinchAPI::Internal::Type::Boolean |
#primary_color ⇒ String?
The hex code for the primary color of the payroll provider.
62 |
# File 'lib/finch_api/models/provider.rb', line 62 optional :primary_color, String |