Class: FinchAPI::Models::Provider
- Defined in:
- lib/finch-api/models/provider.rb
Defined Under Namespace
Classes: AuthenticationMethod
Instance Attribute Summary collapse
-
#authentication_methods ⇒ Array<FinchAPI::Models::Provider::AuthenticationMethod>?
The list of authentication methods supported by the provider.
-
#beta ⇒ Boolean?
‘true` if the integration is in a beta state, `false` otherwise.
-
#display_name ⇒ String?
The display name of the payroll provider.
-
#icon ⇒ String?
The url to the official icon of the payroll provider.
-
#id ⇒ String?
The id of the payroll provider used in Connect.
-
#logo ⇒ String?
The url to the official logo of the payroll provider.
-
#manual ⇒ Boolean?
- DEPRECATED
-
Whether the Finch integration with this provider uses the Assisted Connect Flow by default.
-
#mfa_required ⇒ Boolean?
whether MFA is required for the provider.
-
#primary_color ⇒ String?
The hex code for the primary color of the payroll provider.
-
#products ⇒ Array<String>?
The list of Finch products supported on this payroll provider.
Instance Method Summary collapse
-
#initialize(id: nil, authentication_methods: nil, beta: nil, display_name: nil, icon: nil, logo: nil, manual: nil, mfa_required: nil, primary_color: nil, products: nil) ⇒ Provider
constructor
A new instance of Provider.
Constructor Details
#initialize(id: nil, authentication_methods: nil, beta: nil, display_name: nil, icon: nil, logo: nil, manual: nil, mfa_required: nil, primary_color: nil, products: nil) ⇒ Provider
Returns a new instance of Provider.
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 |
# File 'lib/finch-api/models/provider.rb', line 12 def initialize( id: nil, authentication_methods: nil, beta: nil, display_name: nil, icon: nil, logo: nil, manual: nil, mfa_required: nil, primary_color: nil, products: nil, ** ) super end |
Instance Attribute Details
#authentication_methods ⇒ Array<FinchAPI::Models::Provider::AuthenticationMethod>?
The list of authentication methods supported by the provider.
20 21 |
# File 'lib/finch-api/models/provider.rb', line 20 optional :authentication_methods, -> { FinchAPI::ArrayOf[FinchAPI::Models::Provider::AuthenticationMethod] } |
#beta ⇒ Boolean?
‘true` if the integration is in a beta state, `false` otherwise
31 |
# File 'lib/finch-api/models/provider.rb', line 31 optional :beta, FinchAPI::BooleanModel |
#display_name ⇒ String?
The display name of the payroll provider.
41 |
# File 'lib/finch-api/models/provider.rb', line 41 optional :display_name, String |
#icon ⇒ String?
The url to the official icon of the payroll provider.
51 |
# File 'lib/finch-api/models/provider.rb', line 51 optional :icon, String |
#id ⇒ String?
The id of the payroll provider used in Connect.
10 |
# File 'lib/finch-api/models/provider.rb', line 10 optional :id, String |
#logo ⇒ String?
The url to the official logo of the payroll provider.
61 |
# File 'lib/finch-api/models/provider.rb', line 61 optional :logo, String |
#manual ⇒ Boolean?
- DEPRECATED
-
Whether the Finch integration with this provider uses the Assisted
Connect Flow by default. This field is now deprecated. Please check for a `type`
of `assisted` in the `authentication_methods` field instead.
73 |
# File 'lib/finch-api/models/provider.rb', line 73 optional :manual, FinchAPI::BooleanModel |
#mfa_required ⇒ Boolean?
whether MFA is required for the provider.
83 |
# File 'lib/finch-api/models/provider.rb', line 83 optional :mfa_required, FinchAPI::BooleanModel |
#primary_color ⇒ String?
The hex code for the primary color of the payroll provider.
93 |
# File 'lib/finch-api/models/provider.rb', line 93 optional :primary_color, String |