Class: FinchAPI::Models::Provider
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Provider
- Defined in:
- lib/finch_api/models/provider.rb
Defined Under Namespace
Classes: AuthenticationMethod
Instance Attribute Summary collapse
-
#authentication_methods ⇒ Array<FinchAPI::Models::Provider::AuthenticationMethod>?
The authentication methods supported by the provider.
-
#beta ⇒ Boolean?
‘true` if the integration is in a beta state, `false` otherwise.
-
#display_name ⇒ String
The display name of the payroll provider.
-
#icon ⇒ String?
The url to the official icon of the payroll provider.
-
#id ⇒ String
The id of the payroll provider used in Connect.
-
#logo ⇒ String?
The url to the official logo of the payroll provider.
- #manual ⇒ Boolean? deprecated Deprecated.
-
#mfa_required ⇒ Boolean?
whether MFA is required for the provider.
-
#primary_color ⇒ String?
The hex code for the primary color of the payroll provider.
-
#products ⇒ Array<String>
The list of Finch products supported on this payroll provider.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#authentication_methods ⇒ Array<FinchAPI::Models::Provider::AuthenticationMethod>?
The authentication methods supported by the provider.
28 29 |
# File 'lib/finch_api/models/provider.rb', line 28 optional :authentication_methods, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Provider::AuthenticationMethod] } |
#beta ⇒ Boolean?
‘true` if the integration is in a beta state, `false` otherwise
35 |
# File 'lib/finch_api/models/provider.rb', line 35 optional :beta, FinchAPI::Internal::Type::Boolean |
#display_name ⇒ String
The display name of the payroll provider.
16 |
# File 'lib/finch_api/models/provider.rb', line 16 required :display_name, String |
#icon ⇒ String?
The url to the official icon of the payroll provider.
41 |
# File 'lib/finch_api/models/provider.rb', line 41 optional :icon, String |
#id ⇒ String
The id of the payroll provider used in Connect.
10 |
# File 'lib/finch_api/models/provider.rb', line 10 required :id, String |
#logo ⇒ String?
The url to the official logo of the payroll provider.
47 |
# File 'lib/finch_api/models/provider.rb', line 47 optional :logo, String |
#manual ⇒ Boolean?
- DEPRECATED
-
Whether the Finch integration with this provider uses the Assisted
Connect Flow by default. This field is now deprecated. Please check for a ‘type` of `assisted` in the `authentication_methods` field instead.
57 |
# File 'lib/finch_api/models/provider.rb', line 57 optional :manual, FinchAPI::Internal::Type::Boolean |
#mfa_required ⇒ Boolean?
whether MFA is required for the provider.
63 |
# File 'lib/finch_api/models/provider.rb', line 63 optional :mfa_required, FinchAPI::Internal::Type::Boolean |
#primary_color ⇒ String?
The hex code for the primary color of the payroll provider.
69 |
# File 'lib/finch_api/models/provider.rb', line 69 optional :primary_color, String |