Class: FinchAPI::Models::RequestForwardingForwardParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::RequestForwardingForwardParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/request_forwarding_forward_params.rb
Overview
Instance Attribute Summary collapse
-
#data ⇒ String?
The body for the forwarded request.
-
#headers ⇒ Object?
The HTTP headers to include on the forwarded request.
-
#method_ ⇒ String
The HTTP method for the forwarded request.
-
#params ⇒ Object?
The query parameters for the forwarded request.
-
#route ⇒ String
The URL route path for the forwarded request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(method_: , route: , data: nil, headers: nil, params: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see RequestForwardingForwardParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(method_: , route: , data: nil, headers: nil, params: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::RequestForwardingForwardParams for more details.
|
|
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 47
|
Instance Attribute Details
#data ⇒ String?
The body for the forwarded request. This value must be specified as either a string or a valid JSON object.
30 |
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 30 optional :data, String, nil?: true |
#headers ⇒ Object?
The HTTP headers to include on the forwarded request. This value must be specified as an object of key-value pairs. Example: ‘{“Content-Type”: “application/xml”, “X-API-Version”: “v1” }`
38 |
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 38 optional :headers, FinchAPI::Internal::Type::Unknown, nil?: true |
#method_ ⇒ String
The HTTP method for the forwarded request. Valid values include: ‘GET` , `POST` , `PUT` , `DELETE` , and `PATCH`.
15 |
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 15 required :method_, String, api_name: :method |
#params ⇒ Object?
The query parameters for the forwarded request. This value must be specified as a valid JSON object rather than a query string.
45 |
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 45 optional :params, FinchAPI::Internal::Type::Unknown, nil?: true |
#route ⇒ String
The URL route path for the forwarded request. This value must begin with a forward-slash ( / ) and may only contain alphanumeric characters, hyphens, and underscores.
23 |
# File 'lib/finch_api/models/request_forwarding_forward_params.rb', line 23 required :route, String |