Class: FinchAPI::Models::RequestForwardingForwardResponse
- Defined in:
- lib/finch-api/models/request_forwarding_forward_response.rb
Defined Under Namespace
Classes: Request
Instance Attribute Summary collapse
-
#data ⇒ String?
A string representation of the HTTP response body of the forwarded request’s response received from the underlying integration’s API.
-
#headers ⇒ Object?
The HTTP headers of the forwarded request’s response, exactly as received from the underlying integration’s API.
-
#request ⇒ FinchAPI::Models::RequestForwardingForwardResponse::Request
An object containing details of your original forwarded request, for your ease of reference.
-
#status_code ⇒ Integer
The HTTP status code of the forwarded request’s response, exactly received from the underlying integration’s API.
Instance Method Summary collapse
-
#initialize(data:, headers:, request:, status_code:) ⇒ RequestForwardingForwardResponse
constructor
A new instance of RequestForwardingForwardResponse.
Constructor Details
#initialize(data:, headers:, request:, status_code:) ⇒ RequestForwardingForwardResponse
Returns a new instance of RequestForwardingForwardResponse.
6 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 6 def initialize(data:, headers:, request:, status_code:, **) = super |
Instance Attribute Details
#data ⇒ String?
A string representation of the HTTP response body of the forwarded request’s
response received from the underlying integration’s API. This field may be null
in the case where the upstream system’s response is empty.
12 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 12 required :data, String, nil?: true |
#headers ⇒ Object?
The HTTP headers of the forwarded request’s response, exactly as received from
the underlying integration’s API.
19 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 19 required :headers, FinchAPI::Unknown, nil?: true |
#request ⇒ FinchAPI::Models::RequestForwardingForwardResponse::Request
An object containing details of your original forwarded request, for your ease
of reference.
26 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 26 required :request, -> { FinchAPI::Models::RequestForwardingForwardResponse::Request } |
#status_code ⇒ Integer
The HTTP status code of the forwarded request’s response, exactly received from
the underlying integration’s API. This value will be returned as an integer.
33 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 33 required :status_code, Integer, api_name: :statusCode |