Class: FinchAPI::Models::RequestForwardingForwardResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::RequestForwardingForwardResponse
- Defined in:
- lib/finch_api/models/request_forwarding_forward_response.rb
Overview
Defined Under Namespace
Classes: Request
Instance Attribute Summary collapse
-
#data ⇒ String?
A string representation of the HTTP response body of the forwarded request’s response received from the underlying integration’s API.
-
#headers ⇒ Object?
The HTTP headers of the forwarded request’s response, exactly as received from the underlying integration’s API.
-
#request ⇒ FinchAPI::Models::RequestForwardingForwardResponse::Request
An object containing details of your original forwarded request, for your ease of reference.
-
#status_code ⇒ Integer
The HTTP status code of the forwarded request’s response, exactly received from the underlying integration’s API.
Instance Method Summary collapse
-
#initialize(data: , headers: , request: , status_code: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see RequestForwardingForwardResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(data: , headers: , request: , status_code: ) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::RequestForwardingForwardResponse for more details.
|
|
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 36
|
Instance Attribute Details
#data ⇒ String?
A string representation of the HTTP response body of the forwarded request’s response received from the underlying integration’s API. This field may be null in the case where the upstream system’s response is empty.
13 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 13 required :data, String, nil?: true |
#headers ⇒ Object?
The HTTP headers of the forwarded request’s response, exactly as received from the underlying integration’s API.
20 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 20 required :headers, FinchAPI::Internal::Type::Unknown, nil?: true |
#request ⇒ FinchAPI::Models::RequestForwardingForwardResponse::Request
An object containing details of your original forwarded request, for your ease of reference.
27 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 27 required :request, -> { FinchAPI::Models::RequestForwardingForwardResponse::Request } |
#status_code ⇒ Integer
The HTTP status code of the forwarded request’s response, exactly received from the underlying integration’s API. This value will be returned as an integer.
34 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 34 required :status_code, Integer, api_name: :statusCode |