Class: FinchAPI::Models::RequestForwardingForwardResponse::Request

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/request_forwarding_forward_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(method_: , route: , data: nil, headers: nil, params: nil) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::RequestForwardingForwardResponse::Request for more details.

An object containing details of your original forwarded request, for your ease of reference.

Parameters:

  • method_ (String) (defaults to: )

    The HTTP method that was specified for the forwarded request. Valid values inclu

  • route (String) (defaults to: )

    The URL route path that was specified for the forwarded request.

  • data (String, Hash{Symbol=>Object, nil}, nil) (defaults to: nil)

    The body that was specified for the forwarded request.

  • headers (Hash{Symbol=>String}, nil) (defaults to: nil)

    The HTTP headers that were specified for the forwarded request.

  • params (Hash{Symbol=>Object, nil}, nil) (defaults to: nil)

    The query parameters that were specified for the forwarded request.



# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 87

Instance Attribute Details

#dataString, ...

The body that was specified for the forwarded request.

Returns:

  • (String, Hash{Symbol=>Object, nil}, nil)


69
70
71
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 69

optional :data,
union: -> { FinchAPI::Models::RequestForwardingForwardResponse::Request::Data },
nil?: true

#headersHash{Symbol=>String}?

The HTTP headers that were specified for the forwarded request.

Returns:

  • (Hash{Symbol=>String}, nil)


77
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 77

optional :headers, FinchAPI::Internal::Type::HashOf[String], nil?: true

#method_String

The HTTP method that was specified for the forwarded request. Valid values include: ‘GET` , `POST` , `PUT` , `DELETE` , and `PATCH`.

Returns:

  • (String)


57
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 57

required :method_, String, api_name: :method

#paramsHash{Symbol=>Object, nil}?

The query parameters that were specified for the forwarded request.

Returns:

  • (Hash{Symbol=>Object, nil}, nil)


83
84
85
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 83

optional :params,
FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true],
nil?: true

#routeString

The URL route path that was specified for the forwarded request.

Returns:

  • (String)


63
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 63

required :route, String