Class: FinchAPI::Models::RequestForwardingForwardResponse::Request

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/request_forwarding_forward_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data: , headers: , method_: , params: , route: ) ⇒ Object

Some parameter documentations has been truncated, see FinchAPI::Models::RequestForwardingForwardResponse::Request for more details.

An object containing details of your original forwarded request, for your ease of reference.

Parameters:

  • data (String, nil) (defaults to: )

    The body that was specified for the forwarded request. If a value was not specif

  • headers (Object, nil) (defaults to: )

    The specified HTTP headers that were included in the forwarded request. If no he

  • method_ (String) (defaults to: )

    The HTTP method that was specified for the forwarded request. Valid values inclu

  • params (Object, nil) (defaults to: )

    The query parameters that were included in the forwarded request. If no query pa

  • route (String) (defaults to: )

    The URL route path that was specified for the forwarded request.



# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 85

Instance Attribute Details

#dataString?

The body that was specified for the forwarded request. If a value was not specified in the original request, this value will be returned as null ; otherwise, this value will always be returned as a string.

Returns:

  • (String, nil)


56
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 56

required :data, String, nil?: true

#headersObject?

The specified HTTP headers that were included in the forwarded request. If no headers were specified, this will be returned as ‘null`.

Returns:

  • (Object, nil)


63
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 63

required :headers, FinchAPI::Internal::Type::Unknown, nil?: true

#method_String

The HTTP method that was specified for the forwarded request. Valid values include: ‘GET` , `POST` , `PUT` , `DELETE` , and `PATCH`.

Returns:

  • (String)


70
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 70

required :method_, String, api_name: :method

#paramsObject?

The query parameters that were included in the forwarded request. If no query parameters were specified, this will be returned as ‘null`.

Returns:

  • (Object, nil)


77
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 77

required :params, FinchAPI::Internal::Type::Unknown, nil?: true

#routeString

The URL route path that was specified for the forwarded request.

Returns:

  • (String)


83
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 83

required :route, String