Class: FinchAPI::Models::RequestForwardingForwardResponse::Request
- Defined in:
- lib/finch-api/models/request_forwarding_forward_response.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Instance Attribute Summary collapse
-
#data ⇒ String?
The body that was specified for the forwarded request.
-
#headers ⇒ Object?
The specified HTTP headers that were included in the forwarded request.
-
#method_ ⇒ String
The HTTP method that was specified for the forwarded request.
-
#params ⇒ Object?
The query parameters that were included in the forwarded request.
-
#route ⇒ String
The URL route path that was specified for the forwarded request.
Instance Method Summary collapse
-
#initialize(data:, headers:, method_:, params:, route:) ⇒ Request
constructor
An object containing details of your original forwarded request, for your ease of reference.
Constructor Details
#initialize(data:, headers:, method_:, params:, route:) ⇒ Request
An object containing details of your original forwarded request, for your ease
of reference.
10 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 10 def initialize(data:, headers:, method_:, params:, route:, **) = super |
Instance Attribute Details
#data ⇒ String?
The body that was specified for the forwarded request. If a value was not
specified in the original request, this value will be returned as null ;
otherwise, this value will always be returned as a string.
52 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 52 required :data, String, nil?: true |
#headers ⇒ Object?
The specified HTTP headers that were included in the forwarded request. If no
headers were specified, this will be returned as `null`.
59 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 59 required :headers, FinchAPI::Unknown, nil?: true |
#method_ ⇒ String
The HTTP method that was specified for the forwarded request. Valid values
include: `GET` , `POST` , `PUT` , `DELETE` , and `PATCH`.
66 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 66 required :method_, String, api_name: :method |
#params ⇒ Object?
The query parameters that were included in the forwarded request. If no query
parameters were specified, this will be returned as `null`.
73 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 73 required :params, FinchAPI::Unknown, nil?: true |
#route ⇒ String
The URL route path that was specified for the forwarded request.
79 |
# File 'lib/finch-api/models/request_forwarding_forward_response.rb', line 79 required :route, String |