Class: FinchAPI::Models::RequestForwardingForwardResponse::Request
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::RequestForwardingForwardResponse::Request
- Defined in:
- lib/finch_api/models/request_forwarding_forward_response.rb
Overview
Defined Under Namespace
Modules: Data
Instance Attribute Summary collapse
-
#data ⇒ String, ...
The body that was specified for the forwarded request.
-
#headers ⇒ Hash{Symbol=>String}?
The HTTP headers that were specified for the forwarded request.
-
#method_ ⇒ String
The HTTP method that was specified for the forwarded request.
-
#params ⇒ Hash{Symbol=>Object, nil}?
The query parameters that were specified for the forwarded request.
-
#route ⇒ String
The URL route path that was specified for the forwarded request.
Instance Method Summary collapse
-
#initialize(method_: , route: , data: nil, headers: nil, params: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Request for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(method_: , route: , data: nil, headers: nil, params: nil) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::RequestForwardingForwardResponse::Request for more details.
An object containing details of your original forwarded request, for your ease of reference.
|
|
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 87
|
Instance Attribute Details
#data ⇒ String, ...
The body that was specified for the forwarded request.
69 70 71 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 69 optional :data, union: -> { FinchAPI::Models::RequestForwardingForwardResponse::Request::Data }, nil?: true |
#headers ⇒ Hash{Symbol=>String}?
The HTTP headers that were specified for the forwarded request.
77 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 77 optional :headers, FinchAPI::Internal::Type::HashOf[String], nil?: true |
#method_ ⇒ String
The HTTP method that was specified for the forwarded request. Valid values include: ‘GET` , `POST` , `PUT` , `DELETE` , and `PATCH`.
57 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 57 required :method_, String, api_name: :method |
#params ⇒ Hash{Symbol=>Object, nil}?
The query parameters that were specified for the forwarded request.
83 84 85 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 83 optional :params, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true], nil?: true |
#route ⇒ String
The URL route path that was specified for the forwarded request.
63 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 63 required :route, String |