Class: FinchAPI::Models::RequestForwardingForwardResponse::Request
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::RequestForwardingForwardResponse::Request
- Defined in:
- lib/finch_api/models/request_forwarding_forward_response.rb
Overview
Instance Attribute Summary collapse
-
#data ⇒ String?
The body that was specified for the forwarded request.
-
#headers ⇒ Object?
The specified HTTP headers that were included in the forwarded request.
-
#method_ ⇒ String
The HTTP method that was specified for the forwarded request.
-
#params ⇒ Object?
The query parameters that were included in the forwarded request.
-
#route ⇒ String
The URL route path that was specified for the forwarded request.
Instance Method Summary collapse
-
#initialize(data: , headers: , method_: , params: , route: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Request for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(data: , headers: , method_: , params: , route: ) ⇒ Object
Some parameter documentations has been truncated, see FinchAPI::Models::RequestForwardingForwardResponse::Request for more details.
An object containing details of your original forwarded request, for your ease of reference.
|
|
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 85
|
Instance Attribute Details
#data ⇒ String?
The body that was specified for the forwarded request. If a value was not specified in the original request, this value will be returned as null ; otherwise, this value will always be returned as a string.
56 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 56 required :data, String, nil?: true |
#headers ⇒ Object?
The specified HTTP headers that were included in the forwarded request. If no headers were specified, this will be returned as ‘null`.
63 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 63 required :headers, FinchAPI::Internal::Type::Unknown, nil?: true |
#method_ ⇒ String
The HTTP method that was specified for the forwarded request. Valid values include: ‘GET` , `POST` , `PUT` , `DELETE` , and `PATCH`.
70 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 70 required :method_, String, api_name: :method |
#params ⇒ Object?
The query parameters that were included in the forwarded request. If no query parameters were specified, this will be returned as ‘null`.
77 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 77 required :params, FinchAPI::Internal::Type::Unknown, nil?: true |
#route ⇒ String
The URL route path that was specified for the forwarded request.
83 |
# File 'lib/finch_api/models/request_forwarding_forward_response.rb', line 83 required :route, String |