Class: FinchAPI::Models::Sandbox::CompanyUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/sandbox/company_update_params.rb

Overview

Defined Under Namespace

Classes: Account, Department, Entity

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil) ⇒ Object

The parent department, if present.

Parameters:

  • name (String, nil) (defaults to: nil)

    The parent department’s name.



# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 180

Instance Attribute Details

#accountsArray<FinchAPI::Models::Sandbox::CompanyUpdateParams::Account>?

An array of bank account objects associated with the payroll/HRIS system.



15
16
17
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 15

required :accounts,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::CompanyUpdateParams::Account] },
nil?: true

#departmentsArray<FinchAPI::Models::Sandbox::CompanyUpdateParams::Department, nil>?

The array of company departments.



23
24
25
26
27
28
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 23

required :departments,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::CompanyUpdateParams::Department,
                                    nil?: true]
},
nil?: true

#einString?

The employer identification number.

Returns:

  • (String, nil)


34
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 34

required :ein, String, nil?: true

#entityFinchAPI::Models::Sandbox::CompanyUpdateParams::Entity?

The entity type object.



40
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 40

required :entity, -> { FinchAPI::Sandbox::CompanyUpdateParams::Entity }, nil?: true

The legal name of the company.

Returns:

  • (String, nil)


46
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 46

required :legal_name, String, nil?: true

#locationsArray<FinchAPI::Models::Location, nil>?

Returns:



51
52
53
54
55
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 51

required :locations,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Location, nil?: true]
},
nil?: true

#primary_emailString?

The email of the main administrator on the account.

Returns:

  • (String, nil)


61
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 61

required :primary_email, String, nil?: true

#primary_phone_numberString?

The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g. ‘+NNNNNNNNNNN xExtension`

Returns:

  • (String, nil)


68
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 68

required :primary_phone_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 149