Class: FinchAPI::Models::Sandbox::CompanyUpdateParams

Inherits:
BaseModel
  • Object
show all
Includes:
Type::RequestParameters
Defined in:
lib/finch-api/models/sandbox/company_update_params.rb

Defined Under Namespace

Classes: Account, Department, Entity

Instance Attribute Summary collapse

Attributes included from Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Type::RequestParameters

included

Constructor Details

#initialize(name: nil) ⇒ CompanyUpdateParams

The parent department, if present.

Parameters:

  • name (String, nil) (defaults to: nil)


11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 11

def initialize(
  accounts:,
  departments:,
  ein:,
  entity:,
  legal_name:,
  locations:,
  primary_email:,
  primary_phone_number:,
  request_options: {},
  **
)
  super
end

Instance Attribute Details

#accountsArray<FinchAPI::Models::Sandbox::CompanyUpdateParams::Account>?

An array of bank account objects associated with the payroll/HRIS system.



15
16
17
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 15

required :accounts,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateParams::Account] },
nil?: true

#departmentsArray<FinchAPI::Models::Sandbox::CompanyUpdateParams::Department, nil>?

The array of company departments.



23
24
25
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 23

required :departments,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateParams::Department, nil?: true] },
nil?: true

#einString?

The employer identification number.

Returns:

  • (String, nil)


31
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 31

required :ein, String, nil?: true

#entityFinchAPI::Models::Sandbox::CompanyUpdateParams::Entity?

The entity type object.



37
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 37

required :entity, -> { FinchAPI::Models::Sandbox::CompanyUpdateParams::Entity }, nil?: true

The legal name of the company.

Returns:

  • (String, nil)


43
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 43

required :legal_name, String, nil?: true

#locationsArray<FinchAPI::Models::Location, nil>?

Returns:



48
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 48

required :locations, -> { FinchAPI::ArrayOf[FinchAPI::Models::Location, nil?: true] }, nil?: true

#primary_emailString?

The email of the main administrator on the account.

Returns:

  • (String, nil)


54
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 54

required :primary_email, String, nil?: true

#primary_phone_numberString?

The phone number of the main administrator on the account. Format: ‘XXXXXXXXXX`

Returns:

  • (String, nil)


60
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 60

required :primary_phone_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 2

def self.values; end