Class: FinchAPI::Models::Sandbox::CompanyUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::CompanyUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/sandbox/company_update_params.rb
Overview
Defined Under Namespace
Classes: Account, Department, Entity
Instance Attribute Summary collapse
-
#accounts ⇒ Array<FinchAPI::Sandbox::CompanyUpdateParams::Account>?
An array of bank account objects associated with the payroll/HRIS system.
-
#departments ⇒ Array<FinchAPI::Sandbox::CompanyUpdateParams::Department, nil>?
The array of company departments.
-
#ein ⇒ String?
The employer identification number.
-
#entity ⇒ FinchAPI::Sandbox::CompanyUpdateParams::Entity?
The entity type object.
-
#legal_name ⇒ String?
The legal name of the company.
- #locations ⇒ Array<FinchAPI::Location, nil>?
-
#primary_email ⇒ String?
The email of the main administrator on the account.
-
#primary_phone_number ⇒ String?
The phone number of the main administrator on the account.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The parent department, if present.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(name: nil) ⇒ Object
The parent department, if present.
|
|
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 180
|
Instance Attribute Details
#accounts ⇒ Array<FinchAPI::Sandbox::CompanyUpdateParams::Account>?
An array of bank account objects associated with the payroll/HRIS system.
15 16 17 |
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 15 required :accounts, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::CompanyUpdateParams::Account] }, nil?: true |
#departments ⇒ Array<FinchAPI::Sandbox::CompanyUpdateParams::Department, nil>?
The array of company departments.
23 24 25 26 27 28 |
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 23 required :departments, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::CompanyUpdateParams::Department, nil?: true] }, nil?: true |
#ein ⇒ String?
The employer identification number.
34 |
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 34 required :ein, String, nil?: true |
#entity ⇒ FinchAPI::Sandbox::CompanyUpdateParams::Entity?
The entity type object.
40 |
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 40 required :entity, -> { FinchAPI::Sandbox::CompanyUpdateParams::Entity }, nil?: true |
#legal_name ⇒ String?
The legal name of the company.
46 |
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 46 required :legal_name, String, nil?: true |
#locations ⇒ Array<FinchAPI::Location, nil>?
51 52 53 54 55 |
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 51 required :locations, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Location, nil?: true] }, nil?: true |
#primary_email ⇒ String?
The email of the main administrator on the account.
61 |
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 61 required :primary_email, String, nil?: true |
#primary_phone_number ⇒ String?
The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g. ‘+NNNNNNNNNNN xExtension`
68 |
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 68 required :primary_phone_number, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/company_update_params.rb', line 149
|