Class: FinchAPI::Models::Sandbox::CompanyUpdateParams
- Includes:
- Type::RequestParameters
- Defined in:
- lib/finch-api/models/sandbox/company_update_params.rb
Defined Under Namespace
Classes: Account, Department, Entity
Instance Attribute Summary collapse
-
#accounts ⇒ Array<FinchAPI::Models::Sandbox::CompanyUpdateParams::Account>?
An array of bank account objects associated with the payroll/HRIS system.
-
#departments ⇒ Array<FinchAPI::Models::Sandbox::CompanyUpdateParams::Department, nil>?
The array of company departments.
-
#ein ⇒ String?
The employer identification number.
-
#entity ⇒ FinchAPI::Models::Sandbox::CompanyUpdateParams::Entity?
The entity type object.
-
#legal_name ⇒ String?
The legal name of the company.
- #locations ⇒ Array<FinchAPI::Models::Location, nil>?
-
#primary_email ⇒ String?
The email of the main administrator on the account.
-
#primary_phone_number ⇒ String?
The phone number of the main administrator on the account.
Attributes included from Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ CompanyUpdateParams
constructor
The parent department, if present.
Methods included from Type::RequestParameters
Constructor Details
#initialize(name: nil) ⇒ CompanyUpdateParams
The parent department, if present.
11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 11 def initialize( accounts:, departments:, ein:, entity:, legal_name:, locations:, primary_email:, primary_phone_number:, request_options: {}, ** ) super end |
Instance Attribute Details
#accounts ⇒ Array<FinchAPI::Models::Sandbox::CompanyUpdateParams::Account>?
An array of bank account objects associated with the payroll/HRIS system.
15 16 17 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 15 required :accounts, -> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateParams::Account] }, nil?: true |
#departments ⇒ Array<FinchAPI::Models::Sandbox::CompanyUpdateParams::Department, nil>?
The array of company departments.
23 24 25 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 23 required :departments, -> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateParams::Department, nil?: true] }, nil?: true |
#ein ⇒ String?
The employer identification number.
31 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 31 required :ein, String, nil?: true |
#entity ⇒ FinchAPI::Models::Sandbox::CompanyUpdateParams::Entity?
The entity type object.
37 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 37 required :entity, -> { FinchAPI::Models::Sandbox::CompanyUpdateParams::Entity }, nil?: true |
#legal_name ⇒ String?
The legal name of the company.
43 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 43 required :legal_name, String, nil?: true |
#locations ⇒ Array<FinchAPI::Models::Location, nil>?
48 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 48 required :locations, -> { FinchAPI::ArrayOf[FinchAPI::Models::Location, nil?: true] }, nil?: true |
#primary_email ⇒ String?
The email of the main administrator on the account.
54 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 54 required :primary_email, String, nil?: true |
#primary_phone_number ⇒ String?
The phone number of the main administrator on the account. Format: ‘XXXXXXXXXX`
60 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 60 required :primary_phone_number, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/sandbox/company_update_params.rb', line 2 def self.values; end |