Class: FinchAPI::Models::Sandbox::CompanyUpdateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/company_update_response.rb

Overview

Defined Under Namespace

Classes: Account, Department, Entity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil) ⇒ Object

The parent department, if present.

Parameters:

  • name (String, nil) (defaults to: nil)

    The parent department’s name.



# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 172

Instance Attribute Details

#accountsArray<FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account>?

An array of bank account objects associated with the payroll/HRIS system.



12
13
14
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 12

required :accounts,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account] },
nil?: true

#departmentsArray<FinchAPI::Models::Sandbox::CompanyUpdateResponse::Department, nil>?

The array of company departments.



20
21
22
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 20

required :departments,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateResponse::Department, nil?: true] },
nil?: true

#einString?

The employer identification number.

Returns:

  • (String, nil)


28
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 28

required :ein, String, nil?: true

#entityFinchAPI::Models::Sandbox::CompanyUpdateResponse::Entity?

The entity type object.



34
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 34

required :entity, -> { FinchAPI::Models::Sandbox::CompanyUpdateResponse::Entity }, nil?: true

The legal name of the company.

Returns:

  • (String, nil)


40
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 40

required :legal_name, String, nil?: true

#locationsArray<FinchAPI::Models::Location, nil>?

Returns:



45
46
47
48
49
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 45

required :locations,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Location, nil?: true]
},
nil?: true

#primary_emailString?

The email of the main administrator on the account.

Returns:

  • (String, nil)


55
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 55

required :primary_email, String, nil?: true

#primary_phone_numberString?

The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g. ‘+NNNNNNNNNNN xExtension`

Returns:

  • (String, nil)


62
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 62

required :primary_phone_number, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 141