Class: FinchAPI::Models::Sandbox::CompanyUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::CompanyUpdateResponse
- Defined in:
- lib/finch_api/models/sandbox/company_update_response.rb
Overview
Defined Under Namespace
Classes: Account, Department, Entity
Instance Attribute Summary collapse
-
#accounts ⇒ Array<FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account>?
An array of bank account objects associated with the payroll/HRIS system.
-
#departments ⇒ Array<FinchAPI::Models::Sandbox::CompanyUpdateResponse::Department, nil>?
The array of company departments.
-
#ein ⇒ String?
The employer identification number.
-
#entity ⇒ FinchAPI::Models::Sandbox::CompanyUpdateResponse::Entity?
The entity type object.
-
#legal_name ⇒ String?
The legal name of the company.
- #locations ⇒ Array<FinchAPI::Models::Location, nil>?
-
#primary_email ⇒ String?
The email of the main administrator on the account.
-
#primary_phone_number ⇒ String?
The phone number of the main administrator on the account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The parent department, if present.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil) ⇒ Object
The parent department, if present.
|
|
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 172
|
Instance Attribute Details
#accounts ⇒ Array<FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account>?
An array of bank account objects associated with the payroll/HRIS system.
12 13 14 |
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 12 required :accounts, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account] }, nil?: true |
#departments ⇒ Array<FinchAPI::Models::Sandbox::CompanyUpdateResponse::Department, nil>?
The array of company departments.
20 21 22 |
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 20 required :departments, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::CompanyUpdateResponse::Department, nil?: true] }, nil?: true |
#ein ⇒ String?
The employer identification number.
28 |
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 28 required :ein, String, nil?: true |
#entity ⇒ FinchAPI::Models::Sandbox::CompanyUpdateResponse::Entity?
The entity type object.
34 |
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 34 required :entity, -> { FinchAPI::Models::Sandbox::CompanyUpdateResponse::Entity }, nil?: true |
#legal_name ⇒ String?
The legal name of the company.
40 |
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 40 required :legal_name, String, nil?: true |
#locations ⇒ Array<FinchAPI::Models::Location, nil>?
45 46 47 48 49 |
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 45 required :locations, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Location, nil?: true] }, nil?: true |
#primary_email ⇒ String?
The email of the main administrator on the account.
55 |
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 55 required :primary_email, String, nil?: true |
#primary_phone_number ⇒ String?
The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g. ‘+NNNNNNNNNNN xExtension`
62 |
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 62 required :primary_phone_number, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/company_update_response.rb', line 141
|