Class: FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account
- Defined in:
- lib/finch-api/models/sandbox/company_update_response.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Defined Under Namespace
Modules: AccountType
Instance Attribute Summary collapse
-
#account_name ⇒ String?
The name of the bank associated in the payroll/HRIS system.
-
#account_number ⇒ String?
10-12 digit number to specify the bank account.
-
#account_type ⇒ Symbol, ...
The type of bank account.
-
#institution_name ⇒ String?
Name of the banking institution.
-
#routing_number ⇒ String?
A nine-digit code that’s based on the U.S.
Instance Method Summary collapse
-
#initialize(account_name: nil, account_number: nil, account_type: nil, institution_name: nil, routing_number: nil) ⇒ Account
constructor
A new instance of Account.
Constructor Details
#initialize(account_name: nil, account_number: nil, account_type: nil, institution_name: nil, routing_number: nil) ⇒ Account
Returns a new instance of Account.
7 |
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 7 def initialize(account_name: nil, account_number: nil, account_type: nil, institution_name: nil, routing_number: nil, **) = super |
Instance Attribute Details
#account_name ⇒ String?
The name of the bank associated in the payroll/HRIS system.
77 |
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 77 optional :account_name, String, nil?: true |
#account_number ⇒ String?
10-12 digit number to specify the bank account
83 |
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 83 optional :account_number, String, nil?: true |
#account_type ⇒ Symbol, ...
The type of bank account.
89 90 91 |
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 89 optional :account_type, enum: -> { FinchAPI::Models::Sandbox::CompanyUpdateResponse::Account::AccountType }, nil?: true |
#institution_name ⇒ String?
Name of the banking institution.
97 |
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 97 optional :institution_name, String, nil?: true |
#routing_number ⇒ String?
A nine-digit code that’s based on the U.S. Bank location where your account was
opened.
104 |
# File 'lib/finch-api/models/sandbox/company_update_response.rb', line 104 optional :routing_number, String, nil?: true |