Class: FinchAPI::Models::Sandbox::ConnectionCreateParams

Inherits:
BaseModel
  • Object
show all
Includes:
Type::RequestParameters
Defined in:
lib/finch-api/models/sandbox/connection_create_params.rb

Defined Under Namespace

Modules: AuthenticationType

Instance Attribute Summary collapse

Attributes included from Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Type::RequestParameters

included

Constructor Details

#initialize(provider_id:, authentication_type: nil, employee_size: nil, products: nil, request_options: {}) ⇒ ConnectionCreateParams

Returns a new instance of ConnectionCreateParams.

Parameters:



7
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 7

def initialize(provider_id:, authentication_type: nil, employee_size: nil, products: nil, request_options: {}, **) = super

Instance Attribute Details

#authentication_typeSymbol, ...



20
21
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 20

optional :authentication_type,
enum: -> { FinchAPI::Models::Sandbox::ConnectionCreateParams::AuthenticationType }

#employee_sizeInteger?

Optional: the size of the employer to be created with this connection. Defaults

to 20. Note that if this is higher than 100, historical payroll data will not be
generated, and instead only one pay period will be created.

Returns:

  • (Integer, nil)


33
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 33

optional :employee_size, Integer

#productsArray<String>?

Returns:

  • (Array<String>, nil)


42
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 42

optional :products, FinchAPI::ArrayOf[String]

#provider_idString

The provider associated with the connection

Returns:

  • (String)


15
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 15

required :provider_id, String