Class: FinchAPI::Models::Sandbox::ConnectionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::ConnectionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/sandbox/connection_create_params.rb
Overview
Defined Under Namespace
Modules: AuthenticationType
Instance Attribute Summary collapse
- #authentication_type ⇒ Symbol, ...
-
#employee_size ⇒ Integer?
Optional: the size of the employer to be created with this connection.
- #products ⇒ Array<String>?
-
#provider_id ⇒ String
The provider associated with the connection.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#authentication_type ⇒ Symbol, ...
20 21 22 23 |
# File 'lib/finch_api/models/sandbox/connection_create_params.rb', line 20 optional :authentication_type, enum: -> { FinchAPI::Sandbox::ConnectionCreateParams::AuthenticationType } |
#employee_size ⇒ Integer?
Optional: the size of the employer to be created with this connection. Defaults to 20. Note that if this is higher than 100, historical payroll data will not be generated, and instead only one pay period will be created.
31 |
# File 'lib/finch_api/models/sandbox/connection_create_params.rb', line 31 optional :employee_size, Integer |
#products ⇒ Array<String>?
36 |
# File 'lib/finch_api/models/sandbox/connection_create_params.rb', line 36 optional :products, FinchAPI::Internal::Type::ArrayOf[String] |
#provider_id ⇒ String
The provider associated with the connection
15 |
# File 'lib/finch_api/models/sandbox/connection_create_params.rb', line 15 required :provider_id, String |