Class: FinchAPI::Models::Sandbox::ConnectionCreateParams
- Includes:
- Type::RequestParameters
- Defined in:
- lib/finch-api/models/sandbox/connection_create_params.rb
Defined Under Namespace
Modules: AuthenticationType
Instance Attribute Summary collapse
- #authentication_type ⇒ Symbol, ...
-
#employee_size ⇒ Integer?
Optional: the size of the employer to be created with this connection.
- #products ⇒ Array<String>?
-
#provider_id ⇒ String
The provider associated with the connection.
Attributes included from Type::RequestParameters
Instance Method Summary collapse
-
#initialize(provider_id:, authentication_type: nil, employee_size: nil, products: nil, request_options: {}) ⇒ ConnectionCreateParams
constructor
A new instance of ConnectionCreateParams.
Methods included from Type::RequestParameters
Constructor Details
#initialize(provider_id:, authentication_type: nil, employee_size: nil, products: nil, request_options: {}) ⇒ ConnectionCreateParams
Returns a new instance of ConnectionCreateParams.
7 |
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 7 def initialize(provider_id:, authentication_type: nil, employee_size: nil, products: nil, request_options: {}, **) = super |
Instance Attribute Details
#authentication_type ⇒ Symbol, ...
20 21 |
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 20 optional :authentication_type, enum: -> { FinchAPI::Models::Sandbox::ConnectionCreateParams::AuthenticationType } |
#employee_size ⇒ Integer?
Optional: the size of the employer to be created with this connection. Defaults
to 20. Note that if this is higher than 100, historical payroll data will not be
generated, and instead only one pay period will be created.
33 |
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 33 optional :employee_size, Integer |
#products ⇒ Array<String>?
42 |
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 42 optional :products, FinchAPI::ArrayOf[String] |
#provider_id ⇒ String
The provider associated with the connection
15 |
# File 'lib/finch-api/models/sandbox/connection_create_params.rb', line 15 required :provider_id, String |