Class: FinchAPI::Models::Sandbox::DirectoryCreateParams::Body

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/sandbox/directory_create_params.rb

Overview

def initialize: (Hash | FinchAPI::BaseModel) -> void

Defined Under Namespace

Modules: EmploymentStatus, Ethnicity, Gender Classes: CustomField, Department, Email, Employment, Manager, PhoneNumber

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil) ⇒ Body

The manager object representing the manager of the individual within the org.

Parameters:

  • id (String) (defaults to: nil)


29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 29

def initialize(
  class_code: nil,
  custom_fields: nil,
  department: nil,
  dob: nil,
  emails: nil,
  employment: nil,
  employment_status: nil,
  encrypted_ssn: nil,
  end_date: nil,
  ethnicity: nil,
  first_name: nil,
  gender: nil,
  income: nil,
  income_history: nil,
  is_active: nil,
  last_name: nil,
  latest_rehire_date: nil,
  location: nil,
  manager: nil,
  middle_name: nil,
  phone_numbers: nil,
  preferred_name: nil,
  residence: nil,
  source_id: nil,
  ssn: nil,
  start_date: nil,
  title: nil,
  **
)
  super
end

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


35
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 35

optional :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField>?

Custom fields for the individual. These are fields which are defined by the

employer in the system. Custom fields are not currently supported for assisted
connections.


43
44
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 43

optional :custom_fields,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::CustomField] }

#departmentFinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department?

The department object.



54
55
56
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 54

optional :department,
-> { FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department },
nil?: true

#dobString?

Returns:

  • (String, nil)


61
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 61

optional :dob, String, nil?: true

#emailsArray<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email>?



66
67
68
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 66

optional :emails,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Email] },
nil?: true

#employmentFinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment?

The employment object.



74
75
76
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 74

optional :employment,
-> { FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Employment },
nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual.



82
83
84
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 82

optional :employment_status,
enum: -> { FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::EmploymentStatus },
nil?: true

#encrypted_ssnString?

Social Security Number of the individual in encrypted format. This field is

only available with the `ssn` scope enabled and the
`options: { include: ['ssn'] }` param set in the body.

Returns:

  • (String, nil)


92
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 92

optional :encrypted_ssn, String, nil?: true

#end_dateString?

Returns:

  • (String, nil)


97
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 97

optional :end_date, String, nil?: true

#ethnicitySymbol, ...

The EEOC-defined ethnicity of the individual.



103
104
105
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 103

optional :ethnicity,
enum: -> { FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Ethnicity },
nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


111
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 111

optional :first_name, String, nil?: true

#genderSymbol, ...

The gender of the individual.



117
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 117

optional :gender, enum: -> { FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Gender }, nil?: true

#id=(value) ⇒ String (writeonly)

Returns:

  • (String)


2
3
4
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 2

def id=(value)
  @id = value
end

#incomeFinchAPI::Models::Income?

The employee’s income as reported by the provider. This may not always be

annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc,
depending on what information the provider returns.

Returns:



125
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 125

optional :income, -> { FinchAPI::Models::Income }, nil?: true

#income_historyArray<FinchAPI::Models::Income, nil>?

The array of income history.

Returns:



131
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 131

optional :income_history, -> { FinchAPI::ArrayOf[FinchAPI::Models::Income, nil?: true] }, nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


137
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 137

optional :is_active, FinchAPI::BooleanModel, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


143
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 143

optional :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


148
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 148

optional :latest_rehire_date, String, nil?: true

#locationFinchAPI::Models::Location?

Returns:



153
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 153

optional :location, -> { FinchAPI::Models::Location }, nil?: true

#managerFinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Manager?

The manager object representing the manager of the individual within the org.



159
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 159

optional :manager, -> { FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


165
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 165

optional :middle_name, String, nil?: true

#phone_numbersArray<FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>?



170
171
172
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 170

optional :phone_numbers,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil?: true] },
nil?: true

#preferred_nameString?

The preferred name of the individual.

Returns:

  • (String, nil)


178
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 178

optional :preferred_name, String, nil?: true

#residenceFinchAPI::Models::Location?

Returns:



183
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 183

optional :residence, -> { FinchAPI::Models::Location }, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


189
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 189

optional :source_id, String

#ssnString?

Social Security Number of the individual. This field is only available with the

`ssn` scope enabled and the `options: { include: ['ssn'] }` param set in the
body.
[Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).

Returns:

  • (String, nil)


202
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 202

optional :ssn, String, nil?: true

#start_dateString?

Returns:

  • (String, nil)


207
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 207

optional :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


213
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 213

optional :title, String, nil?: true

#value=(value) ⇒ Object (writeonly)

Returns:

  • (Object)


2
3
4
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 2

def value=(value)
  @value = value
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 2

def self.values; end