Class: FinchAPI::Models::Sandbox::DirectoryCreateParams::Body

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/directory_create_params.rb

Defined Under Namespace

Modules: EmploymentStatus, Ethnicity, Gender Classes: CustomField, Department, Email, Employment, Manager, PhoneNumber

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(id: nil) ⇒ Object

The manager object representing the manager of the individual within the org.

Parameters:

  • id (String) (defaults to: nil)

    A stable Finch ‘id` (UUID v4) for an individual in the company.



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 29

class Body < FinchAPI::Internal::Type::BaseModel
  # @!attribute class_code
  #   Worker's compensation classification code for this employee
  #
  #   @return [String, nil]
  optional :class_code, String, nil?: true

  # @!attribute custom_fields
  #   Custom fields for the individual. These are fields which are defined by the
  #   employer in the system. Custom fields are not currently supported for assisted
  #   connections.
  #
  #   @return [Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField>, nil]
  optional :custom_fields,
           -> {
             FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField]
           },
           nil?: true

  # @!attribute department
  #   The department object.
  #
  #   @return [FinchAPI::Sandbox::DirectoryCreateParams::Body::Department, nil]
  optional :department, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Department }, nil?: true

  # @!attribute dob
  #
  #   @return [String, nil]
  optional :dob, String, nil?: true

  # @!attribute emails
  #
  #   @return [Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::Email>, nil]
  optional :emails,
           -> {
             FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::Email]
           },
           nil?: true

  # @!attribute employment
  #   The employment object.
  #
  #   @return [FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment, nil]
  optional :employment, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment }, nil?: true

  # @!attribute employment_status
  #   The detailed employment status of the individual. Available options: `active`,
  #   `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.
  #
  #   @return [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::EmploymentStatus, nil]
  optional :employment_status,
           enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::EmploymentStatus },
           nil?: true

  # @!attribute encrypted_ssn
  #   Social Security Number of the individual in **encrypted** format. This field is
  #   only available with the `ssn` scope enabled and the
  #   `options: { include: ['ssn'] }` param set in the body.
  #
  #   @return [String, nil]
  optional :encrypted_ssn, String, nil?: true

  # @!attribute end_date
  #
  #   @return [String, nil]
  optional :end_date, String, nil?: true

  # @!attribute ethnicity
  #   The EEOC-defined ethnicity of the individual.
  #
  #   @return [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Ethnicity, nil]
  optional :ethnicity,
           enum: -> {
             FinchAPI::Sandbox::DirectoryCreateParams::Body::Ethnicity
           },
           nil?: true

  # @!attribute first_name
  #   The legal first name of the individual.
  #
  #   @return [String, nil]
  optional :first_name, String, nil?: true

  # @!attribute gender
  #   The gender of the individual.
  #
  #   @return [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Gender, nil]
  optional :gender, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Gender }, nil?: true

  # @!attribute income
  #   The employee's income as reported by the provider. This may not always be
  #   annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc,
  #   depending on what information the provider returns.
  #
  #   @return [FinchAPI::Income, nil]
  optional :income, -> { FinchAPI::Income }, nil?: true

  # @!attribute income_history
  #   The array of income history.
  #
  #   @return [Array<FinchAPI::Income, nil>, nil]
  optional :income_history,
           -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
           nil?: true

  # @!attribute is_active
  #   `true` if the individual an an active employee or contractor at the company.
  #
  #   @return [Boolean, nil]
  optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

  # @!attribute last_name
  #   The legal last name of the individual.
  #
  #   @return [String, nil]
  optional :last_name, String, nil?: true

  # @!attribute latest_rehire_date
  #
  #   @return [String, nil]
  optional :latest_rehire_date, String, nil?: true

  # @!attribute location
  #
  #   @return [FinchAPI::Location, nil]
  optional :location, -> { FinchAPI::Location }, nil?: true

  # @!attribute manager
  #   The manager object representing the manager of the individual within the org.
  #
  #   @return [FinchAPI::Sandbox::DirectoryCreateParams::Body::Manager, nil]
  optional :manager, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Manager }, nil?: true

  # @!attribute middle_name
  #   The legal middle name of the individual.
  #
  #   @return [String, nil]
  optional :middle_name, String, nil?: true

  # @!attribute phone_numbers
  #
  #   @return [Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>, nil]
  optional :phone_numbers,
           -> {
             FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber,
                                               nil?: true]
           },
           nil?: true

  # @!attribute preferred_name
  #   The preferred name of the individual.
  #
  #   @return [String, nil]
  optional :preferred_name, String, nil?: true

  # @!attribute residence
  #
  #   @return [FinchAPI::Location, nil]
  optional :residence, -> { FinchAPI::Location }, nil?: true

  # @!attribute source_id
  #   The source system's unique employment identifier for this individual
  #
  #   @return [String, nil]
  optional :source_id, String, nil?: true

  # @!attribute ssn
  #   Social Security Number of the individual. This field is only available with the
  #   `ssn` scope enabled and the `options: { include: ['ssn'] }` param set in the
  #   body.
  #   [Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).
  #
  #   @return [String, nil]
  optional :ssn, String, nil?: true

  # @!attribute start_date
  #
  #   @return [String, nil]
  optional :start_date, String, nil?: true

  # @!attribute title
  #   The current title of the individual.
  #
  #   @return [String, nil]
  optional :title, String, nil?: true

  # @!method initialize(class_code: nil, custom_fields: nil, department: nil, dob: nil, emails: nil, employment: nil, employment_status: nil, encrypted_ssn: nil, end_date: nil, ethnicity: nil, first_name: nil, gender: nil, income: nil, income_history: nil, is_active: nil, last_name: nil, latest_rehire_date: nil, location: nil, manager: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, source_id: nil, ssn: nil, start_date: nil, title: nil)
  #   Some parameter documentations has been truncated, see
  #   {FinchAPI::Sandbox::DirectoryCreateParams::Body} for more details.
  #
  #   @param class_code [String, nil] Worker's compensation classification code for this employee
  #
  #   @param custom_fields [Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField>, nil] Custom fields for the individual. These are fields which are defined by the empl
  #
  #   @param department [FinchAPI::Sandbox::DirectoryCreateParams::Body::Department, nil] The department object.
  #
  #   @param dob [String, nil]
  #
  #   @param emails [Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::Email>, nil]
  #
  #   @param employment [FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment, nil] The employment object.
  #
  #   @param employment_status [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::EmploymentStatus, nil] The detailed employment status of the individual. Available options: `active`, `
  #
  #   @param encrypted_ssn [String, nil] Social Security Number of the individual in **encrypted** format. This field is
  #
  #   @param end_date [String, nil]
  #
  #   @param ethnicity [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Ethnicity, nil] The EEOC-defined ethnicity of the individual.
  #
  #   @param first_name [String, nil] The legal first name of the individual.
  #
  #   @param gender [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Gender, nil] The gender of the individual.
  #
  #   @param income [FinchAPI::Income, nil] The employee's income as reported by the provider. This may not always be annual
  #
  #   @param income_history [Array<FinchAPI::Income, nil>, nil] The array of income history.
  #
  #   @param is_active [Boolean, nil] `true` if the individual an an active employee or contractor at the company.
  #
  #   @param last_name [String, nil] The legal last name of the individual.
  #
  #   @param latest_rehire_date [String, nil]
  #
  #   @param location [FinchAPI::Location, nil]
  #
  #   @param manager [FinchAPI::Sandbox::DirectoryCreateParams::Body::Manager, nil] The manager object representing the manager of the individual within the org.
  #
  #   @param middle_name [String, nil] The legal middle name of the individual.
  #
  #   @param phone_numbers [Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>, nil]
  #
  #   @param preferred_name [String, nil] The preferred name of the individual.
  #
  #   @param residence [FinchAPI::Location, nil]
  #
  #   @param source_id [String, nil] The source system's unique employment identifier for this individual
  #
  #   @param ssn [String, nil] Social Security Number of the individual. This field is only available with the
  #
  #   @param start_date [String, nil]
  #
  #   @param title [String, nil] The current title of the individual.

  class CustomField < FinchAPI::Internal::Type::BaseModel
    # @!attribute name
    #
    #   @return [String, nil]
    optional :name, String, nil?: true

    # @!attribute value
    #
    #   @return [Object, nil]
    optional :value, FinchAPI::Internal::Type::Unknown

    # @!method initialize(name: nil, value: nil)
    #   @param name [String, nil]
    #   @param value [Object]
  end

  # @see FinchAPI::Sandbox::DirectoryCreateParams::Body#department
  class Department < FinchAPI::Internal::Type::BaseModel
    # @!attribute name
    #   The name of the department associated with the individual.
    #
    #   @return [String, nil]
    optional :name, String, nil?: true

    # @!method initialize(name: nil)
    #   The department object.
    #
    #   @param name [String, nil] The name of the department associated with the individual.
  end

  class Email < FinchAPI::Internal::Type::BaseModel
    # @!attribute data
    #
    #   @return [String, nil]
    optional :data, String

    # @!attribute type
    #
    #   @return [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Email::Type, nil]
    optional :type,
             enum: -> {
               FinchAPI::Sandbox::DirectoryCreateParams::Body::Email::Type
             },
             nil?: true

    # @!method initialize(data: nil, type: nil)
    #   @param data [String]
    #   @param type [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Email::Type, nil]

    # @see FinchAPI::Sandbox::DirectoryCreateParams::Body::Email#type
    module Type
      extend FinchAPI::Internal::Type::Enum

      WORK = :work
      PERSONAL = :personal

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @see FinchAPI::Sandbox::DirectoryCreateParams::Body#employment
  class Employment < FinchAPI::Internal::Type::BaseModel
    # @!attribute subtype
    #   The secondary employment type of the individual. Options: `full_time`,
    #   `part_time`, `intern`, `temp`, `seasonal` and `individual_contractor`.
    #
    #   @return [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment::Subtype, nil]
    optional :subtype,
             enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment::Subtype },
             nil?: true

    # @!attribute type
    #   The main employment type of the individual.
    #
    #   @return [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment::Type, nil]
    optional :type,
             enum: -> {
               FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment::Type
             },
             nil?: true

    # @!method initialize(subtype: nil, type: nil)
    #   Some parameter documentations has been truncated, see
    #   {FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment} for more details.
    #
    #   The employment object.
    #
    #   @param subtype [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment::Subtype, nil] The secondary employment type of the individual. Options: `full_time`, `part_tim
    #
    #   @param type [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment::Type, nil] The main employment type of the individual.

    # The secondary employment type of the individual. Options: `full_time`,
    # `part_time`, `intern`, `temp`, `seasonal` and `individual_contractor`.
    #
    # @see FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment#subtype
    module Subtype
      extend FinchAPI::Internal::Type::Enum

      FULL_TIME = :full_time
      INTERN = :intern
      PART_TIME = :part_time
      TEMP = :temp
      SEASONAL = :seasonal
      INDIVIDUAL_CONTRACTOR = :individual_contractor

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # The main employment type of the individual.
    #
    # @see FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment#type
    module Type
      extend FinchAPI::Internal::Type::Enum

      EMPLOYEE = :employee
      CONTRACTOR = :contractor

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # The detailed employment status of the individual. Available options: `active`,
  # `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.
  #
  # @see FinchAPI::Sandbox::DirectoryCreateParams::Body#employment_status
  module EmploymentStatus
    extend FinchAPI::Internal::Type::Enum

    ACTIVE = :active
    DECEASED = :deceased
    LEAVE = :leave
    ONBOARDING = :onboarding
    PREHIRE = :prehire
    RETIRED = :retired
    TERMINATED = :terminated

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The EEOC-defined ethnicity of the individual.
  #
  # @see FinchAPI::Sandbox::DirectoryCreateParams::Body#ethnicity
  module Ethnicity
    extend FinchAPI::Internal::Type::Enum

    ASIAN = :asian
    WHITE = :white
    BLACK_OR_AFRICAN_AMERICAN = :black_or_african_american
    NATIVE_HAWAIIAN_OR_PACIFIC_ISLANDER = :native_hawaiian_or_pacific_islander
    AMERICAN_INDIAN_OR_ALASKA_NATIVE = :american_indian_or_alaska_native
    HISPANIC_OR_LATINO = :hispanic_or_latino
    TWO_OR_MORE_RACES = :two_or_more_races
    DECLINE_TO_SPECIFY = :decline_to_specify

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The gender of the individual.
  #
  # @see FinchAPI::Sandbox::DirectoryCreateParams::Body#gender
  module Gender
    extend FinchAPI::Internal::Type::Enum

    FEMALE = :female
    MALE = :male
    OTHER = :other
    DECLINE_TO_SPECIFY = :decline_to_specify

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see FinchAPI::Sandbox::DirectoryCreateParams::Body#manager
  class Manager < FinchAPI::Internal::Type::BaseModel
    # @!attribute id
    #   A stable Finch `id` (UUID v4) for an individual in the company.
    #
    #   @return [String, nil]
    optional :id, String

    # @!method initialize(id: nil)
    #   The manager object representing the manager of the individual within the org.
    #
    #   @param id [String] A stable Finch `id` (UUID v4) for an individual in the company.
  end

  class PhoneNumber < FinchAPI::Internal::Type::BaseModel
    # @!attribute data
    #
    #   @return [String, nil]
    optional :data, String, nil?: true

    # @!attribute type
    #
    #   @return [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber::Type, nil]
    optional :type,
             enum: -> {
               FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber::Type
             },
             nil?: true

    # @!method initialize(data: nil, type: nil)
    #   @param data [String, nil]
    #   @param type [Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber::Type, nil]

    # @see FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber#type
    module Type
      extend FinchAPI::Internal::Type::Enum

      WORK = :work
      PERSONAL = :personal

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end
end

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


34
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 34

optional :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.

Returns:

  • (Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField>, nil)


42
43
44
45
46
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 42

optional :custom_fields,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::CustomField]
},
nil?: true

#departmentFinchAPI::Sandbox::DirectoryCreateParams::Body::Department?

The department object.

Returns:

  • (FinchAPI::Sandbox::DirectoryCreateParams::Body::Department, nil)


52
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 52

optional :department, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Department }, nil?: true

#dobString?

Returns:

  • (String, nil)


57
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 57

optional :dob, String, nil?: true

#emailsArray<FinchAPI::Sandbox::DirectoryCreateParams::Body::Email>?

Returns:

  • (Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::Email>, nil)


62
63
64
65
66
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 62

optional :emails,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::Email]
},
nil?: true

#employmentFinchAPI::Sandbox::DirectoryCreateParams::Body::Employment?

The employment object.

Returns:

  • (FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment, nil)


72
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 72

optional :employment, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.

Returns:

  • (Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::EmploymentStatus, nil)


79
80
81
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 79

optional :employment_status,
enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::EmploymentStatus },
nil?: true

#encrypted_ssnString?

Social Security Number of the individual in encrypted format. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body.

Returns:

  • (String, nil)


89
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 89

optional :encrypted_ssn, String, nil?: true

#end_dateString?

Returns:

  • (String, nil)


94
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 94

optional :end_date, String, nil?: true

#ethnicitySymbol, ...

The EEOC-defined ethnicity of the individual.

Returns:

  • (Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Ethnicity, nil)


100
101
102
103
104
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 100

optional :ethnicity,
enum: -> {
  FinchAPI::Sandbox::DirectoryCreateParams::Body::Ethnicity
},
nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


110
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 110

optional :first_name, String, nil?: true

#genderSymbol, ...

The gender of the individual.

Returns:

  • (Symbol, FinchAPI::Sandbox::DirectoryCreateParams::Body::Gender, nil)


116
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 116

optional :gender, enum: -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Gender }, nil?: true

#incomeFinchAPI::Income?

The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Returns:



124
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 124

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Income, nil>?

The array of income history.

Returns:



130
131
132
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 130

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


138
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 138

optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


144
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 144

optional :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


149
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 149

optional :latest_rehire_date, String, nil?: true

#locationFinchAPI::Location?

Returns:



154
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 154

optional :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::Sandbox::DirectoryCreateParams::Body::Manager?

The manager object representing the manager of the individual within the org.

Returns:

  • (FinchAPI::Sandbox::DirectoryCreateParams::Body::Manager, nil)


160
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 160

optional :manager, -> { FinchAPI::Sandbox::DirectoryCreateParams::Body::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


166
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 166

optional :middle_name, String, nil?: true

#phone_numbersArray<FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>?

Returns:

  • (Array<FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber, nil>, nil)


171
172
173
174
175
176
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 171

optional :phone_numbers,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::DirectoryCreateParams::Body::PhoneNumber,
                                    nil?: true]
},
nil?: true

#preferred_nameString?

The preferred name of the individual.

Returns:

  • (String, nil)


182
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 182

optional :preferred_name, String, nil?: true

#residenceFinchAPI::Location?

Returns:



187
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 187

optional :residence, -> { FinchAPI::Location }, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


193
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 193

optional :source_id, String, nil?: true

#ssnString?

Social Security Number of the individual. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body. [Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).

Returns:

  • (String, nil)


202
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 202

optional :ssn, String, nil?: true

#start_dateString?

Returns:

  • (String, nil)


207
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 207

optional :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


213
# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 213

optional :title, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/directory_create_params.rb', line 329