Class: FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department
- Inherits:
-
BaseModel
- Object
- FinchAPI::Models::Sandbox::DirectoryCreateParams::Body::Department
- Defined in:
- lib/finch-api/models/sandbox/directory_create_params.rb
Instance Attribute Summary collapse
-
#name ⇒ String?
The name of the department associated with the individual.
Instance Attribute Details
#name ⇒ String?
The name of the department associated with the individual.
308 |
# File 'lib/finch-api/models/sandbox/directory_create_params.rb', line 308 optional :name, String, nil?: true |