Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/sandbox/employment_update_params.rb,
sig/finch_api/models/sandbox/employment_update_params.rbs
Overview
Defined Under Namespace
Modules: EmploymentStatus, FlsaStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker's compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department?
The department object.
-
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#flsa_status ⇒ Symbol, ...
The FLSA status of the individual.
-
#highly_compensated_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Highly Compensated Employee for nondiscrimination testing purposes (ADP/ACP tests).
-
#income ⇒ FinchAPI::Models::Income?
The employee's income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
- #individual_id ⇒ String
-
#is_active ⇒ Boolean?
trueif the individual an an active employee or contractor at the company. -
#key_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Key Employee for top-heavy testing purposes.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Models::Location?
-
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system's unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
-
#union_code ⇒ String?
The code identifying the union the employee is a member of, as configured in the payroll system.
-
#union_local ⇒ String?
The local chapter or local number within the employee's union.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The department object.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: nil) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 268
|
Instance Attribute Details
#class_code ⇒ String?
Worker's compensation classification code for this employee
20 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 20 optional :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
28 29 30 31 32 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 28 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::EmploymentUpdateParams::CustomField] }, nil?: true |
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department?
The department object.
38 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 38 optional :department, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Department }, nil?: true |
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment?
The employment object.
44 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 44 optional :employment, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
50 51 52 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 50 optional :employment_status, enum: -> { FinchAPI::Sandbox::EmploymentUpdateParams::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
57 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 57 optional :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
63 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 63 optional :first_name, String, nil?: true |
#flsa_status ⇒ Symbol, ...
The FLSA status of the individual. Available options: exempt, non_exempt,
unknown.
70 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 70 optional :flsa_status, enum: -> { FinchAPI::Sandbox::EmploymentUpdateParams::FlsaStatus }, nil?: true |
#highly_compensated_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Highly Compensated Employee for nondiscrimination testing purposes (ADP/ACP tests). US-only.
77 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 77 optional :highly_compensated_employee, FinchAPI::Internal::Type::Boolean, nil?: true |
#income ⇒ FinchAPI::Models::Income?
The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
85 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 85 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
91 92 93 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 91 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#individual_id ⇒ String
14 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 14 required :individual_id, String |
#is_active ⇒ Boolean?
true if the individual an an active employee or contractor at the company.
99 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 99 optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#key_employee ⇒ Boolean?
IRS flag indicating whether the employee is classified as a Key Employee for top-heavy testing purposes. US-only.
106 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 106 optional :key_employee, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
112 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 112 optional :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
117 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 117 optional :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Models::Location?
122 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 122 optional :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager?
The manager object representing the manager of the individual within the org.
128 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 128 optional :manager, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
134 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 134 optional :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system's unique employment identifier for this individual
140 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 140 optional :source_id, String, nil?: true |
#start_date ⇒ String?
145 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 145 optional :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
151 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 151 optional :title, String, nil?: true |
#union_code ⇒ String?
The code identifying the union the employee is a member of, as configured in the payroll system.
158 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 158 optional :union_code, String, nil?: true |
#union_local ⇒ String?
The local chapter or local number within the employee's union.
164 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 164 optional :union_local, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 330
|
Instance Method Details
#to_hash ⇒ {
113 |
# File 'sig/finch_api/models/sandbox/employment_update_params.rbs', line 113
def to_hash: -> {
|