Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/sandbox/employment_update_params.rb,
sig/finch_api/models/sandbox/employment_update_params.rbs

Overview

See Also:

  • FinchAPI::Resources::Sandbox::Employment#update

Defined Under Namespace

Modules: EmploymentStatus, FlsaStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil) ⇒ Object

The department object.

Parameters:

  • name (String, nil) (defaults to: nil)

    The name of the department associated with the individual.



# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 233

Instance Attribute Details

#class_codeString?

Worker's compensation classification code for this employee

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


20
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 20

optional :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.

Parameters:

  • value (::Array[FinchAPI::Sandbox::EmploymentUpdateParams::CustomField], nil)

Returns:



28
29
30
31
32
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 28

optional :custom_fields,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::EmploymentUpdateParams::CustomField]
},
nil?: true

#departmentFinchAPI::Models::Sandbox::EmploymentUpdateParams::Department?

The department object.

Parameters:

  • value (FinchAPI::Sandbox::EmploymentUpdateParams::Department, nil)

Returns:



38
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 38

optional :department, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Department }, nil?: true

#employmentFinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment?

The employment object.

Parameters:

  • value (FinchAPI::Sandbox::EmploymentUpdateParams::Employment, nil)

Returns:



44
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 44

optional :employment, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual.

Parameters:

  • value (FinchAPI::Models::Sandbox::EmploymentUpdateParams::employment_status, nil)

Returns:



50
51
52
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 50

optional :employment_status,
enum: -> { FinchAPI::Sandbox::EmploymentUpdateParams::EmploymentStatus },
nil?: true

#end_dateString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


57
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 57

optional :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


63
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 63

optional :first_name, String, nil?: true

#flsa_statusSymbol, ...

The FLSA status of the individual. Available options: exempt, non_exempt, unknown.

Parameters:

  • value (FinchAPI::Models::Sandbox::EmploymentUpdateParams::flsa_status, nil)

Returns:



70
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 70

optional :flsa_status, enum: -> { FinchAPI::Sandbox::EmploymentUpdateParams::FlsaStatus }, nil?: true

#incomeFinchAPI::Models::Income?

The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Parameters:

Returns:



78
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 78

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Models::Income, nil>?

The array of income history.

Parameters:

Returns:



84
85
86
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 84

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#individual_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 14

required :individual_id, String

#is_activeBoolean?

true if the individual an an active employee or contractor at the company.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


92
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 92

optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


98
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 98

optional :last_name, String, nil?: true

#latest_rehire_dateString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


103
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 103

optional :latest_rehire_date, String, nil?: true

#locationFinchAPI::Models::Location?

Parameters:

Returns:



108
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 108

optional :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager?

The manager object representing the manager of the individual within the org.

Parameters:

  • value (FinchAPI::Sandbox::EmploymentUpdateParams::Manager, nil)

Returns:



114
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 114

optional :manager, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


120
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 120

optional :middle_name, String, nil?: true

#source_idString?

The source system's unique employment identifier for this individual

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


126
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 126

optional :source_id, String, nil?: true

#start_dateString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


131
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 131

optional :start_date, String, nil?: true

#titleString?

The current title of the individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


137
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 137

optional :title, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 295

Instance Method Details

#to_hash{

Returns:

  • ({)


97
# File 'sig/finch_api/models/sandbox/employment_update_params.rbs', line 97

def to_hash: -> {