Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/sandbox/employment_update_params.rb
Overview
Defined Under Namespace
Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department?
The department object.
-
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#income ⇒ FinchAPI::Models::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Models::Location?
-
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The department object.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(name: nil) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 179
|
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
15 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 15 optional :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
23 24 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 23 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField] } |
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department?
The department object.
30 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 30 optional :department, -> { FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department }, nil?: true |
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment?
The employment object.
36 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 36 optional :employment, -> { FinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
42 43 44 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 42 optional :employment_status, enum: -> { FinchAPI::Models::Sandbox::EmploymentUpdateParams::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
49 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 49 optional :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
55 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 55 optional :first_name, String, nil?: true |
#income ⇒ FinchAPI::Models::Income?
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
63 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 63 optional :income, -> { FinchAPI::Models::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Models::Income, nil>?
The array of income history.
69 70 71 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 69 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
77 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 77 optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
83 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 83 optional :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
88 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 88 optional :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Models::Location?
93 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 93 optional :location, -> { FinchAPI::Models::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager?
The manager object representing the manager of the individual within the org.
99 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 99 optional :manager, -> { FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
105 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 105 optional :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
111 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 111 optional :source_id, String |
#start_date ⇒ String?
116 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 116 optional :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
122 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 122 optional :title, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 254
|