Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/sandbox/employment_update_params.rb

Overview

Defined Under Namespace

Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

#initialize(name: nil) ⇒ Object

The department object.

Parameters:

  • name (String, nil) (defaults to: nil)

    The name of the department associated with the individual.



# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 179

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


15
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 15

optional :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Sandbox::EmploymentUpdateParams::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.

Returns:

  • (Array<FinchAPI::Sandbox::EmploymentUpdateParams::CustomField>, nil)


23
24
25
26
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 23

optional :custom_fields,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::EmploymentUpdateParams::CustomField]
}

#departmentFinchAPI::Sandbox::EmploymentUpdateParams::Department?

The department object.

Returns:

  • (FinchAPI::Sandbox::EmploymentUpdateParams::Department, nil)


32
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 32

optional :department, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Department }, nil?: true

#employmentFinchAPI::Sandbox::EmploymentUpdateParams::Employment?

The employment object.

Returns:

  • (FinchAPI::Sandbox::EmploymentUpdateParams::Employment, nil)


38
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 38

optional :employment, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual.

Returns:

  • (Symbol, FinchAPI::Sandbox::EmploymentUpdateParams::EmploymentStatus, nil)


44
45
46
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 44

optional :employment_status,
enum: -> { FinchAPI::Sandbox::EmploymentUpdateParams::EmploymentStatus },
nil?: true

#end_dateString?

Returns:

  • (String, nil)


51
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 51

optional :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


57
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 57

optional :first_name, String, nil?: true

#incomeFinchAPI::Income?

The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Returns:



65
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 65

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Income, nil>?

The array of income history.

Returns:



71
72
73
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 71

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


79
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 79

optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


85
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 85

optional :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


90
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 90

optional :latest_rehire_date, String, nil?: true

#locationFinchAPI::Location?

Returns:



95
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 95

optional :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::Sandbox::EmploymentUpdateParams::Manager?

The manager object representing the manager of the individual within the org.

Returns:

  • (FinchAPI::Sandbox::EmploymentUpdateParams::Manager, nil)


101
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 101

optional :manager, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


107
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 107

optional :middle_name, String, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


113
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 113

optional :source_id, String

#start_dateString?

Returns:

  • (String, nil)


118
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 118

optional :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


124
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 124

optional :title, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 252