Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/sandbox/employment_update_params.rb
Overview
Defined Under Namespace
Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Sandbox::EmploymentUpdateParams::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Sandbox::EmploymentUpdateParams::Department?
The department object.
-
#employment ⇒ FinchAPI::Sandbox::EmploymentUpdateParams::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Location?
-
#manager ⇒ FinchAPI::Sandbox::EmploymentUpdateParams::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The department object.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(name: nil) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 179
|
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
15 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 15 optional :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Sandbox::EmploymentUpdateParams::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
23 24 25 26 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 23 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::EmploymentUpdateParams::CustomField] } |
#department ⇒ FinchAPI::Sandbox::EmploymentUpdateParams::Department?
The department object.
32 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 32 optional :department, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Department }, nil?: true |
#employment ⇒ FinchAPI::Sandbox::EmploymentUpdateParams::Employment?
The employment object.
38 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 38 optional :employment, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
44 45 46 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 44 optional :employment_status, enum: -> { FinchAPI::Sandbox::EmploymentUpdateParams::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
51 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 51 optional :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
57 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 57 optional :first_name, String, nil?: true |
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
65 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 65 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
71 72 73 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 71 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
79 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 79 optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
85 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 85 optional :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
90 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 90 optional :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Location?
95 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 95 optional :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::Sandbox::EmploymentUpdateParams::Manager?
The manager object representing the manager of the individual within the org.
101 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 101 optional :manager, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
107 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 107 optional :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
113 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 113 optional :source_id, String |
#start_date ⇒ String?
118 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 118 optional :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
124 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 124 optional :title, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 252
|