Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/finch_api/models/sandbox/employment_update_params.rb

Overview

Defined Under Namespace

Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil) ⇒ Object

The department object.

Parameters:

  • name (String, nil) (defaults to: nil)

    The name of the department associated with the individual.



# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 181

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


15
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 15

optional :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.



23
24
25
26
27
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 23

optional :custom_fields,
-> {
  FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::EmploymentUpdateParams::CustomField]
},
nil?: true

#departmentFinchAPI::Models::Sandbox::EmploymentUpdateParams::Department?

The department object.



33
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 33

optional :department, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Department }, nil?: true

#employmentFinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment?

The employment object.



39
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 39

optional :employment, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.



46
47
48
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 46

optional :employment_status,
enum: -> { FinchAPI::Sandbox::EmploymentUpdateParams::EmploymentStatus },
nil?: true

#end_dateString?

Returns:

  • (String, nil)


53
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 53

optional :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


59
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 59

optional :first_name, String, nil?: true

#incomeFinchAPI::Models::Income?

The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Returns:



67
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 67

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Models::Income, nil>?

The array of income history.

Returns:



73
74
75
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 73

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


81
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 81

optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


87
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 87

optional :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


92
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 92

optional :latest_rehire_date, String, nil?: true

#locationFinchAPI::Models::Location?

Returns:



97
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 97

optional :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager?

The manager object representing the manager of the individual within the org.



103
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 103

optional :manager, -> { FinchAPI::Sandbox::EmploymentUpdateParams::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


109
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 109

optional :middle_name, String, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


115
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 115

optional :source_id, String, nil?: true

#start_dateString?

Returns:

  • (String, nil)


120
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 120

optional :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


126
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 126

optional :title, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 255