Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams

Inherits:
BaseModel
  • Object
show all
Includes:
Type::RequestParameters
Defined in:
lib/finch-api/models/sandbox/employment_update_params.rb

Defined Under Namespace

Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Attributes included from Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Type::RequestParameters

included

Constructor Details

#initialize(name: nil) ⇒ EmploymentUpdateParams

The department object.

Parameters:

  • name (String, nil) (defaults to: nil)


21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 21

def initialize(
  class_code: nil,
  custom_fields: nil,
  department: nil,
  employment: nil,
  employment_status: nil,
  end_date: nil,
  first_name: nil,
  income: nil,
  income_history: nil,
  is_active: nil,
  last_name: nil,
  latest_rehire_date: nil,
  location: nil,
  manager: nil,
  middle_name: nil,
  source_id: nil,
  start_date: nil,
  title: nil,
  request_options: {},
  **
)
  super
end

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


15
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 15

optional :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField>?

Custom fields for the individual. These are fields which are defined by the

employer in the system. Custom fields are not currently supported for assisted
connections.


23
24
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 23

optional :custom_fields,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::EmploymentUpdateParams::CustomField] }

#departmentFinchAPI::Models::Sandbox::EmploymentUpdateParams::Department?

The department object.



34
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 34

optional :department, -> { FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department }, nil?: true

#employmentFinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment?

The employment object.



40
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 40

optional :employment, -> { FinchAPI::Models::Sandbox::EmploymentUpdateParams::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual.



46
47
48
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 46

optional :employment_status,
enum: -> { FinchAPI::Models::Sandbox::EmploymentUpdateParams::EmploymentStatus },
nil?: true

#end_dateString?

Returns:

  • (String, nil)


53
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 53

optional :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


59
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 59

optional :first_name, String, nil?: true

#incomeFinchAPI::Models::Income?

The employee’s income as reported by the provider. This may not always be

annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc,
depending on what information the provider returns.

Returns:



67
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 67

optional :income, -> { FinchAPI::Models::Income }, nil?: true

#income_historyArray<FinchAPI::Models::Income, nil>?

The array of income history.

Returns:



73
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 73

optional :income_history, -> { FinchAPI::ArrayOf[FinchAPI::Models::Income, nil?: true] }, nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


79
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 79

optional :is_active, FinchAPI::BooleanModel, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


85
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 85

optional :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


90
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 90

optional :latest_rehire_date, String, nil?: true

#locationFinchAPI::Models::Location?

Returns:



95
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 95

optional :location, -> { FinchAPI::Models::Location }, nil?: true

#managerFinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager?

The manager object representing the manager of the individual within the org.



101
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 101

optional :manager, -> { FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


107
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 107

optional :middle_name, String, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


113
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 113

optional :source_id, String

#start_dateString?

Returns:

  • (String, nil)


122
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 122

optional :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


128
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 128

optional :title, String, nil?: true

#value=(value) ⇒ Object (writeonly)

Returns:

  • (Object)


2
3
4
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 2

def value=(value)
  @value = value
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 2

def self.values; end