Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateParams::Department
- Defined in:
- lib/finch_api/models/sandbox/employment_update_params.rb
Instance Attribute Summary collapse
-
#name ⇒ String?
The name of the department associated with the individual.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, #initialize, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#name ⇒ String?
The name of the department associated with the individual.
189 |
# File 'lib/finch_api/models/sandbox/employment_update_params.rb', line 189 optional :name, String, nil?: true |