Class: FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager
- Inherits:
-
BaseModel
- Object
- BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateParams::Manager
- Defined in:
- lib/finch-api/models/sandbox/employment_update_params.rb
Instance Attribute Summary collapse
-
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ Manager
constructor
The manager object representing the manager of the individual within the org.
Methods inherited from BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, #inspect, known_fields, optional, required, #to_h
Methods included from Converter
#coerce, coerce, #dump, dump, type_info
Constructor Details
#initialize(id: nil) ⇒ Manager
The manager object representing the manager of the individual within the org.
5 |
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 5 def initialize(id: nil, **) = super |
Instance Attribute Details
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
305 |
# File 'lib/finch-api/models/sandbox/employment_update_params.rb', line 305 optional :id, String |