Class: FinchAPI::Models::Sandbox::EmploymentUpdateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/employment_update_response.rb

Overview

Defined Under Namespace

Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Constructor Details

#initialize(name: nil) ⇒ Object

The department object.

Parameters:

  • name (String, nil) (defaults to: nil)

    The name of the department associated with the individual.



# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 180

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


18
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 18

optional :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.



26
27
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 26

optional :custom_fields,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField] }

#departmentFinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department?

The department object.



33
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 33

optional :department, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department }, nil?: true

#employmentFinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment?

The employment object.



39
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 39

optional :employment, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual.



45
46
47
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 45

optional :employment_status,
enum: -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::EmploymentStatus },
nil?: true

#end_dateString?

Returns:

  • (String, nil)


52
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 52

optional :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


58
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 58

optional :first_name, String, nil?: true

#idString?

A stable Finch ‘id` (UUID v4) for an individual in the company.

Returns:

  • (String, nil)


12
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 12

optional :id, String

#incomeFinchAPI::Income?

The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Returns:



66
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 66

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Income, nil>?

The array of income history.

Returns:



72
73
74
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 72

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


80
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 80

optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


86
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 86

optional :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


91
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 91

optional :latest_rehire_date, String, nil?: true

#locationFinchAPI::Location?

Returns:



96
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 96

optional :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager?

The manager object representing the manager of the individual within the org.



102
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 102

optional :manager, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


108
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 108

optional :middle_name, String, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


114
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 114

optional :source_id, String

#start_dateString?

Returns:

  • (String, nil)


119
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 119

optional :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


125
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 125

optional :title, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 256