Class: FinchAPI::Models::Sandbox::EmploymentUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateResponse
- Defined in:
- lib/finch_api/models/sandbox/employment_update_response.rb
Overview
Defined Under Namespace
Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department?
The department object.
-
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Location?
-
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The department object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(name: nil) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 180
|
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
18 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 18 optional :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
26 27 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 26 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField] } |
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department?
The department object.
33 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 33 optional :department, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department }, nil?: true |
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment?
The employment object.
39 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 39 optional :employment, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
45 46 47 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 45 optional :employment_status, enum: -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
52 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 52 optional :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
58 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 58 optional :first_name, String, nil?: true |
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
12 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 12 optional :id, String |
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
66 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 66 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
72 73 74 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 72 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
80 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 80 optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
86 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 86 optional :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
91 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 91 optional :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Location?
96 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 96 optional :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager?
The manager object representing the manager of the individual within the org.
102 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 102 optional :manager, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
108 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 108 optional :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
114 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 114 optional :source_id, String |
#start_date ⇒ String?
119 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 119 optional :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
125 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 125 optional :title, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 256
|