Class: FinchAPI::Models::Sandbox::EmploymentUpdateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/employment_update_response.rb

Overview

Defined Under Namespace

Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil) ⇒ Object

The department object.

Parameters:

  • name (String, nil) (defaults to: nil)

    The name of the department associated with the individual.



# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 182

Instance Attribute Details

#class_codeString?

Worker’s compensation classification code for this employee

Returns:

  • (String, nil)


18
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 18

optional :class_code, String, nil?: true

#custom_fieldsArray<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>?

Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.



26
27
28
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 26

optional :custom_fields,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField] },
nil?: true

#departmentFinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department?

The department object.



34
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 34

optional :department, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department }, nil?: true

#employmentFinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment?

The employment object.



40
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 40

optional :employment, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment }, nil?: true

#employment_statusSymbol, ...

The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.



47
48
49
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 47

optional :employment_status,
enum: -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::EmploymentStatus },
nil?: true

#end_dateString?

Returns:

  • (String, nil)


54
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 54

optional :end_date, String, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


60
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 60

optional :first_name, String, nil?: true

#idString?

A stable Finch ‘id` (UUID v4) for an individual in the company.

Returns:

  • (String, nil)


12
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 12

optional :id, String

#incomeFinchAPI::Models::Income?

The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.

Returns:



68
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 68

optional :income, -> { FinchAPI::Income }, nil?: true

#income_historyArray<FinchAPI::Models::Income, nil>?

The array of income history.

Returns:



74
75
76
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 74

optional :income_history,
-> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] },
nil?: true

#is_activeBoolean?

‘true` if the individual an an active employee or contractor at the company.

Returns:

  • (Boolean, nil)


82
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 82

optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


88
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 88

optional :last_name, String, nil?: true

#latest_rehire_dateString?

Returns:

  • (String, nil)


93
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 93

optional :latest_rehire_date, String, nil?: true

#locationFinchAPI::Models::Location?

Returns:



98
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 98

optional :location, -> { FinchAPI::Location }, nil?: true

#managerFinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager?

The manager object representing the manager of the individual within the org.



104
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 104

optional :manager, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager }, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


110
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 110

optional :middle_name, String, nil?: true

#source_idString?

The source system’s unique employment identifier for this individual

Returns:

  • (String, nil)


116
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 116

optional :source_id, String, nil?: true

#start_dateString?

Returns:

  • (String, nil)


121
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 121

optional :start_date, String, nil?: true

#titleString?

The current title of the individual.

Returns:

  • (String, nil)


127
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 127

optional :title, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 258