Class: FinchAPI::Models::Sandbox::EmploymentUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::EmploymentUpdateResponse
- Defined in:
- lib/finch_api/models/sandbox/employment_update_response.rb
Overview
Defined Under Namespace
Modules: EmploymentStatus Classes: CustomField, Department, Employment, Manager
Instance Attribute Summary collapse
-
#class_code ⇒ String?
Worker’s compensation classification code for this employee.
-
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>?
Custom fields for the individual.
-
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department?
The department object.
-
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment?
The employment object.
-
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual.
- #end_date ⇒ String?
-
#first_name ⇒ String?
The legal first name of the individual.
-
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider.
-
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
-
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
-
#last_name ⇒ String?
The legal last name of the individual.
- #latest_rehire_date ⇒ String?
- #location ⇒ FinchAPI::Location?
-
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager?
The manager object representing the manager of the individual within the org.
-
#middle_name ⇒ String?
The legal middle name of the individual.
-
#source_id ⇒ String?
The source system’s unique employment identifier for this individual.
- #start_date ⇒ String?
-
#title ⇒ String?
The current title of the individual.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Object
constructor
The department object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(name: nil) ⇒ Object
The department object.
|
|
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 182
|
Instance Attribute Details
#class_code ⇒ String?
Worker’s compensation classification code for this employee
18 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 18 optional :class_code, String, nil?: true |
#custom_fields ⇒ Array<FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField>?
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
26 27 28 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 26 optional :custom_fields, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::EmploymentUpdateResponse::CustomField] }, nil?: true |
#department ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department?
The department object.
34 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 34 optional :department, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department }, nil?: true |
#employment ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment?
The employment object.
40 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 40 optional :employment, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Employment }, nil?: true |
#employment_status ⇒ Symbol, ...
The detailed employment status of the individual. Available options: ‘active`, `deceased`, `leave`, `onboarding`, `prehire`, `retired`, `terminated`.
47 48 49 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 47 optional :employment_status, enum: -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::EmploymentStatus }, nil?: true |
#end_date ⇒ String?
54 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 54 optional :end_date, String, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
60 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 60 optional :first_name, String, nil?: true |
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
12 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 12 optional :id, String |
#income ⇒ FinchAPI::Income?
The employee’s income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
68 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 68 optional :income, -> { FinchAPI::Income }, nil?: true |
#income_history ⇒ Array<FinchAPI::Income, nil>?
The array of income history.
74 75 76 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 74 optional :income_history, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Income, nil?: true] }, nil?: true |
#is_active ⇒ Boolean?
‘true` if the individual an an active employee or contractor at the company.
82 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 82 optional :is_active, FinchAPI::Internal::Type::Boolean, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
88 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 88 optional :last_name, String, nil?: true |
#latest_rehire_date ⇒ String?
93 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 93 optional :latest_rehire_date, String, nil?: true |
#location ⇒ FinchAPI::Location?
98 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 98 optional :location, -> { FinchAPI::Location }, nil?: true |
#manager ⇒ FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager?
The manager object representing the manager of the individual within the org.
104 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 104 optional :manager, -> { FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Manager }, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
110 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 110 optional :middle_name, String, nil?: true |
#source_id ⇒ String?
The source system’s unique employment identifier for this individual
116 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 116 optional :source_id, String, nil?: true |
#start_date ⇒ String?
121 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 121 optional :start_date, String, nil?: true |
#title ⇒ String?
The current title of the individual.
127 |
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 127 optional :title, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/employment_update_response.rb', line 258
|