Class: FinchAPI::Models::Sandbox::EmploymentUpdateResponse::Department
- Defined in:
- lib/finch-api/models/sandbox/employment_update_response.rb
Instance Attribute Summary collapse
-
#name ⇒ String?
The name of the department associated with the individual.
Instance Attribute Details
#name ⇒ String?
The name of the department associated with the individual.
213 |
# File 'lib/finch-api/models/sandbox/employment_update_response.rb', line 213 optional :name, String, nil?: true |