Class: FinchAPI::Models::Sandbox::IndividualUpdateParams

Inherits:
BaseModel
  • Object
show all
Includes:
Type::RequestParameters
Defined in:
lib/finch-api/models/sandbox/individual_update_params.rb

Defined Under Namespace

Modules: Ethnicity, Gender Classes: Email, PhoneNumber

Instance Attribute Summary collapse

Attributes included from Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Type::RequestParameters

included

Constructor Details

#initialize(dob: nil, emails: nil, encrypted_ssn: nil, ethnicity: nil, first_name: nil, gender: nil, last_name: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, ssn: nil, request_options: {}) ⇒ IndividualUpdateParams

Returns a new instance of IndividualUpdateParams.

Parameters:



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 15

def initialize(
  dob: nil,
  emails: nil,
  encrypted_ssn: nil,
  ethnicity: nil,
  first_name: nil,
  gender: nil,
  last_name: nil,
  middle_name: nil,
  phone_numbers: nil,
  preferred_name: nil,
  residence: nil,
  ssn: nil,
  request_options: {},
  **
)
  super
end

Instance Attribute Details

#dobString?

Returns:

  • (String, nil)


14
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 14

optional :dob, String, nil?: true

#emailsArray<FinchAPI::Models::Sandbox::IndividualUpdateParams::Email>?



19
20
21
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 19

optional :emails,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateParams::Email] },
nil?: true

#encrypted_ssnString?

Social Security Number of the individual in encrypted format. This field is

only available with the `ssn` scope enabled and the
`options: { include: ['ssn'] }` param set in the body.

Returns:

  • (String, nil)


29
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 29

optional :encrypted_ssn, String, nil?: true

#ethnicitySymbol, ...

The EEOC-defined ethnicity of the individual.



35
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 35

optional :ethnicity, enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateParams::Ethnicity }, nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


41
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 41

optional :first_name, String, nil?: true

#genderSymbol, ...

The gender of the individual.



47
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 47

optional :gender, enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateParams::Gender }, nil?: true

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


53
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 53

optional :last_name, String, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


59
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 59

optional :middle_name, String, nil?: true

#phone_numbersArray<FinchAPI::Models::Sandbox::IndividualUpdateParams::PhoneNumber, nil>?



64
65
66
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 64

optional :phone_numbers,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateParams::PhoneNumber, nil?: true] },
nil?: true

#preferred_nameString?

The preferred name of the individual.

Returns:

  • (String, nil)


72
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 72

optional :preferred_name, String, nil?: true

#residenceFinchAPI::Models::Location?

Returns:



77
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 77

optional :residence, -> { FinchAPI::Models::Location }, nil?: true

#ssnString?

Social Security Number of the individual. This field is only available with the

`ssn` scope enabled and the `options: { include: ['ssn'] }` param set in the
body.
[Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).

Returns:

  • (String, nil)


86
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 86

optional :ssn, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 2

def self.values; end