Class: FinchAPI::Models::Sandbox::IndividualUpdateParams
- Includes:
- Type::RequestParameters
- Defined in:
- lib/finch-api/models/sandbox/individual_update_params.rb
Defined Under Namespace
Modules: Ethnicity, Gender Classes: Email, PhoneNumber
Instance Attribute Summary collapse
- #dob ⇒ String?
- #emails ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateParams::Email>?
-
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format.
-
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
-
#first_name ⇒ String?
The legal first name of the individual.
-
#gender ⇒ Symbol, ...
The gender of the individual.
-
#last_name ⇒ String?
The legal last name of the individual.
-
#middle_name ⇒ String?
The legal middle name of the individual.
- #phone_numbers ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateParams::PhoneNumber, nil>?
-
#preferred_name ⇒ String?
The preferred name of the individual.
- #residence ⇒ FinchAPI::Models::Location?
-
#ssn ⇒ String?
Social Security Number of the individual.
Attributes included from Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(dob: nil, emails: nil, encrypted_ssn: nil, ethnicity: nil, first_name: nil, gender: nil, last_name: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, ssn: nil, request_options: {}) ⇒ IndividualUpdateParams
constructor
A new instance of IndividualUpdateParams.
Methods included from Type::RequestParameters
Constructor Details
#initialize(dob: nil, emails: nil, encrypted_ssn: nil, ethnicity: nil, first_name: nil, gender: nil, last_name: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, ssn: nil, request_options: {}) ⇒ IndividualUpdateParams
Returns a new instance of IndividualUpdateParams.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 15 def initialize( dob: nil, emails: nil, encrypted_ssn: nil, ethnicity: nil, first_name: nil, gender: nil, last_name: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, ssn: nil, request_options: {}, ** ) super end |
Instance Attribute Details
#dob ⇒ String?
14 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 14 optional :dob, String, nil?: true |
#emails ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateParams::Email>?
19 20 21 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 19 optional :emails, -> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateParams::Email] }, nil?: true |
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format. This field is
only available with the `ssn` scope enabled and the
`options: { include: ['ssn'] }` param set in the body.
29 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 29 optional :encrypted_ssn, String, nil?: true |
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
35 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 35 optional :ethnicity, enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateParams::Ethnicity }, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
41 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 41 optional :first_name, String, nil?: true |
#gender ⇒ Symbol, ...
The gender of the individual.
47 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 47 optional :gender, enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateParams::Gender }, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
53 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 53 optional :last_name, String, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
59 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 59 optional :middle_name, String, nil?: true |
#phone_numbers ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateParams::PhoneNumber, nil>?
64 65 66 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 64 optional :phone_numbers, -> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateParams::PhoneNumber, nil?: true] }, nil?: true |
#preferred_name ⇒ String?
The preferred name of the individual.
72 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 72 optional :preferred_name, String, nil?: true |
#residence ⇒ FinchAPI::Models::Location?
77 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 77 optional :residence, -> { FinchAPI::Models::Location }, nil?: true |
#ssn ⇒ String?
Social Security Number of the individual. This field is only available with the
`ssn` scope enabled and the `options: { include: ['ssn'] }` param set in the
body.
[Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).
86 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 86 optional :ssn, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/sandbox/individual_update_params.rb', line 2 def self.values; end |