Class: FinchAPI::Models::Sandbox::IndividualUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::IndividualUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/sandbox/individual_update_params.rb
Overview
Defined Under Namespace
Modules: Ethnicity, Gender Classes: Email, PhoneNumber
Instance Attribute Summary collapse
- #dob ⇒ String?
- #emails ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateParams::Email>?
-
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format.
-
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
-
#first_name ⇒ String?
The legal first name of the individual.
-
#gender ⇒ Symbol, ...
The gender of the individual.
-
#last_name ⇒ String?
The legal last name of the individual.
-
#middle_name ⇒ String?
The legal middle name of the individual.
- #phone_numbers ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateParams::PhoneNumber, nil>?
-
#preferred_name ⇒ String?
The preferred name of the individual.
- #residence ⇒ FinchAPI::Models::Location?
-
#ssn ⇒ String?
Social Security Number of the individual.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#dob ⇒ String?
14 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 14 optional :dob, String, nil?: true |
#emails ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateParams::Email>?
19 20 21 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 19 optional :emails, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::IndividualUpdateParams::Email] }, nil?: true |
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body.
29 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 29 optional :encrypted_ssn, String, nil?: true |
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
35 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 35 optional :ethnicity, enum: -> { FinchAPI::Sandbox::IndividualUpdateParams::Ethnicity }, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
41 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 41 optional :first_name, String, nil?: true |
#gender ⇒ Symbol, ...
The gender of the individual.
47 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 47 optional :gender, enum: -> { FinchAPI::Sandbox::IndividualUpdateParams::Gender }, nil?: true |
#last_name ⇒ String?
The legal last name of the individual.
53 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 53 optional :last_name, String, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
59 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 59 optional :middle_name, String, nil?: true |
#phone_numbers ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateParams::PhoneNumber, nil>?
64 65 66 67 68 69 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 64 optional :phone_numbers, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::IndividualUpdateParams::PhoneNumber, nil?: true] }, nil?: true |
#preferred_name ⇒ String?
The preferred name of the individual.
75 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 75 optional :preferred_name, String, nil?: true |
#residence ⇒ FinchAPI::Models::Location?
80 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 80 optional :residence, -> { FinchAPI::Location }, nil?: true |
#ssn ⇒ String?
Social Security Number of the individual. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body. [Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).
89 |
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 89 optional :ssn, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/individual_update_params.rb', line 143
|