Class: FinchAPI::Models::Sandbox::IndividualUpdateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/finch-api/models/sandbox/individual_update_response.rb

Defined Under Namespace

Modules: Ethnicity, Gender Classes: Email, PhoneNumber

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, dob: nil, emails: nil, encrypted_ssn: nil, ethnicity: nil, first_name: nil, gender: nil, last_name: nil, middle_name: nil, phone_numbers: nil, preferred_name: nil, residence: nil, ssn: nil) ⇒ IndividualUpdateResponse

Returns a new instance of IndividualUpdateResponse.

Parameters:



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 15

def initialize(
  id: nil,
  dob: nil,
  emails: nil,
  encrypted_ssn: nil,
  ethnicity: nil,
  first_name: nil,
  gender: nil,
  last_name: nil,
  middle_name: nil,
  phone_numbers: nil,
  preferred_name: nil,
  residence: nil,
  ssn: nil,
  **
)
  super
end

Instance Attribute Details

#dobString?

Returns:

  • (String, nil)


20
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 20

optional :dob, String, nil?: true

#emailsArray<FinchAPI::Models::Sandbox::IndividualUpdateResponse::Email>?



25
26
27
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 25

optional :emails,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateResponse::Email] },
nil?: true

#encrypted_ssnString?

Social Security Number of the individual in encrypted format. This field is

only available with the `ssn` scope enabled and the
`options: { include: ['ssn'] }` param set in the body.

Returns:

  • (String, nil)


35
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 35

optional :encrypted_ssn, String, nil?: true

#ethnicitySymbol, ...

The EEOC-defined ethnicity of the individual.



41
42
43
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 41

optional :ethnicity,
enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateResponse::Ethnicity },
nil?: true

#first_nameString?

The legal first name of the individual.

Returns:

  • (String, nil)


49
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 49

optional :first_name, String, nil?: true

#genderSymbol, ...

The gender of the individual.



55
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 55

optional :gender, enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateResponse::Gender }, nil?: true

#idString?

A stable Finch ‘id` (UUID v4) for an individual in the company.

Returns:

  • (String, nil)


11
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 11

optional :id, String

#last_nameString?

The legal last name of the individual.

Returns:

  • (String, nil)


61
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 61

optional :last_name, String, nil?: true

#middle_nameString?

The legal middle name of the individual.

Returns:

  • (String, nil)


67
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 67

optional :middle_name, String, nil?: true

#phone_numbersArray<FinchAPI::Models::Sandbox::IndividualUpdateResponse::PhoneNumber, nil>?



72
73
74
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 72

optional :phone_numbers,
-> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateResponse::PhoneNumber, nil?: true] },
nil?: true

#preferred_nameString?

The preferred name of the individual.

Returns:

  • (String, nil)


80
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 80

optional :preferred_name, String, nil?: true

#residenceFinchAPI::Models::Location?

Returns:



85
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 85

optional :residence, -> { FinchAPI::Models::Location }, nil?: true

#ssnString?

Social Security Number of the individual. This field is only available with the

`ssn` scope enabled and the `options: { include: ['ssn'] }` param set in the
body.
[Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).

Returns:

  • (String, nil)


94
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 94

optional :ssn, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


2
# File 'lib/finch-api/models/sandbox/individual_update_response.rb', line 2

def self.values; end