Class: FinchAPI::Models::Sandbox::IndividualUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::IndividualUpdateResponse
- Defined in:
- lib/finch_api/models/sandbox/individual_update_response.rb
Overview
Defined Under Namespace
Modules: Ethnicity, Gender Classes: Email, PhoneNumber
Instance Attribute Summary collapse
- #dob ⇒ String?
- #emails ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateResponse::Email>?
-
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format.
-
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
-
#first_name ⇒ String?
The legal first name of the individual.
-
#gender ⇒ Symbol, ...
The gender of the individual.
-
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
-
#last_name ⇒ String?
The legal last name of the individual.
-
#middle_name ⇒ String?
The legal middle name of the individual.
- #phone_numbers ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateResponse::PhoneNumber, nil>?
-
#preferred_name ⇒ String?
The preferred name of the individual.
- #residence ⇒ FinchAPI::Models::Location?
-
#ssn ⇒ String?
Social Security Number of the individual.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#dob ⇒ String?
17 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 17 optional :dob, String, nil?: true |
#emails ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateResponse::Email>?
22 23 24 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 22 optional :emails, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateResponse::Email] }, nil?: true |
#encrypted_ssn ⇒ String?
Social Security Number of the individual in encrypted format. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body.
32 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 32 optional :encrypted_ssn, String, nil?: true |
#ethnicity ⇒ Symbol, ...
The EEOC-defined ethnicity of the individual.
38 39 40 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 38 optional :ethnicity, enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateResponse::Ethnicity }, nil?: true |
#first_name ⇒ String?
The legal first name of the individual.
46 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 46 optional :first_name, String, nil?: true |
#gender ⇒ Symbol, ...
The gender of the individual.
52 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 52 optional :gender, enum: -> { FinchAPI::Models::Sandbox::IndividualUpdateResponse::Gender }, nil?: true |
#id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
12 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 12 optional :id, String |
#last_name ⇒ String?
The legal last name of the individual.
58 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 58 optional :last_name, String, nil?: true |
#middle_name ⇒ String?
The legal middle name of the individual.
64 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 64 optional :middle_name, String, nil?: true |
#phone_numbers ⇒ Array<FinchAPI::Models::Sandbox::IndividualUpdateResponse::PhoneNumber, nil>?
69 70 71 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 69 optional :phone_numbers, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Models::Sandbox::IndividualUpdateResponse::PhoneNumber, nil?: true] }, nil?: true |
#preferred_name ⇒ String?
The preferred name of the individual.
77 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 77 optional :preferred_name, String, nil?: true |
#residence ⇒ FinchAPI::Models::Location?
82 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 82 optional :residence, -> { FinchAPI::Location }, nil?: true |
#ssn ⇒ String?
Social Security Number of the individual. This field is only available with the ‘ssn` scope enabled and the `options: { include: [’ssn’] }‘ param set in the body. [Click here to learn more about enabling the SSN field](/developer-resources/Enable-SSN-Field).
91 |
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 91 optional :ssn, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/individual_update_response.rb', line 145
|