Class: FinchAPI::Models::Sandbox::JobCreateResponse
- Defined in:
- lib/finch-api/models/sandbox/job_create_response.rb
Instance Attribute Summary collapse
-
#allowed_refreshes ⇒ Integer
The number of allowed refreshes per hour (per hour, fixed window).
-
#job_id ⇒ String
The id of the job that has been created.
-
#job_url ⇒ String
The url that can be used to retrieve the job status.
-
#remaining_refreshes ⇒ Integer
The number of remaining refreshes available (per hour, fixed window).
Instance Method Summary collapse
-
#initialize(allowed_refreshes:, job_id:, job_url:, remaining_refreshes:) ⇒ JobCreateResponse
constructor
A new instance of JobCreateResponse.
Constructor Details
#initialize(allowed_refreshes:, job_id:, job_url:, remaining_refreshes:) ⇒ JobCreateResponse
Returns a new instance of JobCreateResponse.
6 |
# File 'lib/finch-api/models/sandbox/job_create_response.rb', line 6 def initialize(allowed_refreshes:, job_id:, job_url:, remaining_refreshes:, **) = super |
Instance Attribute Details
#allowed_refreshes ⇒ Integer
The number of allowed refreshes per hour (per hour, fixed window)
11 |
# File 'lib/finch-api/models/sandbox/job_create_response.rb', line 11 required :allowed_refreshes, Integer |
#job_id ⇒ String
The id of the job that has been created.
17 |
# File 'lib/finch-api/models/sandbox/job_create_response.rb', line 17 required :job_id, String |
#job_url ⇒ String
The url that can be used to retrieve the job status
23 |
# File 'lib/finch-api/models/sandbox/job_create_response.rb', line 23 required :job_url, String |
#remaining_refreshes ⇒ Integer
The number of remaining refreshes available (per hour, fixed window)
29 |
# File 'lib/finch-api/models/sandbox/job_create_response.rb', line 29 required :remaining_refreshes, Integer |