Class: FinchAPI::Models::Sandbox::PaymentCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::PaymentCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/finch_api/models/sandbox/payment_create_params.rb
Overview
Defined Under Namespace
Classes: PayStatement
Instance Attribute Summary collapse
- #end_date ⇒ Date?
-
#pay_statements ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement>?
Array of pay statements to include in the payment.
- #start_date ⇒ Date?
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from FinchAPI::Internal::Type::BaseModel
Instance Attribute Details
#end_date ⇒ Date?
14 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 14 optional :end_date, Date |
#pay_statements ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement>?
Array of pay statements to include in the payment.
20 21 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 20 optional :pay_statements, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement] } |
#start_date ⇒ Date?
26 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 26 optional :start_date, Date |