Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement
- Defined in:
- lib/finch-api/models/sandbox/payment_create_params.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Defined Under Namespace
Modules: PaymentMethod, Type Classes: Earning, EmployeeDeduction, EmployerContribution, Tax
Instance Attribute Summary collapse
-
#earnings ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning, nil>?
The array of earnings objects associated with this pay statement.
-
#employee_deductions ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil>?
The array of deductions objects associated with this pay statement.
- #employer_contributions ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil>?
- #gross_pay ⇒ FinchAPI::Models::Money?
-
#individual_id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
- #metadata ⇒ Hash{Symbol=>Object} writeonly
- #net_pay ⇒ FinchAPI::Models::Money?
-
#payment_method ⇒ Symbol, ...
The payment method.
-
#taxes ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax, nil>?
The array of taxes objects associated with this pay statement.
-
#total_hours ⇒ Float?
The number of hours worked for this pay period.
-
#type ⇒ Symbol, ...
The type of the payment associated with the pay statement.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ PayStatement
constructor
A new instance of PayStatement.
Constructor Details
#initialize(metadata: nil) ⇒ PayStatement
Returns a new instance of PayStatement.
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 12 def initialize( earnings: nil, employee_deductions: nil, employer_contributions: nil, gross_pay: nil, individual_id: nil, net_pay: nil, payment_method: nil, taxes: nil, total_hours: nil, type: nil, ** ) super end |
Instance Attribute Details
#earnings ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning, nil>?
The array of earnings objects associated with this pay statement
54 55 56 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 54 optional :earnings, -> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning, nil?: true] }, nil?: true |
#employee_deductions ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil>?
The array of deductions objects associated with this pay statement.
62 63 64 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 62 optional :employee_deductions, -> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil?: true] }, nil?: true |
#employer_contributions ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil>?
69 70 71 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 69 optional :employer_contributions, -> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil?: true] }, nil?: true |
#gross_pay ⇒ FinchAPI::Models::Money?
76 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 76 optional :gross_pay, -> { FinchAPI::Models::Money }, nil?: true |
#individual_id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company
82 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 82 optional :individual_id, String |
#metadata=(value) ⇒ Hash{Symbol=>Object} (writeonly)
2 3 4 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 2 def (value) @metadata = value end |
#net_pay ⇒ FinchAPI::Models::Money?
91 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 91 optional :net_pay, -> { FinchAPI::Models::Money }, nil?: true |
#payment_method ⇒ Symbol, ...
The payment method.
97 98 99 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 97 optional :payment_method, enum: -> { FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::PaymentMethod }, nil?: true |
#taxes ⇒ Array<FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax, nil>?
The array of taxes objects associated with this pay statement.
105 106 107 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 105 optional :taxes, -> { FinchAPI::ArrayOf[FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax, nil?: true] }, nil?: true |
#total_hours ⇒ Float?
The number of hours worked for this pay period
113 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 113 optional :total_hours, Float, nil?: true |
#type ⇒ Symbol, ...
The type of the payment associated with the pay statement.
119 120 121 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 119 optional :type, enum: -> { FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Type }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
2 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 2 def self.values; end |