Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement
- Defined in:
- lib/finch_api/models/sandbox/payment_create_params.rb
Defined Under Namespace
Modules: PaymentMethod, Type Classes: Earning, EmployeeDeduction, EmployerContribution, Tax
Instance Attribute Summary collapse
-
#earnings ⇒ Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning, nil>?
The array of earnings objects associated with this pay statement.
-
#employee_deductions ⇒ Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil>?
The array of deductions objects associated with this pay statement.
- #employer_contributions ⇒ Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil>?
- #gross_pay ⇒ FinchAPI::Money?
-
#individual_id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company.
- #net_pay ⇒ FinchAPI::Money?
-
#payment_method ⇒ Symbol, ...
The payment method.
-
#taxes ⇒ Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax, nil>?
The array of taxes objects associated with this pay statement.
-
#total_hours ⇒ Float?
The number of hours worked for this pay period.
-
#type ⇒ Symbol, ...
The type of the payment associated with the pay statement.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes::Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes::Metadata for more details.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 35 class PayStatement < FinchAPI::Internal::Type::BaseModel # @!attribute earnings # The array of earnings objects associated with this pay statement # # @return [Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning, nil>, nil] optional :earnings, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning, nil?: true] }, nil?: true # @!attribute employee_deductions # The array of deductions objects associated with this pay statement. # # @return [Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil>, nil] optional :employee_deductions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil?: true] }, nil?: true # @!attribute employer_contributions # # @return [Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil>, nil] optional :employer_contributions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil?: true] }, nil?: true # @!attribute gross_pay # # @return [FinchAPI::Money, nil] optional :gross_pay, -> { FinchAPI::Money }, nil?: true # @!attribute individual_id # A stable Finch `id` (UUID v4) for an individual in the company # # @return [String, nil] optional :individual_id, String # @!attribute net_pay # # @return [FinchAPI::Money, nil] optional :net_pay, -> { FinchAPI::Money }, nil?: true # @!attribute payment_method # The payment method. # # @return [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::PaymentMethod, nil] optional :payment_method, enum: -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::PaymentMethod }, nil?: true # @!attribute taxes # The array of taxes objects associated with this pay statement. # # @return [Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax, nil>, nil] optional :taxes, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax, nil?: true] }, nil?: true # @!attribute total_hours # The number of hours worked for this pay period # # @return [Float, nil] optional :total_hours, Float, nil?: true # @!attribute type # The type of the payment associated with the pay statement. # # @return [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Type, nil] optional :type, enum: -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Type }, nil?: true # @!method initialize(earnings: nil, employee_deductions: nil, employer_contributions: nil, gross_pay: nil, individual_id: nil, net_pay: nil, payment_method: nil, taxes: nil, total_hours: nil, type: nil) # @param earnings [Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning, nil>, nil] The array of earnings objects associated with this pay statement # # @param employee_deductions [Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil>, nil] The array of deductions objects associated with this pay statement. # # @param employer_contributions [Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil>, nil] # # @param gross_pay [FinchAPI::Money, nil] # # @param individual_id [String] A stable Finch `id` (UUID v4) for an individual in the company # # @param net_pay [FinchAPI::Money, nil] # # @param payment_method [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::PaymentMethod, nil] The payment method. # # @param taxes [Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax, nil>, nil] The array of taxes objects associated with this pay statement. # # @param total_hours [Float, nil] The number of hours worked for this pay period # # @param type [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Type, nil] The type of the payment associated with the pay statement. class Earning < FinchAPI::Internal::Type::BaseModel # @!attribute amount # The earnings amount in cents. # # @return [Integer, nil] optional :amount, Integer, nil?: true # @!attribute attributes # # @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes, nil] optional :attributes, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes }, nil?: true # @!attribute currency # The earnings currency code. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute hours # The number of hours associated with this earning. (For salaried employees, this # could be hours per pay period, `0` or `null`, depending on the provider). # # @return [Float, nil] optional :hours, Float, nil?: true # @!attribute name # The exact name of the deduction from the pay statement. # # @return [String, nil] optional :name, String, nil?: true # @!attribute type # The type of earning. # # @return [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Type, nil] optional :type, enum: -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Type }, nil?: true # @!method initialize(amount: nil, attributes: nil, currency: nil, hours: nil, name: nil, type: nil) # Some parameter documentations has been truncated, see # {FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning} for more # details. # # @param amount [Integer, nil] The earnings amount in cents. # # @param attributes [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes, nil] # # @param currency [String, nil] The earnings currency code. # # @param hours [Float, nil] The number of hours associated with this earning. (For salaried employees, this # # @param name [String, nil] The exact name of the deduction from the pay statement. # # @param type [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Type, nil] The type of earning. # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning#attributes class Attributes < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # # @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata, nil] optional :metadata, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata } # @!method initialize(metadata: nil) # @param metadata [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata] # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes#metadata class Metadata < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # The metadata to be attached to the entity by existing rules. It is a key-value # pairs where the values can be of any type (string, number, boolean, object, # array, etc.). # # @return [Hash{Symbol=>Object, nil}, nil] optional :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true] # @!method initialize(metadata: nil) # Some parameter documentations has been truncated, see # {FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes::Metadata} # for more details. # # @param metadata [Hash{Symbol=>Object, nil}] The metadata to be attached to the entity by existing rules. It is a key-value p end end # The type of earning. # # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning#type module Type extend FinchAPI::Internal::Type::Enum SALARY = :salary WAGE = :wage REIMBURSEMENT = :reimbursement OVERTIME = :overtime SEVERANCE = :severance DOUBLE_OVERTIME = :double_overtime PTO = :pto SICK = :sick BONUS = :bonus COMMISSION = :commission TIPS = :tips TYPE_1099 = :"1099" OTHER = :other # @!method self.values # @return [Array<Symbol>] end end class EmployeeDeduction < FinchAPI::Internal::Type::BaseModel # @!attribute amount # The deduction amount in cents. # # @return [Integer, nil] optional :amount, Integer, nil?: true # @!attribute attributes # # @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction::Attributes, nil] optional :attributes, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction::Attributes }, nil?: true # @!attribute currency # The deduction currency. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute name # The deduction name from the pay statement. # # @return [String, nil] optional :name, String, nil?: true # @!attribute pre_tax # Boolean indicating if the deduction is pre-tax. # # @return [Boolean, nil] optional :pre_tax, FinchAPI::Internal::Type::Boolean, nil?: true # @!attribute type # Type of benefit. # # @return [Symbol, FinchAPI::HRIS::BenefitType, nil] optional :type, enum: -> { FinchAPI::HRIS::BenefitType }, nil?: true # @!method initialize(amount: nil, attributes: nil, currency: nil, name: nil, pre_tax: nil, type: nil) # @param amount [Integer, nil] The deduction amount in cents. # # @param attributes [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction::Attributes, nil] # # @param currency [String, nil] The deduction currency. # # @param name [String, nil] The deduction name from the pay statement. # # @param pre_tax [Boolean, nil] Boolean indicating if the deduction is pre-tax. # # @param type [Symbol, FinchAPI::HRIS::BenefitType, nil] Type of benefit. # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction#attributes class Attributes < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # # @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction::Attributes::Metadata, nil] optional :metadata, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction::Attributes::Metadata } # @!method initialize(metadata: nil) # @param metadata [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction::Attributes::Metadata] # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction::Attributes#metadata class Metadata < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # The metadata to be attached to the entity by existing rules. It is a key-value # pairs where the values can be of any type (string, number, boolean, object, # array, etc.). # # @return [Hash{Symbol=>Object, nil}, nil] optional :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true] # @!method initialize(metadata: nil) # Some parameter documentations has been truncated, see # {FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction::Attributes::Metadata} # for more details. # # @param metadata [Hash{Symbol=>Object, nil}] The metadata to be attached to the entity by existing rules. It is a key-value p end end end class EmployerContribution < FinchAPI::Internal::Type::BaseModel # @!attribute amount # The contribution amount in cents. # # @return [Integer, nil] optional :amount, Integer, nil?: true # @!attribute attributes # # @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes, nil] optional :attributes, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes }, nil?: true # @!attribute currency # The contribution currency. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute name # The contribution name from the pay statement. # # @return [String, nil] optional :name, String, nil?: true # @!attribute type # Type of benefit. # # @return [Symbol, FinchAPI::HRIS::BenefitType, nil] optional :type, enum: -> { FinchAPI::HRIS::BenefitType }, nil?: true # @!method initialize(amount: nil, attributes: nil, currency: nil, name: nil, type: nil) # @param amount [Integer, nil] The contribution amount in cents. # # @param attributes [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes, nil] # # @param currency [String, nil] The contribution currency. # # @param name [String, nil] The contribution name from the pay statement. # # @param type [Symbol, FinchAPI::HRIS::BenefitType, nil] Type of benefit. # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution#attributes class Attributes < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # # @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes::Metadata, nil] optional :metadata, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes::Metadata } # @!method initialize(metadata: nil) # @param metadata [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes::Metadata] # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes#metadata class Metadata < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # The metadata to be attached to the entity by existing rules. It is a key-value # pairs where the values can be of any type (string, number, boolean, object, # array, etc.). # # @return [Hash{Symbol=>Object, nil}, nil] optional :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true] # @!method initialize(metadata: nil) # Some parameter documentations has been truncated, see # {FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution::Attributes::Metadata} # for more details. # # @param metadata [Hash{Symbol=>Object, nil}] The metadata to be attached to the entity by existing rules. It is a key-value p end end end # The payment method. # # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement#payment_method module PaymentMethod extend FinchAPI::Internal::Type::Enum CHECK = :check DIRECT_DEPOSIT = :direct_deposit OTHER = :other # @!method self.values # @return [Array<Symbol>] end class Tax < FinchAPI::Internal::Type::BaseModel # @!attribute amount # The tax amount in cents. # # @return [Integer, nil] optional :amount, Integer, nil?: true # @!attribute attributes # # @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes, nil] optional :attributes, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes }, nil?: true # @!attribute currency # The currency code. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute employer # `true` if the amount is paid by the employers. # # @return [Boolean, nil] optional :employer, FinchAPI::Internal::Type::Boolean, nil?: true # @!attribute name # The exact name of tax from the pay statement. # # @return [String, nil] optional :name, String, nil?: true # @!attribute type # The type of taxes. # # @return [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Type, nil] optional :type, enum: -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Type }, nil?: true # @!method initialize(amount: nil, attributes: nil, currency: nil, employer: nil, name: nil, type: nil) # @param amount [Integer, nil] The tax amount in cents. # # @param attributes [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes, nil] # # @param currency [String, nil] The currency code. # # @param employer [Boolean, nil] `true` if the amount is paid by the employers. # # @param name [String, nil] The exact name of tax from the pay statement. # # @param type [Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Type, nil] The type of taxes. # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax#attributes class Attributes < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # # @return [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata, nil] optional :metadata, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata } # @!method initialize(metadata: nil) # @param metadata [FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata] # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes#metadata class Metadata < FinchAPI::Internal::Type::BaseModel # @!attribute metadata # The metadata to be attached to the entity by existing rules. It is a key-value # pairs where the values can be of any type (string, number, boolean, object, # array, etc.). # # @return [Hash{Symbol=>Object, nil}, nil] optional :metadata, FinchAPI::Internal::Type::HashOf[FinchAPI::Internal::Type::Unknown, nil?: true] # @!method initialize(metadata: nil) # Some parameter documentations has been truncated, see # {FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata} # for more details. # # @param metadata [Hash{Symbol=>Object, nil}] The metadata to be attached to the entity by existing rules. It is a key-value p end end # The type of taxes. # # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax#type module Type extend FinchAPI::Internal::Type::Enum STATE = :state FEDERAL = :federal LOCAL = :local FICA = :fica # @!method self.values # @return [Array<Symbol>] end end # The type of the payment associated with the pay statement. # # @see FinchAPI::Sandbox::PaymentCreateParams::PayStatement#type module Type extend FinchAPI::Internal::Type::Enum REGULAR_PAYROLL = :regular_payroll OFF_CYCLE_PAYROLL = :off_cycle_payroll ONE_TIME_PAYMENT = :one_time_payment # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#earnings ⇒ Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning, nil>?
The array of earnings objects associated with this pay statement
40 41 42 43 44 45 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 40 optional :earnings, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Earning, nil?: true] }, nil?: true |
#employee_deductions ⇒ Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil>?
The array of deductions objects associated with this pay statement.
51 52 53 54 55 56 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 51 optional :employee_deductions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployeeDeduction, nil?: true] }, nil?: true |
#employer_contributions ⇒ Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil>?
61 62 63 64 65 66 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 61 optional :employer_contributions, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement::EmployerContribution, nil?: true] }, nil?: true |
#gross_pay ⇒ FinchAPI::Money?
71 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 71 optional :gross_pay, -> { FinchAPI::Money }, nil?: true |
#individual_id ⇒ String?
A stable Finch ‘id` (UUID v4) for an individual in the company
77 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 77 optional :individual_id, String |
#net_pay ⇒ FinchAPI::Money?
82 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 82 optional :net_pay, -> { FinchAPI::Money }, nil?: true |
#payment_method ⇒ Symbol, ...
The payment method.
88 89 90 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 88 optional :payment_method, enum: -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::PaymentMethod }, nil?: true |
#taxes ⇒ Array<FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax, nil>?
The array of taxes objects associated with this pay statement.
96 97 98 99 100 101 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 96 optional :taxes, -> { FinchAPI::Internal::Type::ArrayOf[FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax, nil?: true] }, nil?: true |
#total_hours ⇒ Float?
The number of hours worked for this pay period
107 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 107 optional :total_hours, Float, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 247
|