Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning
- Inherits:
-
BaseModel
- Object
- FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning
- Defined in:
- lib/finch-api/models/sandbox/payment_create_params.rb
Overview
def initialize: (Hash | FinchAPI::BaseModel) -> void
Defined Under Namespace
Modules: Type Classes: Attributes
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The earnings amount in cents.
- #attributes ⇒ FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes?
-
#currency ⇒ String?
The earnings currency code.
-
#hours ⇒ Float?
The number of hours associated with this earning.
- #metadata ⇒ Hash{Symbol=>Object} writeonly
-
#name ⇒ String?
The exact name of the deduction from the pay statement.
-
#type ⇒ Symbol, ...
The type of earning.
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Earning
constructor
A new instance of Earning.
Constructor Details
#initialize(metadata: nil) ⇒ Earning
Returns a new instance of Earning.
8 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 8 def initialize(amount: nil, attributes: nil, currency: nil, hours: nil, name: nil, type: nil, **) = super |
Instance Attribute Details
#amount ⇒ Integer?
The earnings amount in cents.
158 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 158 optional :amount, Integer, nil?: true |
#attributes ⇒ FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes?
163 164 165 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 163 optional :attributes, -> { FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning::Attributes }, nil?: true |
#currency ⇒ String?
The earnings currency code.
171 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 171 optional :currency, String, nil?: true |
#hours ⇒ Float?
The number of hours associated with this earning. (For salaried employees, this
could be hours per pay period, `0` or `null`, depending on the provider).
178 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 178 optional :hours, Float, nil?: true |
#metadata=(value) ⇒ Hash{Symbol=>Object} (writeonly)
2 3 4 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 2 def (value) @metadata = value end |
#name ⇒ String?
The exact name of the deduction from the pay statement.
184 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 184 optional :name, String, nil?: true |
#type ⇒ Symbol, ...
The type of earning.
190 191 192 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 190 optional :type, enum: -> { FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Earning::Type }, nil?: true |