Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax
- Defined in:
- lib/finch_api/models/sandbox/payment_create_params.rb
Defined Under Namespace
Modules: Type Classes: Attributes
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The tax amount in cents.
- #attributes ⇒ FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes?
-
#currency ⇒ String?
The currency code.
-
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
-
#name ⇒ String?
The exact name of tax from the pay statement.
-
#type ⇒ Symbol, ...
The type of taxes.
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, dump, fields, hash, #hash, inspect, #inspect, known_fields, optional, required, #to_h, #to_json, #to_s, #to_yaml, walk
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Constructor Details
#initialize(metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata for more details.
|
|
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 473
|
Instance Attribute Details
#amount ⇒ Integer?
The tax amount in cents.
436 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 436 optional :amount, Integer, nil?: true |
#attributes ⇒ FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes?
441 442 443 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 441 optional :attributes, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes }, nil?: true |
#currency ⇒ String?
The currency code.
449 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 449 optional :currency, String, nil?: true |
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
455 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 455 optional :employer, FinchAPI::Internal::Type::Boolean, nil?: true |
#name ⇒ String?
The exact name of tax from the pay statement.
461 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 461 optional :name, String, nil?: true |