Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/finch_api/models/sandbox/payment_create_params.rb

Defined Under Namespace

Modules: Type Classes: Attributes

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!

Constructor Details

#initialize(metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata for more details.

Parameters:

  • metadata (Hash{Symbol=>Object, nil}) (defaults to: nil)

    The metadata to be attached to the entity by existing rules. It is a key-value p



# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 474

Instance Attribute Details

#amountInteger?

The tax amount in cents.

Returns:

  • (Integer, nil)


437
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 437

optional :amount, Integer, nil?: true

#attributesFinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes?

Returns:

  • (FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes, nil)


442
443
444
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 442

optional :attributes,
-> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes },
nil?: true

#currencyString?

The currency code.

Returns:

  • (String, nil)


450
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 450

optional :currency, String, nil?: true

#employerBoolean?

‘true` if the amount is paid by the employers.

Returns:

  • (Boolean, nil)


456
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 456

optional :employer, FinchAPI::Internal::Type::Boolean, nil?: true

#nameString?

The exact name of tax from the pay statement.

Returns:

  • (String, nil)


462
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 462

optional :name, String, nil?: true

#typeSymbol, ...

The type of taxes.

Returns:

  • (Symbol, FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Type, nil)


468
469
470
471
472
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 468

optional :type,
enum: -> {
  FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Type
},
nil?: true