Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax
- Defined in:
- lib/finch_api/models/sandbox/payment_create_params.rb
Defined Under Namespace
Modules: Type Classes: Attributes
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The tax amount in cents.
- #attributes ⇒ FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes?
-
#currency ⇒ String?
The currency code.
-
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
-
#name ⇒ String?
The exact name of tax from the pay statement.
-
#type ⇒ Symbol, ...
The type of taxes.
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!
Constructor Details
#initialize(metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes::Metadata for more details.
|
|
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 474
|
Instance Attribute Details
#amount ⇒ Integer?
The tax amount in cents.
437 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 437 optional :amount, Integer, nil?: true |
#attributes ⇒ FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes?
442 443 444 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 442 optional :attributes, -> { FinchAPI::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes }, nil?: true |
#currency ⇒ String?
The currency code.
450 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 450 optional :currency, String, nil?: true |
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
456 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 456 optional :employer, FinchAPI::Internal::Type::Boolean, nil?: true |
#name ⇒ String?
The exact name of tax from the pay statement.
462 |
# File 'lib/finch_api/models/sandbox/payment_create_params.rb', line 462 optional :name, String, nil?: true |