Class: FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax
- Inherits:
-
BaseModel
- Object
- FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax
- Defined in:
- lib/finch-api/models/sandbox/payment_create_params.rb
Defined Under Namespace
Modules: Type Classes: Attributes
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The tax amount in cents.
- #attributes ⇒ FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes?
-
#currency ⇒ String?
The currency code.
-
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
- #metadata ⇒ Hash{Symbol=>Object} writeonly
-
#name ⇒ String?
The exact name of tax from the pay statement.
-
#type ⇒ Symbol, ...
The type of taxes.
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Tax
constructor
A new instance of Tax.
Constructor Details
#initialize(metadata: nil) ⇒ Tax
Returns a new instance of Tax.
8 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 8 def initialize(amount: nil, attributes: nil, currency: nil, employer: nil, name: nil, type: nil, **) = super |
Instance Attribute Details
#amount ⇒ Integer?
The tax amount in cents.
466 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 466 optional :amount, Integer, nil?: true |
#attributes ⇒ FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes?
471 472 473 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 471 optional :attributes, -> { FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax::Attributes }, nil?: true |
#currency ⇒ String?
The currency code.
479 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 479 optional :currency, String, nil?: true |
#employer ⇒ Boolean?
‘true` if the amount is paid by the employers.
485 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 485 optional :employer, FinchAPI::BooleanModel, nil?: true |
#metadata=(value) ⇒ Hash{Symbol=>Object} (writeonly)
2 3 4 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 2 def (value) @metadata = value end |
#name ⇒ String?
The exact name of tax from the pay statement.
491 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 491 optional :name, String, nil?: true |
#type ⇒ Symbol, ...
The type of taxes.
497 498 499 |
# File 'lib/finch-api/models/sandbox/payment_create_params.rb', line 497 optional :type, enum: -> { FinchAPI::Models::Sandbox::PaymentCreateParams::PayStatement::Tax::Type }, nil?: true |