Class: FinchAPI::Resources::HRIS::Company::PayStatementItem
- Inherits:
-
Object
- Object
- FinchAPI::Resources::HRIS::Company::PayStatementItem
- Defined in:
- lib/finch_api/resources/hris/company/pay_statement_item.rb,
lib/finch_api/resources/hris/company/pay_statement_item/rules.rb
Defined Under Namespace
Classes: Rules
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(client:) ⇒ PayStatementItem
constructor
private
A new instance of PayStatementItem.
-
#list(categories: nil, end_date: nil, entity_ids: nil, name: nil, start_date: nil, type: nil, request_options: {}) ⇒ FinchAPI::Internal::ResponsesPage<FinchAPI::Models::HRIS::Company::PayStatementItemListResponse>
Some parameter documentations has been truncated, see Models::HRIS::Company::PayStatementItemListParams for more details.
Constructor Details
#initialize(client:) ⇒ PayStatementItem
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of PayStatementItem.
52 53 54 55 |
# File 'lib/finch_api/resources/hris/company/pay_statement_item.rb', line 52 def initialize(client:) @client = client @rules = FinchAPI::Resources::HRIS::Company::PayStatementItem::Rules.new(client: client) end |
Instance Attribute Details
#rules ⇒ FinchAPI::Resources::HRIS::Company::PayStatementItem::Rules (readonly)
9 10 11 |
# File 'lib/finch_api/resources/hris/company/pay_statement_item.rb', line 9 def rules @rules end |
Instance Method Details
#list(categories: nil, end_date: nil, entity_ids: nil, name: nil, start_date: nil, type: nil, request_options: {}) ⇒ FinchAPI::Internal::ResponsesPage<FinchAPI::Models::HRIS::Company::PayStatementItemListResponse>
Some parameter documentations has been truncated, see Models::HRIS::Company::PayStatementItemListParams for more details.
Beta: this endpoint currently serves employers onboarded after March 4th and historical support will be added soon Retrieve a list of detailed pay statement items for the access token’s connection account.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/finch_api/resources/hris/company/pay_statement_item.rb', line 37 def list(params = {}) parsed, = FinchAPI::HRIS::Company::PayStatementItemListParams.dump_request(params) @client.request( method: :get, path: "employer/pay-statement-item", query: parsed, page: FinchAPI::Internal::ResponsesPage, model: FinchAPI::Models::HRIS::Company::PayStatementItemListResponse, options: ) end |