Class: FinchAPI::Resources::HRIS::Payments
- Inherits:
-
Object
- Object
- FinchAPI::Resources::HRIS::Payments
- Defined in:
- lib/finch-api/resources/hris/payments.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ Payments
constructor
A new instance of Payments.
-
#list(params) ⇒ FinchAPI::SinglePage<FinchAPI::Models::HRIS::Payment>
Read payroll and contractor related payments by the company.
Constructor Details
#initialize(client:) ⇒ Payments
Returns a new instance of Payments.
33 34 35 |
# File 'lib/finch-api/resources/hris/payments.rb', line 33 def initialize(client:) @client = client end |
Instance Method Details
#list(params) ⇒ FinchAPI::SinglePage<FinchAPI::Models::HRIS::Payment>
Read payroll and contractor related payments by the company.
20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/finch-api/resources/hris/payments.rb', line 20 def list(params) parsed, = FinchAPI::Models::HRIS::PaymentListParams.dump_request(params) @client.request( method: :get, path: "employer/payment", query: parsed, page: FinchAPI::SinglePage, model: FinchAPI::Models::HRIS::Payment, options: ) end |