Class: FinchAPI::Resources::Jobs::Manual
- Inherits:
-
Object
- Object
- FinchAPI::Resources::Jobs::Manual
- Defined in:
- lib/finch_api/resources/jobs/manual.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ Manual
constructor
private
A new instance of Manual.
-
#retrieve(job_id, request_options: {}) ⇒ FinchAPI::Models::Jobs::ManualAsyncJob
Check the status and outcome of a job by ‘job_id`.
Constructor Details
#initialize(client:) ⇒ Manual
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Manual.
31 32 33 |
# File 'lib/finch_api/resources/jobs/manual.rb', line 31 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(job_id, request_options: {}) ⇒ FinchAPI::Models::Jobs::ManualAsyncJob
Check the status and outcome of a job by ‘job_id`. This includes all deductions jobs including those for both automated and assisted integrations.
18 19 20 21 22 23 24 25 26 |
# File 'lib/finch_api/resources/jobs/manual.rb', line 18 def retrieve(job_id, params = {}) @client.request( method: :get, path: ["jobs/manual/%1$s", job_id], model: FinchAPI::Jobs::ManualAsyncJob, security: {bearer_auth: true}, options: params[:request_options] ) end |