Class: FinchAPI::Resources::RequestForwarding
- Inherits:
-
Object
- Object
- FinchAPI::Resources::RequestForwarding
- Defined in:
- lib/finch-api/resources/request_forwarding.rb
Instance Method Summary collapse
-
#forward(params) ⇒ FinchAPI::Models::RequestForwardingForwardResponse
The Forward API allows you to make direct requests to an employment system.
-
#initialize(client:) ⇒ RequestForwarding
constructor
A new instance of RequestForwarding.
Constructor Details
#initialize(client:) ⇒ RequestForwarding
Returns a new instance of RequestForwarding.
45 46 47 |
# File 'lib/finch-api/resources/request_forwarding.rb', line 45 def initialize(client:) @client = client end |
Instance Method Details
#forward(params) ⇒ FinchAPI::Models::RequestForwardingForwardResponse
The Forward API allows you to make direct requests to an employment system. If
Finch’s unified API doesn’t have a data model that cleanly fits your needs, then
Forward allows you to push or pull data models directly against an integration’s
API.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/finch-api/resources/request_forwarding.rb', line 33 def forward(params) parsed, = FinchAPI::Models::RequestForwardingForwardParams.dump_request(params) @client.request( method: :post, path: "forward", body: parsed, model: FinchAPI::Models::RequestForwardingForwardResponse, options: ) end |